<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(dirname(__FILE__));
$baseDir = dirname($vendorDir);

return array(
    'KubioTheme\\SiteLeadsThemeKit\\Bootstrap' => $baseDir . '/src/Bootstrap.php',
    'KubioTheme\\SiteLeadsThemeKit\\Customizer\\Controls\\SiteLeadsIntegrationButton' => $baseDir . '/src/Customizer/Controls/SiteLeadsIntegrationButton.php',
    'KubioTheme\\SiteLeadsThemeKit\\Customizer\\Sections\\SiteLeadsSection' => $baseDir . '/src/Customizer/Sections/SiteLeadsSection.php',
    'KubioTheme\\SiteLeadsThemeKit\\Flags' => $baseDir . '/src/Flags.php',
    'KubioTheme\\SiteLeadsThemeKit\\Hooks' => $baseDir . '/src/Hooks.php',
    'KubioTheme\\SiteLeadsThemeKit\\Singleton' => $baseDir . '/src/Singleton.php',
    'KubioTheme\\SiteLeadsThemeKit\\SiteLeads' => $baseDir . '/src/SiteLeads.php',
    'KubioTheme\\SiteLeadsThemeKit\\Theme' => $baseDir . '/src/Theme.php',
);
