<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit9e9437d81eba8d924f981eb07060bb7c
{
    public static $prefixLengthsPsr4 = array (
        'K' => 
        array (
            'KubioTheme\\SiteLeadsThemeKit\\' => 29,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'KubioTheme\\SiteLeadsThemeKit\\' => 
        array (
            0 => __DIR__ . '/../..' . '/src',
        ),
    );

    public static $classMap = array (
        'KubioTheme\\SiteLeadsThemeKit\\Bootstrap' => __DIR__ . '/../..' . '/src/Bootstrap.php',
        'KubioTheme\\SiteLeadsThemeKit\\Customizer\\Controls\\SiteLeadsIntegrationButton' => __DIR__ . '/../..' . '/src/Customizer/Controls/SiteLeadsIntegrationButton.php',
        'KubioTheme\\SiteLeadsThemeKit\\Customizer\\Sections\\SiteLeadsSection' => __DIR__ . '/../..' . '/src/Customizer/Sections/SiteLeadsSection.php',
        'KubioTheme\\SiteLeadsThemeKit\\Flags' => __DIR__ . '/../..' . '/src/Flags.php',
        'KubioTheme\\SiteLeadsThemeKit\\Hooks' => __DIR__ . '/../..' . '/src/Hooks.php',
        'KubioTheme\\SiteLeadsThemeKit\\Singleton' => __DIR__ . '/../..' . '/src/Singleton.php',
        'KubioTheme\\SiteLeadsThemeKit\\SiteLeads' => __DIR__ . '/../..' . '/src/SiteLeads.php',
        'KubioTheme\\SiteLeadsThemeKit\\Theme' => __DIR__ . '/../..' . '/src/Theme.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit9e9437d81eba8d924f981eb07060bb7c::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit9e9437d81eba8d924f981eb07060bb7c::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInit9e9437d81eba8d924f981eb07060bb7c::$classMap;

        }, null, ClassLoader::class);
    }
}
