<?php
return array (
  'header' => 
  array (
    'icon_list' => 
    array (
      'selective_selector' => '.kubio-header__k__zY9YjrzJJVK-outer',
      'styleRef' => 'zY9YjrzJJVK',
      'props' => 
      array (
      ),
    ),
    'social_icons' => 
    array (
      'selective_selector' => '.kubio-header__k__8HsNbkMIffG-outer',
      'styleRef' => '8HsNbkMIffG',
      'props' => 
      array (
      ),
    ),
    'logo' => 
    array (
      'selective_selector' => '.kubio-header__k__x8ZMD9qFOX9-container',
      'styleRef' => 'x8ZMD9qFOX9',
      'props' => 
      array (
        'layoutType' => 'image',
      ),
    ),
    'header-menu' => 
    array (
      'selective_selector' => '.kubio-header__k__S2itoG6vEiw-outer',
      'styleRef' => 'S2itoG6vEiw',
      'props' => 
      array (
        'showOffscreenMenuOn' => 'has-offcanvas-tablet',
      ),
    ),
    'navigation' => 
    array (
      'selective_selector' => '.kubio-header__k__cokser9d3k-nav',
      'styleRef' => 'jZZ7ZgkWWk',
      'props' => 
      array (
        'showTopBar' => false,
        'layoutType' => 'logo-spacing-menu',
        'width' => 'boxed',
        'sticky' => false,
        'overlap' => true,
      ),
      'style' => 
      array (
        'descendants' => 
        array (
          'nav' => 
          array (
            'padding' => 
            array (
              'top' => 
              array (
                'value' => 0,
              ),
            ),
            'background' => 
            array (
              'color' => 'transparent',
            ),
          ),
        ),
        'ancestor' => 
        array (
          'sticky' => 
          array (
            'descendants' => 
            array (
              'nav' => 
              array (
                'background' => 
                array (
                  'color' => 'white',
                ),
              ),
            ),
          ),
        ),
      ),
    ),
    'hero' => 
    array (
      'selective_selector' => '.kubio-header__k__KFTMhA6WOVh-outer',
      'styleRef' => 'KFTMhA6WOVh',
      'props' => 
      array (
        'layoutType' => 'textWithMediaOnRight',
        'heroSection' => 
        array (
          'layout' => 'textWithMediaOnRight',
        ),
      ),
      'hero_column_width' => '50',
      'style' => 
      array (
        'descendants' => 
        array (
          'outer' => 
          array (
            'background' => 
            array (
              'type' => 'image',
              'overlay' => 
              array (
                'enabled' => true,
                'type' => 'color',
                'gradient' => 'linear-gradient(0deg, rgba(161,140,209,0.5) 0%, rgba(251,194,235,0.5) 100% )',
                'shape' => 
                array (
                  'value' => 'none',
                  'isTile' => false,
                ),
                'color' => 
                array (
                  'opacity' => '0.60',
                  'value' => '#11121a',
                ),
              ),
              'image' => 
              array (
                0 => 
                array (
                  'source' => 
                  array (
                    'gradient' => 'linear-gradient(0deg, rgba(161,140,209,1) 0%, rgba(251,194,235,1) 100% )',
                  ),
                  'position' => 
                  array (
                    'x' => 52,
                    'y' => 94,
                  ),
                  'attachment' => 'scroll',
                ),
              ),
              'slideshow' => NULL,
            ),
            'padding' => 
            array (
              'top' => 
              array (
                'value' => 100,
                'unit' => 'px',
              ),
            ),
            'separators' => 
            array (
              'separatorBottom' => 
              array (
              ),
            ),
          ),
        ),
      ),
    ),
  ),
  'footer' => 
  array (
    'footer' => 
    array (
      'selective_selector' => '.kubio-footer__k__vP0mYzy99sE-outer',
      'styleRef' => 'vP0mYzy99sE',
      'props' => 
      array (
        'attrs' => 
        array (
          'name' => 'Footer',
        ),
        'lock' => 
        array (
          'move' => true,
          'remove' => true,
          'edit' => true,
        ),
      ),
      'style' => 
      array (
        'descendants' => 
        array (
          'outer' => 
          array (
            'background' => 
            array (
              'color' => 'rgba(var(--kubio-color-5),1)',
            ),
          ),
        ),
      ),
    ),
  ),
  '404-header' => 
  array (
    'logo' => 
    array (
      'selective_selector' => '.kubio-404-header__k__fOYPUOZaWPL-container',
      'styleRef' => 'fOYPUOZaWPL',
      'props' => 
      array (
        'layoutType' => 'image',
      ),
    ),
    'header-menu' => 
    array (
      'selective_selector' => '.kubio-404-header__k___GipAjLnn8q-outer',
      'styleRef' => '_GipAjLnn8q',
      'props' => 
      array (
        'showOffscreenMenuOn' => 'has-offcanvas-tablet',
      ),
    ),
    'navigation' => 
    array (
      'selective_selector' => '.kubio-404-header__k__UyupMWtVE9-nav',
      'styleRef' => '6mt_9f_jXJ',
      'props' => 
      array (
        'showTopBar' => false,
        'layoutType' => 'logo-spacing-menu',
        'width' => 'boxed',
        'sticky' => false,
        'overlap' => true,
      ),
      'style' => 
      array (
        'descendants' => 
        array (
          'nav' => 
          array (
            'padding' => 
            array (
              'top' => 
              array (
                'value' => 0,
              ),
            ),
            'background' => 
            array (
              'color' => 'transparent',
            ),
          ),
        ),
        'ancestor' => 
        array (
          'sticky' => 
          array (
            'descendants' => 
            array (
              'nav' => 
              array (
                'background' => 
                array (
                  'color' => 'white',
                ),
              ),
            ),
          ),
        ),
      ),
    ),
    'hero' => 
    array (
      'selective_selector' => '.kubio-404-header__k__KFTMhA6WOVh-outer',
      'styleRef' => 'KFTMhA6WOVh',
      'props' => 
      array (
        'layoutType' => 'textWithMediaOnRight',
        'heroSection' => 
        array (
          'layout' => 'textWithMediaOnRight',
        ),
      ),
      'hero_column_width' => '50',
      'style' => 
      array (
        'descendants' => 
        array (
          'outer' => 
          array (
            'background' => 
            array (
              'type' => 'image',
              'overlay' => 
              array (
                'enabled' => true,
                'type' => 'color',
                'gradient' => 'linear-gradient(0deg, rgba(161,140,209,0.5) 0%, rgba(251,194,235,0.5) 100% )',
                'shape' => 
                array (
                  'value' => 'none',
                  'isTile' => false,
                ),
                'color' => 
                array (
                  'opacity' => 0.6,
                  'value' => 'rgb(0,0,0)',
                ),
              ),
              'image' => 
              array (
                0 => 
                array (
                  'source' => 
                  array (
                    'gradient' => 'linear-gradient(0deg, rgba(161,140,209,1) 0%, rgba(251,194,235,1) 100% )',
                  ),
                  'position' => 
                  array (
                    'x' => 50,
                    'y' => 50,
                  ),
                  'attachment' => 'scroll',
                ),
              ),
              'slideshow' => 
              array (
                'duration' => 
                array (
                  'value' => 1500,
                ),
                'speed' => 
                array (
                  'value' => 500,
                ),
              ),
            ),
            'padding' => 
            array (
              'top' => 
              array (
                'unit' => 'px',
                'value' => 150,
              ),
              'bottom' => 
              array (
                'value' => 150,
                'unit' => 'px',
              ),
            ),
            'separators' => 
            array (
              'separatorBottom' => 
              array (
              ),
            ),
          ),
        ),
      ),
    ),
  ),
  'front-header' => 
  array (
    'icon_list' => 
    array (
      'selective_selector' => '.kubio-front-header__k__7yznDknZZGE-outer',
      'styleRef' => '7yznDknZZGE',
      'props' => 
      array (
      ),
    ),
    'social_icons' => 
    array (
      'selective_selector' => '.kubio-front-header__k__wlDkjcCCsVj-outer',
      'styleRef' => 'wlDkjcCCsVj',
      'props' => 
      array (
      ),
    ),
    'logo' => 
    array (
      'selective_selector' => '.kubio-front-header__k__nVjkPY2tu-container',
      'styleRef' => 'nVjkPY2tu',
      'props' => 
      array (
        'layoutType' => 'image',
      ),
    ),
    'header-menu' => 
    array (
      'selective_selector' => '.kubio-front-header__k__c6BbujDIAOY-outer',
      'styleRef' => 'c6BbujDIAOY',
      'props' => 
      array (
        'showOffscreenMenuOn' => 'has-offcanvas-tablet',
      ),
    ),
    'navigation' => 
    array (
      'selective_selector' => '.kubio-front-header__k__xLwdIMLPC_l-nav',
      'styleRef' => 'Gp3qTlxXlu',
      'props' => 
      array (
        'showTopBar' => false,
        'layoutType' => 'logo-spacing-menu',
        'width' => 'boxed',
        'sticky' => false,
        'overlap' => true,
      ),
      'style' => 
      array (
        'descendants' => 
        array (
          'nav' => 
          array (
            'padding' => 
            array (
              'top' => 
              array (
                'value' => 0,
              ),
            ),
            'background' => 
            array (
              'color' => 'transparent',
            ),
          ),
        ),
        'ancestor' => 
        array (
          'sticky' => 
          array (
            'descendants' => 
            array (
              'nav' => 
              array (
                'background' => 
                array (
                  'color' => 'white',
                ),
              ),
            ),
          ),
        ),
      ),
    ),
    'title' => 
    array (
      'selective_selector' => '.kubio-front-header__k__ukjZtaF3MN-text',
      'styleRef' => 'ukjZtaF3MN',
      'props' => 
      array (
      ),
      'style' => 
      array (
        'descendants' => 
        array (
          'text' => 
          array (
            'textAlign' => 'center',
          ),
        ),
      ),
    ),
    'subtitle' => 
    array (
      'selective_selector' => '.kubio-front-header__k__Xia0GT4t_-text',
      'styleRef' => 'Xia0GT4t_',
      'props' => 
      array (
      ),
      'style' => 
      array (
        'descendants' => 
        array (
          'text' => 
          array (
            'textAlign' => 'center',
          ),
        ),
      ),
    ),
    'button-0' => 
    array (
      'selective_selector' => '.kubio-front-header__k__Dud6AOZG0Hc-link',
      'styleRef' => 'Dud6AOZG0Hc',
      'props' => 
      array (
        'link' => 
        array (
          'value' => '#',
          'typeOpenLink' => 'sameWindow',
          'noFollow' => false,
          'lightboxMedia' => '',
        ),
        'preserveSpace' => 
        array (
          'text' => false,
        ),
        'icon' => 
        array (
          'name' => 'font-awesome/arrow-right',
        ),
      ),
    ),
    'button-1' => 
    array (
      'selective_selector' => '.kubio-front-header__k__OcIljpMOK-link',
      'styleRef' => 'OcIljpMOK',
      'props' => 
      array (
        'link' => 
        array (
          'value' => '#contact',
          'typeOpenLink' => 'sameWindow',
          'noFollow' => false,
          'lightboxMedia' => '',
        ),
        'preserveSpace' => 
        array (
          'text' => false,
        ),
        'icon' => 
        array (
          'name' => 'font-awesome/arrow-right',
        ),
      ),
    ),
    'buttons' => 
    array (
      'selective_selector' => '.kubio-front-header__k__9uoTT9gnxCy-outer',
      'styleRef' => '9uoTT9gnxCy',
      'props' => 
      array (
      ),
    ),
    'hero' => 
    array (
      'image' => 
      array (
        'selective_selector' => '.kubio-front-header__k__N6ZyU1UDnq-outer',
        'styleRef' => 'N6ZyU1UDnq',
        'props' => 
        array (
        ),
      ),
      'selective_selector' => '.kubio-front-header__k__J6FPNZyUrn-outer',
      'styleRef' => 'J6FPNZyUrn',
      'props' => 
      array (
        'layoutType' => 'textWithMediaOnRight',
        'heroSection' => 
        array (
          'layout' => 'textWithMediaOnRight',
        ),
      ),
      'hero_column_width' => '50',
      'style' => 
      array (
        'descendants' => 
        array (
          'outer' => 
          array (
            'background' => 
            array (
              'type' => 'image',
              'image' => 
              array (
                0 => 
                array (
                  'source' => 
                  array (
                    'type' => 'image',
                    'gradient' => 'linear-gradient(0deg, rgba(161,140,209,1) 0%, rgba(251,194,235,1) 100% )',
                  ),
                  'position' => 
                  array (
                    'x' => 0,
                    'y' => 0,
                  ),
                  'attachment' => 'fixed',
                  'size' => 'cover',
                ),
              ),
              'overlay' => 
              array (
                'enabled' => true,
                'color' => 
                array (
                  'opacity' => '0.60',
                  'value' => '#11121a',
                ),
                'type' => 'color',
                'gradient' => 'linear-gradient(188deg,rgba(var(--kubio-color-3-variant-5),0.7) 0%,rgba(var(--kubio-color-4),0.6) 100%)',
                'shape' => 
                array (
                  'value' => 'none',
                  'isTile' => false,
                  'light' => 0,
                ),
              ),
              'slideshow' => NULL,
            ),
            'padding' => 
            array (
            ),
            'separators' => 
            array (
              'separatorBottom' => 
              array (
              ),
            ),
          ),
        ),
      ),
    ),
  ),
  'colors' => 
  array (
    'kubio-color-1' => 
    array (
      0 => 47,
      1 => 124,
      2 => 255,
    ),
    'kubio-color-2' => 
    array (
      0 => 241,
      1 => 124,
      2 => 32,
    ),
    'kubio-color-3' => 
    array (
      0 => 78,
      1 => 186,
      2 => 154,
    ),
    'kubio-color-4' => 
    array (
      0 => 105,
      1 => 118,
      2 => 139,
    ),
    'kubio-color-5' => 
    array (
      0 => 255,
      1 => 255,
      2 => 255,
    ),
    'kubio-color-6' => 
    array (
      0 => 43,
      1 => 45,
      2 => 66,
    ),
    'kubio-color-1-variant-1' => 
    array (
      0 => 217,
      1 => 231,
      2 => 255,
    ),
    'kubio-color-1-variant-2' => 
    array (
      0 => 132,
      1 => 177,
      2 => 255,
    ),
    'kubio-color-1-variant-3' => 
    array (
      0 => 47,
      1 => 124,
      2 => 255,
    ),
    'kubio-color-1-variant-4' => 
    array (
      0 => 31,
      1 => 82,
      2 => 169,
    ),
    'kubio-color-1-variant-5' => 
    array (
      0 => 15,
      1 => 41,
      2 => 84,
    ),
    'kubio-color-2-variant-1' => 
    array (
      0 => 240,
      1 => 213,
      2 => 192,
    ),
    'kubio-color-2-variant-2' => 
    array (
      0 => 240,
      1 => 168,
      2 => 112,
    ),
    'kubio-color-2-variant-3' => 
    array (
      0 => 241,
      1 => 124,
      2 => 32,
    ),
    'kubio-color-2-variant-4' => 
    array (
      0 => 155,
      1 => 80,
      2 => 20,
    ),
    'kubio-color-2-variant-5' => 
    array (
      0 => 70,
      1 => 36,
      2 => 9,
    ),
    'kubio-color-3-variant-1' => 
    array (
      0 => 139,
      1 => 185,
      2 => 172,
    ),
    'kubio-color-3-variant-2' => 
    array (
      0 => 78,
      1 => 186,
      2 => 154,
    ),
    'kubio-color-3-variant-3' => 
    array (
      0 => 16,
      1 => 185,
      2 => 135,
    ),
    'kubio-color-3-variant-4' => 
    array (
      0 => 42,
      1 => 100,
      2 => 83,
    ),
    'kubio-color-3-variant-5' => 
    array (
      0 => 6,
      1 => 15,
      2 => 13,
    ),
    'kubio-color-4-variant-1' => 
    array (
      0 => 169,
      1 => 190,
      2 => 223,
    ),
    'kubio-color-4-variant-2' => 
    array (
      0 => 105,
      1 => 118,
      2 => 139,
    ),
    'kubio-color-4-variant-3' => 
    array (
      0 => 58,
      1 => 89,
      2 => 138,
    ),
    'kubio-color-4-variant-4' => 
    array (
      0 => 12,
      1 => 60,
      2 => 138,
    ),
    'kubio-color-4-variant-5' => 
    array (
      0 => 40,
      1 => 45,
      2 => 53,
    ),
    'kubio-color-5-variant-1' => 
    array (
      0 => 255,
      1 => 255,
      2 => 255,
    ),
    'kubio-color-5-variant-2' => 
    array (
      0 => 204,
      1 => 204,
      2 => 204,
    ),
    'kubio-color-5-variant-3' => 
    array (
      0 => 153,
      1 => 153,
      2 => 153,
    ),
    'kubio-color-5-variant-4' => 
    array (
      0 => 101,
      1 => 101,
      2 => 101,
    ),
    'kubio-color-5-variant-5' => 
    array (
      0 => 50,
      1 => 50,
      2 => 50,
    ),
    'kubio-color-6-variant-1' => 
    array (
      0 => 153,
      1 => 160,
      2 => 235,
    ),
    'kubio-color-6-variant-2' => 
    array (
      0 => 98,
      1 => 102,
      2 => 150,
    ),
    'kubio-color-6-variant-3' => 
    array (
      0 => 64,
      1 => 65,
      2 => 65,
    ),
    'kubio-color-6-variant-4' => 
    array (
      0 => 43,
      1 => 45,
      2 => 66,
    ),
    'kubio-color-6-variant-5' => 
    array (
      0 => 20,
      1 => 24,
      2 => 65,
    ),
  ),
    'typographyPreset' => [
        'h1' => [
            'family' => 'Mulish',
            'weight' => 700
        ],
        'h2' => [
            'family' => 'Mulish',
            'weight' => 700
        ],
        'h3' => [
            'family' => 'Mulish',
            'weight' => 700
        ],
        'h4' => [
            'family' => 'Mulish',
            'weight' => 500
        ],
        'h5' => [
            'family' => 'Mulish',
            'weight' => 400
        ],
        'h6' =>[
            'family' => 'Mulish',
            'weight' => 400
        ],
        'p' => [
            'family' => 'Mulish',
            'weight' => 300
        ],
        'lead' => [
            'family' => 'Mulish',
            'weight' => 400
        ],
        'a' => [
            'family' => 'Mulish',
            'weight' => 600
        ],
    ],
  'fonts' => 
  array (
    'Open Sans' => 
    array (
      0 => 400,
      1 => '300',
      2 => '300italic',
      3 => '400',
      4 => '400italic',
      5 => '600',
      6 => '600italic',
      7 => '700',
      8 => '700italic',
      9 => '800',
      10 => '800italic',
    ),
    'Mulish' => 
    array (
      0 => 400,
      1 => 300,
      2 => 500,
      3 => 600,
    ),
    'Roboto' => 
    array (
      0 => 400,
      1 => '100',
      2 => '100italic',
      3 => '300',
      4 => '300italic',
      5 => 'regular',
      6 => 'italic',
      7 => '500',
      8 => '500italic',
      9 => '700',
      10 => '700italic',
      11 => '900',
      12 => '900italic',
      13 => 600,
    ),
    'Carter One' => 
    array (
      0 => 400,
    ),
    'Poppins' => 
    array (
      0 => 300,
      1 => 600,
      2 => 600,
      3 => 400,
      4 => 700,
      5 => 500,
      6 => 900,
    ),
    'Syne' => 
    array (
      0 => 400,
      1 => 700,
      2 => 600,
    ),
    'Syncopate' => 
    array (
      0 => 700,
    ),
  ),
);
