<?php $component = \ColibriWP\Theme\View::getData( 'component' ); ?>
<div class="wp-block wp-block-kubio-dropdown-menu  position-relative wp-block-kubio-dropdown-menu__outer kubio-header__k__S2itoG6vEiw-outer kubio-local-477-outer kubio-dropdown-menu h-ignore-global-body-typography <?php echo $component->printHeaderMenuClasses(); ?>" data-kubio="kubio/dropdown-menu" data-kubio-component="dropdown-menu" data-kubio-settings="[]">
	<div class="wp-block wp-block-kubio-menu-items  position-relative wp-block-kubio-menu-items__outer kubio-header__k__dDUW0WNaaoB-outer kubio-local-478-outer kubio-menu" data-kubio="kubio/menu-items">
		<?php $component->printHeaderMenu(); ?>
	</div>
	<div class="wp-block wp-block-kubio-menu-offscreen  position-relative wp-block-kubio-menu-offscreen__container kubio-header__k__LCYaOhT1Q-f-container kubio-local-479-container" data-kubio="kubio/menu-offscreen">
		<div class="position-relative wp-block-kubio-menu-offscreen__align kubio-header__k__LCYaOhT1Q-f-align kubio-local-479-align">
			<button class="position-relative wp-block-kubio-menu-offscreen__iconWrapper kubio-header__k__LCYaOhT1Q-f-iconWrapper kubio-local-479-iconWrapper kubio-offscreen-icon-wrapper" data-target="#kubio-offscreen-65bb4b71ba591" data-target-id="kubio-offscreen-65bb4b71ba591" data-direction="right" data-width="300px" data-offcanvas-overlay-id="kubio-offscreen-65bb4b71ba591-overlay" aria-label="<?php esc_attr_e( 'Mobile Menu', 'kubio' );?>" data-kubio-component="offcanvas" data-kubio-settings="[]">
				<span class="h-svg-icon wp-block-kubio-menu-offscreen__icon kubio-header__k__LCYaOhT1Q-f-icon kubio-local-479-icon" name="icons8-line-awesome/bars">
					<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="bars" viewBox="0 0 512 545.5">
						<path d="M64 144h384v32H64v-32zm0 128h384v32H64v-32zm0 128h384v32H64v-32z"/></svg>
					</span>
				</button>
			</div>
			<div class="position-relative wp-block-kubio-menu-offscreen__offscreenOverlay kubio-header__k__LCYaOhT1Q-f-offscreenOverlay kubio-local-479-offscreenOverlay kubio-offscreen-overlay offscreen-overlay" id="kubio-offscreen-65bb4b71ba591-overlay"></div>
			<div class="position-relative wp-block-kubio-menu-offscreen__offscreen kubio-header__k__LCYaOhT1Q-f-offscreen kubio-local-479-offscreen kubio-offscreen offscreen hide" id="kubio-offscreen-65bb4b71ba591">
				<div class="position-relative wp-block-kubio-menu-offscreen__inner kubio-header__k__LCYaOhT1Q-f-inner kubio-local-479-inner">
					<div class="wp-block wp-block-kubio-menu-offscreen-content  position-relative wp-block-kubio-menu-offscreen-content__container kubio-header__k__g9zzHP3uLIb-container kubio-local-480-container" data-kubio="kubio/menu-offscreen-content">
						<div class="wp-block wp-block-kubio-row  position-relative wp-block-kubio-row__container kubio-header__k__XskQfsGZMJw-container kubio-local-481-container gutters-row-lg-3 gutters-row-v-lg-2 gutters-row-md-3 gutters-row-v-md-2 gutters-row-3 gutters-row-v-3" data-kubio="kubio/row">
							<div class="background-wrapper">
								<div class="background-layer background-layer-media-container-lg"></div>
								<div class="background-layer background-layer-media-container-md"></div>
								<div class="background-layer background-layer-media-container"></div>
							</div>
							<div class="position-relative wp-block-kubio-row__inner kubio-header__k__XskQfsGZMJw-inner kubio-local-481-inner h-row align-items-lg-stretch align-items-md-stretch align-items-stretch justify-content-lg-center justify-content-md-center justify-content-center gutters-col-lg-3 gutters-col-v-lg-2 gutters-col-md-3 gutters-col-v-md-2 gutters-col-3 gutters-col-v-3">
								<div class="wp-block wp-block-kubio-column  position-relative wp-block-kubio-column__container kubio-header__k__MlGjFpYlgDP-container kubio-local-482-container d-flex h-col-lg-auto h-col-md-auto h-col-auto" data-kubio="kubio/column">
									<div class="position-relative wp-block-kubio-column__inner kubio-header__k__MlGjFpYlgDP-inner kubio-local-482-inner d-flex h-flex-basis h-px-lg-2 v-inner-lg-2 h-px-md-3 v-inner-md-2 h-px-3 v-inner-2">
										<div class="background-wrapper">
											<div class="background-layer background-layer-media-container-lg"></div>
											<div class="background-layer background-layer-media-container-md"></div>
											<div class="background-layer background-layer-media-container"></div>
										</div>
										<div class="position-relative wp-block-kubio-column__align kubio-header__k__MlGjFpYlgDP-align kubio-local-482-align h-y-container h-column__content h-column__v-align flex-basis-100 align-self-lg-center align-self-md-center align-self-center">
											<?php kubio_theme()->get('logo')->render(array (
  'wrapper_class' => 'wp-block wp-block-kubio-logo position-relative wp-block-kubio-logo__container  kubio-logo-direction-row kubio-header__k__x8ZMD9qFOX9-container kubio-local--container',
  'logo_image_class' => 'position-relative wp-block-kubio-logo__image  kubio-logo-image  kubio-header__k__x8ZMD9qFOX9-image kubio-local--image',
  'alt_logo_image_class' => 'position-relative wp-block-kubio-logo__alternateImage kubio-logo-image kubio-alternate-logo-image   kubio-header__k__x8ZMD9qFOX9-alternateImage kubio-local--alternateImage',
  'logo_text_class' => 'position-relative wp-block-kubio-logo__text  kubio-header__k__x8ZMD9qFOX9-text kubio-local--text',
)); ?>
										</div>
									</div>
								</div>
							</div>
						</div>
						<div class="wp-block wp-block-kubio-accordion-menu  position-relative wp-block-kubio-accordion-menu__outer kubio-header__k__3ncDYaLs9lk-outer kubio-local-484-outer kubio-accordion-menu h-ignore-global-body-typography" data-kubio="kubio/accordion-menu" data-kubio-component="accordion-menu" data-kubio-settings="[]">
							<div class="wp-block wp-block-kubio-menu-items  position-relative wp-block-kubio-menu-items__outer kubio-header__k__hGBwyB3PAoX-outer kubio-local-485-outer kubio-menu" data-kubio="kubio/menu-items">
								<?php $component->printHeaderMenu(); ?>
							</div>
						</div>
						<div class="wp-block wp-block-kubio-row  position-relative wp-block-kubio-row__container kubio-header__k__0CEEoqk-kF1-container kubio-local-486-container gutters-row-lg-3 gutters-row-v-lg-2 gutters-row-md-3 gutters-row-v-md-2 gutters-row-3 gutters-row-v-2" data-kubio="kubio/row">
							<div class="background-wrapper">
								<div class="background-layer background-layer-media-container-lg"></div>
								<div class="background-layer background-layer-media-container-md"></div>
								<div class="background-layer background-layer-media-container"></div>
							</div>
							<div class="position-relative wp-block-kubio-row__inner kubio-header__k__0CEEoqk-kF1-inner kubio-local-486-inner h-row align-items-lg-stretch align-items-md-stretch align-items-stretch justify-content-lg-center justify-content-md-center justify-content-center gutters-col-lg-3 gutters-col-v-lg-2 gutters-col-md-3 gutters-col-v-md-2 gutters-col-3 gutters-col-v-2">
								<div class="wp-block wp-block-kubio-column  position-relative wp-block-kubio-column__container kubio-header__k__53skekCRYGP-container kubio-local-487-container d-flex h-col-lg-auto h-col-md-auto h-col-auto" data-kubio="kubio/column">
									<div class="position-relative wp-block-kubio-column__inner kubio-header__k__53skekCRYGP-inner kubio-local-487-inner d-flex h-flex-basis h-px-lg-2 v-inner-lg-2 h-px-md-3 v-inner-md-2 h-px-3 v-inner-2">
										<div class="background-wrapper">
											<div class="background-layer background-layer-media-container-lg"></div>
											<div class="background-layer background-layer-media-container-md"></div>
											<div class="background-layer background-layer-media-container"></div>
										</div>
										<div class="position-relative wp-block-kubio-column__align kubio-header__k__53skekCRYGP-align kubio-local-487-align h-y-container h-column__content h-column__v-align flex-basis-100 align-self-lg-center align-self-md-center align-self-center">
											<?php kubio_theme_print_menu_footer_copyright(); ?>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
