<!-- wp:group {"metadata":{"name":"about"},"align":"full","className":"kubio-starter-content-section","style":{"spacing":{"padding":{"top":"90px","bottom":"90px","right":"20px","left":"20px"},"margin":{"top":"0px","bottom":"0px"}}},"layout":{"type":"constrained"}} -->
<div class="wp-block-group alignfull kubio-starter-content-section" id="about" style="margin-top:0px;margin-bottom:0px;padding-top:90px;padding-right:20px;padding-bottom:90px;padding-left:20px"><!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"40","left":"40"},"padding":{"right":"0px","left":"0px","bottom":"0px","top":"0px"}}}} -->
    <div class="wp-block-columns alignwide" style="padding-top:0px;padding-right:0px;padding-bottom:0px;padding-left:0px"><!-- wp:column {"verticalAlignment":"center","width":"45%"} -->
    <div class="wp-block-column is-vertically-aligned-center" style="flex-basis:45%"><!-- wp:heading {"style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6","fontSize":"x-large"} -->
    <h2 class="wp-block-heading has-kubio-color-6-color has-text-color has-link-color has-x-large-font-size">About us</h2>
    <!-- /wp:heading -->
    
    <!-- wp:group {"style":{"spacing":{"padding":{"right":"0","top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}}},"layout":{"type":"flex","flexWrap":"nowrap"}} -->
    <div class="wp-block-group" style="padding-top:var(--wp--preset--spacing--40);padding-right:0;padding-bottom:var(--wp--preset--spacing--40)"><!-- wp:separator {"className":"is-style-default","style":{"spacing":{"margin":{"top":"0","bottom":"0"}},"layout":{"selfStretch":"fixed","flexSize":"25%"}},"backgroundColor":"kubio-color-1"} -->
    <hr class="wp-block-separator has-text-color has-kubio-color-1-color has-alpha-channel-opacity has-kubio-color-1-background-color has-background is-style-default" style="margin-top:0;margin-bottom:0"/>
    <!-- /wp:separator --></div>
    <!-- /wp:group -->
    
    <!-- wp:paragraph {"style":{"typography":{"fontStyle":"normal","fontWeight":"500","fontSize":"1.2em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <p class="has-kubio-color-6-color has-text-color has-link-color" style="font-size:1.2em;font-style:normal;font-weight:500"> Lorem ipsum dolor sit amet, consectetur adipiscing elit aliquet convallis. </p>
    <!-- /wp:paragraph -->
    
    <!-- wp:paragraph {"style":{"typography":{"fontStyle":"normal","fontWeight":"300","lineHeight":1.6},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <p class="has-kubio-color-6-color has-text-color has-link-color" style="font-style:normal;font-weight:300;line-height:1.6"> Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut feugiat aliquet convallis. Morbi cursus scelerisque est, a sodales mi fringilla sit amet. Donec ultrices id ante a tempus. Sed scelerisque elit in lectus fermentum condimentum. </p>
    <!-- /wp:paragraph -->
    
    <!-- wp:buttons {"layout":{"type":"flex","justifyContent":"left","flexWrap":"wrap","orientation":"vertical"}} -->
    <div class="wp-block-buttons"><!-- wp:button {"backgroundColor":"kubio-color-2","textColor":"kubio-color-5","style":{"border":{"radius":"0px"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-5"}}},"typography":{"textTransform":"uppercase","letterSpacing":"1px","fontSize":"14px","fontStyle":"normal","fontWeight":"300"},"spacing":{"padding":{"left":"40px","right":"40px","top":"20px","bottom":"20px"}}}} -->
    <div class="wp-block-button has-custom-font-size" style="font-size:14px;font-style:normal;font-weight:300;letter-spacing:1px;text-transform:uppercase"><a class="wp-block-button__link has-kubio-color-5-color has-kubio-color-2-background-color has-text-color has-background has-link-color wp-element-button" style="border-radius:0px;padding-top:20px;padding-right:40px;padding-bottom:20px;padding-left:40px">Contact us</a></div>
    <!-- /wp:button --></div>
    <!-- /wp:buttons --></div>
    <!-- /wp:column -->
    
    <!-- wp:column {"verticalAlignment":"center","width":"55%","style":{"spacing":{"padding":{"top":"0","right":"0","bottom":"0","left":"0"}}},"layout":{"type":"default"}} -->
    <div class="wp-block-column is-vertically-aligned-center" style="padding-top:0;padding-right:0;padding-bottom:0;padding-left:0;flex-basis:55%"><!-- wp:image {"aspectRatio":"4/3","scale":"cover","sizeSlug":"large","linkDestination":"none","style":{"spacing":{"margin":{"top":"0","bottom":"0","left":"0","right":"0"}}}} -->
    <figure class="wp-block-image size-large" style="margin-top:0;margin-right:0;margin-bottom:0;margin-left:0"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-1.jpg" alt="" class="" style="aspect-ratio:4/3;object-fit:cover"/></figure>
    <!-- /wp:image --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns --></div>
    <!-- /wp:group -->
    
    <!-- wp:group {"metadata":{"name":"features"},"align":"full","className":"kubio-starter-content-section","style":{"spacing":{"padding":{"top":"90px","bottom":"90px","right":"20px","left":"20px"},"blockGap":"0px"},"color":{"background":"#12121408"}},"layout":{"type":"constrained"}} -->
    <div class="wp-block-group alignfull kubio-starter-content-section has-background" id="features" style="background-color:#12121408;padding-top:90px;padding-right:20px;padding-bottom:90px;padding-left:20px"><!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"40","left":"40"},"padding":{"right":"0px","left":"0px","bottom":"0px","top":"0px"}}}} -->
    <div class="wp-block-columns alignwide" style="padding-top:0px;padding-right:0px;padding-bottom:0px;padding-left:0px"><!-- wp:column {"verticalAlignment":"center","width":"","style":{"spacing":{"blockGap":"20px","padding":{"bottom":"30px"}}}} -->
    <div class="wp-block-column is-vertically-aligned-center" style="padding-bottom:30px"><!-- wp:heading {"textAlign":"center","style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6","fontSize":"x-large"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-6-color has-text-color has-link-color has-x-large-font-size">A few things we’re great at</h2>
    <!-- /wp:heading -->
    
    <!-- wp:group {"style":{"spacing":{"padding":{"right":"0","left":"0","top":"0","bottom":"0"},"blockGap":"0","margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}}},"layout":{"type":"flex","flexWrap":"nowrap","justifyContent":"center"}} -->
    <div class="wp-block-group" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40);padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:separator {"className":"is-style-default","style":{"spacing":{"margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}},"layout":{"selfStretch":"fixed","flexSize":"20%"}},"backgroundColor":"kubio-color-1"} -->
    <hr class="wp-block-separator has-text-color has-kubio-color-1-color has-alpha-channel-opacity has-kubio-color-1-background-color has-background is-style-default" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40)"/>
    <!-- /wp:separator --></div>
    <!-- /wp:group -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontStyle":"normal","fontWeight":"500","fontSize":"1.2em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"spacing":{"padding":{"top":"0","bottom":"0","left":"var:preset|spacing|40","right":"var:preset|spacing|40"}}},"textColor":"kubio-color-6"} -->
    <p class="has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="padding-top:0;padding-right:var(--wp--preset--spacing--40);padding-bottom:0;padding-left:var(--wp--preset--spacing--40);font-size:1.2em;font-style:normal;font-weight:500">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut feugiat aliquet convallis. Morbi cursus scelerisque est, a sodales mi fringilla sit amet.</p>
    <!-- /wp:paragraph --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns -->
    
    <!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"3em","left":"3em"},"padding":{"right":"0px","left":"0px","bottom":"0px","top":"0px"}}}} -->
    <div class="wp-block-columns alignwide" style="padding-top:0px;padding-right:0px;padding-bottom:0px;padding-left:0px"><!-- wp:column {"layout":{"type":"default"}} -->
    <div class="wp-block-column"><!-- wp:group {"layout":{"type":"constrained","justifyContent":"left"}} -->
    <div class="wp-block-group"><!-- wp:image {"aspectRatio":"4/3","scale":"cover","sizeSlug":"full","linkDestination":"none"} -->
    <figure class="wp-block-image size-full"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-2.jpg" alt="" class="" style="aspect-ratio:4/3;object-fit:cover"/></figure>
    <!-- /wp:image --></div>
    <!-- /wp:group -->
    
    <!-- wp:heading {"style":{"typography":{"fontSize":"1.3em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <h2 class="wp-block-heading has-kubio-color-6-color has-text-color has-link-color" style="font-size:1.3em">Intelligent Automation</h2>
    <!-- /wp:heading -->
    
    <!-- wp:paragraph {"style":{"typography":{"fontSize":"16px","fontStyle":"normal","fontWeight":"300","lineHeight":1.6},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <p class="has-kubio-color-6-color has-text-color has-link-color" style="font-size:16px;font-style:normal;font-weight:300;line-height:1.6">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut feugiat aliquet convallis. Morbi cursus scelerisque est.</p>
    <!-- /wp:paragraph -->
    
    <!-- wp:buttons -->
    <div class="wp-block-buttons"><!-- wp:button {"textColor":"kubio-color-1","className":"has-custom-font-size","style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}},"spacing":{"padding":{"left":"0","right":"0","top":"0","bottom":"0"}},"typography":{"fontStyle":"normal","fontWeight":"700","textDecoration":"underline"},"color":{"background":"#ffffff00"}}} -->
    <div class="wp-block-button has-custom-font-size" style="font-style:normal;font-weight:700;text-decoration:underline"><a class="wp-block-button__link has-kubio-color-1-color has-text-color has-background has-link-color wp-element-button" style="background-color:#ffffff00;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0">Read more</a></div>
    <!-- /wp:button --></div>
    <!-- /wp:buttons --></div>
    <!-- /wp:column -->
    
    <!-- wp:column -->
    <div class="wp-block-column"><!-- wp:group {"layout":{"type":"constrained","justifyContent":"left"}} -->
    <div class="wp-block-group"><!-- wp:image {"aspectRatio":"4/3","scale":"cover","sizeSlug":"full","linkDestination":"none"} -->
    <figure class="wp-block-image size-full"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-3.jpg" alt="" class="" style="aspect-ratio:4/3;object-fit:cover"/></figure>
    <!-- /wp:image --></div>
    <!-- /wp:group -->
    
    <!-- wp:heading {"style":{"typography":{"fontSize":"1.3em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <h2 class="wp-block-heading has-kubio-color-6-color has-text-color has-link-color" style="font-size:1.3em">Immersive User Interface</h2>
    <!-- /wp:heading -->
    
    <!-- wp:paragraph {"style":{"typography":{"fontSize":"16px","fontStyle":"normal","fontWeight":"300","lineHeight":1.6},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <p class="has-kubio-color-6-color has-text-color has-link-color" style="font-size:16px;font-style:normal;font-weight:300;line-height:1.6">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut feugiat aliquet convallis. Morbi cursus scelerisque est.</p>
    <!-- /wp:paragraph -->
    
    <!-- wp:buttons -->
    <div class="wp-block-buttons"><!-- wp:button {"textColor":"kubio-color-1","className":"has-custom-font-size","style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}},"spacing":{"padding":{"left":"0","right":"0","top":"0","bottom":"0"}},"typography":{"fontStyle":"normal","fontWeight":"700","textDecoration":"underline"},"color":{"background":"#ffffff00"}}} -->
    <div class="wp-block-button has-custom-font-size" style="font-style:normal;font-weight:700;text-decoration:underline"><a class="wp-block-button__link has-kubio-color-1-color has-text-color has-background has-link-color wp-element-button" style="background-color:#ffffff00;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0">Read more</a></div>
    <!-- /wp:button --></div>
    <!-- /wp:buttons --></div>
    <!-- /wp:column -->
    
    <!-- wp:column -->
    <div class="wp-block-column"><!-- wp:group {"layout":{"type":"constrained","justifyContent":"left"}} -->
    <div class="wp-block-group"><!-- wp:image {"aspectRatio":"4/3","scale":"cover","sizeSlug":"full","linkDestination":"none"} -->
    <figure class="wp-block-image size-full"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-4.jpg" alt="" class="" style="aspect-ratio:4/3;object-fit:cover"/></figure>
    <!-- /wp:image --></div>
    <!-- /wp:group -->
    
    <!-- wp:heading {"style":{"typography":{"fontSize":"1.3em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <h2 class="wp-block-heading has-kubio-color-6-color has-text-color has-link-color" style="font-size:1.3em">Real-time Collaboration</h2>
    <!-- /wp:heading -->
    
    <!-- wp:paragraph {"style":{"typography":{"fontSize":"16px","fontStyle":"normal","fontWeight":"300","lineHeight":1.6},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <p class="has-kubio-color-6-color has-text-color has-link-color" style="font-size:16px;font-style:normal;font-weight:300;line-height:1.6">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut feugiat aliquet convallis. Morbi cursus scelerisque est.</p>
    <!-- /wp:paragraph -->
    
    <!-- wp:buttons -->
    <div class="wp-block-buttons"><!-- wp:button {"textColor":"kubio-color-1","className":"has-custom-font-size","style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}},"spacing":{"padding":{"left":"0","right":"0","top":"0","bottom":"0"}},"typography":{"fontStyle":"normal","fontWeight":"700","textDecoration":"underline"},"color":{"background":"#ffffff00"}}} -->
    <div class="wp-block-button has-custom-font-size" style="font-style:normal;font-weight:700;text-decoration:underline"><a class="wp-block-button__link has-kubio-color-1-color has-text-color has-background has-link-color wp-element-button" style="background-color:#ffffff00;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0">Read more</a></div>
    <!-- /wp:button --></div>
    <!-- /wp:buttons --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns --></div>
    <!-- /wp:group -->
    
    <!-- wp:group {"metadata":{"name":"content-1"},"align":"full","className":"kubio-starter-content-section","style":{"spacing":{"margin":{"top":"0px","bottom":"0px"}}},"layout":{"type":"constrained"}} -->
    <div class="wp-block-group alignfull kubio-starter-content-section" id="content-1" style="margin-top:0px;margin-bottom:0px"><!-- wp:columns {"align":"full","style":{"spacing":{"blockGap":{"top":"0","left":"0"},"padding":{"top":"0","bottom":"0","left":"0","right":"0"}}},"backgroundColor":"kubio-color-5-variant-2"} -->
    <div class="wp-block-columns alignfull has-kubio-color-5-variant-2-background-color has-background" style="padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:column {"width":"50%"} -->
    <div class="wp-block-column" style="flex-basis:50%"><!-- wp:cover {"url":"<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-5.jpg","dimRatio":0,"customOverlayColor":"#d8d7d8","isUserOverlayColor":true,"minHeight":650,"minHeightUnit":"px","isDark":false,"layout":{"type":"default"}} -->
    <div class="wp-block-cover is-light" style="min-height:650px"><span aria-hidden="true" class="wp-block-cover__background has-background-dim-0 has-background-dim" style="background-color:#d8d7d8"></span><img class="wp-block-cover__image-background " alt="" src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-5.jpg" data-object-fit="cover"/><div class="wp-block-cover__inner-container"><!-- wp:paragraph {"align":"center","placeholder":"Write title…","fontSize":"large"} -->
    <p class="has-text-align-center has-large-font-size"></p>
    <!-- /wp:paragraph --></div></div>
    <!-- /wp:cover --></div>
    <!-- /wp:column -->
    
    <!-- wp:column {"verticalAlignment":"center","width":"50%","layout":{"type":"default"}} -->
    <div class="wp-block-column is-vertically-aligned-center" style="flex-basis:50%"><!-- wp:group {"style":{"spacing":{"padding":{"top":"10%","right":"10%","bottom":"10%","left":"10%"}}},"layout":{"type":"constrained"}} -->
    <div class="wp-block-group" style="padding-top:10%;padding-right:10%;padding-bottom:10%;padding-left:10%"><!-- wp:heading {"style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6","fontSize":"x-large"} -->
    <h2 class="wp-block-heading has-kubio-color-6-color has-text-color has-link-color has-x-large-font-size">Dynamic Design Showcase</h2>
    <!-- /wp:heading -->
    
    <!-- wp:group {"style":{"spacing":{"padding":{"right":"0"}}},"layout":{"type":"flex","flexWrap":"nowrap"}} -->
    <div class="wp-block-group" style="padding-right:0"><!-- wp:separator {"className":"is-style-default","style":{"spacing":{"margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}},"layout":{"selfStretch":"fixed","flexSize":"25%"}},"backgroundColor":"kubio-color-1"} -->
    <hr class="wp-block-separator has-text-color has-kubio-color-1-color has-alpha-channel-opacity has-kubio-color-1-background-color has-background is-style-default" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40)"/>
    <!-- /wp:separator --></div>
    <!-- /wp:group -->
    
    <!-- wp:paragraph {"style":{"typography":{"fontStyle":"normal","fontWeight":"500","fontSize":"1.2em","lineHeight":1.4},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <p class="has-kubio-color-6-color has-text-color has-link-color" style="font-size:1.2em;font-style:normal;font-weight:500;line-height:1.4">Donec volutpat vel ipsum at posuere. Mauris vitae vulputate erat viverra, pretium massa. Curabitur posuere at lorem vel ullamcorper.</p>
    <!-- /wp:paragraph -->
    
    <!-- wp:paragraph {"style":{"typography":{"fontStyle":"normal","fontWeight":"300","lineHeight":1.6},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <p class="has-kubio-color-6-color has-text-color has-link-color" style="font-style:normal;font-weight:300;line-height:1.6">Phasellus justo risus, dignissim sit amet tellus ac, accumsan hendrerit mauris. Nullam ultricies, urna cursus facilisis posuere, diam nisl egestas erat, vitae posuere est quam ut diam. </p>
    <!-- /wp:paragraph -->
    
    <!-- wp:buttons -->
    <div class="wp-block-buttons"><!-- wp:button {"textColor":"kubio-color-1","className":"has-custom-font-size","style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}},"spacing":{"padding":{"left":"0","right":"0","top":"0","bottom":"0"}},"typography":{"fontStyle":"normal","fontWeight":"700","textDecoration":"underline"},"color":{"background":"#ffffff00"}}} -->
    <div class="wp-block-button has-custom-font-size" style="font-style:normal;font-weight:700;text-decoration:underline"><a class="wp-block-button__link has-kubio-color-1-color has-text-color has-background has-link-color wp-element-button" style="background-color:#ffffff00;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0">Read more</a></div>
    <!-- /wp:button --></div>
    <!-- /wp:buttons --></div>
    <!-- /wp:group --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns --></div>
    <!-- /wp:group -->
    
    <!-- wp:group {"metadata":{"name":"content-2"},"align":"full","className":"kubio-starter-content-section","style":{"spacing":{"padding":{"top":"0","bottom":"0","right":"0","left":"0"},"margin":{"top":"0px","bottom":"0px"}},"color":{"background":"#12121408"}},"layout":{"type":"constrained"}} -->
    <div class="wp-block-group alignfull kubio-starter-content-section has-background" id="content-2" style="background-color:#12121408;margin-top:0px;margin-bottom:0px;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:columns {"align":"full","style":{"spacing":{"blockGap":{"top":"0","left":"0"}}}} -->
    <div class="wp-block-columns alignfull"><!-- wp:column {"verticalAlignment":"center","width":"50%","layout":{"type":"default"}} -->
    <div class="wp-block-column is-vertically-aligned-center" style="flex-basis:50%"><!-- wp:group {"style":{"spacing":{"padding":{"top":"10%","right":"10%","bottom":"10%","left":"10%"}}},"layout":{"type":"constrained"}} -->
    <div class="wp-block-group" style="padding-top:10%;padding-right:10%;padding-bottom:10%;padding-left:10%"><!-- wp:heading {"style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6","fontSize":"x-large"} -->
    <h2 class="wp-block-heading has-kubio-color-6-color has-text-color has-link-color has-x-large-font-size">Collaborative Project Hub</h2>
    <!-- /wp:heading -->
    
    <!-- wp:group {"style":{"spacing":{"padding":{"right":"0"}}},"layout":{"type":"flex","flexWrap":"nowrap"}} -->
    <div class="wp-block-group" style="padding-right:0"><!-- wp:separator {"className":"is-style-default","style":{"spacing":{"margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}},"layout":{"selfStretch":"fixed","flexSize":"25%"}},"backgroundColor":"kubio-color-1"} -->
    <hr class="wp-block-separator has-text-color has-kubio-color-1-color has-alpha-channel-opacity has-kubio-color-1-background-color has-background is-style-default" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40)"/>
    <!-- /wp:separator --></div>
    <!-- /wp:group -->
    
    <!-- wp:paragraph {"style":{"typography":{"fontStyle":"normal","fontWeight":"500","fontSize":"1.2em","lineHeight":1.4},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <p class="has-kubio-color-6-color has-text-color has-link-color" style="font-size:1.2em;font-style:normal;font-weight:500;line-height:1.4">Donec volutpat vel ipsum at posuere. Mauris vitae vulputate erat viverra, pretium massa. Curabitur posuere at lorem vel ullamcorper.</p>
    <!-- /wp:paragraph -->
    
    <!-- wp:paragraph {"style":{"typography":{"fontStyle":"normal","fontWeight":"300","lineHeight":1.6},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <p class="has-kubio-color-6-color has-text-color has-link-color" style="font-style:normal;font-weight:300;line-height:1.6">Phasellus justo risus, dignissim sit amet tellus ac, accumsan hendrerit mauris. Nullam ultricies, urna cursus facilisis posuere, diam nisl egestas erat, vitae posuere est quam ut diam. </p>
    <!-- /wp:paragraph -->
    
    <!-- wp:buttons -->
    <div class="wp-block-buttons"><!-- wp:button {"textColor":"kubio-color-1","className":"has-custom-font-size","style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}},"spacing":{"padding":{"left":"0","right":"0","top":"0","bottom":"0"}},"typography":{"fontStyle":"normal","fontWeight":"700","textDecoration":"underline"},"color":{"background":"#ffffff00"}}} -->
    <div class="wp-block-button has-custom-font-size" style="font-style:normal;font-weight:700;text-decoration:underline"><a class="wp-block-button__link has-kubio-color-1-color has-text-color has-background has-link-color wp-element-button" style="background-color:#ffffff00;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0">Read more</a></div>
    <!-- /wp:button --></div>
    <!-- /wp:buttons --></div>
    <!-- /wp:group --></div>
    <!-- /wp:column -->
    
    <!-- wp:column {"width":"50%"} -->
    <div class="wp-block-column" style="flex-basis:50%"><!-- wp:cover {"url":"<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-6.jpg","dimRatio":0,"customOverlayColor":"#d9dee9","isUserOverlayColor":true,"minHeight":650,"isDark":false,"layout":{"type":"default"}} -->
    <div class="wp-block-cover is-light" style="min-height:650px"><span aria-hidden="true" class="wp-block-cover__background has-background-dim-0 has-background-dim" style="background-color:#d9dee9"></span><img class="wp-block-cover__image-background " alt="" src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-6.jpg" data-object-fit="cover"/><div class="wp-block-cover__inner-container"><!-- wp:paragraph {"align":"center","placeholder":"Write title…","fontSize":"large"} -->
    <p class="has-text-align-center has-large-font-size"></p>
    <!-- /wp:paragraph --></div></div>
    <!-- /wp:cover --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns --></div>
    <!-- /wp:group -->
    
    <!-- wp:group {"metadata":{"name":"services"},"align":"full","className":"kubio-starter-content-section","style":{"spacing":{"padding":{"top":"90px","bottom":"90px","right":"20px","left":"20px"},"blockGap":"0px","margin":{"top":"0px","bottom":"0px"}}},"backgroundColor":"kubio-color-5","layout":{"type":"constrained"}} -->
    <div class="wp-block-group alignfull kubio-starter-content-section has-kubio-color-5-background-color has-background" id="services" style="margin-top:0px;margin-bottom:0px;padding-top:90px;padding-right:20px;padding-bottom:90px;padding-left:20px"><!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"0","left":"0"},"padding":{"top":"0","right":"0","left":"0","bottom":"0"},"margin":{"top":"0","bottom":"0"}}}} -->
    <div class="wp-block-columns alignwide" style="margin-top:0;margin-bottom:0;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:column {"verticalAlignment":"center","width":"","style":{"spacing":{"blockGap":"var:preset|spacing|40","padding":{"bottom":"30px","right":"10px","left":"10px"}}},"layout":{"type":"default"}} -->
    <div class="wp-block-column is-vertically-aligned-center" style="padding-right:10px;padding-bottom:30px;padding-left:10px"><!-- wp:heading {"textAlign":"center","style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"spacing":{"padding":{"top":"0","bottom":"0","left":"0","right":"0"}}},"textColor":"kubio-color-6","fontSize":"x-large"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-6-color has-text-color has-link-color has-x-large-font-size" style="padding-top:0;padding-right:0;padding-bottom:0;padding-left:0">Why Choose Us</h2>
    <!-- /wp:heading -->
    
    <!-- wp:group {"style":{"spacing":{"padding":{"right":"0","left":"0","top":"0","bottom":"0"},"blockGap":"0","margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}}},"layout":{"type":"flex","flexWrap":"nowrap","justifyContent":"center"}} -->
    <div class="wp-block-group" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40);padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:separator {"className":"is-style-default","style":{"spacing":{"margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}},"layout":{"selfStretch":"fixed","flexSize":"20%"}},"backgroundColor":"kubio-color-1"} -->
    <hr class="wp-block-separator has-text-color has-kubio-color-1-color has-alpha-channel-opacity has-kubio-color-1-background-color has-background is-style-default" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40)"/>
    <!-- /wp:separator --></div>
    <!-- /wp:group -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontStyle":"normal","fontWeight":"500","fontSize":"1.2em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"spacing":{"padding":{"right":"0","left":"0"}}},"textColor":"kubio-color-6"} -->
    <p class="has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="padding-right:0;padding-left:0;font-size:1.2em;font-style:normal;font-weight:500">Lorem ipsum dolor sit amet, at mei dolore tritani repudiandae. In his nemore temporibus consequuntur, vim ad prima vivendum consetetur.</p>
    <!-- /wp:paragraph --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns -->
    
    <!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"3em","left":"3em"},"margin":{"top":"3em","bottom":"3em"},"padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px"}}}} -->
    <div class="wp-block-columns alignwide" style="margin-top:3em;margin-bottom:3em;padding-top:0px;padding-right:0px;padding-bottom:0px;padding-left:0px"><!-- wp:column {"layout":{"type":"default"}} -->
    <div class="wp-block-column"><!-- wp:group {"layout":{"type":"constrained","justifyContent":"left"}} -->
    <div class="wp-block-group"><!-- wp:image {"width":"45px","height":"45px","scale":"cover","sizeSlug":"full","linkDestination":"none","align":"center"} -->
    <figure class="wp-block-image aligncenter size-full is-resized"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-7.png" alt="" style="object-fit:cover;width:45px;height:45px"/></figure>
    <!-- /wp:image --></div>
    <!-- /wp:group -->
    
    <!-- wp:heading {"textAlign":"center","style":{"typography":{"fontSize":"1.3em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="font-size:1.3em">Aliquam porttitor interdum enim a rutrum tempus</h2>
    <!-- /wp:heading -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontStyle":"normal","fontWeight":"300","lineHeight":1.6},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6","fontSize":"medium"} -->
    <p class="has-text-align-center has-kubio-color-6-color has-text-color has-link-color has-medium-font-size" style="font-style:normal;font-weight:300;line-height:1.6">Cras tincidunt ut tortor ut vestibulum. Sed molestie laoreet purus, nec tempus lectus tincidunt eu. Lorem ipsum dolor sit amet, at mei dolore.</p>
    <!-- /wp:paragraph --></div>
    <!-- /wp:column -->
    
    <!-- wp:column {"layout":{"type":"default"}} -->
    <div class="wp-block-column"><!-- wp:group {"layout":{"type":"constrained","justifyContent":"left"}} -->
    <div class="wp-block-group"><!-- wp:image {"width":"45px","height":"45px","scale":"cover","sizeSlug":"full","linkDestination":"none","align":"center"} -->
    <figure class="wp-block-image aligncenter size-full is-resized"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-8.png" alt="" style="object-fit:cover;width:45px;height:45px"/></figure>
    <!-- /wp:image --></div>
    <!-- /wp:group -->
    
    <!-- wp:heading {"textAlign":"center","style":{"typography":{"fontSize":"1.3em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="font-size:1.3em">Aliquam porttitor interdum enim a rutrum tempus</h2>
    <!-- /wp:heading -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontStyle":"normal","fontWeight":"300","lineHeight":1.6},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6","fontSize":"medium"} -->
    <p class="has-text-align-center has-kubio-color-6-color has-text-color has-link-color has-medium-font-size" style="font-style:normal;font-weight:300;line-height:1.6">Cras tincidunt ut tortor ut vestibulum. Sed molestie laoreet purus, nec tempus lectus tincidunt eu. Lorem ipsum dolor sit amet, at mei dolore.</p>
    <!-- /wp:paragraph --></div>
    <!-- /wp:column -->
    
    <!-- wp:column {"layout":{"type":"default"}} -->
    <div class="wp-block-column"><!-- wp:group {"layout":{"type":"constrained","justifyContent":"left"}} -->
    <div class="wp-block-group"><!-- wp:image {"width":"45px","height":"45px","scale":"cover","sizeSlug":"full","linkDestination":"none","align":"center"} -->
    <figure class="wp-block-image aligncenter size-full is-resized"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-9.png" alt="" style="object-fit:cover;width:45px;height:45px"/></figure>
    <!-- /wp:image --></div>
    <!-- /wp:group -->
    
    <!-- wp:heading {"textAlign":"center","style":{"typography":{"fontSize":"1.3em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="font-size:1.3em">Aliquam porttitor interdum enim a rutrum tempus</h2>
    <!-- /wp:heading -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontStyle":"normal","fontWeight":"300","lineHeight":1.6},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6","fontSize":"medium"} -->
    <p class="has-text-align-center has-kubio-color-6-color has-text-color has-link-color has-medium-font-size" style="font-style:normal;font-weight:300;line-height:1.6">Cras tincidunt ut tortor ut vestibulum. Sed molestie laoreet purus, nec tempus lectus tincidunt eu. Lorem ipsum dolor sit amet, at mei dolore.</p>
    <!-- /wp:paragraph --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns --></div>
    <!-- /wp:group -->
    
    <!-- wp:group {"metadata":{"name":"projects"},"align":"full","className":"kubio-starter-content-section","style":{"spacing":{"padding":{"top":"0px","bottom":"90px","right":"20px","left":"20px"},"blockGap":"0px","margin":{"top":"0px","bottom":"0px"}}},"backgroundColor":"kubio-color-5","layout":{"type":"constrained"}} -->
    <div class="wp-block-group alignfull kubio-starter-content-section has-kubio-color-5-background-color has-background" id="projects" style="margin-top:0px;margin-bottom:0px;padding-top:0px;padding-right:20px;padding-bottom:90px;padding-left:20px"><!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"0","left":"0"}}}} -->
    <div class="wp-block-columns alignwide"><!-- wp:column {"verticalAlignment":"center","width":"","style":{"spacing":{"blockGap":"20px","padding":{"bottom":"30px"}}},"layout":{"type":"default"}} -->
    <div class="wp-block-column is-vertically-aligned-center" style="padding-bottom:30px"><!-- wp:heading {"textAlign":"center","style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6","fontSize":"x-large"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-6-color has-text-color has-link-color has-x-large-font-size">Our projects</h2>
    <!-- /wp:heading -->
    
    <!-- wp:group {"style":{"spacing":{"padding":{"right":"0","left":"0","top":"0","bottom":"0"},"blockGap":"0","margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}}},"layout":{"type":"flex","flexWrap":"nowrap","justifyContent":"center"}} -->
    <div class="wp-block-group" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40);padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:separator {"className":"is-style-default","style":{"spacing":{"margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}},"layout":{"selfStretch":"fixed","flexSize":"20%"}},"backgroundColor":"kubio-color-1"} -->
    <hr class="wp-block-separator has-text-color has-kubio-color-1-color has-alpha-channel-opacity has-kubio-color-1-background-color has-background is-style-default" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40)"/>
    <!-- /wp:separator --></div>
    <!-- /wp:group -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontStyle":"normal","fontWeight":"500","fontSize":"1.2em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"spacing":{"padding":{"right":"var:preset|spacing|40","left":"var:preset|spacing|40"}}},"textColor":"kubio-color-6"} -->
    <p class="has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="padding-right:var(--wp--preset--spacing--40);padding-left:var(--wp--preset--spacing--40);font-size:1.2em;font-style:normal;font-weight:500">Lorem ipsum dolor sit amet, at mei dolore tritani repudiandae. In his nemore temporibus consequuntur, vim ad prima vivendum consetetur.</p>
    <!-- /wp:paragraph --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns -->
    
    <!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"0","left":"0"},"margin":{"top":"2em","bottom":"2em"}}}} -->
    <div class="wp-block-columns alignwide" style="margin-top:2em;margin-bottom:2em"><!-- wp:column {"style":{"spacing":{"blockGap":"0","padding":{"right":"0","left":"0","top":"0","bottom":"0"}}},"layout":{"type":"default"}} -->
    <div class="wp-block-column" style="padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:gallery {"linkTo":"none","style":{"spacing":{"blockGap":{"top":"var:preset|spacing|30","left":"var:preset|spacing|30"},"padding":{"right":"0","left":"0","top":"0","bottom":"0"},"margin":{"top":"0","bottom":"0","left":"0","right":"0"}}}} -->
    <figure class="wp-block-gallery has-nested-images columns-default is-cropped" style="margin-top:0;margin-right:0;margin-bottom:0;margin-left:0;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:image {"lightbox":{"enabled":true},"sizeSlug":"large","linkDestination":"none","style":{"spacing":{"margin":{"top":"0","bottom":"0","left":"0","right":"0"}}}} -->
    <figure class="wp-block-image size-large" style="margin-top:0;margin-right:0;margin-bottom:0;margin-left:0"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-10.jpg" alt="" class=""/></figure>
    <!-- /wp:image -->
    
    <!-- wp:image {"lightbox":{"enabled":true},"sizeSlug":"large","linkDestination":"none"} -->
    <figure class="wp-block-image size-large"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-11.jpg" alt="" class=""/></figure>
    <!-- /wp:image -->
    
    <!-- wp:image {"lightbox":{"enabled":true},"sizeSlug":"large","linkDestination":"none"} -->
    <figure class="wp-block-image size-large"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-12.jpg" alt="" class=""/></figure>
    <!-- /wp:image -->
    
    <!-- wp:image {"lightbox":{"enabled":true},"sizeSlug":"large","linkDestination":"none"} -->
    <figure class="wp-block-image size-large"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-13.jpg" alt="" class=""/></figure>
    <!-- /wp:image -->
    
    <!-- wp:image {"lightbox":{"enabled":true},"sizeSlug":"large","linkDestination":"none"} -->
    <figure class="wp-block-image size-large"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-14.jpg" alt="" class=""/></figure>
    <!-- /wp:image -->
    
    <!-- wp:image {"lightbox":{"enabled":true},"sizeSlug":"large","linkDestination":"none"} -->
    <figure class="wp-block-image size-large"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-15.jpg" alt="" class=""/></figure>
    <!-- /wp:image --></figure>
    <!-- /wp:gallery --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns --></div>
    <!-- /wp:group -->
    
    <!-- wp:group {"metadata":{"name":"testimonials"},"align":"full","className":"kubio-starter-content-section","style":{"spacing":{"padding":{"top":"90px","bottom":"90px","right":"20px","left":"20px"},"blockGap":"0px","margin":{"top":"0px","bottom":"0px"}}},"backgroundColor":"kubio-color-5-variant-2","layout":{"type":"constrained"}} -->
    <div class="wp-block-group alignfull kubio-starter-content-section has-kubio-color-5-variant-2-background-color has-background" id="testimonials" style="margin-top:0px;margin-bottom:0px;padding-top:90px;padding-right:20px;padding-bottom:90px;padding-left:20px"><!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"0","left":"0"}}}} -->
    <div class="wp-block-columns alignwide"><!-- wp:column {"verticalAlignment":"center","width":"","style":{"spacing":{"blockGap":"20px","padding":{"bottom":"0","right":"0","left":"0","top":"0"}}}} -->
    <div class="wp-block-column is-vertically-aligned-center" style="padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:heading {"textAlign":"center","style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6","fontSize":"x-large"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-6-color has-text-color has-link-color has-x-large-font-size">Testimonials</h2>
    <!-- /wp:heading -->
    
    <!-- wp:group {"style":{"spacing":{"padding":{"right":"0","left":"0","top":"0","bottom":"0"},"blockGap":"0","margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}}},"layout":{"type":"flex","flexWrap":"nowrap","justifyContent":"center"}} -->
    <div class="wp-block-group" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40);padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:separator {"className":"is-style-default","style":{"spacing":{"margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}},"layout":{"selfStretch":"fixed","flexSize":"20%"}},"backgroundColor":"kubio-color-1"} -->
    <hr class="wp-block-separator has-text-color has-kubio-color-1-color has-alpha-channel-opacity has-kubio-color-1-background-color has-background is-style-default" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40)"/>
    <!-- /wp:separator --></div>
    <!-- /wp:group -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontStyle":"normal","fontWeight":"500","fontSize":"1.2em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"spacing":{"padding":{"right":"var:preset|spacing|40","left":"var:preset|spacing|40"}}},"textColor":"kubio-color-6"} -->
    <p class="has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="padding-right:var(--wp--preset--spacing--40);padding-left:var(--wp--preset--spacing--40);font-size:1.2em;font-style:normal;font-weight:500">Lorem ipsum dolor sit amet, at mei dolore tritani repudiandae. In his nemore temporibus consequuntur, vim ad prima vivendum consetetur.</p>
    <!-- /wp:paragraph --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns -->
    
    <!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"2em","left":"1em"},"padding":{"top":"40px"}}}} -->
    <div class="wp-block-columns alignwide" style="padding-top:40px"><!-- wp:column {"style":{"spacing":{"blockGap":"10px","padding":{"right":"30px","left":"30px","top":"30px","bottom":"30px"}}},"backgroundColor":"kubio-color-5","layout":{"type":"default"}} -->
    <div class="wp-block-column has-kubio-color-5-background-color has-background" style="padding-top:30px;padding-right:30px;padding-bottom:30px;padding-left:30px"><!-- wp:image {"width":"40px","sizeSlug":"full","linkDestination":"none","align":"center"} -->
    <figure class="wp-block-image aligncenter size-full is-resized"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-16.png" alt="" class="" style="width:40px"/></figure>
    <!-- /wp:image -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontSize":"16px","fontStyle":"normal","fontWeight":"300","lineHeight":1.6},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"spacing":{"padding":{"top":"20px"}}},"textColor":"kubio-color-6"} -->
    <p class="has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="padding-top:20px;font-size:16px;font-style:normal;font-weight:300;line-height:1.6">Lorem ipsum dolor sit amet, at mei dolore tritani repudiandae. In his nemore temporibus vim ad prima vivendum.</p>
    <!-- /wp:paragraph -->
    
    <!-- wp:heading {"textAlign":"center","style":{"typography":{"fontSize":"0.8em","fontStyle":"normal","fontWeight":"700","lineHeight":1.6,"textTransform":"uppercase"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}}},"textColor":"kubio-color-1"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-1-color has-text-color has-link-color" style="font-size:0.8em;font-style:normal;font-weight:700;line-height:1.6;text-transform:uppercase">Jane Doe</h2>
    <!-- /wp:heading -->
    
    <!-- wp:group {"style":{"spacing":{"margin":{"top":"var:preset|spacing|50","bottom":"-60px"}}},"layout":{"type":"constrained","justifyContent":"left"}} -->
    <div class="wp-block-group" style="margin-top:var(--wp--preset--spacing--50);margin-bottom:-60px"><!-- wp:image {"width":"70px","aspectRatio":"1","scale":"cover","sizeSlug":"full","linkDestination":"none","align":"center","style":{"spacing":{"margin":{"bottom":"var:preset|spacing|40"}}}} -->
    <figure class="wp-block-image aligncenter size-full is-resized" style="margin-bottom:var(--wp--preset--spacing--40)"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-17.jpg" alt="" class="" style="aspect-ratio:1;object-fit:cover;width:70px"/></figure>
    <!-- /wp:image --></div>
    <!-- /wp:group --></div>
    <!-- /wp:column -->
    
    <!-- wp:column {"style":{"spacing":{"blockGap":"10px","padding":{"right":"30px","left":"30px","top":"30px","bottom":"30px"}}},"backgroundColor":"kubio-color-5","layout":{"type":"default"}} -->
    <div class="wp-block-column has-kubio-color-5-background-color has-background" style="padding-top:30px;padding-right:30px;padding-bottom:30px;padding-left:30px"><!-- wp:image {"width":"40px","sizeSlug":"full","linkDestination":"none","align":"center"} -->
    <figure class="wp-block-image aligncenter size-full is-resized"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-16.png" alt="" class="" style="width:40px"/></figure>
    <!-- /wp:image -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontSize":"16px","fontStyle":"normal","fontWeight":"300","lineHeight":1.6},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"spacing":{"padding":{"top":"20px"}}},"textColor":"kubio-color-6"} -->
    <p class="has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="padding-top:20px;font-size:16px;font-style:normal;font-weight:300;line-height:1.6">Lorem ipsum dolor sit amet, at mei dolore tritani repudiandae. In his nemore temporibus vim ad prima vivendum.</p>
    <!-- /wp:paragraph -->
    
    <!-- wp:heading {"textAlign":"center","style":{"typography":{"fontSize":"0.8em","fontStyle":"normal","fontWeight":"700","lineHeight":1.6,"textTransform":"uppercase"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}}},"textColor":"kubio-color-1"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-1-color has-text-color has-link-color" style="font-size:0.8em;font-style:normal;font-weight:700;line-height:1.6;text-transform:uppercase">John Denver</h2>
    <!-- /wp:heading -->
    
    <!-- wp:group {"style":{"spacing":{"margin":{"top":"var:preset|spacing|50","bottom":"-60px"}}},"layout":{"type":"constrained","justifyContent":"left"}} -->
    <div class="wp-block-group" style="margin-top:var(--wp--preset--spacing--50);margin-bottom:-60px"><!-- wp:image {"width":"70px","aspectRatio":"1","scale":"cover","sizeSlug":"full","linkDestination":"none","align":"center","style":{"spacing":{"margin":{"bottom":"var:preset|spacing|40"}}}} -->
    <figure class="wp-block-image aligncenter size-full is-resized" style="margin-bottom:var(--wp--preset--spacing--40)"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-18.jpg" alt="" class="" style="aspect-ratio:1;object-fit:cover;width:70px"/></figure>
    <!-- /wp:image --></div>
    <!-- /wp:group --></div>
    <!-- /wp:column -->
    
    <!-- wp:column {"style":{"spacing":{"blockGap":"10px","padding":{"right":"30px","left":"30px","top":"30px","bottom":"30px"}}},"backgroundColor":"kubio-color-5","layout":{"type":"default"}} -->
    <div class="wp-block-column has-kubio-color-5-background-color has-background" style="padding-top:30px;padding-right:30px;padding-bottom:30px;padding-left:30px"><!-- wp:image {"width":"40px","sizeSlug":"full","linkDestination":"none","align":"center"} -->
    <figure class="wp-block-image aligncenter size-full is-resized"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-16.png" alt="" class="" style="width:40px"/></figure>
    <!-- /wp:image -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontSize":"16px","fontStyle":"normal","fontWeight":"300","lineHeight":1.6},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"spacing":{"padding":{"top":"20px"}}},"textColor":"kubio-color-6"} -->
    <p class="has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="padding-top:20px;font-size:16px;font-style:normal;font-weight:300;line-height:1.6">Lorem ipsum dolor sit amet, at mei dolore tritani repudiandae. In his nemore temporibus vim ad prima vivendum.</p>
    <!-- /wp:paragraph -->
    
    <!-- wp:heading {"textAlign":"center","style":{"typography":{"fontSize":"0.8em","fontStyle":"normal","fontWeight":"700","lineHeight":1.6,"textTransform":"uppercase"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}}},"textColor":"kubio-color-1"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-1-color has-text-color has-link-color" style="font-size:0.8em;font-style:normal;font-weight:700;line-height:1.6;text-transform:uppercase">Michelle Smith</h2>
    <!-- /wp:heading -->
    
    <!-- wp:group {"style":{"spacing":{"margin":{"top":"var:preset|spacing|50","bottom":"-60px"}}},"layout":{"type":"constrained","justifyContent":"left"}} -->
    <div class="wp-block-group" style="margin-top:var(--wp--preset--spacing--50);margin-bottom:-60px"><!-- wp:image {"width":"70px","aspectRatio":"1","scale":"cover","sizeSlug":"full","linkDestination":"none","align":"center","style":{"spacing":{"margin":{"bottom":"var:preset|spacing|40"}}}} -->
    <figure class="wp-block-image aligncenter size-full is-resized" style="margin-bottom:var(--wp--preset--spacing--40)"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-19.jpg" alt="" class="" style="aspect-ratio:1;object-fit:cover;width:70px"/></figure>
    <!-- /wp:image --></div>
    <!-- /wp:group --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns --></div>
    <!-- /wp:group -->
    
    <!-- wp:group {"metadata":{"name":"cta"},"align":"full","className":"kubio-starter-content-section","style":{"spacing":{"padding":{"top":"0","bottom":"0","right":"0","left":"0"},"margin":{"top":"0px","bottom":"0px"}}},"backgroundColor":"kubio-color-4","layout":{"type":"constrained"}} -->
    <div class="wp-block-group alignfull kubio-starter-content-section has-kubio-color-4-background-color has-background" id="cta" style="margin-top:0px;margin-bottom:0px;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:cover {"url":"<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-20.jpg","hasParallax":true,"dimRatio":70,"overlayColor":"kubio-color-6","isUserOverlayColor":true,"align":"full","style":{"spacing":{"padding":{"top":"var:preset|spacing|50","bottom":"var:preset|spacing|50","left":"var:preset|spacing|50","right":"var:preset|spacing|50"}}},"layout":{"type":"constrained"}} -->
    <div class="wp-block-cover alignfull has-parallax" style="padding-top:var(--wp--preset--spacing--50);padding-right:var(--wp--preset--spacing--50);padding-bottom:var(--wp--preset--spacing--50);padding-left:var(--wp--preset--spacing--50)"><span aria-hidden="true" class="wp-block-cover__background has-kubio-color-6-background-color has-background-dim-70 has-background-dim"></span><div class="wp-block-cover__image-background  has-parallax" style="background-position:50% 50%;background-image:url(<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-20.jpg)"></div><div class="wp-block-cover__inner-container"><!-- wp:group {"align":"wide","layout":{"type":"flex","orientation":"vertical","justifyContent":"center"}} -->
    <div class="wp-block-group alignwide"><!-- wp:heading {"textAlign":"center","style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-5"}}}},"textColor":"kubio-color-5","fontSize":"x-large"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-5-color has-text-color has-link-color has-x-large-font-size">What are you waiting for?</h2>
    <!-- /wp:heading -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontStyle":"normal","fontWeight":"500","fontSize":"1.2em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-5"}}},"spacing":{"padding":{"right":"var:preset|spacing|40","left":"var:preset|spacing|40"}}},"textColor":"kubio-color-5"} -->
    <p class="has-text-align-center has-kubio-color-5-color has-text-color has-link-color" style="padding-right:var(--wp--preset--spacing--40);padding-left:var(--wp--preset--spacing--40);font-size:1.2em;font-style:normal;font-weight:500">Ready to take the next step? Let’s bring your vision to life! Explore our services and get in touch today for a consultation. Together, we’ll make it happen.</p>
    <!-- /wp:paragraph -->
    
    <!-- wp:buttons {"layout":{"type":"flex","justifyContent":"center","flexWrap":"wrap","orientation":"vertical"}} -->
    <div class="wp-block-buttons"><!-- wp:button {"backgroundColor":"kubio-color-2","textColor":"kubio-color-5","style":{"border":{"radius":"0px"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-5"}}},"typography":{"textTransform":"uppercase","letterSpacing":"1px","fontSize":"14px","fontStyle":"normal","fontWeight":"300"},"spacing":{"padding":{"left":"40px","right":"40px","top":"20px","bottom":"20px"}}}} -->
    <div class="wp-block-button has-custom-font-size" style="font-size:14px;font-style:normal;font-weight:300;letter-spacing:1px;text-transform:uppercase"><a class="wp-block-button__link has-kubio-color-5-color has-kubio-color-2-background-color has-text-color has-background has-link-color wp-element-button" style="border-radius:0px;padding-top:20px;padding-right:40px;padding-bottom:20px;padding-left:40px">Contact us</a></div>
    <!-- /wp:button --></div>
    <!-- /wp:buttons --></div>
    <!-- /wp:group --></div></div>
    <!-- /wp:cover --></div>
    <!-- /wp:group -->
    
    <!-- wp:group {"metadata":{"name":"team"},"align":"full","className":"kubio-starter-content-section","style":{"spacing":{"padding":{"top":"90px","bottom":"90px","right":"20px","left":"20px"},"blockGap":"0px","margin":{"top":"0px","bottom":"0px"}}},"backgroundColor":"kubio-color-5-variant-2","layout":{"type":"constrained"}} -->
    <div class="wp-block-group alignfull kubio-starter-content-section has-kubio-color-5-variant-2-background-color has-background" id="team" style="margin-top:0px;margin-bottom:0px;padding-top:90px;padding-right:20px;padding-bottom:90px;padding-left:20px"><!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"40","left":"40"}}}} -->
    <div class="wp-block-columns alignwide"><!-- wp:column {"verticalAlignment":"center","width":"","style":{"spacing":{"blockGap":"20px","padding":{"bottom":"var:preset|spacing|50","right":"0","left":"0","top":"0"}}}} -->
    <div class="wp-block-column is-vertically-aligned-center" style="padding-top:0;padding-right:0;padding-bottom:var(--wp--preset--spacing--50);padding-left:0"><!-- wp:heading {"textAlign":"center","style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6","fontSize":"x-large"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-6-color has-text-color has-link-color has-x-large-font-size">Our team</h2>
    <!-- /wp:heading -->
    
    <!-- wp:group {"style":{"spacing":{"padding":{"right":"0","left":"0","top":"0","bottom":"0"},"blockGap":"0","margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}}},"layout":{"type":"flex","flexWrap":"nowrap","justifyContent":"center"}} -->
    <div class="wp-block-group" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40);padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:separator {"className":"is-style-default","style":{"spacing":{"margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}},"layout":{"selfStretch":"fixed","flexSize":"20%"}},"backgroundColor":"kubio-color-1"} -->
    <hr class="wp-block-separator has-text-color has-kubio-color-1-color has-alpha-channel-opacity has-kubio-color-1-background-color has-background is-style-default" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40)"/>
    <!-- /wp:separator --></div>
    <!-- /wp:group -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontStyle":"normal","fontWeight":"500","fontSize":"1.2em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"spacing":{"padding":{"right":"var:preset|spacing|40","left":"var:preset|spacing|40"}}},"textColor":"kubio-color-6"} -->
    <p class="has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="padding-right:var(--wp--preset--spacing--40);padding-left:var(--wp--preset--spacing--40);font-size:1.2em;font-style:normal;font-weight:500">Lorem ipsum dolor sit amet, at mei dolore tritani repudiandae. In his nemore temporibus consequuntur, vim ad prima vivendum consetetur.</p>
    <!-- /wp:paragraph --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns -->
    
    <!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"4.5em","left":"4.5em"}}}} -->
    <div class="wp-block-columns alignwide"><!-- wp:column {"style":{"spacing":{"blockGap":"10px","padding":{"top":"var:preset|spacing|50"}}},"layout":{"type":"default"}} -->
    <div class="wp-block-column" style="padding-top:var(--wp--preset--spacing--50)"><!-- wp:image {"width":"150px","aspectRatio":"1","scale":"cover","sizeSlug":"full","linkDestination":"none","align":"center"} -->
    <figure class="wp-block-image aligncenter size-full is-resized"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-21.jpg" alt="" class="" style="aspect-ratio:1;object-fit:cover;width:150px"/></figure>
    <!-- /wp:image -->
    
    <!-- wp:heading {"textAlign":"center","style":{"typography":{"fontSize":"1.3em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"spacing":{"padding":{"top":"20px"}}},"textColor":"kubio-color-6"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="padding-top:20px;font-size:1.3em">Gilbert Fletche</h2>
    <!-- /wp:heading -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontSize":"0.8em","fontStyle":"normal","fontWeight":"700","lineHeight":1.6,"textTransform":"uppercase"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}}},"textColor":"kubio-color-1"} -->
    <p class="has-text-align-center has-kubio-color-1-color has-text-color has-link-color" style="font-size:0.8em;font-style:normal;font-weight:700;line-height:1.6;text-transform:uppercase">Financial Strategist</p>
    <!-- /wp:paragraph -->
    
    <!-- wp:social-links {"iconColor":"kubio-color-6","iconColorValue":"rgb(18, 19, 21)","className":"is-style-logos-only","style":{"spacing":{"blockGap":{"top":"15px","left":"15px"},"margin":{"top":"var:preset|spacing|50"}}},"layout":{"type":"flex","justifyContent":"center"}} -->
    <ul class="wp-block-social-links has-icon-color is-style-logos-only" style="margin-top:var(--wp--preset--spacing--50)"><!-- wp:social-link {"url":"#","service":"instagram","label":"#"} /-->
    
    <!-- wp:social-link {"url":"#","service":"facebook","label":"#"} /-->
    
    <!-- wp:social-link {"url":"#","service":"whatsapp","label":"#"} /--></ul>
    <!-- /wp:social-links --></div>
    <!-- /wp:column -->
    
    <!-- wp:column {"style":{"spacing":{"blockGap":"10px","padding":{"top":"var:preset|spacing|50"}}},"layout":{"type":"default"}} -->
    <div class="wp-block-column" style="padding-top:var(--wp--preset--spacing--50)"><!-- wp:image {"width":"150px","aspectRatio":"1","scale":"cover","sizeSlug":"full","linkDestination":"none","align":"center"} -->
    <figure class="wp-block-image aligncenter size-full is-resized"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-22.jpg" alt="" class="" style="aspect-ratio:1;object-fit:cover;width:150px"/></figure>
    <!-- /wp:image -->
    
    <!-- wp:heading {"textAlign":"center","style":{"typography":{"fontSize":"1.3em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"spacing":{"padding":{"top":"20px"}}},"textColor":"kubio-color-6"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="padding-top:20px;font-size:1.3em">Olivia Rodriguez</h2>
    <!-- /wp:heading -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontSize":"0.8em","fontStyle":"normal","fontWeight":"700","lineHeight":1.6,"textTransform":"uppercase"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}}},"textColor":"kubio-color-1"} -->
    <p class="has-text-align-center has-kubio-color-1-color has-text-color has-link-color" style="font-size:0.8em;font-style:normal;font-weight:700;line-height:1.6;text-transform:uppercase">Financial Analyst</p>
    <!-- /wp:paragraph -->
    
    <!-- wp:social-links {"iconColor":"kubio-color-6","iconColorValue":"rgb(18, 19, 21)","className":"is-style-logos-only","style":{"spacing":{"blockGap":{"top":"15px","left":"15px"},"margin":{"top":"var:preset|spacing|50"}}},"layout":{"type":"flex","justifyContent":"center"}} -->
    <ul class="wp-block-social-links has-icon-color is-style-logos-only" style="margin-top:var(--wp--preset--spacing--50)"><!-- wp:social-link {"url":"#","service":"instagram","label":"#"} /-->
    
    <!-- wp:social-link {"url":"#","service":"facebook","label":"#"} /-->
    
    <!-- wp:social-link {"url":"#","service":"whatsapp","label":"#"} /--></ul>
    <!-- /wp:social-links --></div>
    <!-- /wp:column -->
    
    <!-- wp:column {"style":{"spacing":{"blockGap":"10px","padding":{"top":"var:preset|spacing|50"}}},"layout":{"type":"default"}} -->
    <div class="wp-block-column" style="padding-top:var(--wp--preset--spacing--50)"><!-- wp:image {"width":"150px","aspectRatio":"1","scale":"cover","sizeSlug":"full","linkDestination":"none","align":"center"} -->
    <figure class="wp-block-image aligncenter size-full is-resized"><img src="<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-23.jpg" alt="" class="" style="aspect-ratio:1;object-fit:cover;width:150px"/></figure>
    <!-- /wp:image -->
    
    <!-- wp:heading {"textAlign":"center","style":{"typography":{"fontSize":"1.3em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"spacing":{"padding":{"top":"20px"}}},"textColor":"kubio-color-6"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="padding-top:20px;font-size:1.3em">Johnny Rodriguez</h2>
    <!-- /wp:heading -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontSize":"0.8em","fontStyle":"normal","fontWeight":"700","lineHeight":1.6,"textTransform":"uppercase"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}}},"textColor":"kubio-color-1"} -->
    <p class="has-text-align-center has-kubio-color-1-color has-text-color has-link-color" style="font-size:0.8em;font-style:normal;font-weight:700;line-height:1.6;text-transform:uppercase">Financial Analyst</p>
    <!-- /wp:paragraph -->
    
    <!-- wp:social-links {"iconColor":"kubio-color-6","iconColorValue":"rgb(18, 19, 21)","className":"is-style-logos-only","style":{"spacing":{"blockGap":{"top":"15px","left":"15px"},"margin":{"top":"var:preset|spacing|50"}}},"layout":{"type":"flex","justifyContent":"center"}} -->
    <ul class="wp-block-social-links has-icon-color is-style-logos-only" style="margin-top:var(--wp--preset--spacing--50)"><!-- wp:social-link {"url":"#","service":"instagram","label":"#"} /-->
    
    <!-- wp:social-link {"url":"#","service":"facebook","label":"#"} /-->
    
    <!-- wp:social-link {"url":"#","service":"whatsapp","label":"#"} /--></ul>
    <!-- /wp:social-links --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns --></div>
    <!-- /wp:group -->
    
    <!-- wp:group {"metadata":{"name":"work-in-numbers"},"align":"full","className":"kubio-starter-content-section","style":{"spacing":{"padding":{"right":"20px","left":"20px","top":"90px","bottom":"90px"}}},"layout":{"type":"constrained"}} -->
    <div class="wp-block-group alignfull kubio-starter-content-section" id="work-in-numbers" style="padding-top:90px;padding-right:20px;padding-bottom:90px;padding-left:20px"><!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"40","left":"40"}}}} -->
    <div class="wp-block-columns alignwide"><!-- wp:column {"verticalAlignment":"center","width":"","style":{"spacing":{"blockGap":"20px","padding":{"bottom":"30px"}}},"layout":{"type":"default"}} -->
    <div class="wp-block-column is-vertically-aligned-center" style="padding-bottom:30px"><!-- wp:heading {"textAlign":"center","style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6","fontSize":"x-large"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-6-color has-text-color has-link-color has-x-large-font-size">Our work in numbers</h2>
    <!-- /wp:heading -->
    
    <!-- wp:group {"style":{"spacing":{"padding":{"right":"0","left":"0","top":"0","bottom":"0"},"blockGap":"0","margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}}},"layout":{"type":"flex","flexWrap":"nowrap","justifyContent":"center"}} -->
    <div class="wp-block-group" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40);padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:separator {"className":"is-style-default","style":{"spacing":{"margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}},"layout":{"selfStretch":"fixed","flexSize":"20%"}},"backgroundColor":"kubio-color-1"} -->
    <hr class="wp-block-separator has-text-color has-kubio-color-1-color has-alpha-channel-opacity has-kubio-color-1-background-color has-background is-style-default" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40)"/>
    <!-- /wp:separator --></div>
    <!-- /wp:group -->
    
    <!-- wp:paragraph {"align":"center","style":{"typography":{"fontStyle":"normal","fontWeight":"500","fontSize":"1.2em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"spacing":{"padding":{"right":"var:preset|spacing|40","left":"var:preset|spacing|40"}}},"textColor":"kubio-color-6"} -->
    <p class="has-text-align-center has-kubio-color-6-color has-text-color has-link-color" style="padding-right:var(--wp--preset--spacing--40);padding-left:var(--wp--preset--spacing--40);font-size:1.2em;font-style:normal;font-weight:500">Lorem ipsum dolor sit amet, at mei dolore tritani repudiandae. In his nemore temporibus consequuntur, vim ad prima vivendum consetetur.</p>
    <!-- /wp:paragraph --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns -->
    
    <!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"var:preset|spacing|50","left":"var:preset|spacing|50"},"margin":{"top":"0","bottom":"0"}}}} -->
    <div class="wp-block-columns alignwide" style="margin-top:0;margin-bottom:0"><!-- wp:column {"style":{"spacing":{"blockGap":"0","padding":{"right":"var:preset|spacing|30","left":"var:preset|spacing|30","top":"var:preset|spacing|30","bottom":"0"}}},"layout":{"type":"default"}} -->
    <div class="wp-block-column" style="padding-top:var(--wp--preset--spacing--30);padding-right:var(--wp--preset--spacing--30);padding-bottom:0;padding-left:var(--wp--preset--spacing--30)"><!-- wp:heading {"textAlign":"center","level":6,"style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}}},"textColor":"kubio-color-1"} -->
    <h6 class="wp-block-heading has-text-align-center has-kubio-color-1-color has-text-color has-link-color">employees</h6>
    <!-- /wp:heading -->
    
    <!-- wp:paragraph {"align":"center","fontSize":"xx-large"} -->
    <p class="has-text-align-center has-xx-large-font-size">230</p>
    <!-- /wp:paragraph --></div>
    <!-- /wp:column -->
    
    <!-- wp:column {"style":{"spacing":{"blockGap":"0","padding":{"right":"var:preset|spacing|30","left":"var:preset|spacing|30","top":"var:preset|spacing|30","bottom":"0"}}},"layout":{"type":"default"}} -->
    <div class="wp-block-column" style="padding-top:var(--wp--preset--spacing--30);padding-right:var(--wp--preset--spacing--30);padding-bottom:0;padding-left:var(--wp--preset--spacing--30)"><!-- wp:heading {"textAlign":"center","level":6,"style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}}},"textColor":"kubio-color-1"} -->
    <h6 class="wp-block-heading has-text-align-center has-kubio-color-1-color has-text-color has-link-color">happy clients</h6>
    <!-- /wp:heading -->
    
    <!-- wp:paragraph {"align":"center","fontSize":"xx-large"} -->
    <p class="has-text-align-center has-xx-large-font-size">+3M</p>
    <!-- /wp:paragraph --></div>
    <!-- /wp:column -->
    
    <!-- wp:column {"style":{"spacing":{"blockGap":"0","padding":{"top":"var:preset|spacing|30","bottom":"0","left":"var:preset|spacing|30","right":"var:preset|spacing|30"}}},"layout":{"type":"default"}} -->
    <div class="wp-block-column" style="padding-top:var(--wp--preset--spacing--30);padding-right:var(--wp--preset--spacing--30);padding-bottom:0;padding-left:var(--wp--preset--spacing--30)"><!-- wp:heading {"textAlign":"center","level":6,"style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}}},"textColor":"kubio-color-1"} -->
    <h6 class="wp-block-heading has-text-align-center has-kubio-color-1-color has-text-color has-link-color">years of experience</h6>
    <!-- /wp:heading -->
    
    <!-- wp:paragraph {"align":"center","fontSize":"xx-large"} -->
    <p class="has-text-align-center has-xx-large-font-size">+25</p>
    <!-- /wp:paragraph --></div>
    <!-- /wp:column -->
    
    <!-- wp:column {"style":{"spacing":{"blockGap":"0","padding":{"top":"var:preset|spacing|30","bottom":"0","left":"var:preset|spacing|30","right":"var:preset|spacing|30"}}},"layout":{"type":"default"}} -->
    <div class="wp-block-column" style="padding-top:var(--wp--preset--spacing--30);padding-right:var(--wp--preset--spacing--30);padding-bottom:0;padding-left:var(--wp--preset--spacing--30)"><!-- wp:heading {"textAlign":"center","level":6,"style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}}},"textColor":"kubio-color-1"} -->
    <h6 class="wp-block-heading has-text-align-center has-kubio-color-1-color has-text-color has-link-color">offices worldwide</h6>
    <!-- /wp:heading -->
    
    <!-- wp:paragraph {"align":"center","fontSize":"xx-large"} -->
    <p class="has-text-align-center has-xx-large-font-size">179</p>
    <!-- /wp:paragraph --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns --></div>
    <!-- /wp:group -->
    
    <!-- wp:group {"metadata":{"name":"blog"},"align":"full","className":"kubio-starter-content-section","style":{"spacing":{"padding":{"top":"5rem","bottom":"5rem","right":"20px","left":"20px"},"blockGap":"0px","margin":{"top":"0px","bottom":"0px"}}},"backgroundColor":"kubio-color-5-variant-2","layout":{"type":"constrained"}} -->
    <div class="wp-block-group alignfull kubio-starter-content-section has-kubio-color-5-variant-2-background-color has-background" id="blog" style="margin-top:0px;margin-bottom:0px;padding-top:5rem;padding-right:20px;padding-bottom:5rem;padding-left:20px"><!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"40","left":"40"}}}} -->
    <div class="wp-block-columns alignwide"><!-- wp:column {"verticalAlignment":"center","width":"","style":{"spacing":{"blockGap":"20px","padding":{"bottom":"30px"}}},"layout":{"type":"default"}} -->
    <div class="wp-block-column is-vertically-aligned-center" style="padding-bottom:30px"><!-- wp:heading {"textAlign":"center","style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6","fontSize":"x-large"} -->
    <h2 class="wp-block-heading has-text-align-center has-kubio-color-6-color has-text-color has-link-color has-x-large-font-size">Explore Our Blog</h2>
    <!-- /wp:heading -->
    
    <!-- wp:group {"style":{"spacing":{"padding":{"right":"0","left":"0","top":"0","bottom":"0"},"blockGap":"0","margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}}},"layout":{"type":"flex","flexWrap":"nowrap","justifyContent":"center"}} -->
    <div class="wp-block-group" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40);padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:separator {"className":"is-style-default","style":{"spacing":{"margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}},"layout":{"selfStretch":"fixed","flexSize":"20%"}},"backgroundColor":"kubio-color-1"} -->
    <hr class="wp-block-separator has-text-color has-kubio-color-1-color has-alpha-channel-opacity has-kubio-color-1-background-color has-background is-style-default" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40)"/>
    <!-- /wp:separator --></div>
    <!-- /wp:group --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns -->
    
    <!-- wp:columns {"align":"wide","style":{"spacing":{"blockGap":{"top":"2em","left":"2em"},"margin":{"top":"2em","bottom":"2em"}}}} -->
    <div class="wp-block-columns alignwide" style="margin-top:2em;margin-bottom:2em"><!-- wp:column {"layout":{"type":"default"}} -->
    <div class="wp-block-column"><!-- wp:query {"queryId":11,"query":{"perPage":6,"pages":0,"offset":0,"postType":"post","order":"desc","orderBy":"date","author":"","search":"","exclude":[],"sticky":"exclude","inherit":false},"metadata":{"categories":["posts"],"patternName":"core/query-grid-posts","name":"Grid"}} -->
    <div class="wp-block-query"><!-- wp:post-template {"style":{"spacing":{"blockGap":"30px"}},"layout":{"type":"grid","columnCount":3}} -->
    <!-- wp:group {"style":{"spacing":{"padding":{"top":"0","right":"0","bottom":"0","left":"0"},"blockGap":"var:preset|spacing|50","margin":{"top":"0","bottom":"0"}},"border":{"width":"0px","style":"none"}},"backgroundColor":"kubio-color-5","layout":{"type":"constrained","justifyContent":"left"}} -->
    <div class="wp-block-group has-kubio-color-5-background-color has-background" style="border-style:none;border-width:0px;margin-top:0;margin-bottom:0;padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:post-featured-image {"isLink":true,"aspectRatio":"4/3","linkTarget":"_blank","style":{"spacing":{"margin":{"right":"0","left":"0","top":"0","bottom":"0"},"padding":{"right":"0","left":"0","top":"0","bottom":"0"}}}} /-->
    
    <!-- wp:columns -->
    <div class="wp-block-columns"><!-- wp:column {"style":{"spacing":{"padding":{"right":"var:preset|spacing|50","left":"var:preset|spacing|50","top":"var:preset|spacing|50","bottom":"var:preset|spacing|50"},"blockGap":"var:preset|spacing|20"}}} -->
    <div class="wp-block-column" style="padding-top:var(--wp--preset--spacing--50);padding-right:var(--wp--preset--spacing--50);padding-bottom:var(--wp--preset--spacing--50);padding-left:var(--wp--preset--spacing--50)"><!-- wp:post-title {"isLink":true,"style":{"typography":{"fontSize":"1.5em","fontStyle":"normal","fontWeight":"500"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"},":hover":{"color":{"text":"var:preset|color|kubio-color-1"}}}}},"textColor":"kubio-color-6"} /-->
    
    <!-- wp:post-date {"style":{"elements":{"link":{"color":{"text":"#1212145e"}}},"typography":{"fontSize":"14px","fontStyle":"normal","fontWeight":"500"},"color":{"text":"#1212145e"}}} /-->
    
    <!-- wp:post-excerpt {"moreText":"\u003cstrong\u003eRead more\u003c/strong\u003e","excerptLength":17,"style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-1"}}},"spacing":{"margin":{"top":"var:preset|spacing|50"}}},"textColor":"kubio-color-6"} /--></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns --></div>
    <!-- /wp:group -->
    <!-- /wp:post-template --></div>
    <!-- /wp:query --></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns --></div>
    <!-- /wp:group -->
    
    <!-- wp:cover {"url":"<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-24.jpg","hasParallax":true,"dimRatio":70,"overlayColor":"kubio-color-6","isUserOverlayColor":true,"minHeight":700,"metadata":{"name":"contact"},"align":"full","className":"kubio-starter-content-section","style":{"spacing":{"padding":{"top":"var:preset|spacing|70","bottom":"var:preset|spacing|70","left":"var:preset|spacing|40","right":"var:preset|spacing|40"}}},"layout":{"type":"constrained"}} -->
    <div class="wp-block-cover alignfull has-parallax kubio-starter-content-section" style="padding-top:var(--wp--preset--spacing--70);padding-right:var(--wp--preset--spacing--40);padding-bottom:var(--wp--preset--spacing--70);padding-left:var(--wp--preset--spacing--40);min-height:700px" id="contact"><span aria-hidden="true" class="wp-block-cover__background has-kubio-color-6-background-color has-background-dim-70 has-background-dim"></span><div class="wp-block-cover__image-background  has-parallax" style="background-position:50% 50%;background-image:url(<?php echo esc_url(get_template_directory_uri()); ?>/starter-content/media/image-24.jpg)"></div><div class="wp-block-cover__inner-container"><!-- wp:columns {"align":"wide","style":{"border":{"radius":"0px"},"spacing":{"padding":{"top":"var:preset|spacing|60","bottom":"var:preset|spacing|60","left":"var:preset|spacing|60","right":"var:preset|spacing|60"},"blockGap":{"top":"var:preset|spacing|40","left":"var:preset|spacing|40"},"margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}}},"backgroundColor":"kubio-color-5"} -->
    <div class="wp-block-columns alignwide has-kubio-color-5-background-color has-background" style="border-radius:0px;margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40);padding-top:var(--wp--preset--spacing--60);padding-right:var(--wp--preset--spacing--60);padding-bottom:var(--wp--preset--spacing--60);padding-left:var(--wp--preset--spacing--60)"><!-- wp:column {"style":{"spacing":{"padding":{"right":"0","left":"0","top":"0","bottom":"0"},"blockGap":"var:preset|spacing|30"}}} -->
    <div class="wp-block-column" style="padding-top:0;padding-right:0;padding-bottom:0;padding-left:0"><!-- wp:heading {"style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6","fontSize":"x-large"} -->
    <h2 class="wp-block-heading has-kubio-color-6-color has-text-color has-link-color has-x-large-font-size">Contact us</h2>
    <!-- /wp:heading -->
    
    <!-- wp:group {"style":{"spacing":{"padding":{"right":"0","top":"0","bottom":"0"}}},"layout":{"type":"flex","flexWrap":"nowrap"}} -->
    <div class="wp-block-group" style="padding-top:0;padding-right:0;padding-bottom:0"><!-- wp:separator {"className":"is-style-default","style":{"spacing":{"margin":{"top":"var:preset|spacing|40","bottom":"var:preset|spacing|40"}},"layout":{"selfStretch":"fixed","flexSize":"25%"}},"backgroundColor":"kubio-color-1"} -->
    <hr class="wp-block-separator has-text-color has-kubio-color-1-color has-alpha-channel-opacity has-kubio-color-1-background-color has-background is-style-default" style="margin-top:var(--wp--preset--spacing--40);margin-bottom:var(--wp--preset--spacing--40)"/>
    <!-- /wp:separator --></div>
    <!-- /wp:group -->
    
    <!-- wp:paragraph {"style":{"typography":{"fontStyle":"normal","fontWeight":"500","fontSize":"1.2em"},"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"spacing":{"padding":{"right":"0","left":"0"}}},"textColor":"kubio-color-6"} -->
    <p class="has-kubio-color-6-color has-text-color has-link-color" style="padding-right:0;padding-left:0;font-size:1.2em;font-style:normal;font-weight:500">Lorem ipsum dolor sit amet, at mei dolore tritani in his nemore temporibus consequuntur, vim ad prima vivendum consetetur. Viderer feugiat at pro, mea.</p>
    <!-- /wp:paragraph -->
    
    <!-- wp:list {"style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}},"typography":{"fontSize":"18px","fontStyle":"normal","fontWeight":"400","lineHeight":"2.2"},"spacing":{"padding":{"top":"15px","right":"15px","bottom":"15px","left":"15px"}}},"textColor":"kubio-color-6"} -->
    <ul style="padding-top:15px;padding-right:15px;padding-bottom:15px;padding-left:15px;font-size:18px;font-style:normal;font-weight:400;line-height:2.2" id="block-be62aa32-e641-4036-a640-5d3389a55005" class="wp-block-list has-kubio-color-6-color has-text-color has-link-color"><!-- wp:list-item -->
    <li><a>425-334-5956</a></li>
    <!-- /wp:list-item -->
    
    <!-- wp:list-item -->
    <li><a>youremail@address.com</a></li>
    <!-- /wp:list-item -->
    
    <!-- wp:list-item -->
    <li><a>4923 Ryder Avenue, NY</a></li>
    <!-- /wp:list-item --></ul>
    <!-- /wp:list --></div>
    <!-- /wp:column -->
    
    <!-- wp:column {"verticalAlignment":"center"} -->
    <div class="wp-block-column is-vertically-aligned-center"><!-- wp:paragraph {"align":"center","style":{"elements":{"link":{"color":{"text":"var:preset|color|kubio-color-6"}}}},"textColor":"kubio-color-6"} -->
    <p class="has-text-align-center has-kubio-color-6-color has-text-color has-link-color">Add a contact form shortcode</p>
    <!-- /wp:paragraph -->
    
    <!-- wp:shortcode /--></div>
    <!-- /wp:column --></div>
    <!-- /wp:columns --></div></div>
    <!-- /wp:cover -->
