/* ----------------------------------------------------------------------------
 * Info Page CSS
 * ------------------------------------------------------------------------- */
/* New Logo */
.wp-badge.epsilon-info-logo {
    background-color: #fff;
    background-image: url(../images/logo.png);
    background-position: center center;
    background-size: 70%;
    background-repeat: no-repeat;
}

/*nav tab font size*/
.about-wrap.info-wrap .nav-tab {
    font-size: 14px;
}

/* proper positioning of the icons */
.epsilon-wrap i.dashicons {
    margin-right: 15px;
    position: relative;
    top: 3px;
}

.action-recommended span.hooray {
    padding: 10px;
    display: inline-block;
}

#reset-all {
    position: relative;
}

.action-recommended span.red {
    color: #a00;
}

.at-theme-info-action-recommended-box {
    background: #fff;
    border-left: 4px solid #f8800c;
    display: block;
    margin-bottom: 15px;
    padding: 10px 30px;
    position: relative;
    -webkit-box-shadow: 0 1px 1px 0 rgba(0, 0, 0, .1);
    -moz-box-shadow: 0 1px 1px 0 rgba(0, 0, 0, .1);
    box-shadow: 0 1px 1px 0 rgba(0, 0, 0, .1);
}

.at-theme-info-action-recommended-box.done {
    border-left: 4px solid #46b450;
}

.action-recommended .at-theme-info-action-recommended-box:last-of-type {
    margin-bottom: 0;
}

.about-wrap.info-wrap .changelog.point-releases h3 {
    padding-top: 0;
}

.info-wrap .at-theme-info-action-recommended-box h4 {
    display: block;
    margin-top: 0;
    margin-bottom: 0;
}

.info-wrap .at-theme-info-action-recommended-box p {
    display: block;
    margin-top: 0;
    width: 100%;
    max-width: 100%;
}

.info-wrap .at-theme-info-dismiss-required-action {
    position: absolute;
    top: 10px;
    right: 10px;
    text-decoration: none;
    color: #d54e21;
    border-radius: 50%;
    cursor: pointer;
}

.info-wrap .at-theme-info-recommended-action-button {
    position: absolute;
    top: 10px;
    right: 10px;
    text-decoration: none;
    color: #b4b9be;
    border-radius: 50%;
    cursor: pointer;
}

.info-wrap .at-theme-info-recommended-action-button:hover:before {
    color: #c00;
}

.info-wrap .feature-section {
    padding: 40px 0 0;
}

.info-wrap .feature-section .col {
    margin-top: 0;
    margin-bottom: 5%;
}

.info-wrap .feature-section .col:nth-child(3n + 1) {
    clear: both;
}

#free_pro .free-pro-table {
    border-spacing: 0;
    width: 100%;
}

#free_pro .free-pro-table th {
    padding-bottom: 20px;
}

#free_pro .free-pro-table td {
    border-top: 1px solid #ccc;
    padding: 20px 0 25px;
}

#free_pro .free-pro-table h3 {
    margin: 0;
}

#free_pro .free-pro-table td p {
    margin: 0;
}

#free_pro .free-pro-table .only-lite,
#free_pro .free-pro-table .only-pro {
    text-align: center;
    width: 15%;
}

#free_pro .free-pro-table .only-lite .dashicons-before:before {
    color: #46b450;
}

#free_pro .free-pro-table .only-pro .dashicons-before:before {
    color: #d54e21;
}

#free_pro .free-pro-table .only-lite .dashicons-before:before,
#free_pro .free-pro-table .only-pro .dashicons-before:before {
    font-size: 35px;
    height: 35px;
    width: 35px;
}

#free_pro .at-theme-info-text-center {
    text-align: center;
}

.badge-action-count {
    padding: 0 6px;
    display: inline-block;
    background-color: #d54e21;
    color: #fff;
    font-size: 9px;
    line-height: 17px;
    font-weight: 600;
    margin: 1px 0 0 2px;
    vertical-align: top;
    -webkit-border-radius: 10px;
    border-radius: 10px;
    z-index: 26;
    margin-top: 5px;
    margin-left: 5px;
}

.wp-submenu .badge-action-count {
    margin-top: 0;
}

.plugin_box {
    height: 330px;
    margin-top: 15px;
    text-align: center;
    background: #FFF;
    position: relative;
    border: 1px solid rgba(0, 0, 0, .1);
    float: left;
}

.plugin_box .recommended {
    background: #d25637;
    color: #FFF;
    text-transform: uppercase;
    height: 28px;
    text-align: center;
    top: 0;
    left: 0;
    right: 0;
    line-height: 28px;
    font-size: 10px;
    position: absolute;
    font-weight: bold;
}

.plugin_box img {
    width: 155px;
    height: 155px;
    padding-top: 50px;
    margin: 0 auto;
    margin-bottom: 15px;
    display: block;
    border: none;
}

.plugin_box .action_bar {
    position: absolute;
    bottom: 0;
    left: 0;
    right: 0;
    font-size: 15px;
    font-weight: 600;
    height: 18px;
    margin: 0;
    padding: 15px;
    -webkit-box-shadow: inset 0 1px 0 rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 0 rgba(0, 0, 0, .1);
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
    background: #fff;
    background: rgba(255, 255, 255, .65);
    text-align: left;
    padding-right: 105px;
}

.plugin_box .action_bar.active {
    background: #23282d;
    color: #FFF;
}

.plugin_box .action_button {
    position: absolute;
    bottom: -1px;
    right: -1px;
    padding: 9px 10px 10px;
    background: #f6f6f6;
    border: 1px solid rgba(0, 0, 0, .1);
}

.plugin_box .action_button.active {
    background: #2c2e2f;
    bottom: 0;
    right: -1px;
    padding: 9px 10px 9px;
}

.info-wrap .three-col .plugin_box.col {
    box-sizing: border-box;
    float: left;
    width: 30%;
}

.at-theme-info-media-control img {
    width: 100%;
}

#demo_content .spinner {
    float: none;
}

#demo_content .updated-message,
#demo_content .spinner {
    display: none;
}

#demo_content .spinner.is-active {
    display: inline-block;
}

#child-themes {
    padding: 40px 0;
}

.at-about-child-theme {
    width: 32%;
    margin-right: 1.3%;
    margin-bottom: 40px;
    display: inline-block;
    border: 1px solid #ddd;
    -webkit-box-shadow: 0 1px 1px -1px rgba(0, 0, 0, .1);
    box-shadow: 0 1px 1px -1px rgba(0, 0, 0, .1);
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
}

.at-about-child-theme:last-child {
    margin-right: 0;
}

.at-theme-info-child-theme-details {
    font-size: 15px;
    font-weight: 600;
    height: 18px;
    margin: 0;
    padding: 10px 15px 20px 15px;
    -webkit-box-shadow: inset 0 1px 0 rgba(0, 0, 0, .1);
    box-shadow: inset 0 1px 0 rgba(0, 0, 0, .1);
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
    background: #fff;
    background: rgba(255, 255, 255, .65);
}

.at-about-child-theme .theme-name {
    max-width: 120px;
    padding-top: 5px;
    float: left;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}

.at-about-child-theme .button.preview {
    margin-right: 5px;
}

/*faq*/
.col-full {
    max-width: 55em;
}

.faq-content {
    display: none;
}

h3.faq-title {
    cursor: pointer;
    position: relative;
}

h3.faq-title::after {
    content: "\f140";
    font-family: dashicons;
}

/*changelog*/
pre.changelog {
    background-color: #f5f5f5;
    background-image: linear-gradient(#f5f5f5 50%, #e6e6e6 50%);
    background-size: 38px 38px;
    border: 1px solid #d4d4d4;
    display: block;
    font-size: 12px;
    line-height: 19px;
    overflow-x: visible;
    overflow-y: hidden;
    margin: 40px 0 0;
    padding: 10px;
}

/*getting started*/
.at-gsm-notice {
    margin-top: 30px;
    margin-bottom: 30px;
}

.plugin-install-notice {
    display: block;
    font-size: 12px;
    color: #72777c;
}

.at-gsm-notice a.at-gsm-btn:before {
    margin: -2px 5px 0 -2px;
    vertical-align: middle;
}