<?php return array (
  0 => 
  array (
    'image' => '%s/header-1-preview.jpg',
    'data' => 
    array (
      'front-header.logo.props.layoutType' => 'text',
      'front-header.header-menu.edit' => '',
      'front-header.header-menu.style.descendants.innerMenu.justifyContent' => 'center',
      'front-header.header-menu.props.showOffscreenMenuOn' => 'has-offcanvas-mobile',
      'front-header.header-menu.props.hoverEffect.type' => 'bordered-active-item bordered-active-item--bottom',
      'front-header.header-menu.props.hoverEffect.activeGroup' => 'border',
      'front-header.header-menu.props.hoverEffect.group.border.transition' => 'effect-borders-grow grow-from-left',
      'front-header.hero.props.heroSection.layout' => 'textOnly',
      'front-header.hero.hero_column_width' => 90,
      'front-header.hero.full_height' => true,
      'front-header.hero.style.descendants.outer.background.color' => 'rgba(234,234,234,0.5)',
      'front-header.hero.style.descendants.outer.background.type' => 'image',
      'front-header.hero.style.descendants.outer.background.image.0.source.url' => '%s/../images/background-image.jpg',
      'front-header.hero.style.descendants.outer.background.image.0.position' => 'center center',
      'front-header.hero.style.descendants.outer.background.image.0.attachment' => 'scroll',
      'front-header.hero.style.descendants.outer.background.image.0.repeat' => 'no-repeat',
      'front-header.hero.style.descendants.outer.background.image.0.size' => 'cover',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient' => 
      array (
        'name' => 'night_fade',
        'angle' => '0',
        'steps' => 
        array (
          0 => 
          array (
            'color' => '#a18cd1',
            'position' => '0',
          ),
          1 => 
          array (
            'color' => '#fbc2eb',
            'position' => '100',
          ),
        ),
      ),
      'front-header.hero.style.descendants.outer.background.slideshow.slides' => 
      array (
        0 => 
        array (
          'url' => '%s/images/beach-landscape-sea-water-nature-sand-1061655-pxhere.com.jpg',
          'index' => 0,
        ),
        1 => 
        array (
          'url' => '%s/images/landscape-tree-water-nature-grass-outdoor-1327743-pxhere.com.jpg',
          'index' => 1,
        ),
        2 => 
        array (
          'url' => '%s/images/leaf-nature-water-green-freshness-dew-1440543-pxhere.com.jpg',
          'index' => 2,
        ),
      ),
      'front-header.hero.style.descendants.outer.background.slideshow.duration.value' => 1500,
      'front-header.hero.style.descendants.outer.background.slideshow.speed.value' => 500,
      'front-header.hero.style.descendants.outer.background.video.videoType' => 'external',
      'front-header.hero.style.descendants.outer.background.video.externalUrl' => 'https://www.youtube.com/watch?v=xXRy-JQ8G0Y',
      'front-header.hero.style.descendants.outer.background.video.internalUrl' => '%s/../videos/demo-video.mp4',
      'front-header.hero.style.descendants.outer.background.video.poster.url' => '%s/../images/demo-video-cover.jpg',
      'front-header.hero.style.descendants.outer.background.overlay.type' => 'color',
      'front-header.hero.style.descendants.outer.background.overlay.shape.value' => 'none',
      'front-header.hero.style.descendants.outer.background.overlay.light' => '',
      'front-header.hero.style.descendants.outer.background.overlay.color.value' => 'rgba(0,0,0,0.6)',
      'front-header.hero.style.descendants.outer.background.overlay.gradient' => 
      array (
        'name' => 'night_fade',
        'angle' => '0',
        'steps' => 
        array (
          0 => 
          array (
            'color' => '#a18cd1',
            'position' => '0',
          ),
          1 => 
          array (
            'color' => '#fbc2eb',
            'position' => '100',
          ),
        ),
      ),
      'front-header.hero.style.descendants.outer.background.overlay.gradient_opacity' => 50,
      'front-header.hero.style.descendants.outer.background.overlay.enabled' => true,
      'front-header.hero.style.padding.top.value' => 100,
      'front-header.hero.style.padding.bottom.value' => 100,
      'front-header.title.show' => true,
      'front-header.title.localProps.content' => 'Unleashing the Hero Within',
      'front-header.title.style.descendants.text.textAlign' => 'center',
      'front-header.subtitle.show' => true,
      'front-header.subtitle.localProps.content' => 'Discover your untapped potential and become the hero of your own narrative – where every day is an opportunity for a new, epic adventure.',
      'front-header.subtitle.style.descendants.text.textAlign' => 'center',
      'front-header.icon_list.localProps.iconList' => 
      array (
        0 => 
        array (
          'icon' => 
          array (
            'name' => 'icons8-line-awesome/map-marker',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="map-marker" viewBox="0 0 512 545.5"><path d="M256 80c79.336 0 144 64.664 144 144 0 22.5-9.116 48.313-21.5 76.5s-28.314 58.098-44.5 86C301.628 442.306 269 489 269 489l-13 19-13-19s-32.628-46.694-65-102.5c-16.186-27.902-32.116-57.813-44.5-86S112 246.5 112 224c0-79.336 64.664-144 144-144zm0 32c-62.04 0-112 49.96-112 112 0 12.844 6.884 37.06 18.5 63.5s27.686 55.738 43.5 83c25.155 43.364 40.74 66.3 50 80 9.26-13.7 24.845-36.636 50-80 15.815-27.262 31.884-56.56 43.5-83S368 236.844 368 224c0-62.04-49.96-112-112-112zm0 80c17.673 0 32 14.327 32 32s-14.327 32-32 32-32-14.327-32-32 14.327-32 32-32z"></path></svg>',
          ),
          'text' => 'Location, State, Country',
          'link_value' => 'https://maps.google.com/',
          'index' => 0,
        ),
        1 => 
        array (
          'icon' => 
          array (
            'name' => 'icons8-line-awesome/phone',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="phone" viewBox="0 0 512 545.5"><path d="M138.5 80c8.375 0 16.656 3.024 23.5 8.5l1 .5.5.5 64 66 1.5 1.5-.5.5c14.174 13.212 13.968 35.53.5 49l-32 32c4.92 11.277 18.33 40.02 44.5 65 26.358 25.16 53.932 39.467 65.5 45l31.5-31.5.5-.5c13.28-13.28 36.72-13.28 50 0l.5 1 65 65c13.28 13.28 13.28 36.22 0 49.5L405 481.5l-.5.5-.5.5c-15.01 12.867-36.04 17.486-55.5 11h-.5c-37.55-14.693-113.51-48.01-181.5-116C98.773 309.773 64.052 234.84 50.5 196c-.035-.1.034-.4 0-.5-6.703-18.434-1.915-39.738 13.5-54l-.5-.5 50-51.5.5-.5 1-.5c6.844-5.476 15.125-8.5 23.5-8.5zm0 32c-1.172 0-2.344.575-3.5 1.5L86.5 163l-.5.5-.5.5c-5.674 4.863-7.44 14.493-5 21 12.12 34.847 45.2 106.7 108.5 170 62.784 62.784 133.224 93.76 169.5 108 9.34 3.113 17.11 1.833 24.5-4.5l49-49c2.72-2.72 2.72-1.78 0-4.5l-65.5-65.5c-2.72-2.72-2.28-2.72-5 0l-40 40-7.5 7.5-10-4.5s-43.83-18.552-81-52.5l-3.5-3c-38.595-36.84-57-86-57-86l-3.5-10 7.5-7 40-40c1.966-1.966.874-3.6 1-3.5l-.5-.5-1-1-64-65.5c-1.156-.925-2.328-1.5-3.5-1.5z"></path></svg>',
          ),
          'text' => '(000) 123 12345',
          'link_value' => 'tel:(000) 123 12345',
          'index' => 1,
        ),
        2 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/envelope',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="envelope" viewBox="0 0 512 545.5"><path d="M48 160h416v288H48V160zm69 32l139 92.5L395 192H117zm-37 14v210h352V206L265 317.5l-9 5.5-9-5.5z"></path></svg>',
          ),
          'text' => 'email@yoursite.com',
          'link_value' => 'mailto:email@yoursite.com',
          'index' => 2,
        ),
      ),
      'front-header.social_icons.localProps.iconList' => 
      array (
        0 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/facebook-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="facebook-square" viewBox="0 0 1536 1896.0833"><path d="M1248 128q119 0 203.5 84.5T1536 416v960q0 119-84.5 203.5T1248 1664h-188v-595h199l30-232h-229V689q0-56 23.5-84t91.5-28l122-1V369q-63-9-178-9-136 0-217.5 80T820 666v171H620v232h200v595H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960z"/></svg>',
          ),
          'link_value' => 'https://www.facebook.com/',
          'index' => 0,
        ),
        1 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/twitter-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="twitter-square" viewBox="0 0 1536 1896.0833"><path d="M1280 610q-56 25-121 34 68-40 93-117-65 38-134 51-61-66-153-66-87 0-148.5 61.5T755 722q0 29 5 48-129-7-242-65T326 550q-29 50-29 106 0 114 91 175-47-1-100-26v2q0 75 50 133.5t123 72.5q-29 8-51 8-13 0-39-4 21 63 74.5 104t121.5 42q-116 90-261 90-26 0-50-3 148 94 322 94 112 0 210-35.5t168-95 120.5-137 75-162T1176 746q0-18-1-27 63-45 105-109zm256-194v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"/></svg>',
          ),
          'link_value' => 'https://www.twitter.com/',
          'index' => 1,
        ),
        2 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/youtube-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1536 1896.0833"><path d="M919 1303v-157q0-50-29-50-17 0-33 16v224q16 16 33 16 29 0 29-49zm184-122h66v-34q0-51-33-51t-33 51v34zM532 915v70h-80v423h-74V985h-78v-70h232zm201 126v367h-67v-40q-39 45-76 45-33 0-42-28-6-17-6-54v-290h66v270q0 24 1 26 1 15 15 15 20 0 42-31v-280h67zm252 111v146q0 52-7 73-12 42-53 42-35 0-68-41v36h-67V915h67v161q32-40 68-40 41 0 53 42 7 21 7 74zm251 129v9q0 29-2 43-3 22-15 40-27 40-80 40-52 0-81-38-21-27-21-86v-129q0-59 20-86 29-38 80-38t78 38q21 29 21 86v76h-133v65q0 51 34 51 24 0 30-26 0-1 .5-7t.5-16.5V1281h68zM785 457v156q0 51-32 51t-32-51V457q0-52 32-52t32 52zm533 713q0-177-19-260-10-44-43-73.5t-76-34.5q-136-15-412-15-275 0-411 15-44 5-76.5 34.5T238 910q-20 87-20 260 0 176 20 260 10 43 42.5 73t75.5 35q137 15 412 15t412-15q43-5 75.5-35t42.5-73q20-84 20-260zM563 519l90-296h-75l-51 195-53-195h-78q7 23 23 69l24 69q35 103 46 158v201h74V519zm289 81V470q0-58-21-87-29-38-78-38-51 0-78 38-21 29-21 87v130q0 58 21 87 27 38 78 38 49 0 78-38 21-27 21-87zm181 120h67V350h-67v283q-22 31-42 31-15 0-16-16-1-2-1-26V350h-67v293q0 37 6 55 11 27 43 27 36 0 77-45v40zm503-304v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"></path></svg>',
          ),
          'link_value' => 'https://www.youtube.com/',
          'index' => 2,
        ),
        3 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/vimeo-square',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="vimeo-square" viewBox="0 0 1536 1896.0833">                                <path d="M1292 638q10-216-161-222-231-8-312 261 44-19 82-19 85 0 74 96-4 57-74 167t-105 110q-43 0-82-169-13-54-45-255-30-189-160-177-59 7-164 100l-81 72-81 72 52 67q76-52 87-52 57 0 107 179 15 55 45 164.5t45 164.5q68 179 164 179 157 0 383-294 220-283 226-444zm244-222v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"></path></svg>',
          ),
          'link_value' => 'https://www.vimeo.com/',
          'index' => 3,
        ),
      ),
      'front-header.navigation.props.layoutType' => 'logo-spacing-menu',
      'front-header.navigation.props.width' => 'boxed',
      'front-header.navigation.style.padding.top.value' => 20,
      'front-header.navigation.hidden' => '',
      'front-header.navigation.props.showTopBar' => false,
      'front-header.hero.image.localProps.url' => '',
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0' => 
      array (
        'x' => 0,
        'y' => 0,
        'spread' => 20,
        'blur' => 0,
        'color' => 'rgba(255, 255, 255, 1)',
      ),
      'front-header.hero.image.style.descendants.image.boxShadow.enabled' => false,
      'front-header.hero.image.props.frame.type' => 'border',
      'front-header.hero.image.style.descendants.frameImage.backgroundColor' => 'rgba(255, 255, 255, 1)',
      'front-header.hero.image.style.descendants.frameImage.width' => 100,
      'front-header.hero.image.style.descendants.frameImage.height' => 100,
      'front-header.hero.image.style.descendants.frameImage.transform.translate' => 
      array (
        'x_value' => 10,
        'y_value' => 10,
      ),
      'front-header.hero.image.style.descendants.frameImage.thickness' => 10,
      'front-header.hero.image.props.showFrameOverImage' => true,
      'front-header.hero.image.props.showFrameShadow' => false,
      'front-header.hero.image.props.enabledFrameOption' => false,
      'front-header.buttons.show' => true,
      'front-header.buttons.value' => 
      array (
        0 => 
        array (
          'label' => 'Get in control',
          'url' => '#',
          'button_type' => '0',
          'index' => 0,
        ),
        1 => 
        array (
          'label' => 'Contact us',
          'url' => '#',
          'button_type' => '1',
          'index' => 1,
        ),
      ),
      'front-header.buttons.style.textAlign' => 'center',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.type' => 'tilt',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.color' => '#FFFFFF',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.height.value' => 200,
      'front-header.hero.style.descendants.outer.separators.separatorBottom.enabled' => false,
      'front-header.hero.style.descendants.outer.separators.separatorBottom.negative' => false,
    ),
  ),
  1 => 
  array (
    'image' => '%s/header-2-preview.jpg',
    'data' => 
    array (
      'front-header.logo.props.layoutType' => 'text',
      'front-header.header-menu.edit' => '',
      'front-header.header-menu.style.descendants.innerMenu.justifyContent' => 'center',
      'front-header.header-menu.props.showOffscreenMenuOn' => 'has-offcanvas-mobile',
      'front-header.header-menu.props.hoverEffect.type' => 'bordered-active-item bordered-active-item--bottom',
      'front-header.header-menu.props.hoverEffect.activeGroup' => 'border',
      'front-header.header-menu.props.hoverEffect.group.border.transition' => 'effect-borders-grow grow-from-left',
      'front-header.hero.props.heroSection.layout' => 'textWithMediaOnRight',
      'front-header.hero.hero_column_width' => 60,
      'front-header.hero.full_height' => true,
      'front-header.hero.style.descendants.outer.background.color' => '',
      'front-header.hero.style.descendants.outer.background.type' => 'image',
      'front-header.hero.style.descendants.outer.background.image.0.source.url' => '%s/images/StockSnap_87ONRC5PWV-hero.jpg',
      'front-header.hero.style.descendants.outer.background.image.0.position' => 'bottom left',
      'front-header.hero.style.descendants.outer.background.image.0.attachment' => 'scroll',
      'front-header.hero.style.descendants.outer.background.image.0.repeat' => 'no-repeat',
      'front-header.hero.style.descendants.outer.background.image.0.size' => 'cover',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient' => 
      array (
        'name' => 'night_fade',
        'angle' => '0',
        'steps' => 
        array (
          0 => 
          array (
            'color' => '#a18cd1',
            'position' => '0',
          ),
          1 => 
          array (
            'color' => '#fbc2eb',
            'position' => '100',
          ),
        ),
      ),
      'front-header.hero.style.descendants.outer.background.slideshow.slides' => 
      array (
        0 => 
        array (
          'url' => '%s/images/beach-landscape-sea-water-nature-sand-1061655-pxhere.com.jpg',
          'index' => 0,
        ),
        1 => 
        array (
          'url' => '%s/images/landscape-tree-water-nature-grass-outdoor-1327743-pxhere.com.jpg',
          'index' => 1,
        ),
        2 => 
        array (
          'url' => '%s/images/leaf-nature-water-green-freshness-dew-1440543-pxhere.com.jpg',
          'index' => 2,
        ),
      ),
      'front-header.hero.style.descendants.outer.background.slideshow.duration.value' => 1500,
      'front-header.hero.style.descendants.outer.background.slideshow.speed.value' => 500,
      'front-header.hero.style.descendants.outer.background.video.videoType' => 'external',
      'front-header.hero.style.descendants.outer.background.video.externalUrl' => 'https://www.youtube.com/watch?v=xXRy-JQ8G0Y',
      'front-header.hero.style.descendants.outer.background.video.internalUrl' => '%s/../videos/demo-video.mp4',
      'front-header.hero.style.descendants.outer.background.video.poster.url' => '%s/../images/demo-video-cover.jpg',
      'front-header.hero.style.descendants.outer.background.overlay.type' => 'color',
      'front-header.hero.style.descendants.outer.background.overlay.shape.value' => 'none',
      'front-header.hero.style.descendants.outer.background.overlay.light' => '',
      'front-header.hero.style.descendants.outer.background.overlay.color.value' => 'rgba(0,0,0,0.6)',
      'front-header.hero.style.descendants.outer.background.overlay.gradient' => 
      array (
        'name' => 'night_fade',
        'angle' => '0',
        'steps' => 
        array (
          0 => 
          array (
            'color' => '#a18cd1',
            'position' => '0',
          ),
          1 => 
          array (
            'color' => '#fbc2eb',
            'position' => '100',
          ),
        ),
      ),
      'front-header.hero.style.descendants.outer.background.overlay.gradient_opacity' => 50,
      'front-header.hero.style.descendants.outer.background.overlay.enabled' => true,
      'front-header.hero.style.padding.top.value' => 50,
      'front-header.hero.style.padding.bottom.value' => 50,
      'front-header.title.show' => true,
      'front-header.title.localProps.content' => 'Build Your Business',
      'front-header.title.style.descendants.text.textAlign' => 'left',
      'front-header.subtitle.show' => true,
      'front-header.subtitle.localProps.content' => 'Lorem ipsum dolor sit amet, at mei dolore tritani repudiandae. In his nemore temporibus consequuntur, vim ad prima vivendum consetetur. Viderer feugiat at pro, mea aperiam.',
      'front-header.subtitle.style.descendants.text.textAlign' => 'left',
      'front-header.icon_list.localProps.iconList' => 
      array (
        0 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/map-marker',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="map-marker" viewBox="0 0 1049.8953 1896.0833"><path d="M768 640q0-106-75-181t-181-75-181 75-75 181 75 181 181 75 181-75 75-181zm256 0q0 109-33 179l-364 774q-16 33-47.5 52t-67.5 19-67.5-19-46.5-52L33 819Q0 749 0 640q0-212 150-362t362-150 362 150 150 362z"></path></svg>',
          ),
          'text' => 'Location, State, Country',
          'link_value' => 'https://maps.google.com/',
          'index' => 0,
        ),
        1 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/phone-square',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="phone-square" viewBox="0 0 1536 1896.0833"><path d="M1280 1193q0-11-2-16t-18-16.5-40.5-25-47.5-26.5-45.5-25-28.5-15q-5-3-19-13t-25-15-21-5q-15 0-36.5 20.5t-39.5 45-38.5 45T885 1167q-7 0-16.5-3.5T853 1157t-17-9.5-14-8.5q-99-55-170-126.5T525 842q-2-3-8.5-14t-9.5-17-6.5-15.5T497 779q0-13 20.5-33.5t45-38.5 45-39.5T628 631q0-10-5-21t-15-25-13-19q-3-6-15-28.5T555 492t-26.5-47.5-25-40.5-16.5-18-16-2q-48 0-101 22-46 21-80 94.5T256 631q0 16 2.5 34t5 30.5 9 33 10 29.5 12.5 33 11 30q60 164 216.5 320.5T843 1358q6 2 30 11t33 12.5 29.5 10 33 9 30.5 5 34 2.5q57 0 130.5-34t94.5-80q22-53 22-101zm256-777v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"></path></svg>',
          ),
          'text' => '(000) 123 12345',
          'link_value' => 'tel:(000) 123 12345',
          'index' => 1,
        ),
        2 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/envelope-open-o',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="envelope" viewBox="0 0 1792 1896.0833"><path d="M1792 710v794q0 66-47 113t-113 47H160q-66 0-113-47T0 1504V710q44 49 101 87 362 246 497 345 57 42 92.5 65.5t94.5 48 110 24.5h2q51 0 110-24.5t94.5-48 92.5-65.5q170-123 498-345 57-39 100-87zm0-294q0 79-49 151t-122 123q-376 261-468 325-10 7-42.5 30.5t-54 38-52 32.5-57.5 27-50 9h-2q-23 0-50-9t-57.5-27-52-32.5-54-38T639 1015q-91-64-262-182.5T172 690q-62-42-117-115.5T0 438q0-78 41.5-130T160 256h1472q65 0 112.5 47t47.5 113z"></path></svg>',
          ),
          'text' => 'email@yoursite.com',
          'link_value' => 'mailto:email@yoursite.com',
          'index' => 2,
        ),
      ),
      'front-header.social_icons.localProps.iconList' => 
      array (
        0 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/facebook-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="facebook-square" viewBox="0 0 1536 1896.0833"><path d="M1248 128q119 0 203.5 84.5T1536 416v960q0 119-84.5 203.5T1248 1664h-188v-595h199l30-232h-229V689q0-56 23.5-84t91.5-28l122-1V369q-63-9-178-9-136 0-217.5 80T820 666v171H620v232h200v595H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960z"/></svg>',
          ),
          'link_value' => 'http://www.facebook.com/',
          'index' => 0,
        ),
        1 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/twitter-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="twitter-square" viewBox="0 0 1536 1896.0833"><path d="M1280 610q-56 25-121 34 68-40 93-117-65 38-134 51-61-66-153-66-87 0-148.5 61.5T755 722q0 29 5 48-129-7-242-65T326 550q-29 50-29 106 0 114 91 175-47-1-100-26v2q0 75 50 133.5t123 72.5q-29 8-51 8-13 0-39-4 21 63 74.5 104t121.5 42q-116 90-261 90-26 0-50-3 148 94 322 94 112 0 210-35.5t168-95 120.5-137 75-162T1176 746q0-18-1-27 63-45 105-109zm256-194v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"/></svg>',
          ),
          'link_value' => 'http://www.twitter.com/',
          'index' => 1,
        ),
        2 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/youtube-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="youtube-square" viewBox="0 0 1536 1896.0833">                                <path d="M919 1303v-157q0-50-29-50-17 0-33 16v224q16 16 33 16 29 0 29-49zm184-122h66v-34q0-51-33-51t-33 51v34zM532 915v70h-80v423h-74V985h-78v-70h232zm201 126v367h-67v-40q-39 45-76 45-33 0-42-28-6-17-6-54v-290h66v270q0 24 1 26 1 15 15 15 20 0 42-31v-280h67zm252 111v146q0 52-7 73-12 42-53 42-35 0-68-41v36h-67V915h67v161q32-40 68-40 41 0 53 42 7 21 7 74zm251 129v9q0 29-2 43-3 22-15 40-27 40-80 40-52 0-81-38-21-27-21-86v-129q0-59 20-86 29-38 80-38t78 38q21 29 21 86v76h-133v65q0 51 34 51 24 0 30-26 0-1 .5-7t.5-16.5V1281h68zM785 457v156q0 51-32 51t-32-51V457q0-52 32-52t32 52zm533 713q0-177-19-260-10-44-43-73.5t-76-34.5q-136-15-412-15-275 0-411 15-44 5-76.5 34.5T238 910q-20 87-20 260 0 176 20 260 10 43 42.5 73t75.5 35q137 15 412 15t412-15q43-5 75.5-35t42.5-73q20-84 20-260zM563 519l90-296h-75l-51 195-53-195h-78q7 23 23 69l24 69q35 103 46 158v201h74V519zm289 81V470q0-58-21-87-29-38-78-38-51 0-78 38-21 29-21 87v130q0 58 21 87 27 38 78 38 49 0 78-38 21-27 21-87zm181 120h67V350h-67v283q-22 31-42 31-15 0-16-16-1-2-1-26V350h-67v293q0 37 6 55 11 27 43 27 36 0 77-45v40zm503-304v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"></path></svg>',
          ),
          'link_value' => 'http://www.youtube.com/',
          'index' => 2,
        ),
        3 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/vimeo-square',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="vimeo-square" viewBox="0 0 1536 1896.0833">                                <path d="M1292 638q10-216-161-222-231-8-312 261 44-19 82-19 85 0 74 96-4 57-74 167t-105 110q-43 0-82-169-13-54-45-255-30-189-160-177-59 7-164 100l-81 72-81 72 52 67q76-52 87-52 57 0 107 179 15 55 45 164.5t45 164.5q68 179 164 179 157 0 383-294 220-283 226-444zm244-222v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"></path></svg>',
          ),
          'link_value' => 'http://www.vimeo.com/',
          'index' => 3,
        ),
      ),
      'front-header.navigation.props.layoutType' => 'logo-spacing-menu',
      'front-header.navigation.props.width' => 'boxed',
      'front-header.navigation.style.padding.top.value' => 20,
      'front-header.navigation.hidden' => '',
      'front-header.navigation.props.showTopBar' => false,
      'front-header.hero.image.localProps.url' => '%s/images/StockSnap_MUNCW5ZFUZ-hero2.jpg',
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0' => 
      array (
        'x' => 0,
        'y' => 0,
        'spread' => 10,
        'blur' => 4,
        'color' => '#000000',
      ),
      'front-header.hero.image.style.descendants.image.boxShadow.enabled' => false,
      'front-header.hero.image.props.frame.type' => 'border',
      'front-header.hero.image.style.descendants.frameImage.backgroundColor' => 'rgba(255,255,255,1)',
      'front-header.hero.image.style.descendants.frameImage.width' => 100,
      'front-header.hero.image.style.descendants.frameImage.height' => 100,
      'front-header.hero.image.style.descendants.frameImage.transform.translate' => 
      array (
        'x_value' => 0,
        'y_value' => 0,
      ),
      'front-header.hero.image.style.descendants.frameImage.thickness' => 10,
      'front-header.hero.image.props.showFrameOverImage' => true,
      'front-header.hero.image.props.showFrameShadow' => true,
      'front-header.hero.image.props.enabledFrameOption' => true,
      'front-header.buttons.show' => true,
      'front-header.buttons.value' => 
      array (
        0 => 
        array (
          'label' => 'Start today',
          'url' => '#',
          'button_type' => '0',
          'index' => 0,
        ),
        1 => 
        array (
          'label' => 'Contact us',
          'url' => '#',
          'button_type' => '1',
          'index' => 1,
        ),
      ),
      'front-header.buttons.style.textAlign' => 'left',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.type' => 'tilt',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.color' => 'rgba(255, 255, 255, 1)',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.height.value' => 200,
      'front-header.hero.style.descendants.outer.separators.separatorBottom.enabled' => false,
      'front-header.hero.style.descendants.outer.separators.separatorBottom.negative' => false,
      'front-header.hero.image.style.descendants.frameImage.transform.translate.x_value' => 10,
      'front-header.hero.image.style.descendants.frameImage.transform.translate.y_value' => 10,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.blur' => 0,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.color' => '#000000',
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.spread' => 20,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.x' => 0,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.y' => 0,
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.angle' => 0,
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.name' => 'night_fade',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.0.color' => '#a18cd1',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.0.position' => 0,
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.1.color' => '#fbc2eb',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.1.position' => 100,
      'front-header.hero.style.descendants.outer.background.overlay.gradient.angle' => 0,
      'front-header.hero.style.descendants.outer.background.overlay.gradient.name' => 'night_fade',
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.0.color' => '#a18cd1',
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.0.position' => 0,
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.1.color' => '#fbc2eb',
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.1.position' => 100,
      'front-header.hero.style.descendants.outer.background.overlay.shape.isTile' => false,
      'front-header.icon_list.show' => true,
      'front-header.navigation.style.padding.top.unit' => 'px',
      'front-header.social_icons.show' => true,
    ),
  ),
  2 => 
  array (
    'image' => '%s/header-3-preview.jpg',
    'data' => 
    array (
      'front-header.logo.props.layoutType' => 'text',
      'front-header.header-menu.edit' => '',
      'front-header.header-menu.style.descendants.innerMenu.justifyContent' => 'center',
      'front-header.header-menu.props.showOffscreenMenuOn' => 'has-offcanvas-mobile',
      'front-header.header-menu.props.hoverEffect.type' => 'bordered-active-item bordered-active-item--bottom',
      'front-header.header-menu.props.hoverEffect.activeGroup' => 'border',
      'front-header.header-menu.props.hoverEffect.group.border.transition' => 'effect-borders-grow grow-from-left',
      'front-header.hero.props.heroSection.layout' => 'textOnly',
      'front-header.hero.hero_column_width' => 100,
      'front-header.hero.full_height' => true,
      'front-header.hero.style.descendants.outer.background.color' => 'rgba(255,255,255,0.5)',
      'front-header.hero.style.descendants.outer.background.type' => 'image',
      'front-header.hero.style.descendants.outer.background.image.0.source.url' => '%s/images/51854277936_91eb700b8e_c.jpg',
      'front-header.hero.style.descendants.outer.background.image.0.position' => 'top left',
      'front-header.hero.style.descendants.outer.background.image.0.attachment' => 'fixed',
      'front-header.hero.style.descendants.outer.background.image.0.repeat' => 'no-repeat',
      'front-header.hero.style.descendants.outer.background.image.0.size' => 'cover',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient' => 
      array (
        'name' => 'night_fade',
        'angle' => '0',
        'steps' => 
        array (
          0 => 
          array (
            'color' => '#a18cd1',
            'position' => '0',
          ),
          1 => 
          array (
            'color' => '#fbc2eb',
            'position' => '100',
          ),
        ),
      ),
      'front-header.hero.style.descendants.outer.background.slideshow.slides' => 
      array (
        0 => 
        array (
          'url' => '%s/images/beach-landscape-sea-water-nature-sand-1061655-pxhere.com.jpg',
          'index' => 0,
        ),
        1 => 
        array (
          'url' => '%s/images/landscape-tree-water-nature-grass-outdoor-1327743-pxhere.com.jpg',
          'index' => 1,
        ),
        2 => 
        array (
          'url' => '%s/images/leaf-nature-water-green-freshness-dew-1440543-pxhere.com.jpg',
          'index' => 2,
        ),
      ),
      'front-header.hero.style.descendants.outer.background.slideshow.duration.value' => 1500,
      'front-header.hero.style.descendants.outer.background.slideshow.speed.value' => 500,
      'front-header.hero.style.descendants.outer.background.video.videoType' => 'external',
      'front-header.hero.style.descendants.outer.background.video.externalUrl' => 'https://www.youtube.com/watch?v=xXRy-JQ8G0Y',
      'front-header.hero.style.descendants.outer.background.video.internalUrl' => '%s/../videos/demo-video.mp4',
      'front-header.hero.style.descendants.outer.background.video.poster.url' => '%s/../images/demo-video-cover.jpg',
      'front-header.hero.style.descendants.outer.background.overlay.type' => 'color',
      'front-header.hero.style.descendants.outer.background.overlay.shape.value' => '10degree-stripes',
      'front-header.hero.style.descendants.outer.background.overlay.light' => 100,
      'front-header.hero.style.descendants.outer.background.overlay.color.value' => 'rgba(24,115,213,0.79)',
      'front-header.hero.style.descendants.outer.background.overlay.gradient' => 
      array (
        'steps' => 
        array (
          0 => 
          array (
            'color' => '#a18cd1',
            'position' => '0',
          ),
          1 => 
          array (
            'color' => '#fbc2eb',
            'position' => '100',
          ),
        ),
        'name' => 'night_fade',
        'angle' => '0',
      ),
      'front-header.hero.style.descendants.outer.background.overlay.gradient_opacity' => 85,
      'front-header.hero.style.descendants.outer.background.overlay.enabled' => true,
      'front-header.hero.style.padding.top.value' => 100,
      'front-header.hero.style.padding.bottom.value' => 100,
      'front-header.title.show' => true,
      'front-header.title.localProps.content' => 'Discover Our Coffee Blends',
      'front-header.title.style.descendants.text.textAlign' => 'left',
      'front-header.subtitle.show' => true,
      'front-header.subtitle.localProps.content' => 'Lorem ipsum dolor sit amet, at mei dolore tritani repudiandae. In his nemore temporibus consequuntur, vim ad prima vivendum consetetur. Viderer feugiat at pro, mea aperiam.',
      'front-header.subtitle.style.descendants.text.textAlign' => 'left',
      'front-header.icon_list.localProps.iconList' => 
      array (
        0 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/map-marker',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="map-marker" viewBox="0 0 1049.8953 1896.0833"><path d="M768 640q0-106-75-181t-181-75-181 75-75 181 75 181 181 75 181-75 75-181zm256 0q0 109-33 179l-364 774q-16 33-47.5 52t-67.5 19-67.5-19-46.5-52L33 819Q0 749 0 640q0-212 150-362t362-150 362 150 150 362z"></path></svg>',
          ),
          'text' => 'Location, State, Country',
          'link_value' => 'https://maps.google.com/',
          'index' => 0,
        ),
        1 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/phone-square',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="phone-square" viewBox="0 0 1536 1896.0833"><path d="M1280 1193q0-11-2-16t-18-16.5-40.5-25-47.5-26.5-45.5-25-28.5-15q-5-3-19-13t-25-15-21-5q-15 0-36.5 20.5t-39.5 45-38.5 45T885 1167q-7 0-16.5-3.5T853 1157t-17-9.5-14-8.5q-99-55-170-126.5T525 842q-2-3-8.5-14t-9.5-17-6.5-15.5T497 779q0-13 20.5-33.5t45-38.5 45-39.5T628 631q0-10-5-21t-15-25-13-19q-3-6-15-28.5T555 492t-26.5-47.5-25-40.5-16.5-18-16-2q-48 0-101 22-46 21-80 94.5T256 631q0 16 2.5 34t5 30.5 9 33 10 29.5 12.5 33 11 30q60 164 216.5 320.5T843 1358q6 2 30 11t33 12.5 29.5 10 33 9 30.5 5 34 2.5q57 0 130.5-34t94.5-80q22-53 22-101zm256-777v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"></path></svg>',
          ),
          'text' => '(000) 123 12345',
          'link_value' => 'tel:(000) 123 12345',
          'index' => 1,
        ),
        2 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/envelope-open-o',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="envelope" viewBox="0 0 1792 1896.0833"><path d="M1792 710v794q0 66-47 113t-113 47H160q-66 0-113-47T0 1504V710q44 49 101 87 362 246 497 345 57 42 92.5 65.5t94.5 48 110 24.5h2q51 0 110-24.5t94.5-48 92.5-65.5q170-123 498-345 57-39 100-87zm0-294q0 79-49 151t-122 123q-376 261-468 325-10 7-42.5 30.5t-54 38-52 32.5-57.5 27-50 9h-2q-23 0-50-9t-57.5-27-52-32.5-54-38T639 1015q-91-64-262-182.5T172 690q-62-42-117-115.5T0 438q0-78 41.5-130T160 256h1472q65 0 112.5 47t47.5 113z"></path></svg>',
          ),
          'text' => 'email@yoursite.com',
          'link_value' => 'mailto:email@yoursite.com',
          'index' => 2,
        ),
      ),
      'front-header.social_icons.localProps.iconList' => 
      array (
        0 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/facebook-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="facebook-square" viewBox="0 0 1536 1896.0833"><path d="M1248 128q119 0 203.5 84.5T1536 416v960q0 119-84.5 203.5T1248 1664h-188v-595h199l30-232h-229V689q0-56 23.5-84t91.5-28l122-1V369q-63-9-178-9-136 0-217.5 80T820 666v171H620v232h200v595H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960z"/></svg>',
          ),
          'link_value' => 'http://www.facebook.com/',
          'index' => 0,
        ),
        1 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/twitter-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="twitter-square" viewBox="0 0 1536 1896.0833"><path d="M1280 610q-56 25-121 34 68-40 93-117-65 38-134 51-61-66-153-66-87 0-148.5 61.5T755 722q0 29 5 48-129-7-242-65T326 550q-29 50-29 106 0 114 91 175-47-1-100-26v2q0 75 50 133.5t123 72.5q-29 8-51 8-13 0-39-4 21 63 74.5 104t121.5 42q-116 90-261 90-26 0-50-3 148 94 322 94 112 0 210-35.5t168-95 120.5-137 75-162T1176 746q0-18-1-27 63-45 105-109zm256-194v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"/></svg>',
          ),
          'link_value' => 'http://www.twitter.com/',
          'index' => 1,
        ),
        2 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/youtube-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="youtube-square" viewBox="0 0 1536 1896.0833">                                <path d="M919 1303v-157q0-50-29-50-17 0-33 16v224q16 16 33 16 29 0 29-49zm184-122h66v-34q0-51-33-51t-33 51v34zM532 915v70h-80v423h-74V985h-78v-70h232zm201 126v367h-67v-40q-39 45-76 45-33 0-42-28-6-17-6-54v-290h66v270q0 24 1 26 1 15 15 15 20 0 42-31v-280h67zm252 111v146q0 52-7 73-12 42-53 42-35 0-68-41v36h-67V915h67v161q32-40 68-40 41 0 53 42 7 21 7 74zm251 129v9q0 29-2 43-3 22-15 40-27 40-80 40-52 0-81-38-21-27-21-86v-129q0-59 20-86 29-38 80-38t78 38q21 29 21 86v76h-133v65q0 51 34 51 24 0 30-26 0-1 .5-7t.5-16.5V1281h68zM785 457v156q0 51-32 51t-32-51V457q0-52 32-52t32 52zm533 713q0-177-19-260-10-44-43-73.5t-76-34.5q-136-15-412-15-275 0-411 15-44 5-76.5 34.5T238 910q-20 87-20 260 0 176 20 260 10 43 42.5 73t75.5 35q137 15 412 15t412-15q43-5 75.5-35t42.5-73q20-84 20-260zM563 519l90-296h-75l-51 195-53-195h-78q7 23 23 69l24 69q35 103 46 158v201h74V519zm289 81V470q0-58-21-87-29-38-78-38-51 0-78 38-21 29-21 87v130q0 58 21 87 27 38 78 38 49 0 78-38 21-27 21-87zm181 120h67V350h-67v283q-22 31-42 31-15 0-16-16-1-2-1-26V350h-67v293q0 37 6 55 11 27 43 27 36 0 77-45v40zm503-304v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"></path></svg>',
          ),
          'link_value' => 'http://www.youtube.com/',
          'index' => 2,
        ),
        3 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/vimeo-square',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="vimeo-square" viewBox="0 0 1536 1896.0833">                                <path d="M1292 638q10-216-161-222-231-8-312 261 44-19 82-19 85 0 74 96-4 57-74 167t-105 110q-43 0-82-169-13-54-45-255-30-189-160-177-59 7-164 100l-81 72-81 72 52 67q76-52 87-52 57 0 107 179 15 55 45 164.5t45 164.5q68 179 164 179 157 0 383-294 220-283 226-444zm244-222v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"></path></svg>',
          ),
          'link_value' => 'http://www.vimeo.com/',
          'index' => 3,
        ),
      ),
      'front-header.navigation.props.layoutType' => 'logo-spacing-menu',
      'front-header.navigation.props.width' => 'boxed',
      'front-header.navigation.style.padding.top.value' => 20,
      'front-header.navigation.hidden' => '',
      'front-header.navigation.props.showTopBar' => false,
      'front-header.hero.image.localProps.url' => '',
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0' => 
      array (
        'x' => 0,
        'y' => 0,
        'spread' => 20,
        'blur' => 0,
        'color' => 'rgba(255, 255, 255, 1)',
      ),
      'front-header.hero.image.style.descendants.image.boxShadow.enabled' => false,
      'front-header.hero.image.props.frame.type' => 'border',
      'front-header.hero.image.style.descendants.frameImage.backgroundColor' => 'rgba(255, 255, 255, 1)',
      'front-header.hero.image.style.descendants.frameImage.width' => 100,
      'front-header.hero.image.style.descendants.frameImage.height' => 100,
      'front-header.hero.image.style.descendants.frameImage.transform.translate' => 
      array (
        'x_value' => 10,
        'y_value' => 10,
      ),
      'front-header.hero.image.style.descendants.frameImage.thickness' => 10,
      'front-header.hero.image.props.showFrameOverImage' => true,
      'front-header.hero.image.props.showFrameShadow' => false,
      'front-header.hero.image.props.enabledFrameOption' => true,
      'front-header.buttons.show' => true,
      'front-header.buttons.value' => 
      array (
        0 => 
        array (
          'label' => 'DISCOVER',
          'url' => '#',
          'button_type' => '0',
          'index' => 0,
        ),
        1 => 
        array (
          'label' => 'TRY TODAY',
          'url' => '#',
          'button_type' => '1',
          'index' => 1,
        ),
      ),
      'front-header.buttons.style.textAlign' => 'left',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.type' => 'tilt',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.color' => 'rgba(255,255,255,1)',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.height.value' => 220,
      'front-header.hero.style.descendants.outer.separators.separatorBottom.enabled' => true,
      'front-header.hero.style.descendants.outer.separators.separatorBottom.negative' => false,
      'front-header.hero.image.style.descendants.frameImage.transform.translate.x_value' => 10,
      'front-header.hero.image.style.descendants.frameImage.transform.translate.y_value' => 10,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.blur' => 0,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.color' => '#000000',
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.spread' => 20,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.x' => 0,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.y' => 0,
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.angle' => 0,
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.name' => 'night_fade',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.0.color' => '#a18cd1',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.0.position' => 0,
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.1.color' => '#fbc2eb',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.1.position' => 100,
      'front-header.hero.style.descendants.outer.background.overlay.gradient.angle' => 0,
      'front-header.hero.style.descendants.outer.background.overlay.gradient.name' => 'night_fade',
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.0.color' => '#a18cd1',
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.0.position' => 0,
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.1.color' => '#fbc2eb',
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.1.position' => 100,
      'front-header.hero.style.descendants.outer.background.overlay.shape.isTile' => false,
      'front-header.icon_list.show' => true,
      'front-header.navigation.style.padding.top.unit' => 'px',
      'front-header.social_icons.show' => true,
    ),
  ),
  3 => 
  array (
    'image' => '%s/header-4-preview.jpg',
    'data' => 
    array (
      'front-header.logo.props.layoutType' => 'text',
      'front-header.header-menu.edit' => '',
      'front-header.header-menu.style.descendants.innerMenu.justifyContent' => 'center',
      'front-header.header-menu.props.showOffscreenMenuOn' => 'has-offcanvas-mobile',
      'front-header.header-menu.props.hoverEffect.type' => 'bordered-active-item bordered-active-item--bottom',
      'front-header.header-menu.props.hoverEffect.activeGroup' => 'border',
      'front-header.header-menu.props.hoverEffect.group.border.transition' => 'effect-borders-grow grow-from-left',
      'front-header.hero.props.heroSection.layout' => 'textOnly',
      'front-header.hero.hero_column_width' => 90,
      'front-header.hero.full_height' => true,
      'front-header.hero.style.descendants.outer.background.color' => '',
      'front-header.hero.style.descendants.outer.background.type' => 'slideshow',
      'front-header.hero.style.descendants.outer.background.image.0.source.url' => '%s/images/StockSnap_LV4AFQREZC-hero.jpg',
      'front-header.hero.style.descendants.outer.background.image.0.position' => 'center center',
      'front-header.hero.style.descendants.outer.background.image.0.attachment' => 'fixed',
      'front-header.hero.style.descendants.outer.background.image.0.repeat' => 'no-repeat',
      'front-header.hero.style.descendants.outer.background.image.0.size' => 'cover',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient' => 
      array (
        'steps' => 
        array (
          0 => 
          array (
            'color' => '#a18cd1',
            'position' => '0',
          ),
          1 => 
          array (
            'color' => '#fbc2eb',
            'position' => '100',
          ),
        ),
        'name' => 'night_fade',
        'angle' => '0',
      ),
      'front-header.hero.style.descendants.outer.background.slideshow.slides' => 
      array (
        0 => 
        array (
          'url' => '%s/images/StockSnap_LV4AFQREZC-hero.jpg',
          'index' => 0,
        ),
        1 => 
        array (
          'url' => '%s/images/14010286447_a1e0ec0174_hero.jpg',
          'index' => 1,
        ),
        2 => 
        array (
          'url' => '%s/images/17914308602_3eddd72aa9_hero.jpg',
          'index' => 2,
        ),
      ),
      'front-header.hero.style.descendants.outer.background.slideshow.duration.value' => 3000,
      'front-header.hero.style.descendants.outer.background.slideshow.speed.value' => 1000,
      'front-header.hero.style.descendants.outer.background.video.videoType' => 'external',
      'front-header.hero.style.descendants.outer.background.video.externalUrl' => 'https://www.youtube.com/watch?v=xXRy-JQ8G0Y',
      'front-header.hero.style.descendants.outer.background.video.internalUrl' => '%s/../videos/demo-video.mp4',
      'front-header.hero.style.descendants.outer.background.video.poster.url' => '%s/../images/demo-video-cover.jpg',
      'front-header.hero.style.descendants.outer.background.overlay.type' => 'color',
      'front-header.hero.style.descendants.outer.background.overlay.shape.value' => 'dots',
      'front-header.hero.style.descendants.outer.background.overlay.light' => 30,
      'front-header.hero.style.descendants.outer.background.overlay.color.value' => 'rgba(0,0,0,0.3)',
      'front-header.hero.style.descendants.outer.background.overlay.gradient' => 
      array (
        'steps' => 
        array (
          0 => 
          array (
            'color' => '#a18cd1',
            'position' => '0',
          ),
          1 => 
          array (
            'color' => '#fbc2eb',
            'position' => '100',
          ),
        ),
        'name' => 'night_fade',
        'angle' => '0',
      ),
      'front-header.hero.style.descendants.outer.background.overlay.gradient_opacity' => 50,
      'front-header.hero.style.descendants.outer.background.overlay.enabled' => true,
      'front-header.hero.style.padding.top.value' => 100,
      'front-header.hero.style.padding.bottom.value' => 100,
      'front-header.title.show' => true,
      'front-header.title.localProps.content' => 'World Performance',
      'front-header.title.style.descendants.text.textAlign' => 'center',
      'front-header.subtitle.show' => true,
      'front-header.subtitle.localProps.content' => 'Lorem ipsum dolor sit amet, at mei dolore tritani repudiandae. In his nemore temporibus consequuntur, vim ad prima vivendum consetetur. Viderer feugiat at pro, mea aperiam.',
      'front-header.subtitle.style.descendants.text.textAlign' => 'center',
      'front-header.icon_list.localProps.iconList' => 
      array (
        0 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/map-marker',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="map-marker" viewBox="0 0 1049.8953 1896.0833"><path d="M768 640q0-106-75-181t-181-75-181 75-75 181 75 181 181 75 181-75 75-181zm256 0q0 109-33 179l-364 774q-16 33-47.5 52t-67.5 19-67.5-19-46.5-52L33 819Q0 749 0 640q0-212 150-362t362-150 362 150 150 362z"></path></svg>',
          ),
          'text' => 'Location, State, Country',
          'link_value' => 'https://maps.google.com/',
          'index' => 0,
        ),
        1 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/phone-square',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="phone-square" viewBox="0 0 1536 1896.0833"><path d="M1280 1193q0-11-2-16t-18-16.5-40.5-25-47.5-26.5-45.5-25-28.5-15q-5-3-19-13t-25-15-21-5q-15 0-36.5 20.5t-39.5 45-38.5 45T885 1167q-7 0-16.5-3.5T853 1157t-17-9.5-14-8.5q-99-55-170-126.5T525 842q-2-3-8.5-14t-9.5-17-6.5-15.5T497 779q0-13 20.5-33.5t45-38.5 45-39.5T628 631q0-10-5-21t-15-25-13-19q-3-6-15-28.5T555 492t-26.5-47.5-25-40.5-16.5-18-16-2q-48 0-101 22-46 21-80 94.5T256 631q0 16 2.5 34t5 30.5 9 33 10 29.5 12.5 33 11 30q60 164 216.5 320.5T843 1358q6 2 30 11t33 12.5 29.5 10 33 9 30.5 5 34 2.5q57 0 130.5-34t94.5-80q22-53 22-101zm256-777v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"></path></svg>',
          ),
          'text' => '(000) 123 12345',
          'link_value' => 'tel:(000) 123 12345',
          'index' => 1,
        ),
        2 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/envelope-open-o',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="envelope" viewBox="0 0 1792 1896.0833"><path d="M1792 710v794q0 66-47 113t-113 47H160q-66 0-113-47T0 1504V710q44 49 101 87 362 246 497 345 57 42 92.5 65.5t94.5 48 110 24.5h2q51 0 110-24.5t94.5-48 92.5-65.5q170-123 498-345 57-39 100-87zm0-294q0 79-49 151t-122 123q-376 261-468 325-10 7-42.5 30.5t-54 38-52 32.5-57.5 27-50 9h-2q-23 0-50-9t-57.5-27-52-32.5-54-38T639 1015q-91-64-262-182.5T172 690q-62-42-117-115.5T0 438q0-78 41.5-130T160 256h1472q65 0 112.5 47t47.5 113z"></path></svg>',
          ),
          'text' => 'email@yoursite.com',
          'link_value' => 'mailto:email@yoursite.com',
          'index' => 2,
        ),
      ),
      'front-header.social_icons.localProps.iconList' => 
      array (
        0 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/facebook-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="facebook-square" viewBox="0 0 1536 1896.0833"><path d="M1248 128q119 0 203.5 84.5T1536 416v960q0 119-84.5 203.5T1248 1664h-188v-595h199l30-232h-229V689q0-56 23.5-84t91.5-28l122-1V369q-63-9-178-9-136 0-217.5 80T820 666v171H620v232h200v595H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960z"/></svg>',
          ),
          'link_value' => 'http://www.facebook.com/',
          'index' => 0,
        ),
        1 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/twitter-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="twitter-square" viewBox="0 0 1536 1896.0833"><path d="M1280 610q-56 25-121 34 68-40 93-117-65 38-134 51-61-66-153-66-87 0-148.5 61.5T755 722q0 29 5 48-129-7-242-65T326 550q-29 50-29 106 0 114 91 175-47-1-100-26v2q0 75 50 133.5t123 72.5q-29 8-51 8-13 0-39-4 21 63 74.5 104t121.5 42q-116 90-261 90-26 0-50-3 148 94 322 94 112 0 210-35.5t168-95 120.5-137 75-162T1176 746q0-18-1-27 63-45 105-109zm256-194v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"/></svg>',
          ),
          'link_value' => 'http://www.twitter.com/',
          'index' => 1,
        ),
        2 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/youtube-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="youtube-square" viewBox="0 0 1536 1896.0833">                                <path d="M919 1303v-157q0-50-29-50-17 0-33 16v224q16 16 33 16 29 0 29-49zm184-122h66v-34q0-51-33-51t-33 51v34zM532 915v70h-80v423h-74V985h-78v-70h232zm201 126v367h-67v-40q-39 45-76 45-33 0-42-28-6-17-6-54v-290h66v270q0 24 1 26 1 15 15 15 20 0 42-31v-280h67zm252 111v146q0 52-7 73-12 42-53 42-35 0-68-41v36h-67V915h67v161q32-40 68-40 41 0 53 42 7 21 7 74zm251 129v9q0 29-2 43-3 22-15 40-27 40-80 40-52 0-81-38-21-27-21-86v-129q0-59 20-86 29-38 80-38t78 38q21 29 21 86v76h-133v65q0 51 34 51 24 0 30-26 0-1 .5-7t.5-16.5V1281h68zM785 457v156q0 51-32 51t-32-51V457q0-52 32-52t32 52zm533 713q0-177-19-260-10-44-43-73.5t-76-34.5q-136-15-412-15-275 0-411 15-44 5-76.5 34.5T238 910q-20 87-20 260 0 176 20 260 10 43 42.5 73t75.5 35q137 15 412 15t412-15q43-5 75.5-35t42.5-73q20-84 20-260zM563 519l90-296h-75l-51 195-53-195h-78q7 23 23 69l24 69q35 103 46 158v201h74V519zm289 81V470q0-58-21-87-29-38-78-38-51 0-78 38-21 29-21 87v130q0 58 21 87 27 38 78 38 49 0 78-38 21-27 21-87zm181 120h67V350h-67v283q-22 31-42 31-15 0-16-16-1-2-1-26V350h-67v293q0 37 6 55 11 27 43 27 36 0 77-45v40zm503-304v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"></path></svg>',
          ),
          'link_value' => 'http://www.youtube.com/',
          'index' => 2,
        ),
        3 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/vimeo-square',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="vimeo-square" viewBox="0 0 1536 1896.0833">                                <path d="M1292 638q10-216-161-222-231-8-312 261 44-19 82-19 85 0 74 96-4 57-74 167t-105 110q-43 0-82-169-13-54-45-255-30-189-160-177-59 7-164 100l-81 72-81 72 52 67q76-52 87-52 57 0 107 179 15 55 45 164.5t45 164.5q68 179 164 179 157 0 383-294 220-283 226-444zm244-222v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"></path></svg>',
          ),
          'link_value' => 'http://www.vimeo.com/',
          'index' => 3,
        ),
      ),
      'front-header.navigation.props.layoutType' => 'logo-spacing-menu',
      'front-header.navigation.props.width' => 'boxed',
      'front-header.navigation.style.padding.top.value' => 20,
      'front-header.navigation.hidden' => '',
      'front-header.navigation.props.showTopBar' => false,
      'front-header.hero.image.localProps.url' => '',
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0' => 
      array (
        'x' => 0,
        'y' => 0,
        'spread' => 20,
        'blur' => 0,
        'color' => 'rgba(255, 255, 255, 1)',
      ),
      'front-header.hero.image.style.descendants.image.boxShadow.enabled' => false,
      'front-header.hero.image.props.frame.type' => 'border',
      'front-header.hero.image.style.descendants.frameImage.backgroundColor' => 'rgba(255, 255, 255, 1)',
      'front-header.hero.image.style.descendants.frameImage.width' => 100,
      'front-header.hero.image.style.descendants.frameImage.height' => 100,
      'front-header.hero.image.style.descendants.frameImage.transform.translate' => 
      array (
        'x_value' => 10,
        'y_value' => 10,
      ),
      'front-header.hero.image.style.descendants.frameImage.thickness' => 10,
      'front-header.hero.image.props.showFrameOverImage' => true,
      'front-header.hero.image.props.showFrameShadow' => false,
      'front-header.hero.image.props.enabledFrameOption' => false,
      'front-header.buttons.show' => true,
      'front-header.buttons.value' => 
      array (
        0 => 
        array (
          'label' => 'Read More',
          'url' => '#',
          'button_type' => '0',
          'index' => 0,
        ),
      ),
      'front-header.buttons.style.textAlign' => 'center',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.type' => 'tilt',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.color' => 'rgba(255, 255, 255, 1)',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.height.value' => 100,
      'front-header.hero.style.descendants.outer.separators.separatorBottom.enabled' => false,
      'front-header.hero.style.descendants.outer.separators.separatorBottom.negative' => false,
      'front-header.hero.image.style.descendants.frameImage.transform.translate.x_value' => 10,
      'front-header.hero.image.style.descendants.frameImage.transform.translate.y_value' => 10,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.blur' => 0,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.color' => '#000000',
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.spread' => 20,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.x' => 0,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.y' => 0,
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.angle' => 0,
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.name' => 'night_fade',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.0.color' => '#a18cd1',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.0.position' => 0,
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.1.color' => '#fbc2eb',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.1.position' => 100,
      'front-header.hero.style.descendants.outer.background.overlay.gradient.angle' => 0,
      'front-header.hero.style.descendants.outer.background.overlay.gradient.name' => 'night_fade',
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.0.color' => '#a18cd1',
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.0.position' => 0,
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.1.color' => '#fbc2eb',
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.1.position' => 100,
      'front-header.hero.style.descendants.outer.background.overlay.shape.isTile' => false,
      'front-header.icon_list.show' => true,
      'front-header.navigation.style.padding.top.unit' => 'px',
      'front-header.social_icons.show' => true,
    ),
  ),
  4 => 
  array (
    'image' => '%s/header-5-preview.jpg',
    'data' => 
    array (
      'front-header.logo.props.layoutType' => 'text',
      'front-header.header-menu.edit' => '',
      'front-header.header-menu.style.descendants.innerMenu.justifyContent' => 'center',
      'front-header.header-menu.props.showOffscreenMenuOn' => 'has-offcanvas-mobile',
      'front-header.header-menu.props.hoverEffect.type' => 'bordered-active-item bordered-active-item--bottom',
      'front-header.header-menu.props.hoverEffect.activeGroup' => 'border',
      'front-header.header-menu.props.hoverEffect.group.border.transition' => 'effect-borders-grow grow-from-left',
      'front-header.hero.props.heroSection.layout' => 'textWithMediaOnLeft',
      'front-header.hero.hero_column_width' => 50,
      'front-header.hero.full_height' => true,
      'front-header.hero.style.descendants.outer.background.color' => 'rgba(130,75,69,0.5)',
      'front-header.hero.style.descendants.outer.background.type' => 'color',
      'front-header.hero.style.descendants.outer.background.image.0.source.url' => '%s/../images/background-image.jpg',
      'front-header.hero.style.descendants.outer.background.image.0.position' => 'center center',
      'front-header.hero.style.descendants.outer.background.image.0.attachment' => 'scroll',
      'front-header.hero.style.descendants.outer.background.image.0.repeat' => 'no-repeat',
      'front-header.hero.style.descendants.outer.background.image.0.size' => 'cover',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient' => 
      array (
        'name' => 'night_fade',
        'angle' => '0',
        'steps' => 
        array (
          0 => 
          array (
            'color' => '#a18cd1',
            'position' => '0',
          ),
          1 => 
          array (
            'color' => '#fbc2eb',
            'position' => '100',
          ),
        ),
      ),
      'front-header.hero.style.descendants.outer.background.slideshow.slides' => 
      array (
        0 => 
        array (
          'url' => '%s/images/beach-landscape-sea-water-nature-sand-1061655-pxhere.com.jpg',
          'index' => 0,
        ),
        1 => 
        array (
          'url' => '%s/images/landscape-tree-water-nature-grass-outdoor-1327743-pxhere.com.jpg',
          'index' => 1,
        ),
        2 => 
        array (
          'url' => '%s/images/leaf-nature-water-green-freshness-dew-1440543-pxhere.com.jpg',
          'index' => 2,
        ),
      ),
      'front-header.hero.style.descendants.outer.background.slideshow.duration.value' => 1500,
      'front-header.hero.style.descendants.outer.background.slideshow.speed.value' => 500,
      'front-header.hero.style.descendants.outer.background.video.videoType' => 'external',
      'front-header.hero.style.descendants.outer.background.video.externalUrl' => 'https://www.youtube.com/watch?v=coYirc_qoSA',
      'front-header.hero.style.descendants.outer.background.video.internalUrl' => '%s/../videos/demo-video.mp4',
      'front-header.hero.style.descendants.outer.background.video.poster.url' => '%s/../images/demo-video-cover.jpg',
      'front-header.hero.style.descendants.outer.background.overlay.type' => 'color',
      'front-header.hero.style.descendants.outer.background.overlay.shape.value' => 'none',
      'front-header.hero.style.descendants.outer.background.overlay.light' => '',
      'front-header.hero.style.descendants.outer.background.overlay.color.value' => 'rgba(0,0,0,0.6)',
      'front-header.hero.style.descendants.outer.background.overlay.gradient' => 
      array (
        'name' => 'night_fade',
        'angle' => '0',
        'steps' => 
        array (
          0 => 
          array (
            'color' => '#a18cd1',
            'position' => '0',
          ),
          1 => 
          array (
            'color' => '#fbc2eb',
            'position' => '100',
          ),
        ),
      ),
      'front-header.hero.style.descendants.outer.background.overlay.gradient_opacity' => 50,
      'front-header.hero.style.descendants.outer.background.overlay.enabled' => false,
      'front-header.hero.style.padding.top.value' => 100,
      'front-header.hero.style.padding.bottom.value' => 100,
      'front-header.title.show' => true,
      'front-header.title.localProps.content' => 'Your Guide to Floral Beauty',
      'front-header.title.style.descendants.text.textAlign' => 'left',
      'front-header.subtitle.show' => true,
      'front-header.subtitle.localProps.content' => 'Lorem ipsum dolor sit amet, at mei dolore tritani repudiandae. In his nemore temporibus consequuntur, vim ad prima.',
      'front-header.subtitle.style.descendants.text.textAlign' => 'left',
      'front-header.icon_list.localProps.iconList' => 
      array (
        0 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/map-marker',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="map-marker" viewBox="0 0 1049.8953 1896.0833"><path d="M768 640q0-106-75-181t-181-75-181 75-75 181 75 181 181 75 181-75 75-181zm256 0q0 109-33 179l-364 774q-16 33-47.5 52t-67.5 19-67.5-19-46.5-52L33 819Q0 749 0 640q0-212 150-362t362-150 362 150 150 362z"></path></svg>',
          ),
          'text' => 'Location, State, Country',
          'link_value' => 'https://maps.google.com/',
          'index' => 0,
        ),
        1 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/phone-square',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="phone-square" viewBox="0 0 1536 1896.0833"><path d="M1280 1193q0-11-2-16t-18-16.5-40.5-25-47.5-26.5-45.5-25-28.5-15q-5-3-19-13t-25-15-21-5q-15 0-36.5 20.5t-39.5 45-38.5 45T885 1167q-7 0-16.5-3.5T853 1157t-17-9.5-14-8.5q-99-55-170-126.5T525 842q-2-3-8.5-14t-9.5-17-6.5-15.5T497 779q0-13 20.5-33.5t45-38.5 45-39.5T628 631q0-10-5-21t-15-25-13-19q-3-6-15-28.5T555 492t-26.5-47.5-25-40.5-16.5-18-16-2q-48 0-101 22-46 21-80 94.5T256 631q0 16 2.5 34t5 30.5 9 33 10 29.5 12.5 33 11 30q60 164 216.5 320.5T843 1358q6 2 30 11t33 12.5 29.5 10 33 9 30.5 5 34 2.5q57 0 130.5-34t94.5-80q22-53 22-101zm256-777v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"></path></svg>',
          ),
          'text' => '(000) 123 12345',
          'link_value' => 'tel:(000) 123 12345',
          'index' => 1,
        ),
        2 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/envelope-open-o',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="envelope" viewBox="0 0 1792 1896.0833"><path d="M1792 710v794q0 66-47 113t-113 47H160q-66 0-113-47T0 1504V710q44 49 101 87 362 246 497 345 57 42 92.5 65.5t94.5 48 110 24.5h2q51 0 110-24.5t94.5-48 92.5-65.5q170-123 498-345 57-39 100-87zm0-294q0 79-49 151t-122 123q-376 261-468 325-10 7-42.5 30.5t-54 38-52 32.5-57.5 27-50 9h-2q-23 0-50-9t-57.5-27-52-32.5-54-38T639 1015q-91-64-262-182.5T172 690q-62-42-117-115.5T0 438q0-78 41.5-130T160 256h1472q65 0 112.5 47t47.5 113z"></path></svg>',
          ),
          'text' => 'email@yoursite.com',
          'link_value' => 'mailto:email@yoursite.com',
          'index' => 2,
        ),
      ),
      'front-header.social_icons.localProps.iconList' => 
      array (
        0 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/facebook-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="facebook-square" viewBox="0 0 1536 1896.0833"><path d="M1248 128q119 0 203.5 84.5T1536 416v960q0 119-84.5 203.5T1248 1664h-188v-595h199l30-232h-229V689q0-56 23.5-84t91.5-28l122-1V369q-63-9-178-9-136 0-217.5 80T820 666v171H620v232h200v595H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960z"/></svg>',
          ),
          'link_value' => 'http://www.facebook.com/',
          'index' => 0,
        ),
        1 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/twitter-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="twitter-square" viewBox="0 0 1536 1896.0833"><path d="M1280 610q-56 25-121 34 68-40 93-117-65 38-134 51-61-66-153-66-87 0-148.5 61.5T755 722q0 29 5 48-129-7-242-65T326 550q-29 50-29 106 0 114 91 175-47-1-100-26v2q0 75 50 133.5t123 72.5q-29 8-51 8-13 0-39-4 21 63 74.5 104t121.5 42q-116 90-261 90-26 0-50-3 148 94 322 94 112 0 210-35.5t168-95 120.5-137 75-162T1176 746q0-18-1-27 63-45 105-109zm256-194v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"/></svg>',
          ),
          'link_value' => 'http://www.twitter.com/',
          'index' => 1,
        ),
        2 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/youtube-square',
            'content' => '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="youtube-square" viewBox="0 0 1536 1896.0833">                                <path d="M919 1303v-157q0-50-29-50-17 0-33 16v224q16 16 33 16 29 0 29-49zm184-122h66v-34q0-51-33-51t-33 51v34zM532 915v70h-80v423h-74V985h-78v-70h232zm201 126v367h-67v-40q-39 45-76 45-33 0-42-28-6-17-6-54v-290h66v270q0 24 1 26 1 15 15 15 20 0 42-31v-280h67zm252 111v146q0 52-7 73-12 42-53 42-35 0-68-41v36h-67V915h67v161q32-40 68-40 41 0 53 42 7 21 7 74zm251 129v9q0 29-2 43-3 22-15 40-27 40-80 40-52 0-81-38-21-27-21-86v-129q0-59 20-86 29-38 80-38t78 38q21 29 21 86v76h-133v65q0 51 34 51 24 0 30-26 0-1 .5-7t.5-16.5V1281h68zM785 457v156q0 51-32 51t-32-51V457q0-52 32-52t32 52zm533 713q0-177-19-260-10-44-43-73.5t-76-34.5q-136-15-412-15-275 0-411 15-44 5-76.5 34.5T238 910q-20 87-20 260 0 176 20 260 10 43 42.5 73t75.5 35q137 15 412 15t412-15q43-5 75.5-35t42.5-73q20-84 20-260zM563 519l90-296h-75l-51 195-53-195h-78q7 23 23 69l24 69q35 103 46 158v201h74V519zm289 81V470q0-58-21-87-29-38-78-38-51 0-78 38-21 29-21 87v130q0 58 21 87 27 38 78 38 49 0 78-38 21-27 21-87zm181 120h67V350h-67v283q-22 31-42 31-15 0-16-16-1-2-1-26V350h-67v293q0 37 6 55 11 27 43 27 36 0 77-45v40zm503-304v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"></path></svg>',
          ),
          'link_value' => 'http://www.youtube.com/',
          'index' => 2,
        ),
        3 => 
        array (
          'icon' => 
          array (
            'name' => 'font-awesome/vimeo-square',
            'content' => '<svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="vimeo-square" viewBox="0 0 1536 1896.0833">                                <path d="M1292 638q10-216-161-222-231-8-312 261 44-19 82-19 85 0 74 96-4 57-74 167t-105 110q-43 0-82-169-13-54-45-255-30-189-160-177-59 7-164 100l-81 72-81 72 52 67q76-52 87-52 57 0 107 179 15 55 45 164.5t45 164.5q68 179 164 179 157 0 383-294 220-283 226-444zm244-222v960q0 119-84.5 203.5T1248 1664H288q-119 0-203.5-84.5T0 1376V416q0-119 84.5-203.5T288 128h960q119 0 203.5 84.5T1536 416z"></path></svg>',
          ),
          'link_value' => 'http://www.vimeo.com/',
          'index' => 3,
        ),
      ),
      'front-header.navigation.props.layoutType' => 'logo-spacing-menu',
      'front-header.navigation.props.width' => 'boxed',
      'front-header.navigation.style.padding.top.value' => 20,
      'front-header.navigation.hidden' => '',
      'front-header.navigation.props.showTopBar' => false,
      'front-header.hero.image.localProps.url' => '%s/images/image-from-rawpixel-id-843203-hero.jpg',
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0' => 
      array (
        'x' => -27,
        'y' => 20,
        'spread' => 0,
        'blur' => 85,
        'color' => '#A26B6B',
      ),
      'front-header.hero.image.style.descendants.image.boxShadow.enabled' => true,
      'front-header.hero.image.props.frame.type' => 'border',
      'front-header.hero.image.style.descendants.frameImage.backgroundColor' => 'rgba(255, 255, 255, 1)',
      'front-header.hero.image.style.descendants.frameImage.width' => 100,
      'front-header.hero.image.style.descendants.frameImage.height' => 100,
      'front-header.hero.image.style.descendants.frameImage.transform.translate' => 
      array (
        'x_value' => -5,
        'y_value' => -3,
      ),
      'front-header.hero.image.style.descendants.frameImage.thickness' => 2,
      'front-header.hero.image.props.showFrameOverImage' => false,
      'front-header.hero.image.props.showFrameShadow' => false,
      'front-header.hero.image.props.enabledFrameOption' => true,
      'front-header.buttons.show' => true,
      'front-header.buttons.value' => 
      array (
        0 => 
        array (
          'label' => 'Read More',
          'url' => '#',
          'button_type' => '1',
          'index' => 1,
        ),
      ),
      'front-header.buttons.style.textAlign' => 'left',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.type' => 'tilt',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.color' => 'rgba(255, 255, 255, 1)',
      'front-header.hero.style.descendants.outer.separators.separatorBottom.height.value' => 100,
      'front-header.hero.style.descendants.outer.separators.separatorBottom.enabled' => false,
      'front-header.hero.style.descendants.outer.separators.separatorBottom.negative' => false,
      'front-header.hero.image.style.descendants.frameImage.transform.translate.x_value' => 10,
      'front-header.hero.image.style.descendants.frameImage.transform.translate.y_value' => 10,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.blur' => 0,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.color' => '#000000',
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.spread' => 20,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.x' => 0,
      'front-header.hero.image.style.descendants.image.boxShadow.layers.0.y' => 0,
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.angle' => 0,
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.name' => 'night_fade',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.0.color' => '#a18cd1',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.0.position' => 0,
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.1.color' => '#fbc2eb',
      'front-header.hero.style.descendants.outer.background.image.0.source.gradient.steps.1.position' => 100,
      'front-header.hero.style.descendants.outer.background.overlay.gradient.angle' => 0,
      'front-header.hero.style.descendants.outer.background.overlay.gradient.name' => 'night_fade',
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.0.color' => '#a18cd1',
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.0.position' => 0,
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.1.color' => '#fbc2eb',
      'front-header.hero.style.descendants.outer.background.overlay.gradient.steps.1.position' => 100,
      'front-header.hero.style.descendants.outer.background.overlay.shape.isTile' => false,
      'front-header.icon_list.show' => true,
      'front-header.navigation.style.padding.top.unit' => 'px',
      'front-header.social_icons.show' => true,
    ),
  ),
);
