<?php

return array(

	// panel / sections general texts
	'press_enter_to_open_section'             => __( 'Press return or enter to open this section', 'kubio' ),
	'back'                                    => __( 'Back', 'kubio' ),
	'help'                                    => __( 'Help', 'kubio' ),
	'header_sections'                         => __( 'Header', 'kubio' ),
	'footer_sections'                         => __( 'Footer', 'kubio' ),
	'content_sections'                        => __( 'Content', 'kubio' ),
	'content_settings'                        => __( 'Content Settings', 'kubio' ),
	'top_bar_settings'                        => __( 'Top Bar Settings', 'kubio' ),
	'nav_settings'                            => __( 'Navigation Settings', 'kubio' ),
	'hero_settings'                           => __( 'Hero Settings', 'kubio' ),
	'footer_settings'                         => __( 'Footer Settings', 'kubio' ),
	'blog_settings'                           => __( 'Blog Settings', 'kubio' ),
	'content'                                 => __( 'Content', 'kubio' ),
	'style'                                   => __( 'Style', 'kubio' ),
	'advanced'                                => __( 'Advanced', 'kubio' ),

	// hero
	'background_type'                         => __( 'Background Type', 'kubio' ),
	'background_color'                        => __( 'Background Color', 'kubio' ),
	'background_image'                        => __( 'Background Image', 'kubio' ),
	'color'                                   => __( 'Color', 'kubio' ),
	'image'                                   => __( 'Image', 'kubio' ),
	'gradient'                                => __( 'Gradient', 'kubio' ),
	'slideshow'                               => __( 'Slideshow', 'kubio' ),
	'video'                                   => __( 'Video', 'kubio' ),

	// divider
	'show_bottom_divider'                     => __( 'Show bottom divider', 'kubio' ),
	'divider_style'                           => __( 'Divider style', 'kubio' ),
	'divider_height'                          => __( 'Divider height', 'kubio' ),
	'divider_negative'                        => __( 'Divider negative', 'kubio' ),
	// divider style
	'tilt'                                    => __( 'Tilt', 'kubio' ),
	'tilt-flipped'                            => __( 'Tilt Flipped', 'kubio' ),

	// controls
	'select'                                  => __( 'Select', 'kubio' ),
	'select_item'                             => __( 'Select item', 'kubio' ),
	'select_image'                            => __( 'Select image', 'kubio' ),
	'OK'                                      => __( 'OK', 'kubio' ),
	'clear'                                   => __( 'Clear', 'kubio' ),
	'none'                                    => __( 'None', 'kubio' ),
	'add'                                     => __( 'Add', 'kubio' ),
	'remove'                                  => __( 'Remove', 'kubio' ),
	'slide_n'                                 => __( 'Slide %s', 'kubio' ),
	'add_slide'                               => __( 'Add Slide', 'kubio' ),
	'position'                                => __( 'Position', 'kubio' ),

	// position
	'top_left'                                => __( 'Top Left', 'kubio' ),
	'top_center'                              => __( 'Top Center', 'kubio' ),
	'top_right'                               => __( 'Top Right', 'kubio' ),
	'center_left'                             => __( 'Center Left', 'kubio' ),
	'center_center'                           => __( 'Center Center', 'kubio' ),
	'center_right'                            => __( 'Center Right', 'kubio' ),
	'bottom_left'                             => __( 'Bottom Left', 'kubio' ),
	'bottom_center'                           => __( 'Bottom Center', 'kubio' ),
	'bottom_right'                            => __( 'Bottom Right', 'kubio' ),
	'attachment'                              => __( 'Attachment', 'kubio' ),
	'scroll'                                  => __( 'Scroll', 'kubio' ),
	'fixed'                                   => __( 'Fixed', 'kubio' ),
	'size'                                    => __( 'Size', 'kubio' ),
	'no-repeat'                               => __( 'Do not repeat', 'kubio' ),
	'repeat'                                  => __( 'Repeat %s', 'kubio' ),
	'auto'                                    => __( 'Auto', 'kubio' ),
	'cover'                                   => __( 'Cover', 'kubio' ),
	'contain'                                 => __( 'Contain', 'kubio' ),
	'slide_duration'                          => __( 'Slide Duration', 'kubio' ),
	'effect_speed'                            => __( 'Effect Speed', 'kubio' ),
	'video_type'                              => __( 'Video type', 'kubio' ),
	'self_hosted'                             => __( 'Self Hosted', 'kubio' ),
	'self_hosted_video'                       => __( 'Self Hosted Video', 'kubio' ),
	'external_video'                          => __( 'External', 'kubio' ),
	'video_poster'                            => __( 'Video Poster', 'kubio' ),
	'youtube_url'                             => __( 'Youtube link', 'kubio' ),
	'show_background_overlay'                 => __( 'Show Background Overlay', 'kubio' ),
	'overlay_type'                            => __( 'Overlay Type', 'kubio' ),
	'shape_only'                              => __( 'Shape Only', 'kubio' ),
	'opacity'                                 => __( 'Opacity', 'kubio' ),
	'circles'                                 => __( 'Circles', 'kubio' ),
	'10degree_stripes'                        => __( '10deg Stripes', 'kubio' ),
	'rounded_squares_blue'                    => __( 'Rounded Square Blue', 'kubio' ),
	'many_rounded_squares_blue'               => __( 'Many Rounded Squares Blue', 'kubio' ),
	'two_circles'                             => __( 'Two Circles', 'kubio' ),
	'circles_2'                               => __( 'Circles 2', 'kubio' ),
	'circles_3'                               => __( 'Circles 3', 'kubio' ),
	'circles_gradient'                        => __( 'Circles Gradient', 'kubio' ),
	'circles_white_gradient'                  => __( 'Circles White Gradient', 'kubio' ),
	'waves'                                   => __( 'Waves', 'kubio' ),
	'waves_inverted'                          => __( 'Waves Inverted', 'kubio' ),
	'dots'                                    => __( 'Dots', 'kubio' ),
	'left_tilted_lines'                       => __( 'Left Tilted Lines', 'kubio' ),
	'right_tilted_lines'                      => __( 'Right Tilted Lines', 'kubio' ),
	'right_tilted_strips'                     => __( 'Right Tilted Strips', 'kubio' ),
	'shape_light'                             => __( 'Shape Light', 'kubio' ),
	'overlay_shape'                           => __( 'Overlay Shape', 'kubio' ),

	// hero content
	'hero_layout'                             => __( 'Hero layout', 'kubio' ),
	'text_only'                               => __( 'Text only', 'kubio' ),
	'text_with_media_on_right'                => __( 'Text with media on right', 'kubio' ),
	'text_with_media_on_left'                 => __( 'Text with media on left', 'kubio' ),
	'show_title'                              => __( 'Show Title', 'kubio' ),
	'show_subtitle'                           => __( 'Show Subtitle', 'kubio' ),
	'title'                                   => __( 'Title', 'kubio' ),
	'subtitle'                                => __( 'Subtitle', 'kubio' ),
	'text_width'                              => __( 'Text width', 'kubio' ),
	'button'                                  => __( 'Button', 'kubio' ),
	'add_button'                              => __( 'Add Button', 'kubio' ),
	'buttons'                                 => __( 'Buttons', 'kubio' ),
	'button_type'                             => __( 'Button Type', 'kubio' ),
	'primary_button'                          => __( 'Primary Button', 'kubio' ),
	'secondary_button'                        => __( 'Secondary Button', 'kubio' ),
	'label'                                   => __( 'Label', 'kubio' ),
	'link'                                    => __( 'Link', 'kubio' ),
	'icons'                                   => __( 'Icons', 'kubio' ),
	'align'                                   => __( 'Align', 'kubio' ),
	'spacing_top'                             => __( 'Spacing top', 'kubio' ),
	'spacing_bottom'                          => __( 'Spacing bottom', 'kubio' ),
	'full_height'                             => __( 'Full Height', 'kubio' ),
	'hero_column_width'                       => __( 'Text column width', 'kubio' ),

	// hero image
	'box_shadow'                              => __( 'Box shadow', 'kubio' ),
	'horizontal'                              => __( 'Horizontal', 'kubio' ),
	'vertical'                                => __( 'Vertical', 'kubio' ),
	'spread'                                  => __( 'Spread', 'kubio' ),
	'blur'                                    => __( 'Blur', 'kubio' ),
	'frame_options'                           => __( 'Frame options', 'kubio' ),
	'type'                                    => __( 'Type', 'kubio' ),
	'border'                                  => __( 'Border', 'kubio' ),
	'width'                                   => __( 'Width', 'kubio' ),
	'height'                                  => __( 'Height', 'kubio' ),
	'offset'                                  => __( 'Offset', 'kubio' ),
	'offset_left'                             => __( 'Offset left', 'kubio' ),
	'offset_top'                              => __( 'Offset top', 'kubio' ),
	'frame_thickness'                         => __( 'Frame thickness', 'kubio' ),
	'frame_over_image'                        => __( 'Show frame over image', 'kubio' ),
	'frame_shadow'                            => __( 'Show frame shadow', 'kubio' ),

	// top bar
	'information_fields'                      => __( 'Information Fields', 'kubio' ),
	'social_icons'                            => __( 'Social Icons', 'kubio' ),
	'content_type'                            => __( 'Content Type', 'kubio' ),
	'field_n'                                 => __( 'Field %s', 'kubio' ),
	'add_field'                               => __( 'Add Field', 'kubio' ),
	'icon_n'                                  => __( 'Icon %s', 'kubio' ),
	'add_item'                                => __( 'Add Item', 'kubio' ),
	'add_icon'                                => __( 'Add Icon', 'kubio' ),
	'icon'                                    => __( 'Icon', 'kubio' ),
	'text'                                    => __( 'Text', 'kubio' ),

	// nav bar
	'show_top_bar'                            => __( 'Show top bar', 'kubio' ),
	'boxed'                                   => __( 'Boxed', 'kubio' ),
	'container_width'                         => __( 'Container width', 'kubio' ),
	'full_width'                              => __( 'Full width', 'kubio' ),
	'transparent_nav'                         => __( 'Transparent nav', 'kubio' ),
	'button_align'                            => __( 'Button align', 'kubio' ),

	// logo
	'layout_type'                             => __( 'Layout type', 'kubio' ),
	'alternate_logo_image'                    => __( 'Alternate logo image', 'kubio' ),
	'navigation_padding'                      => __( 'Navigation padding', 'kubio' ),
	'logo'                                    => __( 'Logo', 'kubio' ),

	'logo_image_only'                         => __( 'Logo image only', 'kubio' ),
	'site_title_text_only'                    => __( 'Site title text only', 'kubio' ),
	'image_with_text_below'                   => __( 'Image with text below', 'kubio' ),
	'image_with_text_right'                   => __( 'Image with text on the right', 'kubio' ),
	'image_with_text_above'                   => __( 'Image with text above', 'kubio' ),
	'image_with_text_left'                    => __( 'Image with text on the left', 'kubio' ),

	// menu
	'menu'                                    => __( 'Menu', 'kubio' ),
	'no_menu'                                 => __( '- No menu -', 'kubio' ),
	'edit_menu_structure'                     => __( 'Edit Menu Structure', 'kubio' ),
	'show_offscreen_menu_on'                  => __( 'Show offscreen menu on', 'kubio' ),
	'mobile'                                  => __( 'Mobile', 'kubio' ),
	'mobile_tablet'                           => __( 'Mobile and tablet', 'kubio' ),
	'mobile_tablet_desktop'                   => __( 'Mobile, tablet and desktop', 'kubio' ),
	'button_highlight_type'                   => __( 'Button highlight type', 'kubio' ),
	'button_hover_effect'                     => __( 'Button hover effect', 'kubio' ),

	// menu style
	'bottom_line'                             => __( 'Bottom line', 'kubio' ),
	'top_line'                                => __( 'Top line', 'kubio' ),
	'double_line'                             => __( 'Double line', 'kubio' ),
	'background'                              => __( 'Background', 'kubio' ),

	'drop_in'                                 => __( 'Drop in', 'kubio' ),
	'drop_out'                                => __( 'Drop out', 'kubio' ),
	'grow_from_left'                          => __( 'Grow from left', 'kubio' ),
	'grow_from_right'                         => __( 'Grow from right', 'kubio' ),
	'grow_from_center'                        => __( 'Grow from center', 'kubio' ),

	'grow_up'                                 => __( 'Grow up', 'kubio' ),
	'grow_down'                               => __( 'Grow down', 'kubio' ),
	'grow_left'                               => __( 'Grow left', 'kubio' ),
	'grow_right'                              => __( 'Grow right', 'kubio' ),
	'shutter_in_horizontal'                   => __( 'Shutter in horizontal', 'kubio' ),
	'shutter_out_horizontal'                  => __( 'Shutter out horizontal', 'kubio' ),
	'shutter_in_vertical'                     => __( 'Shutter in vertical', 'kubio' ),
	'shutter_out_vertical'                    => __( 'Shutter out vertical', 'kubio' ),

	// navbar
	'logo_nav'                                => __( 'Logo / Nav', 'kubio' ), // logo /nav
	'logo_above'                              => __( 'Logo above', 'kubio' ), // logo above

	// frontend

	'read_more'                               => __( 'Read More', 'kubio' ),

	// plugin

	'plugin_message'                          => __(
		'To enable all the theme features, please install %s plugin',
		'kubio'
	),
	'install_with_placeholder'                => __( 'Install %s', 'kubio' ),
	'activate_with_placeholder'               => __( 'Activate %s', 'kubio' ),

	// blog

	'posts_per_row'                           => __( 'Posts per row', 'kubio' ),
	'show_blog_sidebar'                       => __( 'Show blog sidebar ', 'kubio' ),
	'enable_masonry'                          => __( 'Enable masonry', 'kubio' ),
	'show_thumbnail_placeholder'              => __( 'Show thumbnail placeholder', 'kubio' ),
	'thumbnail_placeholder_color'             => __( 'Thumbnail placeholder color', 'kubio' ),

	// admin
	'theme_page_name'                         => __( 'Colibri Settings', 'kubio' ),
	'or'                                      => __( 'or', 'kubio' ),
	'get_started'                             => __( 'Get Started', 'kubio' ),
	'get_started_section_1_title'             => __( 'Recommended plugins', 'kubio' ),
	'get_started_section_2_title'             => __( 'Links to Customizer Settings', 'kubio' ),
	'get_started_set_logo'                    => __( 'Set your logo', 'kubio' ),
	'get_started_change_hero_image'           => __( 'Change the hero image', 'kubio' ),
	'get_started_change_customize_navigation' => __( 'Customize navigation', 'kubio' ),
	'get_started_change_customize_hero'       => __( 'Customize frontpage hero', 'kubio' ),
	'get_started_customize_footer'            => __( 'Customize footer', 'kubio' ),
	'get_started_change_color_settings'       => __( 'Change color settings', 'kubio' ),
	'get_started_customize_fonts'             => __( 'Customize fonts', 'kubio' ),
	'get_started_set_menu_links'              => __( 'Customize menu', 'kubio' ),
	'customize'                               => __( 'Customize', 'kubio' ),
	'welcome_message'                         => __( 'Welcome to %s', 'kubio' ),
	'check_all_demo_sites_page'               => __( 'Check all demo sites page', 'kubio' ),
	'admin_sidebar_documentation_title'       => __( 'Documentation', 'kubio' ),
	'admin_sidebar_documentation_description' => __(
		'Colibri is easy to learn and master, but you can always check out our documentation to check out features you might have missed.',
		'kubio'
	),
	'admin_sidebar_documentation_action'      => __( 'Check documentation', 'kubio' ),
	'admin_sidebar_support_title'             => __( 'Support', 'kubio' ),
	'admin_sidebar_support_description'       => __(
		'Our technical team is here to help you build an awesome website. We usually answer support issues in less than 1 business day.',
		'kubio'
	),
	'admin_sidebar_support_action'            => __( 'Open a support ticket', 'kubio' ),
	'admin_sidebar_review_title'              => __( 'Leave a Review', 'kubio' ),
	'admin_sidebar_review_description'        => __(
		'We strive to provide our customers with the best service in our industry, so your feedback is very important to us. We would greatly appreciate it if you would take a few minutes to share your experience with us via this survey.',
		'kubio'
	),
	'admin_sidebar_review_action'             => __( 'Leave a review', 'kubio' ),
	'contact_form_plugin_description'         => sprintf(
		__( '%1$s plugin is recommended for the %2$s contact section.', 'kubio' ),
		'Forminator',
		'Kubio Page Builder'
	),
	'page_builder_plugin_description'         => sprintf(
		__( '%1$s plugin adds drag and drop functionality and many other features to the %2$s theme.', 'kubio' ),
		'Kubio Page Builder',
		wp_get_theme( get_stylesheet() )->get( 'Name' )
	),
	'activate'                                => __( 'Activate', 'kubio' ),
	'install'                                 => __( 'Install', 'kubio' ),
	'continue'                                => __( 'Continue', 'kubio' ),
	'installing'                              => __( 'Installing %s', 'kubio' ),
	'activating'                              => __( 'Activating %s', 'kubio' ),
	'preparing_front_page_installation'       => __( 'Preparing Front Page installation', 'kubio' ),
    'would_you_like_to_install_front_page'    => __( "Would you like to generate a homepage using AI? It's fast and FREE!", 'kubio' ),
    'theme_description'                       => __( "%s uses an AI page generator to create a homepage that is adapted to your website. Here’s what you’ll get:", 'kubio' ),
    'install_homepage_with_ai'                => __( 'Generate homepage with AI', 'kubio' ),
    'install_default_homepage'                => __( 'No thanks, install the default homepage', 'kubio' ),
	'plugin_installed_and_active'             => __( 'Active', 'kubio' ),
	'skip_to_content'                         => __( 'Skip to content', 'kubio' ),
	'change_header_design'                    => __( 'Choose header design', 'kubio' ),
	'change_footer_design'                    => __( 'Choose footer design', 'kubio' ),
    'dont_show_anymore'                       => __( "Don't show anymore", 'kubio' ),
    'add_section'                             => __( 'Add Predefined Section', 'kubio' ),
    'benefit_1'                               => __( 'A homepage customized for your website', 'kubio' ),
    'benefit_2'                               => __( 'Texts and images based on your website subject', 'kubio' ),
    'benefit_3'                               => __( 'Matching color scheme and typography', 'kubio' ),
    'benefit_4'                               => __( 'Contact form and social media integration', 'kubio' ),
    'start_with_a_front_page_plugin_info'     => __(
        'Any of these actions will also install the Kubio Page Builder plugin.',
        'kubio'
    ),
	'start_with_selected_page'                => __( 'Start with selected option', 'kubio' ),

	'undefined_sanitize_function_for_control' => __(
		'Undefined sanitize function for control "%s"',
		'kubio'
	),

    // Kubio themebase
    'themebase_step1_title' => __( 'What would you like to display on your front page?', 'kubio' ),
    'themebase_step1_option1_title' => __( 'Custom Home Page', 'kubio' ),
    'themebase_step1_option1_subtitle' => __( 'Choose this if you\'re building a presentation website', 'kubio' ),
    'themebase_step2_title' => __( 'Would you like to generate a new homepage using AI? It\'s fast & FREE!', 'kubio' ),
    'themebase_step2_option1_title' => __( 'Latest Blog Posts', 'kubio' ),
    'themebase_step2_option1_subtitle' => __( 'Choose this if you\'re building a blog or a content website', 'kubio' ),

    'themebase_step2_button1' => __( 'Generate Homepage', 'kubio' ),
    'themebase_step2_button2' => __( 'No thanks, install the default homepage', 'kubio' ),
    'themebase_step2_footer_info' => __( '*Any of these actions will also install the Kubio Page Builder plugin.', 'kubio' ),
);
