<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'ColibriWP\\Theme\\ActiveCallback' => $baseDir . '/lib/colibriwp/src/ActiveCallback.php',
    'ColibriWP\\Theme\\AssetsManager' => $baseDir . '/lib/colibriwp/src/AssetsManager.php',
    'ColibriWP\\Theme\\ComponentsRepository' => $baseDir . '/lib/colibriwp/src/ComponentsRepository.php',
    'ColibriWP\\Theme\\Components\\CSSOutput' => $baseDir . '/lib/colibriwp/src/Components/CSSOutput.php',
    'ColibriWP\\Theme\\Components\\Footer' => $baseDir . '/lib/colibriwp/src/Components/Footer.php',
    'ColibriWP\\Theme\\Components\\Footer\\FrontFooter' => $baseDir . '/lib/colibriwp/src/Components/Footer/FrontFooter.php',
    'ColibriWP\\Theme\\Components\\FrontHeader\\ButtonsGroup' => $baseDir . '/lib/colibriwp/src/Components/FrontHeader/ButtonsGroup.php',
    'ColibriWP\\Theme\\Components\\FrontHeader\\Hero' => $baseDir . '/lib/colibriwp/src/Components/FrontHeader/Hero.php',
    'ColibriWP\\Theme\\Components\\FrontHeader\\Image' => $baseDir . '/lib/colibriwp/src/Components/FrontHeader/Image.php',
    'ColibriWP\\Theme\\Components\\FrontHeader\\NavBar' => $baseDir . '/lib/colibriwp/src/Components/FrontHeader/NavBar.php',
    'ColibriWP\\Theme\\Components\\FrontHeader\\Subtitle' => $baseDir . '/lib/colibriwp/src/Components/FrontHeader/Subtitle.php',
    'ColibriWP\\Theme\\Components\\FrontHeader\\Title' => $baseDir . '/lib/colibriwp/src/Components/FrontHeader/Title.php',
    'ColibriWP\\Theme\\Components\\FrontHeader\\TopBar' => $baseDir . '/lib/colibriwp/src/Components/FrontHeader/TopBar.php',
    'ColibriWP\\Theme\\Components\\FrontHeader\\TopBarListIcons' => $baseDir . '/lib/colibriwp/src/Components/FrontHeader/TopBarListIcons.php',
    'ColibriWP\\Theme\\Components\\FrontHeader\\TopBarSocialIcons' => $baseDir . '/lib/colibriwp/src/Components/FrontHeader/TopBarSocialIcons.php',
    'ColibriWP\\Theme\\Components\\FrontPageContent' => $baseDir . '/lib/colibriwp/src/Components/FrontPageContent.php',
    'ColibriWP\\Theme\\Components\\Header' => $baseDir . '/lib/colibriwp/src/Components/Header.php',
    'ColibriWP\\Theme\\Components\\Header\\HeaderMenu' => $baseDir . '/lib/colibriwp/src/Components/Header/HeaderMenu.php',
    'ColibriWP\\Theme\\Components\\Header\\HeroStyle' => $baseDir . '/lib/colibriwp/src/Components/Header/HeroStyle.php',
    'ColibriWP\\Theme\\Components\\Header\\Logo' => $baseDir . '/lib/colibriwp/src/Components/Header/Logo.php',
    'ColibriWP\\Theme\\Components\\Header\\NavBarStyle' => $baseDir . '/lib/colibriwp/src/Components/Header/NavBarStyle.php',
    'ColibriWP\\Theme\\Components\\Header\\TopBar' => $baseDir . '/lib/colibriwp/src/Components/Header/TopBar.php',
    'ColibriWP\\Theme\\Components\\InnerHeader\\Hero' => $baseDir . '/lib/colibriwp/src/Components/InnerHeader/Hero.php',
    'ColibriWP\\Theme\\Components\\InnerHeader\\NavBar' => $baseDir . '/lib/colibriwp/src/Components/InnerHeader/NavBar.php',
    'ColibriWP\\Theme\\Components\\InnerHeader\\Title' => $baseDir . '/lib/colibriwp/src/Components/InnerHeader/Title.php',
    'ColibriWP\\Theme\\Components\\InnerHeader\\TopBar' => $baseDir . '/lib/colibriwp/src/Components/InnerHeader/TopBar.php',
    'ColibriWP\\Theme\\Components\\MainContent' => $baseDir . '/lib/colibriwp/src/Components/MainContent.php',
    'ColibriWP\\Theme\\Components\\MainContent\\ArchiveLoop' => $baseDir . '/lib/colibriwp/src/Components/MainContent/ArchiveLoop.php',
    'ColibriWP\\Theme\\Components\\MainContent\\Loop' => $baseDir . '/lib/colibriwp/src/Components/MainContent/Loop.php',
    'ColibriWP\\Theme\\Components\\MainContent\\PostLoop' => $baseDir . '/lib/colibriwp/src/Components/MainContent/PostLoop.php',
    'ColibriWP\\Theme\\Components\\MainContent\\SingleItemTemplate' => $baseDir . '/lib/colibriwp/src/Components/MainContent/SingleItemTemplate.php',
    'ColibriWP\\Theme\\Components\\PageContent' => $baseDir . '/lib/colibriwp/src/Components/PageContent.php',
    'ColibriWP\\Theme\\Components\\PageNotFound' => $baseDir . '/lib/colibriwp/src/Components/PageNotFound.php',
    'ColibriWP\\Theme\\Components\\PageSearch' => $baseDir . '/lib/colibriwp/src/Components/PageSearch.php',
    'ColibriWP\\Theme\\Components\\Sidebar' => $baseDir . '/lib/colibriwp/src/Components/Sidebar.php',
    'ColibriWP\\Theme\\Components\\SingleContent' => $baseDir . '/lib/colibriwp/src/Components/SingleContent.php',
    'ColibriWP\\Theme\\Components\\WooContent' => $baseDir . '/lib/colibriwp/src/Components/WooContent.php',
    'ColibriWP\\Theme\\Core\\ComponentBase' => $baseDir . '/lib/colibriwp/src/Core/ComponentBase.php',
    'ColibriWP\\Theme\\Core\\ComponentInterface' => $baseDir . '/lib/colibriwp/src/Core/ComponentInterface.php',
    'ColibriWP\\Theme\\Core\\ConfigurableInterface' => $baseDir . '/lib/colibriwp/src/Core/ConfigurableInterface.php',
    'ColibriWP\\Theme\\Core\\EnableKubioInCustomizerPanel' => $baseDir . '/lib/colibriwp/src/Core/EnableKubioInCustomizerPanel.php',
    'ColibriWP\\Theme\\Core\\Hooks' => $baseDir . '/lib/colibriwp/src/Core/Hooks.php',
    'ColibriWP\\Theme\\Core\\PartialComponent' => $baseDir . '/lib/colibriwp/src/Core/PartialComponent.php',
    'ColibriWP\\Theme\\Core\\PartialComponentInterface' => $baseDir . '/lib/colibriwp/src/Core/PartialComponentInterface.php',
    'ColibriWP\\Theme\\Core\\Tree' => $baseDir . '/lib/colibriwp/src/Core/Tree.php',
    'ColibriWP\\Theme\\Core\\Utils' => $baseDir . '/lib/colibriwp/src/Core/Utils.php',
    'ColibriWP\\Theme\\Customizer' => $baseDir . '/lib/colibriwp/src/Customizer.php',
    'ColibriWP\\Theme\\Customizer\\ControlFactory' => $baseDir . '/lib/colibriwp/src/Customizer/ControlFactory.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\AlignButtonGroupControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/AlignButtonGroupControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\ButtonControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/ButtonControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\ButtonGroupControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/ButtonGroupControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\ColibriControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/ColibriControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\ColibriWPControlsAdapter' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/ColibriWPControlsAdapter.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\ColorControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/ColorControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\ComposedControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/ComposedControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\ControlsGroupControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/ControlsGroupControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\CroppedImageControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/CroppedImageControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\GradientControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/GradientControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\IconControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/IconControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\ImageControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/ImageControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\InputControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/InputControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\LinkedSelectControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/LinkedSelectControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\MediaControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/MediaControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\PenControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/PenControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\PluginMessageControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/PluginMessageControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\RepeaterControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/RepeaterControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\SelectControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/SelectControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\SelectIconControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/SelectIconControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\SeparatorControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/SeparatorControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\SliderControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/SliderControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\SpacingControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/SpacingControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\SwitchControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/SwitchControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\UploadControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/UploadControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\VideoControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/VideoControl.php',
    'ColibriWP\\Theme\\Customizer\\Controls\\VueControl' => $baseDir . '/lib/colibriwp/src/Customizer/Controls/VueControl.php',
    'ColibriWP\\Theme\\Customizer\\CustomizerApi' => $baseDir . '/lib/colibriwp/src/Customizer/CustomizerApi.php',
    'ColibriWP\\Theme\\Customizer\\Formatter' => $baseDir . '/lib/colibriwp/src/Customizer/Formatter.php',
    'ColibriWP\\Theme\\Customizer\\PanelFactory' => $baseDir . '/lib/colibriwp/src/Customizer/PanelFactory.php',
    'ColibriWP\\Theme\\Customizer\\Panel\\ColibriPanel' => $baseDir . '/lib/colibriwp/src/Customizer/Panel/ColibriPanel.php',
    'ColibriWP\\Theme\\Customizer\\SectionFactory' => $baseDir . '/lib/colibriwp/src/Customizer/SectionFactory.php',
    'ColibriWP\\Theme\\Customizer\\Sections\\ColibriSection' => $baseDir . '/lib/colibriwp/src/Customizer/Sections/ColibriSection.php',
    'ColibriWP\\Theme\\Defaults' => $baseDir . '/lib/colibriwp/src/Defaults.php',
    'ColibriWP\\Theme\\HeaderPresets' => $baseDir . '/lib/colibriwp/src/HeaderPresets.php',
    'ColibriWP\\Theme\\PluginsManager' => $baseDir . '/lib/colibriwp/src/PluginsManager.php',
    'ColibriWP\\Theme\\Theme' => $baseDir . '/lib/colibriwp/src/Theme.php',
    'ColibriWP\\Theme\\ThemeTranslations' => $baseDir . '/lib/colibriwp/src/ThemeTranslations.php',
    'ColibriWP\\Theme\\Translations' => $baseDir . '/lib/colibriwp/src/Translations.php',
    'ColibriWP\\Theme\\View' => $baseDir . '/lib/colibriwp/src/View.php',
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'Kubio\\StarterContent\\StarterContent' => $baseDir . '/lib/kubio-starter-content/src/StarterContent.php',
    'Kubio\\Theme\\AiOnboarding' => $baseDir . '/lib/kubio-themebase/src/AiOnboarding.php',
    'Kubio\\Theme\\Components\\Common\\HeroStyle' => $baseDir . '/lib/kubio-themebase/src/Components/Common/HeroStyle.php',
    'Kubio\\Theme\\Components\\Common\\NavigationStyle' => $baseDir . '/lib/kubio-themebase/src/Components/Common/NavigationStyle.php',
    'Kubio\\Theme\\Components\\Footer' => $baseDir . '/lib/kubio-themebase/src/Components/Footer.php',
    'Kubio\\Theme\\Components\\FrontHeader\\Buttons' => $baseDir . '/lib/kubio-themebase/src/Components/FrontHeader/Buttons.php',
    'Kubio\\Theme\\Components\\FrontHeader\\Hero' => $baseDir . '/lib/kubio-themebase/src/Components/FrontHeader/Hero.php',
    'Kubio\\Theme\\Components\\FrontHeader\\Image' => $baseDir . '/lib/kubio-themebase/src/Components/FrontHeader/Image.php',
    'Kubio\\Theme\\Components\\FrontHeader\\Navigation' => $baseDir . '/lib/kubio-themebase/src/Components/FrontHeader/Navigation.php',
    'Kubio\\Theme\\Components\\FrontHeader\\Subtitle' => $baseDir . '/lib/kubio-themebase/src/Components/FrontHeader/Subtitle.php',
    'Kubio\\Theme\\Components\\FrontHeader\\Title' => $baseDir . '/lib/kubio-themebase/src/Components/FrontHeader/Title.php',
    'Kubio\\Theme\\Components\\FrontHeader\\TopBar' => $baseDir . '/lib/kubio-themebase/src/Components/FrontHeader/TopBar.php',
    'Kubio\\Theme\\Components\\FrontHeader\\TopBarListIcons' => $baseDir . '/lib/kubio-themebase/src/Components/FrontHeader/TopBarListIcons.php',
    'Kubio\\Theme\\Components\\FrontHeader\\TopBarSocialIcons' => $baseDir . '/lib/kubio-themebase/src/Components/FrontHeader/TopBarSocialIcons.php',
    'Kubio\\Theme\\Components\\FrontPageContent' => $baseDir . '/lib/kubio-themebase/src/Components/FrontPageContent.php',
    'Kubio\\Theme\\Components\\Header' => $baseDir . '/lib/kubio-themebase/src/Components/Header.php',
    'Kubio\\Theme\\Components\\HeaderMenu' => $baseDir . '/lib/kubio-themebase/src/Components/HeaderMenu.php',
    'Kubio\\Theme\\Components\\Header\\Logo' => $baseDir . '/lib/kubio-themebase/src/Components/Header/Logo.php',
    'Kubio\\Theme\\Components\\InnerHeader\\Hero' => $baseDir . '/lib/kubio-themebase/src/Components/InnerHeader/Hero.php',
    'Kubio\\Theme\\Components\\InnerHeader\\Navigation' => $baseDir . '/lib/kubio-themebase/src/Components/InnerHeader/Navigation.php',
    'Kubio\\Theme\\Components\\InnerHeader\\Title' => $baseDir . '/lib/kubio-themebase/src/Components/InnerHeader/Title.php',
    'Kubio\\Theme\\Components\\InnerHeader\\TopBar' => $baseDir . '/lib/kubio-themebase/src/Components/InnerHeader/TopBar.php',
    'Kubio\\Theme\\Components\\MainContent' => $baseDir . '/lib/kubio-themebase/src/Components/MainContent.php',
    'Kubio\\Theme\\Components\\MainContent\\ArchiveLoop' => $baseDir . '/lib/kubio-themebase/src/Components/MainContent/ArchiveLoop.php',
    'Kubio\\Theme\\Components\\MainContent\\Loop' => $baseDir . '/lib/kubio-themebase/src/Components/MainContent/Loop.php',
    'Kubio\\Theme\\Components\\MainContent\\PostLoop' => $baseDir . '/lib/kubio-themebase/src/Components/MainContent/PostLoop.php',
    'Kubio\\Theme\\Components\\MainContent\\SingleItemTemplate' => $baseDir . '/lib/kubio-themebase/src/Components/MainContent/SingleItemTemplate.php',
    'Kubio\\Theme\\Components\\PageContent' => $baseDir . '/lib/kubio-themebase/src/Components/PageContent.php',
    'Kubio\\Theme\\Components\\PageNotFound' => $baseDir . '/lib/kubio-themebase/src/Components/PageNotFound.php',
    'Kubio\\Theme\\Components\\SingleContent' => $baseDir . '/lib/kubio-themebase/src/Components/SingleContent.php',
    'Kubio\\Theme\\Flags' => $baseDir . '/lib/kubio-themebase/src/Flags.php',
    'Kubio\\Theme\\Panels\\AiOnboardingPanel' => $baseDir . '/lib/kubio-themebase/src/Panels/AiOnboardingPanel.php',
    'Kubio\\Theme\\ReactAssetsRegistry' => $baseDir . '/lib/kubio-themebase/src/ReactAssetsRegistry.php',
    'Kubio\\Theme\\Singleton' => $baseDir . '/lib/kubio-themebase/src/Singleton.php',
    'Kubio\\Theme\\Theme' => $baseDir . '/lib/kubio-themebase/src/Theme.php',
    'Wolfcast\\BrowserDetection' => $baseDir . '/lib/browser-detection/BrowserDetection.php',
);
