<?php

// autoload_psr4.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Wolfcast\\' => array($baseDir . '/lib/browser-detection'),
    'Kubio\\Theme\\' => array($baseDir . '/lib/kubio-themebase/src'),
    'Kubio\\StarterContent\\' => array($baseDir . '/lib/kubio-starter-content/src'),
    'ColibriWP\\Theme\\' => array($baseDir . '/lib/colibriwp/src'),
);
