<div class="wp-block wp-block-kubio-section  position-relative wp-block-kubio-section__outer kubio-footer__k__vP0mYzy99sE-outer kubio-local-689-outer d-flex h-section-global-spacing align-items-lg-center align-items-md-center align-items-center" data-kubio="kubio/section" id="footer">
	<div class="position-relative wp-block-kubio-section__inner kubio-footer__k__vP0mYzy99sE-inner kubio-local-689-inner h-section-grid-container h-section-boxed-container">
		<div class="wp-block wp-block-kubio-row  position-relative wp-block-kubio-row__container kubio-footer__k__e6PC03TfkKI-container kubio-local-690-container gutters-row-lg-2 gutters-row-v-lg-2 gutters-row-md-2 gutters-row-v-md-2 gutters-row-0 gutters-row-v-2" data-kubio="kubio/row">
			<div class="position-relative wp-block-kubio-row__inner kubio-footer__k__e6PC03TfkKI-inner kubio-local-690-inner h-row align-items-lg-stretch align-items-md-stretch align-items-stretch justify-content-lg-center justify-content-md-center justify-content-center gutters-col-lg-2 gutters-col-v-lg-2 gutters-col-md-2 gutters-col-v-md-2 gutters-col-0 gutters-col-v-2">
				<div class="wp-block wp-block-kubio-column  position-relative wp-block-kubio-column__container kubio-footer__k__nJpox2eRXHV-container kubio-local-691-container d-flex h-col-lg-12 h-col-md-12 h-col-12" data-kubio="kubio/column">
					<div class="position-relative wp-block-kubio-column__inner kubio-footer__k__nJpox2eRXHV-inner kubio-local-691-inner d-flex h-flex-basis h-px-lg-2 v-inner-lg-2 h-px-md-2 v-inner-md-2 h-px-2 v-inner-2">
						<div class="position-relative wp-block-kubio-column__align kubio-footer__k__nJpox2eRXHV-align kubio-local-691-align h-y-container h-column__content h-column__v-align flex-basis-100 align-self-lg-start align-self-md-start align-self-start">
							<?php kubio_theme_print_footer_copyright(); ?>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>
