/*
Theme Name: Corporate Plus
Theme URI: https://www.acmethemes.com/themes/corporate-plus
Author: acmethemes
Author URI: https://www.acmethemes.com/
Description: Corporate Plus is a professional-looking multi-purpose WordPress theme. It is a simple, attractive and responsive theme with lots of theme options which helps the user to easily customize the theme.  Corporate plus theme is also a one-page ready theme, you can easily design this theme on one-page sites too. It includes unique slider section, about section, service section, parallax section, blog section and contact section. Besides, this theme has footer widgets, full screen and responsive slider, sticky menu and many more. Corporate Plus is WooCommerce compatible theme, now you can easily sell your products online. This theme is fully widgetized, so it is easier to operate. If you want to head start by installing demo content it is available through Acme Demo Setup plugin. The code/setup is easy to customize and extend by various hooks offered in the build. This is the ideal WordPress theme for anyone looking to spice-up their site. This theme is child theme ready, cross-browser compatible, responsive and SEO friendly theme.  Support Forum: https://www.acmethemes.com/supports/ Demo: http://www.demo.acmethemes.com/corporate-plus/
Version: 3.1.0
License: GNU General Public License v2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Tested up to: 6.8
Requires PHP: 5.6.20
Text Domain: corporate-plus
Tags: e-commerce, portfolio, education, one-column, two-columns, three-columns, four-columns, left-sidebar, right-sidebar, custom-background, custom-colors, custom-menu, custom-logo, footer-widgets, featured-images, full-width-template, rtl-language-support, sticky-post, theme-options, threaded-comments, translation-ready, wide-blocks

*/

/*--------------------------------------------------------------
>>> TABLE OF CONTENTS:
----------------------------------------------------------------
# Normalize
# Typography
# Elements
# Forms
# Navigation
	## Links
	## Menus
# Accessibility
# Alignments
# Clearings
# Widgets
# Content
    ## Posts and pages
	## Post Formats
	## Comments
# Infinite scroll
# Media
	## Captions
	## Galleries
#Custom CSS

/*--------------------------------------------------------------
# Normalize
--------------------------------------------------------------*/
html {
    font-family: sans-serif;
    box-sizing: border-box;
    -webkit-text-size-adjust: 100%;
}

body {
    margin: 0;
    -ms-word-wrap: break-word;
    word-wrap: break-word;
}

article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
nav,
section,
summary {
    display: block
}

audio,
canvas,
progress,
video {
    display: inline-block;
    vertical-align: baseline
}

audio:not([controls]) {
    display: none;
    height: 0
}

[hidden],
template {
    display: none
}

a {
    background: transparent;
    color: #aaa;
}

a:hover,
a:active,
a:focus {
    outline: 0;
    background: transparent;
    text-decoration: none;
}

abbr[title] {
    border-bottom: 1px dotted
}

b,
strong {
    font-weight: bold;
}

dfn {
    font-style: italic
}

mark,
ins {
    color: #2d2d2d;
}

small {
    font-size: 80%
}

sub,
sup {
    font-size: 75%;
    line-height: 0;
    position: relative;
    vertical-align: baseline;
}

sup {
    top: -0.5em
}

sub {
    bottom: -0.25em
}

img {
    border: 0;
    max-width: 100%;
    height: auto;
}

svg:not(:root) {
    overflow: hidden
}

hr {
    -moz-box-sizing: content-box;
    box-sizing: content-box;
    height: 0;
}

pre {
    overflow: auto;
}

code,
kbd,
pre,
samp {
    font-family: monospace, monospace;
    font-size: 1em;
}

button,
input,
optgroup,
select,
textarea {
    color: inherit;
    font: inherit;
    margin: 0;
    font-size: 16px;
    font-size: 1.5rem;
    line-height: 1.5;
}

button {
    overflow: visible;
}

button,
select {
    text-transform: none;
}

select {
    background: #ffffff;
    border: 1px solid #cccccc;
    max-width: 100%;
    padding: 8px 15px;
}

button,
html input[type="button"],
input[type="reset"],
input[type="submit"] {
    -webkit-appearance: button;
    cursor: pointer;
}

button[disabled],
html input[disabled] {
    cursor: default
}

button::-moz-focus-inner,
input::-moz-focus-inner {
    border: 0;
    padding: 0
}

input {
    line-height: normal;
    max-width: 100%;
    padding: 7px;
}

input[type="checkbox"],
input[type="radio"] {
    box-sizing: border-box;
    padding: 0;
}

input[type="number"]::-webkit-inner-spin-button,
input[type="number"]::-webkit-outer-spin-button {
    height: auto;
}

input[type="search"] {
    -webkit-appearance: textfield;
    -moz-box-sizing: content-box;
    -webkit-box-sizing: content-box;
    box-sizing: content-box
}

input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
    -webkit-appearance: none
}

fieldset {
    border: 1px solid #c0c0c0;
    margin: 0 2px;
    padding: 0.35em 0.625em 0.75em
}

legend {
    border: 0;
    padding: 0
}

textarea {
    overflow: auto
}

optgroup {
    font-weight: bold
}

table {
    border-collapse: collapse;
    border-spacing: 0;
    margin: 0 0 1.5em;
    width: 100%;
}

td,
th {
    padding: 0
}

/*--------------------------------------------------------------
# Typography
--------------------------------------------------------------*/
body {
    font-style: normal;
    font-family: 'Lato', sans-serif;
    font-size: 16px;
    color: #2d2d2d;
    font-weight: 400;
}

h1,
h1 a,
h2,
h2 a,
h3,
h3 a,
h4,
h4 a,
h5,
h5 a,
h6,
h6 a {
    font-family: 'Lato', sans-serif;
    text-transform: uppercase;
    font-weight: 700;
    color: #2d2d2d;
}

h1 {
    font-size: 26px;
}

h2 {
    font-size: 20px;
}

h3 {
    font-size: 18px;
}

h4 {
    font-size: 16px;
}

h5 {
    font-size: 14px;
}

h6 {
    font-size: 12px;
}

ul,
ol {
    margin: 0 0 1.5em 3em;
}

ul {
    list-style: disc;
}

ol {
    list-style: decimal;
}

dt {
    font-weight: bold;
}

dd {
    margin: 0 1.5em 1.5em;
}

blockquote:before,
blockquote:after,
q:before,
q:after {
    content: "";
}

blockquote,
q {
    quotes: "" "";
}

address {
    margin: 0 0 1.5em;
}

.entry-meta i.fa,
.entry-footer i.fa {
    margin-right: 5px;
}

.row {
    margin-bottom: 50px;
}

/*--------------------------------------------------------------
# Navigation
--------------------------------------------------------------*/
.navbar {
    background: transparent;
    padding: 30px 0;
    transition: all 0.2s ease-out 0s;
    z-index: 3000;
}

.navbar-brand>img {
    display: block;
    max-height: 55px;
    max-width: 310px;
}

.navbar-small,
.navbar-no-fs {
    background: rgba(0, 0, 0, 1) !important;
    padding: 5px 0px !important;
}

.navbar .navbar-brand {
    margin: 0 0 0 15px;
    padding: 0;
    max-width: 40%;
}

.no-fs-clearfix {
    height: 50px;
}

.navbar .navbar-toggle {
    background-color: #2d2d2d;
    color: #ffffff;
    font-size: 22px;
    border-radius: 4px;
    margin-bottom: 3px;
    margin-top: 3px;
    outline: medium none;
    transition: all 0.2s ease-out 0s;
}

.navbar .navbar-toggle .icon-bar {
    background-color: #2d2d2d;
}

.navbar-nav>li {
    float: none;
}

.nav>li>a:focus {
    background-color: transparent;
}

/*remove fixed top*/
.navbar-remove-fixed-top {
    position: relative;
    margin: 0;
    padding-bottom: 10px;
    background: #000000;
}

/*main-navigation*/
.main-navigation {
    text-align: right;
    float: right;
}

.main-navigation ul {
    list-style: none;
    margin: 0;
    padding-left: 0;
}

.main-navigation li {
    display: inline-block;
    position: relative;
}

.main-navigation a {
    color: #ffffff;
    display: block;
    padding: 12px 16px;
    text-decoration: none;
    font-size: 16px;
    transition: all 0.5s ease 0s;
    -webkit-transition: all 0.5s ease 0s;
    -moz-transition: all 0.5s ease 0s;
    -o-transition: all 0.5s ease 0s;
    -ms-transition: all 0.5s ease 0s;

}

.main-navigation a:hover,
.main-navigation a:focus {
    background: transparent;
}

/*submenu*/
.main-navigation ul ul {
    box-shadow: 0 3px 3px rgba(0, 0, 0, 0.2);
    float: left;
    position: absolute;
    left: -999em;
    z-index: 99999;
    background: #2d2d2d;
    text-align: left;
}

.main-navigation ul ul ul {
    top: 0;
}

.main-navigation ul ul a {
    font-size: 14px;
    padding: 12px 18px;
    width: 200px;
}

.main-navigation li:hover>a {
    background: rgba(0, 0, 0, 0);
}

.main-navigation ul ul a:hover {
    background: rgba(0, 0, 0, 0.2);
}

.main-navigation ul li:hover>ul {
    left: auto;
}

.main-navigation ul ul li:hover>ul {
    left: 100%;
}

.main-navigation li:focus-within>a {
    background: rgba(0, 0, 0, 0);
}

.main-navigation ul ul a:focus-within {
    background: rgba(0, 0, 0, 0.2);
}

.main-navigation ul li:focus-within>ul {
    left: auto;
}

.main-navigation ul ul li:focus-within>ul {
    left: 100%;
}

.main-navigation .current_page_item>a:before,
.main-navigation .current-menu-item>a:before,
.main-navigation .active>a:before,
.main-navigation .current_page_ancestor>a:before {
    content: "";
    height: 5px;
    left: 0;
    margin: auto;
    position: absolute;
    right: 0;
    bottom: 0;
    width: 100%;
}

.main-navigation .current_page_item>a,
.main-navigation .current-menu-item>a,
.main-navigation .active>a,
.main-navigation .current_page_ancestor>a {
    background: none repeat scroll 0 0 rgba(0, 0, 0, 0);
}

@media screen and (max-width: 1199px) and (min-width: 1024px) {
    .main-navigation a {
        font-size: 16px;
        padding: 18px 23px;
    }
}

@media screen and (max-width: 836px) {
    .main-navigation {
        text-align: left;
    }
}

@media screen and (max-width: 1023px) {
    .main-navigation a {
        font-size: 14px;
        padding: 16px 13px;
    }

    .main-navigation li.menu-item-has-children>a,
    .main-navigation li.menu-item-has-children:hover>a,
    .main-navigation li.menu-item-has-children:focus>a {
        padding: 16px 36px 16px 10px;
    }

    .main-navigation ul ul a {
        font-size: 14px;
    }

    .main-navigation ul ul {
        top: 3.2em;
    }
}

@media screen and (max-width: 767px) {
    .main-navigation {
        float: none;
    }

    .navbar {
        margin-bottom: 0;
    }

    .main-navigation li {
        float: none;
        display: block;
        border-top: 1px solid #999;
    }

    .main-navigation {
        background: transparent;
    }

    .main-navigation.toggled .nav-menu {
        background: none repeat scroll 0 0 #2d2d2d;
    }

    .main-navigation ul ul {
        background: none repeat scroll 0 0 #2d2d2d;
        display: block;
        float: none;
        position: static;
        text-align: left;
        box-shadow: none;
    }

    .main-navigation ul ul li {
        padding-left: 25px;
    }

    .main-navigation ul ul li a {
        display: block;
        width: auto;
    }

    .main-navigation ul ul a:hover,
    .main-navigation ul ul a:focus {
        background: rgba(0, 0, 0, 0);
    }
}

@media screen and (min-width: 768px) {
    .navbar-small .main-navigation ul.nav-menu>li>a {
        padding: 23px 12px;
        transition: all 0.5s ease 0s;
        -webkit-transition: all 0.9s ease 0s;
        -moz-transition: all 0.9s ease 0s;
        -o-transition: all 0.9s ease 0s;
        -ms-transition: all 0.9s ease 0s;
    }
}

@media screen and (max-width: 767px) {

    .navbar .container>.navbar-collapse,
    .navbar .container>.navbar-header {
        margin: 0;
    }
}

.site-main .comment-navigation,
.site-main .posts-navigation,
.site-main .post-navigation {
    margin: 0 0 1.5em;
    overflow: hidden;
}

.comment-navigation .nav-previous,
.posts-navigation .nav-previous,
.post-navigation .nav-previous {
    float: left;
    width: 50%;
}

.comment-navigation .nav-next,
.posts-navigation .nav-next,
.post-navigation .nav-next {
    float: right;
    text-align: right;
    width: 50%;
}

/*inner page nav fixed*/
.at-inner-nav {
    background: rgba(0, 0, 0, 0.7);
}

/*--------------------------------------------------------------
# Accessibility
--------------------------------------------------------------*/
/* Text meant only for screen readers. */
.screen-reader-text {
    clip: rect(1px, 1px, 1px, 1px);
    position: absolute !important;
    height: 1px;
    width: 1px;
    overflow: hidden;
}

.screen-reader-text:focus {
    background-color: #f1f1f1;
    border-radius: 3px;
    box-shadow: 0 0 2px 2px rgba(0, 0, 0, 0.6);
    clip: auto !important;
    display: block;
    font-size: 14px;
    font-weight: bold;
    height: auto;
    left: 5px;
    line-height: normal;
    padding: 15px 23px 14px;
    text-decoration: none;
    top: 5px;
    width: auto;
    z-index: 100000;
    /* Above WP toolbar. */
}

/*--------------------------------------------------------------
# Alignments
--------------------------------------------------------------*/
.alignleft {
    display: inline;
    float: left;
    margin-right: 1.5em;
}

.alignright {
    display: inline;
    float: right;
    margin-left: 1.5em;
}

.aligncenter {
    clear: both;
    display: block;
    margin-left: auto;
    margin-right: auto;
}

/*--------------------------------------------------------------
# Clearings
--------------------------------------------------------------*/
.clear {
    clear: both;
}

.clearfix:after,
.clearfix:before {
    display: table;
    content: ""
}

.clearfix:after {
    clear: both
}

.clearfix {
    *zoom: 1
}

* {
    box-sizing: border-box;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
}

/*--------------------------------------------------------------
# Widgets
--------------------------------------------------------------*/
.widget ul,
.widget ol {
    margin: 0;
    padding: 0;
}

/* Search widget. */
.widget_search .search-submit {
    display: none;
}

.widget_search {
    position: relative;
    width: 100%;
}

/*** CALENDER ***/
#calendar_wrap #wp-calendar {
    width: 100%;
}

#calendar_wrap #wp-calendar caption {
    font-size: 13px;
    font-weight: 700;
    padding: 15px 0;
    text-align: center;
    text-transform: uppercase;
}

#calendar_wrap table,
#calendar_wrap th,
#calendar_wrap td,
#calendar_wrap tr {
    border: 1px solid rgba(0, 0, 0, 0.03);
    border-collapse: collapse;
    padding: 3px;
}

#calendar_wrap #wp-calendar th,
#calendar_wrap #wp-calendar td {
    border: 1px solid rgba(0, 0, 0, 0.03);
    text-align: center;
}

#calendar_wrap th {
    background: rgba(0, 0, 0, 0.03);
    line-height: 20px;
    text-shadow: 0 1px 0 rgba(0, 0, 0, 0.05);
}

#calendar_wrap #wp-calendar #today,
#calendar_wrap #wp-calendar #today a {
    color: #ffffff;
}

/*--------------------------------------------------------------
# Content
--------------------------------------------------------------*/
.inner-main-title {
    position: relative;
    width: 100%;
    height: 300px;
    background-size: cover;
    background-color: #2D2D2D;
    text-align: center;
    padding-top: 187px;
    margin-bottom: 60px;
}

.inner-main-title .entry-title,
.inner-main-title .page-title {
    color: #ffffff;
    font-size: 28px;
    font-weight: 700;
}

/*--------------------------------------------------------------
## Posts and pages
--------------------------------------------------------------*/
article.sticky {
    display: block;
}

.hentry {
    margin: 0 0 1.5em;
}

.updated:not(.published) {
    display: none;
}

.single .byline,
.group-blog .byline {
    display: inline;
}

.page-content,
.entry-content,
.entry-summary {
    margin: 1.5em 0 0;
}

.page-links {
    clear: both;
    margin: 0 0 1.5em;
}

/*--------------------------------------------------------------
## Post Formats
--------------------------------------------------------------*/
.format-aside .entry-title,
.format-image .entry-title,
.format-video .entry-title,
.format-quote .entry-title,
.format-gallery .entry-title,
.format-status .entry-title,
.format-link .entry-title,
.format-audio .entry-title,
.format-chat .entry-title {
    font-size: 20px;
}

.blog .format-status .entry-title,
.archive .format-status .entry-title {
    display: none;
}

.blog .format-aside .entry-title,
.archive .format-aside .entry-title {
    display: none;
}

/*--------------------------------------------------------------
## Comments
--------------------------------------------------------------*/
.comment-reply-title,
.comments-title {
    border-bottom: 1px solid #d9d9d9;
    font-size: 16px;
    font-weight: 500;
    line-height: 48px;
    margin-bottom: 15px;
    position: relative;
}

.comment-form input {
    border: 1px solid #d9d9d9;
    color: #b8b8b8;
    font-size: 14px;
    padding: 10px;
    width: 313px;
}

.comment-form-author input,
.comment-form-email input {
    float: left;
    margin: 0 0 16px;
}

.comment-form-author input {
    margin: 0 29px 16px 0;
}

.comment-form-url input {
    clear: both;
    width: 655px;
}

.comment-form textarea {
    width: 77%;
    display: block;
    border: 1px solid #d9d9d9;
    resize: none;
    font-size: 14px;
    padding: 10px;
}

.comment-form .form-submit input,
.read-more {
    color: #ffffff;
    font-size: 13px;
    font-weight: 700;
    text-align: center;
    line-height: 26px;
    padding: 4px 10px;
    width: auto;
    transition: all 0.3s ease-in-out 0s;
    -webkit-transition: all 0.3s ease-in-out 0s;
    -moz-transition: all 0.3s ease-in-out 0s;
}

.comment-list {
    margin: 0 0 20px 0;
    font-size: 13px;
    list-style-type: none;
}

.comment-list li.comment {
    list-style-type: none;
    clear: both;
}

.comment-list li.comment .comment-body {
    border-bottom: 1px solid #e5e5e5;
    margin: 0 0 20px;
    background-color: #fff;
    border-radius: 4px;
    box-shadow: 0 0.15em 0.35em 0 rgba(0, 0, 0, 0.133);
    padding: 30px;
    position: relative;
}

.comment-author img {
    float: left;
    margin: 0 20px 0 0;
    border-radius: 50%;
}

.comment-list .fn {
    font-size: 16px;
    font-style: normal;
    font-weight: 700;
    color: #2d2d2d;
}

.comment-list .fa.fa-clock-o {
    font-size: 14px;
    margin-right: 3px;
}

.comment-form p.comment-form-author,
.comment-form p.comment-form-email {
    display: inline-block;
    float: left;
}

.bypostauthor {
    display: block;
}

@media screen and (max-width:679px) {

    .comment-form input,
    .comment-form-url input,
    .comment-form textarea {
        width: 100%;
    }
}

/*--------------------------------------------------------------
# Infinite scroll
--------------------------------------------------------------*/
/* Globally hidden elements when Infinite Scroll is supported and in use. */
.infinite-scroll .posts-navigation,
/* Older / Newer Posts Navigation (always hidden) */
.infinite-scroll.neverending .site-footer {
    /* Theme Footer (when set to scrolling) */
    display: none;
}

/* When Infinite Scroll has reached its end we need to re-display elements that were hidden (via .neverending) before. */
.infinity-end.neverending .site-footer {
    display: block;
}

/*--------------------------------------------------------------
# Media
--------------------------------------------------------------*/
.page-content .wp-smiley,
.entry-content .wp-smiley,
.comment-content .wp-smiley {
    border: none;
    margin-bottom: 0;
    margin-top: 0;
    padding: 0;
}

/* Make sure embeds and iframes fit their containers. */
embed,
iframe,
object {
    max-width: 100%;
}

/*--------------------------------------------------------------
## Captions
--------------------------------------------------------------*/
.wp-caption {
    margin-bottom: 1.5em;
    max-width: 100%;
}

.wp-caption img[class*="wp-image-"] {
    display: block;
    margin: 0 auto;
}

.wp-caption-text {
    text-align: center;
}

.wp-caption .wp-caption-text {
    margin: 0.8075em 0;
}

/*--------------------------------------------------------------
## Galleries
--------------------------------------------------------------*/
.gallery {
    margin-bottom: 1.5em;
}

.gallery-item {
    display: inline-block;
    text-align: center;
    vertical-align: top;
    width: 100%;
    padding: 2px;
}

.gallery-columns-2 .gallery-item {
    max-width: 50%;
}

.gallery-columns-3 .gallery-item {
    max-width: 33.33%;
}

.gallery-columns-4 .gallery-item {
    max-width: 25%;
}

.gallery-columns-5 .gallery-item {
    max-width: 20%;
}

.gallery-columns-6 .gallery-item {
    max-width: 16.66%;
}

.gallery-columns-7 .gallery-item {
    max-width: 14.28%;
}

.gallery-columns-8 .gallery-item {
    max-width: 12.5%;
}

.gallery-columns-9 .gallery-item {
    max-width: 11.11%;
}

.gallery-caption {
    display: block;
}

/*------------------------------------------------------*\
    #Custom CSS
\*--------------------------------------------------------*/
/*-----------------*\
    #HEADER
\*-----------------*/
.site-title,
.site-title a {
    color: #ffffff;
    font-size: 30px;
    margin: 0;
}

.site-description,
.site-description a {
    color: #ffffff;
    margin: 0;
}

/*slider*/
#at-banner-slider {
    position: relative;
    width: 100%;
    background-color: #2D2D2D;
}

.home-bxslider {
    overflow: hidden;
    position: relative;
}

.at-featured-text-slider {
    display: none;
}

.text-slider-wrapper {
    position: absolute;
    top: 50%;
    width: 100%;
    text-align: center;
    display: inline-block;
    padding: 40px;
    transform: translateY(-50%);
}

.text-slider-caption {
    margin-left: auto;
    margin-right: auto;
    padding-left: 0;
    width: 80%;
    margin-bottom: 30px;
    color: #ffffff;
    font-size: 18px;
}

.text-slider-wrapper ul {
    margin: 0;
    padding: 0;
}

.bx-wrapper .bx-prev {
    left: 10px;
}

.bx-wrapper .bx-next {
    right: 10px;
}

.bx-wrapper .bx-controls-direction a {
    position: absolute;
    opacity: 0;
    top: 50%;
    margin-top: -16px;
    outline: 0;
    width: 32px;
    height: 32px;
    z-index: 9999;
}

.bx-wrapper:hover .bx-controls-direction a {
    opacity: 1;
}

.bx-wrapper:focus-within .bx-controls-direction a {
    opacity: 1;
}

.bx-wrapper .bx-controls-direction a.disabled {
    display: none;
}

.bx-controls-direction a>i {
    font-size: 4em;
}

.bx-controls-direction a>i:hover,
.bx-controls-direction a>i:focus {
    color: #ffffff;
}

.home-bxslider .lead {
    display: block;
    color: #ffffff;
    font-weight: bold;
    font-size: 56px;
    text-transform: uppercase;
    width: 80%;
    margin: 0 auto;
}

.scroll-wrap {
    color: #ffffff;
    display: block;
    line-height: 60px;
    right: 50%;
    bottom: 5%;
    text-align: center;
    position: fixed;
    left: 50%;
    margin-left: -20px;
    width: 40px;
    height: 40px;
    background-size: contain;
    background-repeat: no-repeat;
    z-index: 999;
}

.scroll-wrap:hover,
.scroll-wrap:focus {
    color: #dddddd;
}

.scroll-wrap .fa {
    line-height: 60px;
    font-size: 3em;
}

/*image slider start*/
.image-slider-container {
    display: none;
}

.home-fullscreen.full-screen-bg,
.home-fullscreen.full-screen-bg .bx-viewport,
.home-fullscreen.full-screen-bg .bx-wrapper {
    position: relative;
    width: 100%;
    height: 100vh !important;
    top: 0;
    left: 0;
    right: 0;
}

.home-fullscreen.full-screen-bg .bx-viewport .text-slider li {
    height: 100% !important;
}

.bx-wrapper .bx-viewport {
    border: none !important;
}

.at-slide-wrap ul {
    padding-left: 0;
    margin: 0;
    list-style: none;
}

.full-screen-bg .at-slide-wrap ul,
.full-screen-bg .at-slide-wrap ul li {
    height: 100% !important;
}

.image-slider-wrapper ul li {
    background-repeat: no-repeat;
    background-position: top center;
    background-size: cover;
    left: 0;
}

.at-slide-wrap ul li img {
    width: 100%;
    vertical-align: top;
}

.at-slide-wrap .bx-wrapper .bx-controls-direction a {
    top: 50%;
}

.home-fullscreen.image-slider .scroll-wrap {
    z-index: 99;
}

/*image slider end*/
@media only screen and (max-width: 767px) {
    .home-bxslider .lead {
        font-size: 36px;
        margin-bottom: 0;
    }
}

/*Image slider Responsive*/
.home-bxslider.responsive-img img {
    width: 100%;
}

.num-1.responsive-img .bx-controls.bx-has-controls-direction {
    display: none !important;
}


@media only screen and (max-width: 640px) and (min-width: 480px) {
    .home-bxslider .lead {
        font-size: 28px;
    }

    .text-slider-caption,
    .banner-title-line.line>span {
        display: none;
    }

    .home-bxslider .bx-wrapper .bx-controls-direction a {
        top: 25%;
    }
}

@media only screen and (max-width: 479px) {

    .text-slider-caption,
    .banner-title-line.line>span {
        display: none;
    }

    .text-slider-caption,
    .banner-title-line.line>span {
        display: none;
    }
}

/*button style*/
.at-btn-wrap {
    margin-bottom: 50px;
    text-align: center;
}

.btn {
    border-radius: 0;
    padding: 10px 35px;
    font-size: 15px;
}

.btn-primary {
    color: #ffffff;
    display: inline-block;
    margin: 10px;
    position: relative;
    -webkit-transform: translateZ(0);
    -ms-transform: translateZ(0);
    transform: translateZ(0);
    border: none;
}

.btn-primary:hover,
.btn-primary:focus {
    background: transparent;
    border: none;
}

.btn-primary:before {
    content: '';
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    -webkit-transition-duration: .3s;
    transition-duration: .3s;
    -webkit-transition-property: top, right, bottom, left;
    transition-property: top, right, bottom, left;
}

.btn-primary:hover:before,
.btn-primary:focus:before {
    top: -4px;
    right: -4px;
    bottom: -4px;
    left: -4px;
}

/*circle*/
.circle {
    display: inline-block;
    width: 50px;
    height: 50px;
    border-radius: 50%;
    text-align: center;
    line-height: 55px;
    transition: all 0.3s ease 0s;
    -webkit-transition: all 0.3s ease 0s;
    -moz-transition: all 0.3s ease 0s;
    -o-transition: all 0.3s ease 0s;
    -ms-transition: all 0.3s ease 0s;
}

.circle:hover,
.circle:focus {
    background: #2d2d2d;
}

.circle .fa {
    color: #ffffff;
}

/*line border*/
.line {
    text-align: center;
    margin-bottom: 10px;
}

.line>span {
    display: inline-block;
    width: 170px;
    height: 2px;
}

/*main title*/
.main-title {
    margin: 50px 0;
    text-align: center;
    color: #000;
    position: relative;
}

.main-title>div {
    text-transform: uppercase;
    font-weight: normal;
    color: #707070;
}

.main-title h2 {
    text-transform: uppercase;
    font-weight: bold;
    font-size: 30px;
}

.main-title p {
    font-size: 16px;
    width: 80%;
    margin: 0 auto;
}

/*about section*/
.about-item {
    margin-bottom: 50px;
}

.about-item i {
    font-size: 25px;
    line-height: 50px;
}

.about-item h4,
.about-item p {
    margin-left: 70px;

}

.about-item h4 {
    font-weight: 700;
}

.about-item p {
    font-size: 16px;
}

/*service*/
.service-item {
    padding: 0 20px;
    text-align: center;
}

.service-item .circle {
    line-height: 60px;
}

@media only screen and (max-width: 1023px) {
    .service-item {
        margin-bottom: 40px;
    }
}

/*parallax*/
.featured-section {
    width: 100%;
    background-position: center 35px;
    background-repeat: no-repeat;
    background-size: cover;
    background-attachment: fixed;
    color: #ffffff;
}

.featured-section h1,
.featured-section h2,
.featured-section h3,
.featured-section p {
    color: #fff;
}

.at-overlay {
    background: rgba(45, 45, 45, 0.5);
    width: 100%;
    height: 100%;
    display: block;
    margin: 0;
    padding: 0;
}

/*blog*/
.blog-item {
    text-align: center;
}

.blog-item h3 {
    margin-bottom: 0;
}

.blog-item .entry-header {
    margin-bottom: 5px;
}

.blog-item .blog-img a {
    overflow: hidden;
    display: block;
}

.blog-img img {
    transition: all 0.5s ease-in-out 0s;
    -webkit-transition: all 0.5s ease-in-out 0s;
    -moz-transition: all 0.5s ease-in-out 0s;
    width: 100%;
}

.blog-img img:hover {
    transform: scale(1.1);
}

/*contact form*/
.contact-form {
    background-attachment: fixed;
    background-image: url("assets/img/continents-bg.png");
    background-position: center 35px;
    background-repeat: no-repeat;
    background-size: cover;
}

.contact-form .form-control {
    background-color: transparent;
    margin-bottom: 20px;
    color: #fff;
    border-width: 2px;
}

.contact-form input[type="text"],
.contact-form input[type="email"] {
    height: 45px;
}

/*--------------------------------------------------------------
# FOOTER
--------------------------------------------------------------*/
.site-footer {
    padding: 20px;
    background: #2d2d2d;
    color: #ffffff;
    position: relative;
}

.site-footer .socials a,
.site-footer .socials a:hover,
.site-footer .socials a:focus {
    color: #ffffff;
}

.site-footer .socials {
    list-style: none;
    margin: 0 0 10px 0;
    padding: 0;
}

.site-footer .socials li {
    display: inline-block;
    padding: 10px;
}

.socials li a {
    width: 32px;
    height: 32px;
    text-align: center;
    line-height: 32px;
    display: inline-block;
    transition: background 0.5s;
    -webkit-transition: background 0.5s;
}

.socials li.facebook a:hover,
.socials li.facebook a:focus {
    background: #3E5993;
}

.socials li.twitter a:hover,
.socials li.twitter a:focus {
    background: #00C3F8;
}

.socials li.youtube a:hover,
.socials li.youtube a:focus {
    background: #CC181E;
}

.socials li.google-plus a:hover,
.socials li.google-plus a:focus {
    background: #ea4335;
}

/*footer fixed*/
.site-footer h1,
.site-footer h1 a,
.site-footer h2,
.site-footer h2 a,
.site-footer h3,
.site-footer h3 a,
.site-footer h4,
.site-footer h4 a,
.site-footer h5,
.site-footer h5 a,
.site-footer h6,
.site-footer h6 a,
.site-footer .main-title,
.site-footer li,
.site-footer li a,
.site-footer .widget li a {
    color: #ffffff;
}

.site-footer select {
    color: #777;
}

/*back to top*/
.sm-up-container {
    display: none;
    height: auto;
    right: 3px;
    margin-right: 22px;
    margin-top: auto;
    padding: 3px 6px;
    position: fixed;
    top: 85%;
    width: 44px;
    z-index: 60;
}

.sm-up {
    display: block;
    font-size: 36px;
    line-height: 40px;
    padding-bottom: 2px;
    text-align: center;
    vertical-align: middle;
}

/***** Sidebars  *****/
.site-content {
    margin: 0 auto;
    max-width: 1200px;
    width: 90%;
}

#primary {
    float: left;
    width: 69.5%;
    display: block;
    margin-bottom: 60px;
}

.secondary-sidebar {
    float: right;
    width: 28%;
    margin-top: -24px;
}

@media only screen and (max-width: 1170px) {
    .site-content {
        width: 96%;
    }
}

.secondary-sidebar .container {
    max-width: 100%;
}

.secondary-sidebar .container .row>div,
.secondary-sidebar .form-group>div {
    width: 100%;
}

/*** RIGHT-SIDEBAR ***/
.right-sidebar #primary {
    float: left;
}

.right-sidebar .secondary-sidebar {
    float: right;
}

/*** LEFT-SIDEBAR ***/
.left-sidebar #primary {
    float: right;
}

.left-sidebar .secondary-sidebar {
    float: left;
}

/*** NO-SIDEBAR ***/
.no-sidebar #primary {
    width: 100%;
}

/*** BOTH-SIDEBAR ***/
.both-sidebar #primary-wrap {
    float: left;
    width: 73%;
}

.both-sidebar #primary-wrap #secondary-left {
    float: left;
    width: 32%;
}

.both-sidebar #primary-wrap #primary {
    float: right;
    width: 65%;
}

.both-sidebar #secondary-right {
    float: right;
    width: 25%;
}

/*middle column*/
.middle-col #primary {
    float: none;
    margin: 0 auto;
    width: 70%;
    padding-bottom: 40px;
}

@media only screen and (max-width: 767px) {
    .site-content {
        margin-top: 2em;
    }

    .inner-main-title {
        margin-bottom: 30px;
    }
}

/* Landscape phone to portrait tablet */
@media screen and (max-width:767px) {

    /*** SIDEBAR ***/
    #primary,
    .both-sidebar #primary,
    .middle-col #primary,
    .both-sidebar #primary-wrap #primary,
    .left-sidebar #primary {
        margin: 0 0 20px;
        width: 100%;
    }

    .secondary-sidebar,
    .both-sidebar #primary-wrap,
    .both-sidebar #primary-wrap #secondary-left,
    .both-sidebar #secondary-right,
    .middle-col .secondary-sidebar,
    .right-sidebar .secondary-sidebar,
    .left-sidebar .secondary-sidebar,
    .no-sidebar .secondary-sidebar {
        clear: both;
        float: none;
        margin: 0 0 20px;
        width: 100%;
    }
}

/*** COMMON WIDGETS ***/
.widget-title {
    font-size: 28px;
    margin-bottom: 0;
    text-align: center;
}

.widget-title span {
    display: block;
}

.widget li {
    border-top: 1px solid #d7d7d7;
    display: block;
    padding-bottom: 5px;
    padding-top: 5px;
}

.widget li a {
    color: #2d2d2d;
}

.widget select {
    background: #ffffff;
    border: 1px solid #cccccc;
    max-width: 100%;
    padding: 8px 15px;
}

/*tags*/
.tagcloud a {
    display: inline-block;
    font-size: 13px !important;
    margin-bottom: 8px;
    margin-right: 4px;
    padding: 5px;
}

/*search*/
.widget .search-block {
    width: 85%;
    float: none;
}

.search-block {
    display: inline-block;
    float: right;
    margin: 7px 10px;
    position: relative;
    width: 185px;
}

.error404 #primary .page-content .search-block,
.search-no-results #primary .page-content .search-block {
    float: none;
    width: 50%;
}

.search-block input#menu-search,
.widget_search input#s {
    font-size: 13px;
    line-height: 31px;
    height: 31px;
    padding: 2px 23px 2px 8px;
    width: 100%;
}

.search-block #searchsubmit,
.widget_search #searchsubmit {
    background: rgba(0, 0, 0, 0);
    border: medium none;
    font-size: 20px;
    height: 25px;
    position: absolute;
    right: 7px;
    top: 3px;
    width: 25px;
}

/*Inner Pages*/
.single-thumb-full,
.single-thumb-full img {
    width: 100%;
}

.posted-on,
.cat-links,
.comments-link,
.edit-link {
    margin-right: 15px;
    display: inline-block;
}

.posted-on a,
.cat-links a,
.comments-link a,
.edit-link a,
.tags-links a,
.byline a,
.nav-links a {
    color: #2d2d2d;
    font-size: 13px;
}

.single-feat {
    width: 100%;
    border-bottom: 1px solid #ddd;
    box-shadow: 4px 2px 4px -4px rgba(0, 0, 0, 0.133), -4px 2px 4px -4px rgba(0, 0, 0, 0.133);
    position: relative;
    text-align: center;
}

.single .entry-content {
    line-height: 22px;
    padding: 0 0 10px 0;
}

.single article.post .entry-content,
.single article.page .entry-content {
    width: auto;
    padding: 0;
}

article.post .content-wrapper,
article.page .content-wrapper {
    padding: 41px;
}

article.post .entry-footer,
article.page .entry-footer {
    clear: both;
}

article.post .entry-header,
article.page .entry-header {
    margin: 0 0 10px;
}

article.post .entry-header .entry-title,
article.page .entry-header .entry-title {
    margin: 0 0 10px;
}

article.post .entry-content,
article.page .entry-content {
    margin: 0;
}

article.post .content-wrapper .post-thumb {
    float: left;
    margin-right: 10px;
    width: 38%;
}

article.post .post-thumb,
article.page .post-thumb {
    text-align: center;
    width: 100%;
}

article.post,
article.page {
    border-bottom: 1px solid #e5e5e5;
    padding: 0 0 10px;
    background-color: #fff;
    border-radius: 4px;
    box-shadow: 0 0.15em 0.35em 0 rgba(0, 0, 0, 0.133);
}

article.post.sticky {
    padding: 8px;
}

.comments-link,
.edit-link {
    border-left: 1px solid #cccccc;
    margin-left: 12px;
    padding-left: 10px;
}

article.post .read-more,
article.page .read-more {
    display: block;
    float: right;
    margin-bottom: 16px;
    width: 100px;
}

/*archive pages*/
.nav-links div {
    display: inline-block;
    margin-bottom: 10px;
}

.nav-next {
    float: right;
}

.nav-previous>a::before,
.nav-next a::after {
    content: "\f100";
    font-family: fontawesome;
    padding: 5px;
}

.nav-next a::after {
    content: "\f101";
}

.nav-links .nav-previous a,
.nav-links .nav-next a {
    border: 1px solid #e5e5e5;
    border-radius: 2px;
    display: inline-block;
    font-size: 14px;
    padding: 6px;
    position: relative;
    background: #ffffff;
}

/*BLOG TYPES*/
/*** BLOG-no-image ***/
.blog-no-image article .entry-content {
    padding: 0 2% 0 0;
}

/*** ERROR404 ***/
.error404 #primary {
    text-align: center;
    width: 100%;
}

.error404 #primary .not-found {
    min-height: 400px;
    padding-top: 100px;
}

/*Contact form 7*/
.wpcf7-form input,
.wpcf7-form .your-message textarea {
    background: #f2f2f2;
    color: #2d2d2d;
    border: 1px solid #dddddd;
    outline: medium none;
    padding: 5px;
    font-size: 15px;
    width: 100%;
    box-sizing: border-box;
    -webkit-box-sizing: border-box;
}

.wpcf7-form input.wpcf7-submit {
    border: medium none;
    color: #ffffff;
    display: inline-block;
    margin: 10px;
    padding: 10px;
    position: relative;
    text-align: center;
    transform: translateZ(0px);
    width: 200px;
}

.wpcf7-form input.wpcf7-submit:hover,
.wpcf7-form input.wpcf7-submit:focus {
    border: medium none;
    color: #ffffff;
}

.wpcf7-form input.wpcf7-submit::before {
    bottom: 0;
    content: "";
    left: 0;
    position: absolute;
    right: 0;
    top: 0;
    transition-duration: 0.3s;
    transition-property: top, right, bottom, left;
}

.wpcf7-form input.wpcf7-submit:hover::before,
.wpcf7-form input.wpcf7-submit:focus::before {
    bottom: -8px;
    left: -8px;
    right: -8px;
    top: -8px;
}

.wpcf7-response-output {
    clear: both;
}

.wpcf7-form p {
    text-align: center;
}

/*breadcrumbs*/
.breadcrumb {
    color: #ffffff;
    font-size: 12px;
    position: absolute;
}

.breadcrumb::after {
    border-bottom: 5px solid transparent;
    border-top: 5px solid transparent;
    content: "";
    height: 0;
    margin-top: -3px;
    position: absolute;
    right: -5px;
    top: 50%;
    width: 0;
}

.breadcrumbs {
    margin-bottom: 20px;
}

#corporate-plus-breadcrumbs {
    background: #eeeeef;
    padding: 0;
    margin-left: 38px;
}

#corporate-plus-breadcrumbs .breadcrumb-trail li {
    display: block;
    float: left;
    list-style: outside none none;
    padding: 5px 0 5px 10px;
}

#corporate-plus-breadcrumbs .breadcrumb-trail li a {
    display: inline-block;
}

#corporate-plus-breadcrumbs a:hover,
#corporate-plus-breadcrumbs a:focus {
    text-decoration: underline;
}

#corporate-plus-breadcrumbs .breadcrumb-trail li.trail-item.trail-end::after {
    display: none;
}

#corporate-plus-breadcrumbs .breadcrumb-trail li::after {
    color: #ddd;
    content: "\f105";
    font-family: FontAwesome;
    margin-left: 10px;
}

#corporate-plus-breadcrumbs .breadcrumb-trail .trail-items {
    margin: 0;
    padding: 0;
}

/********************************************
				WOOCMMERCE
********************************************/
.woocommerce nav.woocommerce-pagination ul {
    display: inline !important;
}

.woocommerce-pagination .page-numbers {
    border: none;
}

.woocommerce nav.woocommerce-pagination ul li {
    background-color: #ffffff;
    border: 1px solid #cccccc;
    display: inline-block;
    font-size: 18px;
    height: 44px;
    line-height: 40px;
    margin: 15px 3px;
    text-align: center;
    transition: all 0.3s ease-in-out 0s;
    vertical-align: middle;
    width: 44px;
}

.woocommerce nav.woocommerce-pagination ul li a,
.woocommerce nav.woocommerce-pagination ul li a:hover,
.woocommerce nav.woocommerce-pagination ul li span.current,
.woocommerce nav.woocommerce-pagination ul li a:focus {
    background: transparent;
    color: #000000;
}

.woocommerce #respond input#submit,
.woocommerce a.button,
.woocommerce button.button,
.woocommerce input.button {
    color: #ffffff;
}

.woocommerce #respond input#submit.alt:hover,
.woocommerce a.button.alt:hover,
.woocommerce button.button.alt:hover,
.woocommerce input.button.alt:hover,
.woocommerce #respond input#submit:hover,
.woocommerce a.button:hover,
.woocommerce button.button:hover,
.woocommerce input.button:hover {
    background-color: #2d2d2d;
    color: #fff;
}

.woocommerce #content #primary ul.products li.product .button {
    color: #ffffff;
    display: inline-block;
    margin: 10px;
    position: relative;
    -webkit-transform: translateZ(0);
    -ms-transform: translateZ(0);
    transform: translateZ(0);
    border: none;
}

.woocommerce #content #primary ul.products li.product .button:before {
    content: '';
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    -webkit-transition-duration: .3s;
    transition-duration: .3s;
    -webkit-transition-property: top, right, bottom, left;
    transition-property: top, right, bottom, left;
}

.woocommerce #content #primary ul.products li.product .button:hover:before {
    top: -4px;
    right: -4px;
    bottom: -4px;
    left: -4px;
}

.woocommerce .quantity .qty {
    padding: 7px;
}

/*header*/
.at-woo .menu-primary-menu-container {
    float: left;
}

.at-woo .user-login a {
    float: left;
    margin-left: 11px;
}

.at-woo .user-login {
    float: right;
    -webkit-transition: all 0.5s;
    -moz-transition: all 0.5s;
    -o-transition: all 0.5s;
    -mz-transition: all 0.5s;
    transition: all 0.5s;
    padding-right: 16px
}

.at-woo .user-login .button,
.at-woo .cart-contents {
    font-size: 12px;
    color: #ffffff;
    text-transform: uppercase;
    padding: 3px 8px;
    border-radius: 3px;
    font-weight: bolder;
    -webkit-transition: all 0.3s;
    -moz-transition: all 0.3s;
    -o-transition: all 0.3s;
    -mz-transition: all 0.3s;
    transition: all 0.3s;
}

.at-woo .cart-contents {
    background: transparent;
    font-weight: normal;
}

.main-navigation .user-login .button.menu {
    display: none;
}

/*extra small device*/
@media (max-width: 767px) {
    .at-woo .user-login {
        width: 100%;
        text-align: center;
        padding: 7px 15px;
    }

    .at-woo .user-login a {
        float: none;
    }

    .at-woo .menu-primary-menu-container {
        float: none;
    }
}

/*extra small device*/
@media (max-width: 640px) {
    .woocommerce .actions input {
        font-size: 11px;
    }
}

.entry-content p a,
.comment-content p a,
.comment-content li a,
.textwidget a {
    text-decoration: underline;
}