<?php $component = \ColibriWP\Theme\View::getData( 'component' ); ?>
<figure class="wp-block wp-block-kubio-image  position-relative wp-block-kubio-image__outer kubio-front-header__k__N6ZyU1UDnq-outer kubio-local-687-outer size-large align-items-center" data-kubio="kubio/image">
	<div class="position-relative wp-block-kubio-image__captionContainer kubio-front-header__k__N6ZyU1UDnq-captionContainer kubio-local-687-captionContainer">
		<div class="position-relative wp-block-kubio-image__frameContainer kubio-front-header__k__N6ZyU1UDnq-frameContainer kubio-local-687-frameContainer">
			<?php $component->printImage(...array (
  0 => 'position-relative wp-block-kubio-image__image kubio-front-header__k__N6ZyU1UDnq-image kubio-local-687-image d-flex',
  1 => NULL,
)); ?>
<?php $component->printFrame('position-relative wp-block-kubio-image__frameImage'); ?>
		</div>
	</div>
</figure>
