<?php

// autoload_files.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'f40eb6b6e72038beec37d8a0baa6e2f0' => $baseDir . '/inc/template-functions.php',
);
