@charset "UTF-8";
/*! 
 Theme Name:   Kubio
 Theme URI:    https://kubiobuilder.com/kubio-theme
 Version:      1.0.96
 Description:  Kubio is an innovative,  easily customizable, multi-purpose theme, focused on empowering users to build astonishing WordPress websites. Kubio is mainly designed for small businesses, startups, or personal portfolio websites and works perfectly with Kubio Page Builder which enriches the WordPress block editor with a variety of new blocks and advanced styling options to give you full design freedom.
 Author:       Extend Themes
 Author URI:   https://kubiobuilder.com
 License:      GNU General Public License version 3
 License URI:  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 Tags:         entertainment, food-and-drink, portfolio, one-column, two-columns, grid-layout, custom-header, custom-menu, custom-logo, full-width-template, theme-options, translation-ready, featured-images, threaded-comments
 Text Domain:  kubio

 Tested up to: 7.0
 Requires PHP: 7.1
 Requires at least: 5.8.3

*/
 body{background-color:#fff}
 .screen-reader-text{clip:rect(1px,1px,1px,1px);word-wrap:normal!important;height:1px;margin:-1px;overflow:hidden;position:absolute!important;width:1px}
 .screen-reader-text:focus{clip:auto!important;background-color:#f1f1f1;border-radius:3px;box-shadow:0 0 2px 2px rgba(0,0,0,.6);-webkit-clip-path:none;clip-path:none;color:#21759b;display:block;font-weight:700;height:auto;left:5px;line-height:normal;padding:15px 23px 14px;text-decoration:none;top:5px;width:auto;z-index:100000}
 .alignleft{display:inline;float:left;margin-right:1.5em}
 .alignright{display:inline;float:right;margin-left:1.5em}
 .aligncenter{clear:both;display:block;margin-left:auto;margin-right:auto}
 #wp-toolbar ul{display:inline-block}
 .bypostauthor,
 .gallery-caption,
 .sticky{font-family:inherit}
 .aligncenter,
 div.aligncenter{display:block;margin-bottom:"16px"}
 a img.aligncenter{display:block;margin-left:auto;margin-right:auto}
 .wp-caption{background:#fff;border:1px solid #f0f0f0;max-width:96%;padding:5px 3px 10px;text-align:center}
 .wp-caption.alignleft,
 .wp-caption.alignnone,
 .wp-caption.alignright{margin-bottom:"16px"}
 .wp-caption img{border:0;height:auto;margin:0;max-width:98.5%;padding:0;width:auto}
 .wp-caption p.wp-caption-text{font-size:.6em;line-height:150%;margin:0;padding:0 4px 5px}
 .fancybox-container{z-index:100000!important}
 .fancybox-container .fancybox-slide--iframe .fancybox-content{max-height:100%!important}
 .embed-container,
 .embed-youtube{height:0;margin-bottom:1rem;padding-bottom:56.25%;padding-top:25px;position:relative}
 .embed-container>iframe,
 .embed-youtube>iframe{height:100%;left:0;position:absolute;top:0;width:100%}
 .mejs-inner .mejs-button>button[aria-controls]{background-color:transparent;border:none;border-radius:0;display:block;min-width:10px;padding:0;transition:none;width:20px}
 .mejs-inner .mejs-button>button[aria-controls]:focus,
 .mejs-inner .mejs-button>button[aria-controls]:hover{background-color:transparent}
 .entry-content>.alignfull{max-width:unset}
 .entry-content [data-align=wide]{max-width:1200px;width:100%}
 :where(.wp-block-group.has-background){padding:unset}@media screen and (max-width:782px){
 .logged-in.admin-bar .h-navigation_sticky{top:0!important}}
 pre{white-space:pre-line}
 :root{--wp--style--global--content-size:620px;--wp--style--global--wide-size:1232px}
 .is-layout-constrained>.alignleft{-webkit-margin-start:0;-webkit-margin-end:2em;float:left;margin-inline-end:2em;margin-inline-start:0}
 .is-layout-constrained>.alignright{-webkit-margin-start:2em;-webkit-margin-end:0;float:right;margin-inline-end:0;margin-inline-start:2em}
 .is-layout-constrained>.aligncenter{margin-left:auto!important;margin-right:auto!important}
 .is-layout-constrained>:where(:not(.alignleft):not(.alignright):not(.alignfull)){margin-left:auto!important;margin-right:auto!important;max-width:var(--wp--style--global--content-size)}
 .is-layout-constrained>.alignwide{max-width:var(--wp--style--global--wide-size)}
 [data-kubio] :where(.wp-block-buttons){font-family:Poppins,Helvetica,Arial,Sans-Serif,serif;font-size:14px}
html{-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;font-family:sans-serif}
 body{margin:0}
 article,
 aside,
 details,
 figcaption,
 figure,
 footer,
 header,
 main,
 menu,
 nav,
 section,
 summary{display:block}
 audio,
 canvas,
 progress,
 video{display:inline-block;vertical-align:baseline}
 audio:not([controls]){display:none;height:0}
 [hidden],
 template{display:none}
 a{background-color:transparent}
 a:active,
 a:hover{outline:0}
 abbr[title]{border-bottom:1px dotted}
 b,
 strong{font-weight:700}
 dfn{font-style:italic}
 h1{font-size:2.44em;margin:.67em 0}
 h1,
 h2{line-height:1.4}
 h2{font-size:1.95em}
 h3{font-size:1.56em;line-height:1.4}
 h4{font-size:1.25em;line-height:1.5}
 h5{font-size:1em}
 h6{font-size:.8em}
 mark{background:#ff0;color:#000}
 small{font-size:80%}
 sub,
 sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}
 sup{top:-.5em}
 sub{bottom:-.25em}
 :where(img):not([style*=border-width]){border:0}
 svg:not(:root){overflow:hidden}
 figure{margin:1em 40px}
 hr{box-sizing:content-box;height:0}
 pre{overflow:auto}
 code,
 kbd,
 pre,
 samp{font-family:Monaco,Consolas,Andale Mono,DejaVu Sans Mono,monospace;font-size:.875rem}
 button{overflow:visible}
 button,
 select{text-transform:none}
 button,
html input[type=button],
 input[type=reset],
 input[type=submit]{-webkit-appearance:button;cursor:pointer}
 button[disabled],
html input[disabled]{cursor:default}
 button::-moz-focus-inner,
 input::-moz-focus-inner{border:0;padding:0}
 input{line-height:normal}
 input[type=checkbox],
 input[type=radio]{box-sizing:border-box;padding:0}
 input[type=number]::-webkit-inner-spin-button,
 input[type=number]::-webkit-outer-spin-button{height:auto}
 input[type=search]::-webkit-search-cancel-button,
 input[type=search]::-webkit-search-decoration{-webkit-appearance:none}
 fieldset{border:1px solid silver;margin:0 2px;padding:.35em .625em .75em}
 legend{border:0;padding:0}
 textarea{overflow:auto}
 optgroup{font-weight:700}
 table{border-collapse:collapse;border-spacing:0}
 td,
 th{padding:0}
 :root{--kubio-system-fonts:-apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,Oxygen-Sans,Ubuntu,Cantarell,"Helvetica Neue",sans-serif}
 *,
 :after,
 :before{box-sizing:inherit}
 .h-global-transition,
 .h-global-transition-all *,
 [class*=local-style-],
 [class*=style-]{transition-property:background,padding,margin,border,transform,filter,box-shadow,opacity,color,fill,font,border-radius,max-height,max-width}
 .new-stacking-context{position:relative;z-index:1}
 .h-svg-icon{line-height:0}
 .hide{display:none}
 .mw-100{max-width:100%}
 .mh-100{max-height:100%}
 .h-100{height:100%}
 .z-index-zero{z-index:0}@media (min-width:1024px){
 .h-hide-lg{display:none}}@media (min-width:768px) and (max-width:1023px){
 .h-hide-md{display:none}}@media (max-width:767px){
 .h-hide-sm{display:none}
 .h-hide-sm-force{display:none!important}}@media (max-width:320px){
 .h-hide-xs{display:none}
 .h-hide-xs-force{display:none!important}}
 .section-option-submenu-hidden{display:none}
 .h-ignore-global-body-typography{color:initial;font-family:Roboto,sans-serif;font-size:medium;font-style:normal;letter-spacing:normal;line-height:normal}
 .kubio-theme-nav-full-width .h-section-boxed-container,
 .kubio-theme-nav-full-width .h-section-grid-container,
 .kubio-theme-nav-full-width .wp-block-kubio-navigation-section__nav{max-width:unset;padding:0}@media (max-width:767px){
 .kubio-theme-nav-full-width .h-section-boxed-container,
 .kubio-theme-nav-full-width .h-section-grid-container,
 .kubio-theme-nav-full-width .wp-block-kubio-navigation-section__nav{padding:0 1rem}}@media (max-width:1023px){
 .kubio-theme-nav-full-width .h-section-boxed-container,
 .kubio-theme-nav-full-width .h-section-grid-container,
 .kubio-theme-nav-full-width .wp-block-kubio-navigation-section__nav{padding:0 .5rem}}
 .content.page-content{position:relative}
 .shape-layer{background-size:cover}
 :root{--kubio-gap-fallback-half:20}
 body h1>a,
 body h2>a,
 body h3>a,
 body h4>a,
 body h5>a,
 body h6>a,
 body p>a{text-decoration:underline}
 .wp-block-kubio-hero [class*=h-row]:after,
 .wp-block-kubio-hero [class*=h-row]:before{display:none}
 .wp-block-kubio-iconlist .customize-partial-edit-shortcut{right:-40px!important;top:-5px!important}
 .wp-block-kubio-navigation-top-bar .wp-block-kubio-social-icons a:last-of-type span{margin-right:-5px!important}
 .kubio-theme-nav-full-width .customizer-logo-above-menu .wp-block-kubio-dropdown-menu .customize-partial-edit-shortcut{left:40px}
 .kubio-theme-nav-full-width .customizer-logo-above-menu [data-kubio-partial-refresh=logo] .customize-partial-edit-shortcut{right:65px!important}
 .wp-block-kubio-image .customize-partial-edit-shortcut{right:0!important}
 .wp-block-kubio-post-categories__placeholder:empty{padding-right:0!important}
 .wp-block-kubio-post-comments .comment-list .comment .comment-author img{height:60px;width:60px}
 .kubio-offscreen [data-kubio-partial-refresh=logo] .customize-partial-edit-shortcut{right:0!important}@media (max-width:1023px){
 .kubio-theme-nav-full-width .customizer-logo-above-menu [data-kubio-partial-refresh=logo] .customize-partial-edit-shortcut{right:30px!important}
 .kubio-theme-nav-boxed .customizer-logo-above-menu [data-kubio-partial-refresh=logo] .customize-partial-edit-shortcut{right:0!important}}@media (max-width:767px){
 .kubio-theme-nav-full-width .customizer-logo-above-menu .wp-block-kubio-dropdown-menu .customize-partial-edit-shortcut{left:0}
 .kubio-theme-nav-full-width .customizer-logo-above-menu [data-kubio-partial-refresh=logo] .customize-partial-edit-shortcut{right:0!important}
 [data-kubio-partial-refresh=buttons] .customize-partial-edit-shortcut,
 [data-kubio-partial-refresh=subtitle] .customize-partial-edit-shortcut,
 [data-kubio-partial-refresh=title] .customize-partial-edit-shortcut{right:-25px}}
 #start-resizable-kubio-section{display:none}
 #kubio,
 #kubio body{max-width:100%;position:relative}
 #kubio body{overflow-x:hidden!important}
 [data-kubio]{-webkit-margin-before:0;-webkit-margin-after:0;margin-block-end:0;margin-block-start:0;outline:0;padding:0}
 [data-kubio],
 [data-kubio] *,
 [data-kubio] :after,
 [data-kubio] :before{-webkit-overflow-scrolling:touch;box-sizing:border-box}
 [data-kubio] audio,
 [data-kubio] img,
 [data-kubio] video{max-width:100%}
 [data-kubio] img,
 [data-kubio] video{height:auto}
 [data-kubio] svg{max-height:100%}
 [data-kubio] iframe{border:none;max-width:100%}
 [data-kubio] ::-moz-focus-inner{border:0;padding:0}
 [data-kubio] input:matches([type=password],[type="search;"]){border-radius:0}
 [data-kubio] input[type=checkbox],
 [data-kubio] input[type=radio]{bottom:.15rem;font-size:115%;margin-right:3px;position:relative;vertical-align:middle}
 [data-kubio] input[type=search]{-webkit-appearance:textfield}
 [data-kubio] input[type=search]::-webkit-search-cancel-button,
 [data-kubio] input[type=search]::-webkit-search-decoration{-webkit-appearance:none}
 [data-kubio] :focus:focus-visible{outline:none}
 [data-kubio] code{background:inherit;font-family:monospace;font-size:inherit;margin:0;padding:0}
 [data-kubio] .wp-editor-wrap .wp-editor-tabs button{border:1px solid transparent;border-bottom:none;border-bottom-left-radius:0;border-bottom-right-radius:0;color:#646970}
 [data-kubio] .wp-editor-wrap .wp-editor-tabs button:hover{border-color:transparent}
 [data-kubio] .wp-editor-wrap .wp-editor-tabs button.toggle{background-color:#f6f7f7}
 [data-kubio] .wp-editor-wrap.html-active .wp-editor-tabs button.switch-html,
 [data-kubio] .wp-editor-wrap.tmce-active .wp-editor-tabs button.switch-tmce{background-color:#f6f7f7!important;border-color:#dcdcde!important}
 [data-kubio] .wp-editor-wrap .mce-widget button{border-color:transparent;color:#646970}
 [data-kubio] .wp-editor-wrap .mce-widget button:hover{border-color:transparent}
 [data-kubio] .wp-editor-wrap .mce-divider{display:inline-block;margin:0 6px}
 [data-kubio] .quicktags-toolbar .ed_button{background:#f6f7f7;border:1px solid #2271b1!important;border-radius:3px!important;box-sizing:border-box;color:#2271b1!important;display:inline-block!important;font-size:13px!important;height:unset!important;line-height:2.15384615!important;padding:0 10px!important;text-decoration:none;white-space:nowrap;width:auto!important}
 [data-kubio] .quicktags-toolbar .ed_button:focus,
 [data-kubio] .quicktags-toolbar .ed_button:hover{background:#f0f0f1!important;border-color:#0a4b78!important;color:#0a4b78!important}
 [data-kubio] img.emoji{height:1em}
 [data-kubio] summary{display:list-item;list-style:disclosure-closed}
 [data-kubio] details[open] summary{list-style:disclosure-open}
 .h-container{margin-left:auto;margin-right:auto;padding-left:15px;padding-right:15px;width:100%}@media (min-width:576px){
 .h-container{max-width:540px}}@media (min-width:768px){
 .h-container{max-width:720px}}@media (min-width:1024px){
 .h-container{max-width:960px}}@media (min-width:1200px){
 .h-container{max-width:1232px}}
 .h-container-fluid{margin-left:auto;margin-right:auto;padding-left:15px;padding-right:15px;width:100%}
 .h-section-boxed-container{margin-left:auto;margin-right:auto;padding-left:0;padding-right:0;width:100%}@media (min-width:576px){
 .h-section-boxed-container{max-width:540px}}@media (min-width:768px){
 .h-section-boxed-container{max-width:720px}}@media (min-width:1024px){
 .h-section-boxed-container{max-width:960px}}@media (min-width:1200px){
 .h-section-boxed-container{max-width:1232px}}
 .h-section-fluid-container{margin-left:auto;margin-right:auto;padding-left:0;padding-right:0;width:100%}
 .h-row{display:flex;flex-wrap:wrap;margin-left:-15px;margin-right:-15px}
 .no-gutters{margin-left:0;margin-right:0}
 .no-gutters>.h-col,
 .no-gutters>[class*=h-col-]{padding-left:0;padding-right:0}
 .h-row.gutters-col-0{margin-left:0;margin-right:0}
 .h-px-0,
 .h-row.gutters-col-0>.h-col,
 .h-row.gutters-col-0>[class*=h-col-]{padding-left:0;padding-right:0}
 .h-px-0-remove{margin-left:0;margin-right:0}
 .gutters-row-0{padding-left:0;padding-right:0}
 .h-row.gutters-col-1{margin-left:-5px;margin-right:-5px}
 .h-px-1,
 .h-row.gutters-col-1>.h-col,
 .h-row.gutters-col-1>[class*=h-col-]{padding-left:5px;padding-right:5px}
 .h-px-1-remove{margin-left:-5px;margin-right:-5px}
 .gutters-row-1{padding-left:5px;padding-right:5px}
 .h-row.gutters-col-2{margin-left:-10px;margin-right:-10px}
 .h-px-2,
 .h-row.gutters-col-2>.h-col,
 .h-row.gutters-col-2>[class*=h-col-]{padding-left:10px;padding-right:10px}
 .h-px-2-remove{margin-left:-10px;margin-right:-10px}
 .gutters-row-2{padding-left:10px;padding-right:10px}
 .h-row.gutters-col-3{margin-left:-15px;margin-right:-15px}
 .h-px-3,
 .h-row.gutters-col-3>.h-col,
 .h-row.gutters-col-3>[class*=h-col-]{padding-left:15px;padding-right:15px}
 .h-px-3-remove{margin-left:-15px;margin-right:-15px}
 .gutters-row-3{padding-left:15px;padding-right:15px}
 .h-row.gutters-col-4{margin-left:-15px;margin-right:-15px}
 .h-px-4,
 .h-row.gutters-col-4>.h-col,
 .h-row.gutters-col-4>[class*=h-col-]{padding-left:15px;padding-right:15px}
 .h-px-4-remove{margin-left:-15px;margin-right:-15px}
 .gutters-row-4{padding-left:15px;padding-right:15px}
 .h-row.gutters-col-custom{margin-left:0;margin-right:0}
 .h-px-custom,
 .h-row.gutters-col-custom>.h-col,
 .h-row.gutters-col-custom>[class*=h-col-]{padding-left:0;padding-right:0}
 .h-px-custom-remove{margin-left:0;margin-right:0}
 .gutters-row-custom{padding-left:0;padding-right:0}@media (min-width:576px){
 .h-row.gutters-col-sm-0{margin-left:0;margin-right:0}
 .h-px-sm-0,
 .h-row.gutters-col-sm-0>.h-col,
 .h-row.gutters-col-sm-0>[class*=h-col-]{padding-left:0;padding-right:0}
 .h-px-sm-0-remove{margin-left:0;margin-right:0}
 .gutters-row-sm-0{padding-left:0;padding-right:0}
 .h-row.gutters-col-sm-1{margin-left:-5px;margin-right:-5px}
 .h-px-sm-1,
 .h-row.gutters-col-sm-1>.h-col,
 .h-row.gutters-col-sm-1>[class*=h-col-]{padding-left:5px;padding-right:5px}
 .h-px-sm-1-remove{margin-left:-5px;margin-right:-5px}
 .gutters-row-sm-1{padding-left:5px;padding-right:5px}
 .h-row.gutters-col-sm-2{margin-left:-10px;margin-right:-10px}
 .h-px-sm-2,
 .h-row.gutters-col-sm-2>.h-col,
 .h-row.gutters-col-sm-2>[class*=h-col-]{padding-left:10px;padding-right:10px}
 .h-px-sm-2-remove{margin-left:-10px;margin-right:-10px}
 .gutters-row-sm-2{padding-left:10px;padding-right:10px}
 .h-row.gutters-col-sm-3{margin-left:-15px;margin-right:-15px}
 .h-px-sm-3,
 .h-row.gutters-col-sm-3>.h-col,
 .h-row.gutters-col-sm-3>[class*=h-col-]{padding-left:15px;padding-right:15px}
 .h-px-sm-3-remove{margin-left:-15px;margin-right:-15px}
 .gutters-row-sm-3{padding-left:15px;padding-right:15px}
 .h-row.gutters-col-sm-4{margin-left:-15px;margin-right:-15px}
 .h-px-sm-4,
 .h-row.gutters-col-sm-4>.h-col,
 .h-row.gutters-col-sm-4>[class*=h-col-]{padding-left:15px;padding-right:15px}
 .h-px-sm-4-remove{margin-left:-15px;margin-right:-15px}
 .gutters-row-sm-4{padding-left:15px;padding-right:15px}
 .h-row.gutters-col-sm-custom{margin-left:0;margin-right:0}
 .h-px-sm-custom,
 .h-row.gutters-col-sm-custom>.h-col,
 .h-row.gutters-col-sm-custom>[class*=h-col-]{padding-left:0;padding-right:0}
 .h-px-sm-custom-remove{margin-left:0;margin-right:0}
 .gutters-row-sm-custom{padding-left:0;padding-right:0}}@media (min-width:768px){
 .h-row.gutters-col-md-0{margin-left:0;margin-right:0}
 .h-px-md-0,
 .h-row.gutters-col-md-0>.h-col,
 .h-row.gutters-col-md-0>[class*=h-col-]{padding-left:0;padding-right:0}
 .h-px-md-0-remove{margin-left:0;margin-right:0}
 .gutters-row-md-0{padding-left:0;padding-right:0}
 .h-row.gutters-col-md-1{margin-left:-5px;margin-right:-5px}
 .h-px-md-1,
 .h-row.gutters-col-md-1>.h-col,
 .h-row.gutters-col-md-1>[class*=h-col-]{padding-left:5px;padding-right:5px}
 .h-px-md-1-remove{margin-left:-5px;margin-right:-5px}
 .gutters-row-md-1{padding-left:5px;padding-right:5px}
 .h-row.gutters-col-md-2{margin-left:-10px;margin-right:-10px}
 .h-px-md-2,
 .h-row.gutters-col-md-2>.h-col,
 .h-row.gutters-col-md-2>[class*=h-col-]{padding-left:10px;padding-right:10px}
 .h-px-md-2-remove{margin-left:-10px;margin-right:-10px}
 .gutters-row-md-2{padding-left:10px;padding-right:10px}
 .h-row.gutters-col-md-3{margin-left:-15px;margin-right:-15px}
 .h-px-md-3,
 .h-row.gutters-col-md-3>.h-col,
 .h-row.gutters-col-md-3>[class*=h-col-]{padding-left:15px;padding-right:15px}
 .h-px-md-3-remove{margin-left:-15px;margin-right:-15px}
 .gutters-row-md-3{padding-left:15px;padding-right:15px}
 .h-row.gutters-col-md-4{margin-left:-15px;margin-right:-15px}
 .h-px-md-4,
 .h-row.gutters-col-md-4>.h-col,
 .h-row.gutters-col-md-4>[class*=h-col-]{padding-left:15px;padding-right:15px}
 .h-px-md-4-remove{margin-left:-15px;margin-right:-15px}
 .gutters-row-md-4{padding-left:15px;padding-right:15px}
 .h-row.gutters-col-md-custom{margin-left:0;margin-right:0}
 .h-px-md-custom,
 .h-row.gutters-col-md-custom>.h-col,
 .h-row.gutters-col-md-custom>[class*=h-col-]{padding-left:0;padding-right:0}
 .h-px-md-custom-remove{margin-left:0;margin-right:0}
 .gutters-row-md-custom{padding-left:0;padding-right:0}}@media (min-width:1024px){
 .h-row.gutters-col-lg-0{margin-left:0;margin-right:0}
 .h-px-lg-0,
 .h-row.gutters-col-lg-0>.h-col,
 .h-row.gutters-col-lg-0>[class*=h-col-]{padding-left:0;padding-right:0}
 .h-px-lg-0-remove{margin-left:0;margin-right:0}
 .gutters-row-lg-0{padding-left:0;padding-right:0}
 .h-row.gutters-col-lg-1{margin-left:-8px;margin-right:-8px}
 .h-px-lg-1,
 .h-row.gutters-col-lg-1>.h-col,
 .h-row.gutters-col-lg-1>[class*=h-col-]{padding-left:8px;padding-right:8px}
 .h-px-lg-1-remove{margin-left:-8px;margin-right:-8px}
 .gutters-row-lg-1{padding-left:8px;padding-right:8px}
 .h-row.gutters-col-lg-2{margin-left:-15px;margin-right:-15px}
 .h-px-lg-2,
 .h-row.gutters-col-lg-2>.h-col,
 .h-row.gutters-col-lg-2>[class*=h-col-]{padding-left:15px;padding-right:15px}
 .h-px-lg-2-remove{margin-left:-15px;margin-right:-15px}
 .gutters-row-lg-2{padding-left:15px;padding-right:15px}
 .h-row.gutters-col-lg-3{margin-left:-30px;margin-right:-30px}
 .h-px-lg-3,
 .h-row.gutters-col-lg-3>.h-col,
 .h-row.gutters-col-lg-3>[class*=h-col-]{padding-left:30px;padding-right:30px}
 .h-px-lg-3-remove{margin-left:-30px;margin-right:-30px}
 .gutters-row-lg-3{padding-left:30px;padding-right:30px}
 .h-row.gutters-col-lg-4{margin-left:-30px;margin-right:-30px}
 .h-px-lg-4,
 .h-row.gutters-col-lg-4>.h-col,
 .h-row.gutters-col-lg-4>[class*=h-col-]{padding-left:30px;padding-right:30px}
 .h-px-lg-4-remove{margin-left:-30px;margin-right:-30px}
 .gutters-row-lg-4{padding-left:30px;padding-right:30px}
 .h-row.gutters-col-lg-custom{margin-left:0;margin-right:0}
 .h-px-lg-custom,
 .h-row.gutters-col-lg-custom>.h-col,
 .h-row.gutters-col-lg-custom>[class*=h-col-]{padding-left:0;padding-right:0}
 .h-px-lg-custom-remove{margin-left:0;margin-right:0}
 .gutters-row-lg-custom{padding-left:0;padding-right:0}}@media (min-width:1200px){
 .h-row.gutters-col-xl-0{margin-left:0;margin-right:0}
 .h-px-xl-0,
 .h-row.gutters-col-xl-0>.h-col,
 .h-row.gutters-col-xl-0>[class*=h-col-]{padding-left:0;padding-right:0}
 .h-px-xl-0-remove{margin-left:0;margin-right:0}
 .gutters-row-xl-0{padding-left:0;padding-right:0}
 .h-row.gutters-col-xl-1{margin-left:-8px;margin-right:-8px}
 .h-px-xl-1,
 .h-row.gutters-col-xl-1>.h-col,
 .h-row.gutters-col-xl-1>[class*=h-col-]{padding-left:8px;padding-right:8px}
 .h-px-xl-1-remove{margin-left:-8px;margin-right:-8px}
 .gutters-row-xl-1{padding-left:8px;padding-right:8px}
 .h-row.gutters-col-xl-2{margin-left:-15px;margin-right:-15px}
 .h-px-xl-2,
 .h-row.gutters-col-xl-2>.h-col,
 .h-row.gutters-col-xl-2>[class*=h-col-]{padding-left:15px;padding-right:15px}
 .h-px-xl-2-remove{margin-left:-15px;margin-right:-15px}
 .gutters-row-xl-2{padding-left:15px;padding-right:15px}
 .h-row.gutters-col-xl-3{margin-left:-30px;margin-right:-30px}
 .h-px-xl-3,
 .h-row.gutters-col-xl-3>.h-col,
 .h-row.gutters-col-xl-3>[class*=h-col-]{padding-left:30px;padding-right:30px}
 .h-px-xl-3-remove{margin-left:-30px;margin-right:-30px}
 .gutters-row-xl-3{padding-left:30px;padding-right:30px}
 .h-row.gutters-col-xl-4{margin-left:-30px;margin-right:-30px}
 .h-px-xl-4,
 .h-row.gutters-col-xl-4>.h-col,
 .h-row.gutters-col-xl-4>[class*=h-col-]{padding-left:30px;padding-right:30px}
 .h-px-xl-4-remove{margin-left:-30px;margin-right:-30px}
 .gutters-row-xl-4{padding-left:30px;padding-right:30px}
 .h-row.gutters-col-xl-custom{margin-left:0;margin-right:0}
 .h-px-xl-custom,
 .h-row.gutters-col-xl-custom>.h-col,
 .h-row.gutters-col-xl-custom>[class*=h-col-]{padding-left:0;padding-right:0}
 .h-px-xl-custom-remove{margin-left:0;margin-right:0}
 .gutters-row-xl-custom{padding-left:0;padding-right:0}}
 .h-row.gutters-col-v-0{margin-bottom:0;margin-top:0}
 .gutters-row-v-0,
 .h-row.gutters-col-v-0>.h-col,
 .h-row.gutters-col-v-0>[class*=h-col-],
 .v-inner-0{padding-bottom:0;padding-top:0}
 .h-row.gutters-col-v-1{margin-bottom:-5px;margin-top:-5px}
 .gutters-row-v-1,
 .h-row.gutters-col-v-1>.h-col,
 .h-row.gutters-col-v-1>[class*=h-col-],
 .v-inner-1{padding-bottom:5px;padding-top:5px}
 .h-row.gutters-col-v-2{margin-bottom:-10px;margin-top:-10px}
 .gutters-row-v-2,
 .h-row.gutters-col-v-2>.h-col,
 .h-row.gutters-col-v-2>[class*=h-col-],
 .v-inner-2{padding-bottom:10px;padding-top:10px}
 .h-row.gutters-col-v-3{margin-bottom:-15px;margin-top:-15px}
 .gutters-row-v-3,
 .h-row.gutters-col-v-3>.h-col,
 .h-row.gutters-col-v-3>[class*=h-col-],
 .v-inner-3{padding-bottom:15px;padding-top:15px}
 .h-row.gutters-col-v-4{margin-bottom:-15px;margin-top:-15px}
 .gutters-row-v-4,
 .h-row.gutters-col-v-4>.h-col,
 .h-row.gutters-col-v-4>[class*=h-col-],
 .v-inner-4{padding-bottom:15px;padding-top:15px}
 .h-row.gutters-col-v-custom{margin-bottom:0;margin-top:0}
 .gutters-row-v-custom,
 .h-row.gutters-col-v-custom>.h-col,
 .h-row.gutters-col-v-custom>[class*=h-col-],
 .v-inner-custom{padding-bottom:0;padding-top:0}@media (min-width:576px){
 .h-row.gutters-col-v-sm-0{margin-bottom:0;margin-top:0}
 .gutters-row-v-sm-0,
 .h-row.gutters-col-v-sm-0>.h-col,
 .h-row.gutters-col-v-sm-0>[class*=h-col-],
 .v-inner-sm-0{padding-bottom:0;padding-top:0}
 .h-row.gutters-col-v-sm-1{margin-bottom:-5px;margin-top:-5px}
 .gutters-row-v-sm-1,
 .h-row.gutters-col-v-sm-1>.h-col,
 .h-row.gutters-col-v-sm-1>[class*=h-col-],
 .v-inner-sm-1{padding-bottom:5px;padding-top:5px}
 .h-row.gutters-col-v-sm-2{margin-bottom:-10px;margin-top:-10px}
 .gutters-row-v-sm-2,
 .h-row.gutters-col-v-sm-2>.h-col,
 .h-row.gutters-col-v-sm-2>[class*=h-col-],
 .v-inner-sm-2{padding-bottom:10px;padding-top:10px}
 .h-row.gutters-col-v-sm-3{margin-bottom:-15px;margin-top:-15px}
 .gutters-row-v-sm-3,
 .h-row.gutters-col-v-sm-3>.h-col,
 .h-row.gutters-col-v-sm-3>[class*=h-col-],
 .v-inner-sm-3{padding-bottom:15px;padding-top:15px}
 .h-row.gutters-col-v-sm-4{margin-bottom:-15px;margin-top:-15px}
 .gutters-row-v-sm-4,
 .h-row.gutters-col-v-sm-4>.h-col,
 .h-row.gutters-col-v-sm-4>[class*=h-col-],
 .v-inner-sm-4{padding-bottom:15px;padding-top:15px}
 .h-row.gutters-col-v-sm-custom{margin-bottom:0;margin-top:0}
 .gutters-row-v-sm-custom,
 .h-row.gutters-col-v-sm-custom>.h-col,
 .h-row.gutters-col-v-sm-custom>[class*=h-col-],
 .v-inner-sm-custom{padding-bottom:0;padding-top:0}}@media (min-width:768px){
 .h-row.gutters-col-v-md-0{margin-bottom:0;margin-top:0}
 .gutters-row-v-md-0,
 .h-row.gutters-col-v-md-0>.h-col,
 .h-row.gutters-col-v-md-0>[class*=h-col-],
 .v-inner-md-0{padding-bottom:0;padding-top:0}
 .h-row.gutters-col-v-md-1{margin-bottom:-5px;margin-top:-5px}
 .gutters-row-v-md-1,
 .h-row.gutters-col-v-md-1>.h-col,
 .h-row.gutters-col-v-md-1>[class*=h-col-],
 .v-inner-md-1{padding-bottom:5px;padding-top:5px}
 .h-row.gutters-col-v-md-2{margin-bottom:-10px;margin-top:-10px}
 .gutters-row-v-md-2,
 .h-row.gutters-col-v-md-2>.h-col,
 .h-row.gutters-col-v-md-2>[class*=h-col-],
 .v-inner-md-2{padding-bottom:10px;padding-top:10px}
 .h-row.gutters-col-v-md-3{margin-bottom:-15px;margin-top:-15px}
 .gutters-row-v-md-3,
 .h-row.gutters-col-v-md-3>.h-col,
 .h-row.gutters-col-v-md-3>[class*=h-col-],
 .v-inner-md-3{padding-bottom:15px;padding-top:15px}
 .h-row.gutters-col-v-md-4{margin-bottom:-15px;margin-top:-15px}
 .gutters-row-v-md-4,
 .h-row.gutters-col-v-md-4>.h-col,
 .h-row.gutters-col-v-md-4>[class*=h-col-],
 .v-inner-md-4{padding-bottom:15px;padding-top:15px}
 .h-row.gutters-col-v-md-custom{margin-bottom:0;margin-top:0}
 .gutters-row-v-md-custom,
 .h-row.gutters-col-v-md-custom>.h-col,
 .h-row.gutters-col-v-md-custom>[class*=h-col-],
 .v-inner-md-custom{padding-bottom:0;padding-top:0}}@media (min-width:1024px){
 .h-row.gutters-col-v-lg-0{margin-bottom:0;margin-top:0}
 .gutters-row-v-lg-0,
 .h-row.gutters-col-v-lg-0>.h-col,
 .h-row.gutters-col-v-lg-0>[class*=h-col-],
 .v-inner-lg-0{padding-bottom:0;padding-top:0}
 .h-row.gutters-col-v-lg-1{margin-bottom:-8px;margin-top:-8px}
 .gutters-row-v-lg-1,
 .h-row.gutters-col-v-lg-1>.h-col,
 .h-row.gutters-col-v-lg-1>[class*=h-col-],
 .v-inner-lg-1{padding-bottom:8px;padding-top:8px}
 .h-row.gutters-col-v-lg-2{margin-bottom:-15px;margin-top:-15px}
 .gutters-row-v-lg-2,
 .h-row.gutters-col-v-lg-2>.h-col,
 .h-row.gutters-col-v-lg-2>[class*=h-col-],
 .v-inner-lg-2{padding-bottom:15px;padding-top:15px}
 .h-row.gutters-col-v-lg-3{margin-bottom:-30px;margin-top:-30px}
 .gutters-row-v-lg-3,
 .h-row.gutters-col-v-lg-3>.h-col,
 .h-row.gutters-col-v-lg-3>[class*=h-col-],
 .v-inner-lg-3{padding-bottom:30px;padding-top:30px}
 .h-row.gutters-col-v-lg-4{margin-bottom:-30px;margin-top:-30px}
 .gutters-row-v-lg-4,
 .h-row.gutters-col-v-lg-4>.h-col,
 .h-row.gutters-col-v-lg-4>[class*=h-col-],
 .v-inner-lg-4{padding-bottom:30px;padding-top:30px}
 .h-row.gutters-col-v-lg-custom{margin-bottom:0;margin-top:0}
 .gutters-row-v-lg-custom,
 .h-row.gutters-col-v-lg-custom>.h-col,
 .h-row.gutters-col-v-lg-custom>[class*=h-col-],
 .v-inner-lg-custom{padding-bottom:0;padding-top:0}}@media (min-width:1200px){
 .h-row.gutters-col-v-xl-0{margin-bottom:0;margin-top:0}
 .gutters-row-v-xl-0,
 .h-row.gutters-col-v-xl-0>.h-col,
 .h-row.gutters-col-v-xl-0>[class*=h-col-],
 .v-inner-xl-0{padding-bottom:0;padding-top:0}
 .h-row.gutters-col-v-xl-1{margin-bottom:-8px;margin-top:-8px}
 .gutters-row-v-xl-1,
 .h-row.gutters-col-v-xl-1>.h-col,
 .h-row.gutters-col-v-xl-1>[class*=h-col-],
 .v-inner-xl-1{padding-bottom:8px;padding-top:8px}
 .h-row.gutters-col-v-xl-2{margin-bottom:-15px;margin-top:-15px}
 .gutters-row-v-xl-2,
 .h-row.gutters-col-v-xl-2>.h-col,
 .h-row.gutters-col-v-xl-2>[class*=h-col-],
 .v-inner-xl-2{padding-bottom:15px;padding-top:15px}
 .h-row.gutters-col-v-xl-3{margin-bottom:-30px;margin-top:-30px}
 .gutters-row-v-xl-3,
 .h-row.gutters-col-v-xl-3>.h-col,
 .h-row.gutters-col-v-xl-3>[class*=h-col-],
 .v-inner-xl-3{padding-bottom:30px;padding-top:30px}
 .h-row.gutters-col-v-xl-4{margin-bottom:-30px;margin-top:-30px}
 .gutters-row-v-xl-4,
 .h-row.gutters-col-v-xl-4>.h-col,
 .h-row.gutters-col-v-xl-4>[class*=h-col-],
 .v-inner-xl-4{padding-bottom:30px;padding-top:30px}
 .h-row.gutters-col-v-xl-custom{margin-bottom:0;margin-top:0}
 .gutters-row-v-xl-custom,
 .h-row.gutters-col-v-xl-custom>.h-col,
 .h-row.gutters-col-v-xl-custom>[class*=h-col-],
 .v-inner-xl-custom{padding-bottom:0;padding-top:0}}
 .h-row>.h-col,
 .h-row>.h-col-1,
 .h-row>.h-col-2,
 .h-row>.h-col-3,
 .h-row>.h-col-4,
 .h-row>.h-col-5,
 .h-row>.h-col-6,
 .h-row>.h-col-7,
 .h-row>.h-col-8,
 .h-row>.h-col-9,
 .h-row>.h-col-10,
 .h-row>.h-col-11,
 .h-row>.h-col-12,
 .h-row>.h-col-auto,
 .h-row>.h-col-lg,
 .h-row>.h-col-lg-1,
 .h-row>.h-col-lg-2,
 .h-row>.h-col-lg-3,
 .h-row>.h-col-lg-4,
 .h-row>.h-col-lg-5,
 .h-row>.h-col-lg-6,
 .h-row>.h-col-lg-7,
 .h-row>.h-col-lg-8,
 .h-row>.h-col-lg-9,
 .h-row>.h-col-lg-10,
 .h-row>.h-col-lg-11,
 .h-row>.h-col-lg-12,
 .h-row>.h-col-lg-auto,
 .h-row>.h-col-md,
 .h-row>.h-col-md-1,
 .h-row>.h-col-md-2,
 .h-row>.h-col-md-3,
 .h-row>.h-col-md-4,
 .h-row>.h-col-md-5,
 .h-row>.h-col-md-6,
 .h-row>.h-col-md-7,
 .h-row>.h-col-md-8,
 .h-row>.h-col-md-9,
 .h-row>.h-col-md-10,
 .h-row>.h-col-md-11,
 .h-row>.h-col-md-12,
 .h-row>.h-col-md-auto,
 .h-row>.h-col-sm,
 .h-row>.h-col-sm-1,
 .h-row>.h-col-sm-2,
 .h-row>.h-col-sm-3,
 .h-row>.h-col-sm-4,
 .h-row>.h-col-sm-5,
 .h-row>.h-col-sm-6,
 .h-row>.h-col-sm-7,
 .h-row>.h-col-sm-8,
 .h-row>.h-col-sm-9,
 .h-row>.h-col-sm-10,
 .h-row>.h-col-sm-11,
 .h-row>.h-col-sm-12,
 .h-row>.h-col-sm-auto,
 .h-row>.h-col-xl,
 .h-row>.h-col-xl-1,
 .h-row>.h-col-xl-2,
 .h-row>.h-col-xl-3,
 .h-row>.h-col-xl-4,
 .h-row>.h-col-xl-5,
 .h-row>.h-col-xl-6,
 .h-row>.h-col-xl-7,
 .h-row>.h-col-xl-8,
 .h-row>.h-col-xl-9,
 .h-row>.h-col-xl-10,
 .h-row>.h-col-xl-11,
 .h-row>.h-col-xl-12,
 .h-row>.h-col-xl-auto{min-height:1px;padding-left:15px;padding-right:15px;position:relative;width:100%}
 .h-row>.h-col{flex-basis:0;flex-grow:1;max-width:100%}
 .h-row>.h-col-auto{flex:0 0 auto;max-width:100%;width:auto}
 .h-row>.h-col-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}
 .h-row>.h-col-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}
 .h-row>.h-col-3{flex:0 0 25%;max-width:25%}
 .h-row>.h-col-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}
 .h-row>.h-col-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}
 .h-row>.h-col-6{flex:0 0 50%;max-width:50%}
 .h-row>.h-col-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}
 .h-row>.h-col-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}
 .h-row>.h-col-9{flex:0 0 75%;max-width:75%}
 .h-row>.h-col-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}
 .h-row>.h-col-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}
 .h-row>.h-col-12{flex:0 0 100%;max-width:100%}
 .h-row>.order-first{order:-1}
 .h-row>.order-last{order:13}
 .h-row>.order-0{order:0}
 .h-row>.order-1{order:1}
 .h-row>.order-2{order:2}
 .h-row>.order-3{order:3}
 .h-row>.order-4{order:4}
 .h-row>.order-5{order:5}
 .h-row>.order-6{order:6}
 .h-row>.order-7{order:7}
 .h-row>.order-8{order:8}
 .h-row>.order-9{order:9}
 .h-row>.order-10{order:10}
 .h-row>.order-11{order:11}
 .h-row>.order-12{order:12}
 .h-row>.offset-1{margin-left:8.3333333333%}
 .h-row>.offset-2{margin-left:16.6666666667%}
 .h-row>.offset-3{margin-left:25%}
 .h-row>.offset-4{margin-left:33.3333333333%}
 .h-row>.offset-5{margin-left:41.6666666667%}
 .h-row>.offset-6{margin-left:50%}
 .h-row>.offset-7{margin-left:58.3333333333%}
 .h-row>.offset-8{margin-left:66.6666666667%}
 .h-row>.offset-9{margin-left:75%}
 .h-row>.offset-10{margin-left:83.3333333333%}
 .h-row>.offset-11{margin-left:91.6666666667%}@media (min-width:576px){
 .h-row>.h-col-sm{flex-basis:0;flex-grow:1;max-width:100%}
 .h-row>.h-col-sm-auto{flex:0 0 auto;max-width:100%;width:auto}
 .h-row>.h-col-sm-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}
 .h-row>.h-col-sm-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}
 .h-row>.h-col-sm-3{flex:0 0 25%;max-width:25%}
 .h-row>.h-col-sm-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}
 .h-row>.h-col-sm-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}
 .h-row>.h-col-sm-6{flex:0 0 50%;max-width:50%}
 .h-row>.h-col-sm-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}
 .h-row>.h-col-sm-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}
 .h-row>.h-col-sm-9{flex:0 0 75%;max-width:75%}
 .h-row>.h-col-sm-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}
 .h-row>.h-col-sm-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}
 .h-row>.h-col-sm-12{flex:0 0 100%;max-width:100%}
 .h-row>.order-sm-first{order:-1}
 .h-row>.order-sm-last{order:13}
 .h-row>.order-sm-0{order:0}
 .h-row>.order-sm-1{order:1}
 .h-row>.order-sm-2{order:2}
 .h-row>.order-sm-3{order:3}
 .h-row>.order-sm-4{order:4}
 .h-row>.order-sm-5{order:5}
 .h-row>.order-sm-6{order:6}
 .h-row>.order-sm-7{order:7}
 .h-row>.order-sm-8{order:8}
 .h-row>.order-sm-9{order:9}
 .h-row>.order-sm-10{order:10}
 .h-row>.order-sm-11{order:11}
 .h-row>.order-sm-12{order:12}
 .h-row>.offset-sm-0{margin-left:0}
 .h-row>.offset-sm-1{margin-left:8.3333333333%}
 .h-row>.offset-sm-2{margin-left:16.6666666667%}
 .h-row>.offset-sm-3{margin-left:25%}
 .h-row>.offset-sm-4{margin-left:33.3333333333%}
 .h-row>.offset-sm-5{margin-left:41.6666666667%}
 .h-row>.offset-sm-6{margin-left:50%}
 .h-row>.offset-sm-7{margin-left:58.3333333333%}
 .h-row>.offset-sm-8{margin-left:66.6666666667%}
 .h-row>.offset-sm-9{margin-left:75%}
 .h-row>.offset-sm-10{margin-left:83.3333333333%}
 .h-row>.offset-sm-11{margin-left:91.6666666667%}}@media (min-width:768px){
 .h-row>.h-col-md{flex-basis:0;flex-grow:1;max-width:100%}
 .h-row>.h-col-md-auto{flex:0 0 auto;max-width:100%;width:auto}
 .h-row>.h-col-md-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}
 .h-row>.h-col-md-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}
 .h-row>.h-col-md-3{flex:0 0 25%;max-width:25%}
 .h-row>.h-col-md-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}
 .h-row>.h-col-md-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}
 .h-row>.h-col-md-6{flex:0 0 50%;max-width:50%}
 .h-row>.h-col-md-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}
 .h-row>.h-col-md-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}
 .h-row>.h-col-md-9{flex:0 0 75%;max-width:75%}
 .h-row>.h-col-md-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}
 .h-row>.h-col-md-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}
 .h-row>.h-col-md-12{flex:0 0 100%;max-width:100%}
 .h-row>.order-md-first{order:-1}
 .h-row>.order-md-last{order:13}
 .h-row>.order-md-0{order:0}
 .h-row>.order-md-1{order:1}
 .h-row>.order-md-2{order:2}
 .h-row>.order-md-3{order:3}
 .h-row>.order-md-4{order:4}
 .h-row>.order-md-5{order:5}
 .h-row>.order-md-6{order:6}
 .h-row>.order-md-7{order:7}
 .h-row>.order-md-8{order:8}
 .h-row>.order-md-9{order:9}
 .h-row>.order-md-10{order:10}
 .h-row>.order-md-11{order:11}
 .h-row>.order-md-12{order:12}
 .h-row>.offset-md-0{margin-left:0}
 .h-row>.offset-md-1{margin-left:8.3333333333%}
 .h-row>.offset-md-2{margin-left:16.6666666667%}
 .h-row>.offset-md-3{margin-left:25%}
 .h-row>.offset-md-4{margin-left:33.3333333333%}
 .h-row>.offset-md-5{margin-left:41.6666666667%}
 .h-row>.offset-md-6{margin-left:50%}
 .h-row>.offset-md-7{margin-left:58.3333333333%}
 .h-row>.offset-md-8{margin-left:66.6666666667%}
 .h-row>.offset-md-9{margin-left:75%}
 .h-row>.offset-md-10{margin-left:83.3333333333%}
 .h-row>.offset-md-11{margin-left:91.6666666667%}}@media (min-width:1024px){
 .h-row>.h-col-lg{flex-basis:0;flex-grow:1;max-width:100%}
 .h-row>.h-col-lg-auto{flex:0 0 auto;max-width:100%;width:auto}
 .h-row>.h-col-lg-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}
 .h-row>.h-col-lg-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}
 .h-row>.h-col-lg-3{flex:0 0 25%;max-width:25%}
 .h-row>.h-col-lg-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}
 .h-row>.h-col-lg-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}
 .h-row>.h-col-lg-6{flex:0 0 50%;max-width:50%}
 .h-row>.h-col-lg-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}
 .h-row>.h-col-lg-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}
 .h-row>.h-col-lg-9{flex:0 0 75%;max-width:75%}
 .h-row>.h-col-lg-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}
 .h-row>.h-col-lg-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}
 .h-row>.h-col-lg-12{flex:0 0 100%;max-width:100%}
 .h-row>.order-lg-first{order:-1}
 .h-row>.order-lg-last{order:13}
 .h-row>.order-lg-0{order:0}
 .h-row>.order-lg-1{order:1}
 .h-row>.order-lg-2{order:2}
 .h-row>.order-lg-3{order:3}
 .h-row>.order-lg-4{order:4}
 .h-row>.order-lg-5{order:5}
 .h-row>.order-lg-6{order:6}
 .h-row>.order-lg-7{order:7}
 .h-row>.order-lg-8{order:8}
 .h-row>.order-lg-9{order:9}
 .h-row>.order-lg-10{order:10}
 .h-row>.order-lg-11{order:11}
 .h-row>.order-lg-12{order:12}
 .h-row>.offset-lg-0{margin-left:0}
 .h-row>.offset-lg-1{margin-left:8.3333333333%}
 .h-row>.offset-lg-2{margin-left:16.6666666667%}
 .h-row>.offset-lg-3{margin-left:25%}
 .h-row>.offset-lg-4{margin-left:33.3333333333%}
 .h-row>.offset-lg-5{margin-left:41.6666666667%}
 .h-row>.offset-lg-6{margin-left:50%}
 .h-row>.offset-lg-7{margin-left:58.3333333333%}
 .h-row>.offset-lg-8{margin-left:66.6666666667%}
 .h-row>.offset-lg-9{margin-left:75%}
 .h-row>.offset-lg-10{margin-left:83.3333333333%}
 .h-row>.offset-lg-11{margin-left:91.6666666667%}}@media (min-width:1200px){
 .h-row>.h-col-xl{flex-basis:0;flex-grow:1;max-width:100%}
 .h-row>.h-col-xl-auto{flex:0 0 auto;max-width:100%;width:auto}
 .h-row>.h-col-xl-1{flex:0 0 8.3333333333%;max-width:8.3333333333%}
 .h-row>.h-col-xl-2{flex:0 0 16.6666666667%;max-width:16.6666666667%}
 .h-row>.h-col-xl-3{flex:0 0 25%;max-width:25%}
 .h-row>.h-col-xl-4{flex:0 0 33.3333333333%;max-width:33.3333333333%}
 .h-row>.h-col-xl-5{flex:0 0 41.6666666667%;max-width:41.6666666667%}
 .h-row>.h-col-xl-6{flex:0 0 50%;max-width:50%}
 .h-row>.h-col-xl-7{flex:0 0 58.3333333333%;max-width:58.3333333333%}
 .h-row>.h-col-xl-8{flex:0 0 66.6666666667%;max-width:66.6666666667%}
 .h-row>.h-col-xl-9{flex:0 0 75%;max-width:75%}
 .h-row>.h-col-xl-10{flex:0 0 83.3333333333%;max-width:83.3333333333%}
 .h-row>.h-col-xl-11{flex:0 0 91.6666666667%;max-width:91.6666666667%}
 .h-row>.h-col-xl-12{flex:0 0 100%;max-width:100%}
 .h-row>.order-xl-first{order:-1}
 .h-row>.order-xl-last{order:13}
 .h-row>.order-xl-0{order:0}
 .h-row>.order-xl-1{order:1}
 .h-row>.order-xl-2{order:2}
 .h-row>.order-xl-3{order:3}
 .h-row>.order-xl-4{order:4}
 .h-row>.order-xl-5{order:5}
 .h-row>.order-xl-6{order:6}
 .h-row>.order-xl-7{order:7}
 .h-row>.order-xl-8{order:8}
 .h-row>.order-xl-9{order:9}
 .h-row>.order-xl-10{order:10}
 .h-row>.order-xl-11{order:11}
 .h-row>.order-xl-12{order:12}
 .h-row>.offset-xl-0{margin-left:0}
 .h-row>.offset-xl-1{margin-left:8.3333333333%}
 .h-row>.offset-xl-2{margin-left:16.6666666667%}
 .h-row>.offset-xl-3{margin-left:25%}
 .h-row>.offset-xl-4{margin-left:33.3333333333%}
 .h-row>.offset-xl-5{margin-left:41.6666666667%}
 .h-row>.offset-xl-6{margin-left:50%}
 .h-row>.offset-xl-7{margin-left:58.3333333333%}
 .h-row>.offset-xl-8{margin-left:66.6666666667%}
 .h-row>.offset-xl-9{margin-left:75%}
 .h-row>.offset-xl-10{margin-left:83.3333333333%}
 .h-row>.offset-xl-11{margin-left:91.6666666667%}}
 .d-none{display:none}
 .d-inline{display:inline}
 .d-inline-block{display:inline-block}
 .d-block{display:block}
 .d-table{display:table}
 .d-table-row{display:table-row}
 .d-table-cell{display:table-cell}
 .d-flex{display:flex}
 .d-inline-flex{display:inline-flex}@media (min-width:576px){
 .d-sm-none{display:none}
 .d-sm-inline{display:inline}
 .d-sm-inline-block{display:inline-block}
 .d-sm-block{display:block}
 .d-sm-table{display:table}
 .d-sm-table-row{display:table-row}
 .d-sm-table-cell{display:table-cell}
 .d-sm-flex{display:flex}
 .d-sm-inline-flex{display:inline-flex}}@media (min-width:768px){
 .d-md-none{display:none}
 .d-md-inline{display:inline}
 .d-md-inline-block{display:inline-block}
 .d-md-block{display:block}
 .d-md-table{display:table}
 .d-md-table-row{display:table-row}
 .d-md-table-cell{display:table-cell}
 .d-md-flex{display:flex}
 .d-md-inline-flex{display:inline-flex}}@media (min-width:1024px){
 .d-lg-none{display:none}
 .d-lg-inline{display:inline}
 .d-lg-inline-block{display:inline-block}
 .d-lg-block{display:block}
 .d-lg-table{display:table}
 .d-lg-table-row{display:table-row}
 .d-lg-table-cell{display:table-cell}
 .d-lg-flex{display:flex}
 .d-lg-inline-flex{display:inline-flex}}@media (min-width:1200px){
 .d-xl-none{display:none}
 .d-xl-inline{display:inline}
 .d-xl-inline-block{display:inline-block}
 .d-xl-block{display:block}
 .d-xl-table{display:table}
 .d-xl-table-row{display:table-row}
 .d-xl-table-cell{display:table-cell}
 .d-xl-flex{display:flex}
 .d-xl-inline-flex{display:inline-flex}}@media print{
 .d-print-none{display:none!important}
 .d-print-inline{display:inline!important}
 .d-print-inline-block{display:inline-block!important}
 .d-print-block{display:block!important}
 .d-print-table{display:table!important}
 .d-print-table-row{display:table-row!important}
 .d-print-table-cell{display:table-cell!important}
 .d-print-flex{display:flex!important}
 .d-print-inline-flex{display:inline-flex!important}}
 .flex-row{flex-direction:row!important}
 .flex-column{flex-direction:column!important}
 .flex-row-reverse{flex-direction:row-reverse!important}
 .flex-column-reverse{flex-direction:column-reverse!important}
 .flex-wrap{flex-wrap:wrap!important}
 .flex-nowrap{flex-wrap:nowrap!important}
 .flex-wrap-reverse{flex-wrap:wrap-reverse!important}
 .justify-content-start{justify-content:flex-start!important}
 .justify-content-end{justify-content:flex-end!important}
 .justify-content-center{justify-content:center!important}
 .justify-content-between{justify-content:space-between!important}
 .justify-content-around{justify-content:space-around!important}
 .justify-self-auto{justify-self:auto!important}
 .justify-self-start{justify-self:flex-start!important}
 .justify-self-end{justify-self:flex-end!important}
 .justify-self-center{justify-self:center!important}
 .justify-self-baseline{justify-self:baseline!important}
 .justify-self-stretch{justify-self:stretch!important}
 .align-items-start{align-items:flex-start!important}
 .align-items-end{align-items:flex-end!important}
 .align-items-center{align-items:center!important}
 .align-items-baseline{align-items:baseline!important}
 .align-items-stretch{align-items:stretch!important}
 .align-content-start{align-content:flex-start!important}
 .align-content-end{align-content:flex-end!important}
 .align-content-center{align-content:center!important}
 .align-content-between{align-content:space-between!important}
 .align-content-around{align-content:space-around!important}
 .align-content-stretch{align-content:stretch!important}
 .align-self-auto{align-self:auto!important}
 .align-self-start{align-self:flex-start!important}
 .align-self-end{align-self:flex-end!important}
 .align-self-center{align-self:center!important}
 .align-self-baseline{align-self:baseline!important}
 .align-self-stretch{align-self:stretch!important}@media (min-width:576px){
 .flex-sm-row{flex-direction:row!important}
 .flex-sm-column{flex-direction:column!important}
 .flex-sm-row-reverse{flex-direction:row-reverse!important}
 .flex-sm-column-reverse{flex-direction:column-reverse!important}
 .flex-sm-wrap{flex-wrap:wrap!important}
 .flex-sm-nowrap{flex-wrap:nowrap!important}
 .flex-sm-wrap-reverse{flex-wrap:wrap-reverse!important}
 .justify-content-sm-start{justify-content:flex-start!important}
 .justify-content-sm-end{justify-content:flex-end!important}
 .justify-content-sm-center{justify-content:center!important}
 .justify-content-sm-between{justify-content:space-between!important}
 .justify-content-sm-around{justify-content:space-around!important}
 .justify-self-sm-auto{justify-self:auto!important}
 .justify-self-sm-start{justify-self:flex-start!important}
 .justify-self-sm-end{justify-self:flex-end!important}
 .justify-self-sm-center{justify-self:center!important}
 .justify-self-sm-baseline{justify-self:baseline!important}
 .justify-self-sm-stretch{justify-self:stretch!important}
 .align-items-sm-start{align-items:flex-start!important}
 .align-items-sm-end{align-items:flex-end!important}
 .align-items-sm-center{align-items:center!important}
 .align-items-sm-baseline{align-items:baseline!important}
 .align-items-sm-stretch{align-items:stretch!important}
 .align-content-sm-start{align-content:flex-start!important}
 .align-content-sm-end{align-content:flex-end!important}
 .align-content-sm-center{align-content:center!important}
 .align-content-sm-between{align-content:space-between!important}
 .align-content-sm-around{align-content:space-around!important}
 .align-content-sm-stretch{align-content:stretch!important}
 .align-self-sm-auto{align-self:auto!important}
 .align-self-sm-start{align-self:flex-start!important}
 .align-self-sm-end{align-self:flex-end!important}
 .align-self-sm-center{align-self:center!important}
 .align-self-sm-baseline{align-self:baseline!important}
 .align-self-sm-stretch{align-self:stretch!important}}@media (min-width:768px){
 .flex-md-row{flex-direction:row!important}
 .flex-md-column{flex-direction:column!important}
 .flex-md-row-reverse{flex-direction:row-reverse!important}
 .flex-md-column-reverse{flex-direction:column-reverse!important}
 .flex-md-wrap{flex-wrap:wrap!important}
 .flex-md-nowrap{flex-wrap:nowrap!important}
 .flex-md-wrap-reverse{flex-wrap:wrap-reverse!important}
 .justify-content-md-start{justify-content:flex-start!important}
 .justify-content-md-end{justify-content:flex-end!important}
 .justify-content-md-center{justify-content:center!important}
 .justify-content-md-between{justify-content:space-between!important}
 .justify-content-md-around{justify-content:space-around!important}
 .justify-self-md-auto{justify-self:auto!important}
 .justify-self-md-start{justify-self:flex-start!important}
 .justify-self-md-end{justify-self:flex-end!important}
 .justify-self-md-center{justify-self:center!important}
 .justify-self-md-baseline{justify-self:baseline!important}
 .justify-self-md-stretch{justify-self:stretch!important}
 .align-items-md-start{align-items:flex-start!important}
 .align-items-md-end{align-items:flex-end!important}
 .align-items-md-center{align-items:center!important}
 .align-items-md-baseline{align-items:baseline!important}
 .align-items-md-stretch{align-items:stretch!important}
 .align-content-md-start{align-content:flex-start!important}
 .align-content-md-end{align-content:flex-end!important}
 .align-content-md-center{align-content:center!important}
 .align-content-md-between{align-content:space-between!important}
 .align-content-md-around{align-content:space-around!important}
 .align-content-md-stretch{align-content:stretch!important}
 .align-self-md-auto{align-self:auto!important}
 .align-self-md-start{align-self:flex-start!important}
 .align-self-md-end{align-self:flex-end!important}
 .align-self-md-center{align-self:center!important}
 .align-self-md-baseline{align-self:baseline!important}
 .align-self-md-stretch{align-self:stretch!important}}@media (min-width:1024px){
 .flex-lg-row{flex-direction:row!important}
 .flex-lg-column{flex-direction:column!important}
 .flex-lg-row-reverse{flex-direction:row-reverse!important}
 .flex-lg-column-reverse{flex-direction:column-reverse!important}
 .flex-lg-wrap{flex-wrap:wrap!important}
 .flex-lg-nowrap{flex-wrap:nowrap!important}
 .flex-lg-wrap-reverse{flex-wrap:wrap-reverse!important}
 .justify-content-lg-start{justify-content:flex-start!important}
 .justify-content-lg-end{justify-content:flex-end!important}
 .justify-content-lg-center{justify-content:center!important}
 .justify-content-lg-between{justify-content:space-between!important}
 .justify-content-lg-around{justify-content:space-around!important}
 .justify-self-lg-auto{justify-self:auto!important}
 .justify-self-lg-start{justify-self:flex-start!important}
 .justify-self-lg-end{justify-self:flex-end!important}
 .justify-self-lg-center{justify-self:center!important}
 .justify-self-lg-baseline{justify-self:baseline!important}
 .justify-self-lg-stretch{justify-self:stretch!important}
 .align-items-lg-start{align-items:flex-start!important}
 .align-items-lg-end{align-items:flex-end!important}
 .align-items-lg-center{align-items:center!important}
 .align-items-lg-baseline{align-items:baseline!important}
 .align-items-lg-stretch{align-items:stretch!important}
 .align-content-lg-start{align-content:flex-start!important}
 .align-content-lg-end{align-content:flex-end!important}
 .align-content-lg-center{align-content:center!important}
 .align-content-lg-between{align-content:space-between!important}
 .align-content-lg-around{align-content:space-around!important}
 .align-content-lg-stretch{align-content:stretch!important}
 .align-self-lg-auto{align-self:auto!important}
 .align-self-lg-start{align-self:flex-start!important}
 .align-self-lg-end{align-self:flex-end!important}
 .align-self-lg-center{align-self:center!important}
 .align-self-lg-baseline{align-self:baseline!important}
 .align-self-lg-stretch{align-self:stretch!important}}@media (min-width:1200px){
 .flex-xl-row{flex-direction:row!important}
 .flex-xl-column{flex-direction:column!important}
 .flex-xl-row-reverse{flex-direction:row-reverse!important}
 .flex-xl-column-reverse{flex-direction:column-reverse!important}
 .flex-xl-wrap{flex-wrap:wrap!important}
 .flex-xl-nowrap{flex-wrap:nowrap!important}
 .flex-xl-wrap-reverse{flex-wrap:wrap-reverse!important}
 .justify-content-xl-start{justify-content:flex-start!important}
 .justify-content-xl-end{justify-content:flex-end!important}
 .justify-content-xl-center{justify-content:center!important}
 .justify-content-xl-between{justify-content:space-between!important}
 .justify-content-xl-around{justify-content:space-around!important}
 .justify-self-xl-auto{justify-self:auto!important}
 .justify-self-xl-start{justify-self:flex-start!important}
 .justify-self-xl-end{justify-self:flex-end!important}
 .justify-self-xl-center{justify-self:center!important}
 .justify-self-xl-baseline{justify-self:baseline!important}
 .justify-self-xl-stretch{justify-self:stretch!important}
 .align-items-xl-start{align-items:flex-start!important}
 .align-items-xl-end{align-items:flex-end!important}
 .align-items-xl-center{align-items:center!important}
 .align-items-xl-baseline{align-items:baseline!important}
 .align-items-xl-stretch{align-items:stretch!important}
 .align-content-xl-start{align-content:flex-start!important}
 .align-content-xl-end{align-content:flex-end!important}
 .align-content-xl-center{align-content:center!important}
 .align-content-xl-between{align-content:space-between!important}
 .align-content-xl-around{align-content:space-around!important}
 .align-content-xl-stretch{align-content:stretch!important}
 .align-self-xl-auto{align-self:auto!important}
 .align-self-xl-start{align-self:flex-start!important}
 .align-self-xl-end{align-self:flex-end!important}
 .align-self-xl-center{align-self:center!important}
 .align-self-xl-baseline{align-self:baseline!important}
 .align-self-xl-stretch{align-self:stretch!important}}
 .h-flex-basis{flex:1 0 auto}
 .flex-basis-auto{flex-basis:auto}
 .flex-basis-100{flex-basis:100%}
 .position-relative{position:relative}
 .align-items-center{align-items:center}
 .align-items-left{align-items:flex-start}
 .align-items-right{align-items:flex-end}
 .h-global-transition,
 .h-global-transition-all *{transition-property:background,padding,margin,border,transform,filter,box-shadow,opacity,color,fill,font,border-radius,max-height,max-width}
 .h-global-transition-disable,
 .h-global-transition-disable *{transition-property:none!important;transition:none!important}
 .white-space-nowrap{white-space:nowrap}
 .w-100{width:100%}
 *{word-wrap:break-word}
 .h-hidden{display:none!important}
 .h-visible{display:block!important}
 .h-stop-animation{-webkit-animation-duration:0s!important;animation-duration:0s!important}
 .h-word-wrap{word-break:break-word}
 .h-new-stacking-context{position:relative;z-index:1}
 .h-overflow-visible{overflow:visible}
 .h-overflow-hidden{overflow:hidden}
 .h-mw-100{max-width:100%}
 .h-mh-100{max-height:100%}
 .h-w-100{width:100%}
 .h-h-100{height:100%}
 .h-hide{display:none}
 .h-force-hide{display:none!important}
 .h-display-none{display:none}
 .h-text-success{color:#28a745!important}
 .h-text-danger{color:#dc3545!important}
 .h-cursor-pointer{cursor:pointer}
 .h-pointer-event-none{pointer-events:none}
 .kubio-frontent-placeholder{background-color:#e7eef4;border:1px solid #cedce9;color:#555;font-family:Open Sans,Helvetica,Arial,Sans-Serif,serif;font-size:1em;padding:20px 40px}
 .kubio-frontent-placeholder,
 .kubio-frontent-placeholder *{text-align:left}
 .kubio-frontent-placeholder--info{align-items:center;display:flex}
 .kubio-frontent-placeholder--logo{flex-basis:1.5em;flex-grow:0}
 .kubio-frontent-placeholder--logo svg{fill:#09f;display:block}
 .kubio-frontent-placeholder--title{color:#000;font-size:1.3em;margin-left:.5em}
 .kubio-frontent-placeholder--small{font-size:80%}
 .h-y-container>*{margin-top:0}
 .h-y-container>:last-child{margin-bottom:0}
 .wp-block-cover:before{height:100%!important;width:100%!important}
 .wp-block[data-align=full]{max-width:unset!important}
html .h-y-container .wp-block:not([data-kubio]){max-width:100%}
 .h-ignore-global-body-typography.wp-block[data-kubio],
 .h-ignore-global-body-typography.wp-block[data-kubio] [data-kubio]{color:initial;font-size:medium;font-style:normal;letter-spacing:normal;line-height:normal}
 .page-template-kubio-full-width :where(.wp-site-blocks)>*{margin-top:0!important}
 [data-kubio] .wp-block-separator:not(.is-style-wide):not(.is-style-dots){width:100px}
 .wp-block-image .hide:not(#extra-1){display:block!important;visibility:hidden}
 .h-svg-icon{fill:currentColor;box-sizing:content-box;display:inline-block;height:16px;line-height:0!important;vertical-align:middle;width:16px}
 .background-wrapper{border-radius:inherit;pointer-events:none;z-index:0}
 .background-layer,
 .background-wrapper{bottom:0;left:0;overflow:hidden;position:absolute;right:0;top:0}
 .background-layer{z-index:-10}
 .overlay-image-layer,
 .overlay-layer,
 .shape-layer{bottom:-1px;left:0;position:absolute;right:0;top:-1px}
 .overlay-layer{z-index:1}
 .shape-layer{z-index:2}
 .overlay-image-layer{z-index:1}
 .kubio-slideshow:not([data-loaded=true]) .slideshow-image{display:none}
 .kubio-slideshow:not([data-loaded=true]) .slideshow-image:first-of-type{display:block;opacity:1!important}
 .kubio-slideshow .slideshow-image{background-repeat:no-repeat;background-size:cover;bottom:0;left:0;opacity:1!important;position:absolute;right:0;top:0}
 .kubio-slideshow .slideshow-image.current{opacity:0!important;z-index:1001!important}
 .kubio-slideshow .slideshow-image.next{z-index:1000!important}
 .background-layer-media-container-lg{display:block}
 .background-layer-media-container,
 .background-layer-media-container-md{display:none}
 .height-auto-forced{height:auto!important;min-height:unset!important}@media (min-width:768px) and (max-width:1023px){
 .background-layer-media-container-md{display:block}
 .background-layer-media-container,
 .background-layer-media-container-lg{display:none}}@media (max-width:767px){
 .background-layer-media-container{display:block}
 .background-layer-media-container-lg,
 .background-layer-media-container-md{display:none}}
 div.cp-video-bg{background-color:#000;background-position:50%;background-repeat:no-repeat;background-size:cover;margin-top:0;position:absolute;top:0;-webkit-transform:translateZ(-2px);width:100%;z-index:-3}
 .cp-video-bg{background-color:transparent!important;font-size:0;height:100%;line-height:0!important;max-height:100%;max-width:100%;overflow:hidden}
 .cp-video-bg iframe,
 .cp-video-bg video{display:block;visibility:hidden}
 .cp-video-bg.visible iframe,
 .cp-video-bg.visible video{visibility:visible}
 div.cp-video-bg .wp-custom-header-video{opacity:0;position:absolute;transition:opacity .4s cubic-bezier(.44,.94,.25,.34);width:100%}
 div.cp-video-bg button.wp-custom-header-video-button{display:none}
 .background-video-youtube-blocker{background-color:transparent;height:100%;position:absolute;width:100%;z-index:9999}
 .kubio-video-background:before{background:transparent;bottom:0;content:" ";display:block;height:100%;left:0;position:absolute;right:0;top:0;width:100%;z-index:1}
 video.kubio-video-background-item{max-width:unset;min-height:100%;min-width:100%;position:relative;width:auto;z-index:0}
 iframe.kubio-video-background-item{max-height:unset;max-width:unset;min-height:unset;min-width:unset;visibility:hidden}
 iframe.kubio-video-background-item.ready{visibility:visible}
 .paraxify{background-attachment:fixed;background-position:50%;background-repeat:no-repeat;background-size:cover}
 .paraxify--ios.paraxify{background-attachment:scroll}
 .h-separator{display:flex;height:10%;left:0;max-width:100%;overflow:hidden;pointer-events:none;position:absolute;width:100%;z-index:0}
 .h-separator svg{display:block;height:100%;max-height:100%;width:100%}
 .h-separator.h-separator--display-flex{display:flex}
 .h-separator.h-separator--display-none{display:none}@media (min-width:576px){
 .h-separator.h-separator--display-flex-sm{display:flex}
 .h-separator.h-separator--display-none-sm{display:none}}@media (min-width:768px){
 .h-separator.h-separator--display-flex-md{display:flex}
 .h-separator.h-separator--display-none-md{display:none}}@media (min-width:1024px){
 .h-separator.h-separator--display-flex-lg{display:flex}
 .h-separator.h-separator--display-none-lg{display:none}}@media (min-width:1200px){
 .h-separator.h-separator--display-flex-xl{display:flex}
 .h-separator.h-separator--display-none-xl{display:none}}@media (min-width:1024px){
 .h-hide-lg{display:none!important}}@media (min-width:768px) and (max-width:1023px){
 .h-hide-md{display:none!important}}@media (max-width:767px){
 .h-hide-sm,
 .h-hide-sm-force,
 .kubio-hide-on-mobile{display:none!important}}@media (min-width:768px) and (max-width:1023px){
 .kubio-hide-on-tablet{display:none!important}}@media (min-width:1024px){
 .kubio-hide-on-desktop{display:none!important}}
 [data-kubio] .wp-block-accordion{text-align:left}
 [data-kubio] .wp-block-accordion .wp-block-accordion-heading,
 [data-kubio] .wp-block-accordion .wp-block-accordion-panel{width:100%}
 [data-kubio] .wp-block-post-comments-form .wp-block-button__link{height:auto}
 .has-fit-text.wp-block-heading,
 p.has-fit-text{max-width:100%;overflow:hidden;transition:none!important}
 [data-kubio] .wp-block-icon svg{height:auto}
.kubio-enable-gap-fallback .kubio-has-gap-fallback{--kubio-gap-fallback-half:calc(var(--kubio-gap-fallback)*0.5);gap:0!important;margin:calc(var(--kubio-gap-fallback-half)*-1)!important}
.kubio-enable-gap-fallback .kubio-has-gap-fallback>*{margin:var(--kubio-gap-fallback-half)!important}
.kubio-attachment-fixed-support-fallback [data-kubio],
.kubio-attachment-fixed-support-fallback [data-kubio] [class*=style-]{background-attachment:scroll!important}
 #kubio-language-selector{position:fixed;right:0;top:150px;z-index:12345}
 #kubio-language-selector .--is-editor .kubio-language-selector a,
 #kubio-language-selector .--is-editor .kubio-language-selector select{pointer-events:none}
 #kubio-language-selector .kubio-language-selector{background-color:#fff;border-radius:5px 0 0 5px;box-shadow:0 0 5px #000}
 #kubio-language-selector .kubio-language-selector select{margin:0}
 #kubio-language-selector .kubio-language-selector li{list-style:none;margin-bottom:0}
 #kubio-language-selector .kubio-language-selector .wpml-ls{border:none;padding:0}
 #kubio-language-selector .kubio-language-selector .wpml-ls .wpml-ls-link{padding:0}
 #kubio-language-selector .kubio-language-selector .wpml-ls.wpml-ls-legacy-dropdown-click{width:auto}
 #kubio-language-selector .kubio-language-selector .wpml-ls .wpml-ls-item{padding:14px 18px}
 #kubio-language-selector .kubio-language-selector .wpml-ls .wpml-ls-item:not(.wpml-ls-current-language){display:none}
 #kubio-language-selector .kubio-language-selector .wpml-ls .wpml-ls-item a{line-height:0}
 #kubio-language-selector .kubio-language-selector .wpml-ls .wpml-ls-item a span{display:none}
 #kubio-language-selector .kubio-language-selector .wpml-ls:hover .wpml-ls-item{display:inline-block}
 .single-kubio_recommend_page #wpadminbar{display:none}
html:has(.single-kubio_recommend_page){margin-top:0!important}
 .kubio-recommendation-page-iframe__wrapper{bottom:0;height:100%;left:0;margin:0!important;max-width:100%!important;opacity:0;pointer-events:none;position:fixed;right:0;top:0;transition:opacity .3s ease-in-out;width:100%;z-index:99999999}
 .kubio-recommendation-page-iframe__wrapper iframe{border:none;height:100%;width:100%}
 .kubio-recommendation-page-iframe__wrapper--is-visible{opacity:1;pointer-events:auto;visibility:visible}
 .kubio-recommendation-page-iframe__close{--size:30px;--transition:0.3s ease-in-out;align-items:center;background-color:#1e1e1e;border-radius:100%;color:#fff;cursor:pointer;display:flex;font-size:var(--size);font-weight:500;height:var(--size);justify-content:center;line-height:1;position:absolute;right:40px;top:40px;transition:var(--transition);transition-property:background-color;width:var(--size);z-index:9999999}
 .kubio-recommendation-page-iframe__close svg{fill:currentColor;display:block;height:calc(var(--size)*.6);transition:var(--transition);transition-property:color;width:calc(var(--size)*.6)}@media (max-width:768px){
 .kubio-recommendation-page-iframe__close{right:10px;top:10px}}
 .kubio-recommendation-page-iframe__close:hover{background-color:#fff;color:#333}
 .wp-block-kubio-accordion .wp-block-kubio-accordionitem__title{cursor:pointer;text-align:left;text-decoration:none}
 .wp-block-kubio-accordion .wp-block-kubio-accordionitem__title .wp-block-kubio-accordionitem__titleText{flex:1;order:2;word-break:break-word}
 .wp-block-kubio-accordion .wp-block-kubio-accordionitem__title .h-accordion-item-title-icon{display:inline-flex;height:16px;text-align:center;width:16px}
 .wp-block-kubio-accordion .wp-block-kubio-accordionitem__title .h-accordion-item-title-icon--left{order:1}
 .wp-block-kubio-accordion .wp-block-kubio-accordionitem__title .h-accordion-item-title-icon--right{margin-right:auto;order:3}
 .wp-block-kubio-accordion .wp-block-kubio-accordionitem__title .h-accordion-item-title-active-icon,
 .wp-block-kubio-accordion .wp-block-kubio-accordionitem__title~.h-accordion-item-content__container{display:none}
 .wp-block-kubio-accordion .wp-block-kubio-accordionitem__title .h-accordion-item-title-normal-icon{display:inline-block}
 .wp-block-kubio-accordion .wp-block-kubio-accordionitem__title.accordion-active~.h-accordion-item-content__container{display:block}
 .wp-block-kubio-accordion .wp-block-kubio-accordionitem__title.accordion-active .h-accordion-item-title-active-icon{display:inline-block}
 .wp-block-kubio-accordion .wp-block-kubio-accordionitem__title.accordion-active .h-accordion-item-title-normal-icon{display:none}
 .wp-block-kubio-buttongroup{display:block;width:100%}
 [data-kubio] .wp-block-kubio-buttongroup{display:inline-block}
 .wp-block-kubio-button__outer{display:inline-flex}
 .wp-block-kubio-button__link{align-items:center;cursor:pointer;display:inline-flex}
 .wp-block-kubio-button__link svg{transform:translateY(1px)}
 .wp-block-kubio-button__inner{cursor:pointer;text-decoration:none}
 .wp-block-kubio-button__icon{flex-shrink:0}
 .wp-block-kubio-button__text:empty{display:none}
 .wp-block-kubio-button__inline-fancybox:empty{display:none;visibility:hidden}
 .kubio-recommendation-lightbox__inner-content .wpcf7 input:not([type=file]):not([type=radio]):not([type=checkbox]):not([type=submit]),
 .kubio-recommendation-lightbox__inner-content .wpcf7 select,
 .kubio-recommendation-lightbox__inner-content .wpcf7 textarea{display:block;width:100%}
 .wp-block-kubio-column{max-width:100%;min-width:0}
 .wp-block-kubio-column.masonry-item{transition-duration:0s}
 .wp-block-kubio-column__content .h-heading h1:last-child,
 .wp-block-kubio-column__content .h-heading h2:last-child,
 .wp-block-kubio-column__content .h-heading h3:last-child,
 .wp-block-kubio-column__content .h-heading h4:last-child,
 .wp-block-kubio-column__content .h-heading h5:last-child,
 .wp-block-kubio-column__content .h-heading h6:last-child,
 .wp-block-kubio-column__content .h-heading p:last-child,
 .wp-block-kubio-column__content .h-text h1:last-child,
 .wp-block-kubio-column__content .h-text h2:last-child,
 .wp-block-kubio-column__content .h-text h3:last-child,
 .wp-block-kubio-column__content .h-text h4:last-child,
 .wp-block-kubio-column__content .h-text h5:last-child,
 .wp-block-kubio-column__content .h-text h6:last-child,
 .wp-block-kubio-column__content .h-text p:last-child,
 .wp-block-kubio-column__content>:last-child{margin-bottom:0}
 .wp-block-kubio-column__inner{flex-shrink:1;max-width:100%;position:relative}
 .wp-block-kubio-column__align{flex:1 0 auto;max-width:100%}
 .wp-block-kubio-contact .h-block-placeholder{font-style:normal;font-weight:400;letter-spacing:normal;text-decoration:none;text-transform:none}
 .wp-block-kubio-contact__formContainer.kubio-use-style input,
 .wp-block-kubio-contact__formContainer.kubio-use-style select,
 .wp-block-kubio-contact__formContainer.kubio-use-style textarea{line-height:normal;max-width:100%}
 .wp-block-kubio-contact__formContainer.kubio-use-style form select{height:auto!important}
 .wp-block-kubio-contact__formContainer.kubio-use-style textarea{overflow:auto}
 .wp-block-kubio-contact__formContainer.kubio-use-style p{margin:0}
 .wp-block-kubio-contact__formContainer.kubio-use-style button,
 .wp-block-kubio-contact__formContainer.kubio-use-style input:not([type=file]):not([type=radio]):not([type=checkbox]):not([type=submit]),
 .wp-block-kubio-contact__formContainer.kubio-use-style input[type=submit]{-webkit-appearance:none;-moz-appearance:none;appearance:none}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 input:not([type=file]):not([type=radio]):not([type=checkbox]):not([type=submit]),
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 select,
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 textarea{display:block;width:100%}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 label{display:block;text-align:inherit}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 label>span{display:block}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 .wpcf7-spinner{display:none}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 form.submitting .wpcf7-spinner{display:inline-block}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 .wpcf7-submit{margin-bottom:16px}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 .wpcf7-response-output{margin:15px 0 0;padding:.2em 1em;text-align:left}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 .screen-reader-response{clip:rect(1px,1px,1px,1px);border:0;height:1px;margin:0;overflow:hidden;padding:0;position:absolute;width:1px}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 fieldset.hidden-fields-container{border:none!important;padding:0!important}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 .ajax-loader{display:none}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 .wpcf7-select{-webkit-appearance:listbox}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 .wpcf7-checkbox .wpcf7-list-item,
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 .wpcf7-radio .wpcf7-list-item{display:block;margin-bottom:1em}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 .wpcf7-checkbox .wpcf7-list-item label,
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 .wpcf7-radio .wpcf7-list-item label{text-align:inherit!important}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 .wpcf7-checkbox .wpcf7-list-item label>*,
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 .wpcf7-radio .wpcf7-list-item label>*{display:inline-block}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 .wpcf7-checkbox .wpcf7-list-item .wpcf7-list-item-label,
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpcf7 .wpcf7-radio .wpcf7-list-item .wpcf7-list-item-label{margin:auto 8px}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpforms-container .wpform-error{color:#900!important}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui input:not([type=file]):not([type=radio]):not([type=checkbox]):not([type=submit]),
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui select,
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui textarea{display:block;width:100%}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui label{display:block}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-field .forminator-checkbox.forminator-checkbox-inline,
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-field .forminator-checkbox:not(.forminator-checkbox-inline):last-child,
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-field .forminator-file-upload,
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-field .forminator-radio.forminator-radio-inline,
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-field .forminator-radio:not(.forminator-radio-inline):last-child,
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-field .forminator-select2+.forminator-select,
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-field .forminator-select--field+.forminator-select{margin-bottom:16px!important}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-checkbox span[aria-hidden],
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-radio span[aria-hidden]{background-color:#fff!important}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-pagination-footer:after,
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-pagination-footer:before{display:none!important}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-icon-calendar{transform:translateY(calc(-50% - 6px))!important}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-datepicker{padding-left:38px!important}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-error-message,
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-row [id^=checkbox]{text-align:left}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-description{display:flex}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-description span{margin-left:auto;margin-right:0;min-width:80px;text-align:right}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-button-submit{cursor:pointer;display:block;margin-bottom:16px}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-response-message{border-radius:0;display:block;margin:0 0 30px;padding:15px 20px 15px 22px;text-align:left}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-response-message[aria-hidden=true]{display:none}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-response-message.forminator-loading{background-color:#f8f8f8;padding-left:46px;position:relative}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-response-message.forminator-loading:before{speak:none;text-rendering:auto;-webkit-font-smoothing:antialiased;color:inherit;content:"◌";display:inline-block;font-family:forminator-icons-font!important;font-size:1em;font-style:normal;font-variant:normal;font-weight:400;left:20px;line-height:1em;position:absolute;text-transform:none;top:calc(50% - .5em);width:1em}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-response-message label,
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-response-message p{color:inherit!important;font-family:inherit!important;font-size:inherit!important;font-style:inherit!important;font-weight:inherit!important;letter-spacing:inherit!important;line-height:inherit!important;text-decoration:inherit!important;text-transform:inherit!important}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-error-message{background-color:#f9e4e8;border-radius:0;color:#e04562;display:block!important;font-family:inherit;font-size:12px;font-weight:500;line-height:2em;margin:5px 0 16px;padding:2px 10px}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-row{margin-bottom:0!important}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-textarea{min-height:140px}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui .forminator-response-message.forminator-accessible{clip:rect(0 0 0 0)!important;border:0!important;-webkit-clip-path:inset(50%)!important;clip-path:inset(50%)!important;height:1px!important;margin:-1px!important;overflow:hidden!important;padding:0!important;position:absolute!important;white-space:nowrap!important;width:1px!important}
 .wp-block-kubio-contact__formContainer.kubio-use-style form.forminator-ui{display:block!important}
 .wp-block-kubio-contact__formContainer.kubio-use-style div.forminator-ui{display:none}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpforms-confirmation-container-full p,
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpforms-confirmation-container p{color:inherit;font-family:inherit;font-size:inherit;font-style:inherit;font-weight:inherit;letter-spacing:inherit;line-height:inherit;text-decoration:inherit;text-transform:inherit}
 .wp-block-kubio-contact__formContainer.kubio-use-style .wpforms-form legend{text-align:left}
 .wp-block-kubio-contact__formContainer.kubio-use-style [type=submit]{cursor:pointer;display:block;margin-left:0;margin-right:auto;text-align:left}
 .wp-block-kubio-contact__formContainer.kubio-no-style{text-align:left}
 .wp-block-kubio-contact__formContainer.kubio-no-style form.forminator-ui{display:block!important}
 .wp-block-kubio-contact__formContainer.kubio-no-style .wpcf7 input{max-width:100%}
 .wp-block-kubio-contact__formContainer .wp-block form p{color:inherit;font-family:inherit;font-size:inherit;font-style:inherit;font-weight:inherit;letter-spacing:inherit;line-height:inherit;text-decoration:inherit;text-transform:inherit}
 .wp-block-kubio-copyright p{margin:0}
 .wp-block-kubio-divider{font-size:0!important;line-height:0!important}
 .wp-block-kubio-divider .divider-icon{display:inline-block;flex-grow:0;margin-left:10px;margin-right:10px;vertical-align:middle}
 .wp-block-kubio-divider .divider-icon .h-svg-icon{fill:#03a9f4;height:40px;width:40px}
 .wp-block-kubio-divider__line{border:0;border-bottom:3px solid #03a9f4;display:inline-block;flex-grow:1;vertical-align:middle}
 .wp-block-kubio-divider__inner{flex-shrink:0;justify-self:center}
 .wp-block-kubio-divider .line-type .components-select-control__input{float:right;width:50%}
 .wp-block-kubio-divider .line-type .components-base-control__label{margin-top:8px}
 .wp-block-kubio-divider__width-container{align-items:center;display:inline-flex;justify-content:center}
 .wp-block-kubio-footer.wp-block,
 .wp-block-kubio-footer [data-kubio]:not([class*=h-col-]){max-width:unset!important}
 .h-footer-parallax{bottom:0!important;left:0!important;position:fixed!important;right:0!important;z-index:-1!important}
 .h-footer-parallax-content-class{box-shadow:0 20px 20px -10px rgba(49,52,57,.3),0 20px 30px rgba(0,0,0,.08)}
 .h-footer-parallax-content-class,
 .h-footer-parallax-header-class{background-color:#fff;position:relative;transition-duration:0s!important}
 .wp-block-kubio-header.wp-block,
 .wp-block-kubio-header [data-kubio]:not([class*=h-col-]){max-width:unset!important}
 .wp-block-kubio-heading .h-hidden,
 .wp-block-kubio-heading__text .ah-headline.type .ah-words-wrapper.selected:after,
 .wp-block-kubio-heading__text .ah-headline.type b{visibility:hidden}
 .wp-block-kubio-heading__text .ah-headline.clip span,
 .wp-block-kubio-heading__text .ah-headline.loading-bar span,
 .wp-block-kubio-heading__text .ah-headline.slide span{display:inline-block;padding:.2em 0}
 .wp-block-kubio-heading__text .ah-headline.clip .ah-words-wrapper,
 .wp-block-kubio-heading__text .ah-headline.loading-bar .ah-words-wrapper,
 .wp-block-kubio-heading__text .ah-headline.slide .ah-words-wrapper,
 .wp-block-kubio-heading__text .ah-headline.type .ah-words-wrapper{overflow:hidden;vertical-align:top}
 .wp-block-kubio-heading__text .ah-words-wrapper{display:inline-block;position:relative;text-align:left}
 .wp-block-kubio-heading__text .ah-words-wrapper b{display:inline-block;left:0;position:absolute;top:0;transition:none!important;white-space:nowrap}
 .wp-block-kubio-heading__text .ah-words-wrapper b.is-visible{position:relative}
 .wp-block-kubio-heading__text .no-js .ah-words-wrapper b{opacity:0}
 .wp-block-kubio-heading__text .no-js .ah-words-wrapper b.is-visible{opacity:1}
 .wp-block-kubio-heading__text .ah-headline.rotate-1 .ah-words-wrapper{perspective:300px}
 .wp-block-kubio-heading__text .ah-headline.rotate-1 b{opacity:0;transform:rotateX(180deg);transform-origin:50% 100%}
 .wp-block-kubio-heading__text .ah-headline.rotate-1 b.is-visible{-webkit-animation:ah-rotate-1-in 1.2s;animation:ah-rotate-1-in 1.2s;opacity:1;transform:rotateX(0)}
 .wp-block-kubio-heading__text .ah-headline.rotate-1 b.is-hidden{-webkit-animation:ah-rotate-1-out 1.2s;animation:ah-rotate-1-out 1.2s;transform:rotateX(180deg)}@-webkit-keyframes ah-rotate-1-in{0%{opacity:0;transform:rotateX(180deg)}35%{opacity:0;transform:rotateX(120deg)}65%{opacity:0}to{opacity:1;transform:rotateX(1turn)}}@keyframes ah-rotate-1-in{0%{opacity:0;transform:rotateX(180deg)}35%{opacity:0;transform:rotateX(120deg)}65%{opacity:0}to{opacity:1;transform:rotateX(1turn)}}@-webkit-keyframes ah-rotate-1-out{0%{opacity:1;transform:rotateX(0)}35%{opacity:1;transform:rotateX(-40deg)}65%{opacity:0}to{opacity:0;transform:rotateX(180deg)}}@keyframes ah-rotate-1-out{0%{opacity:1;transform:rotateX(0)}35%{opacity:1;transform:rotateX(-40deg)}65%{opacity:0}to{opacity:0;transform:rotateX(180deg)}}
 .wp-block-kubio-heading__text .ah-headline.type .ah-words-wrapper:after{background-color:#363636;bottom:auto;content:"";height:90%;position:absolute;right:0;top:50%;transform:translateY(-50%);width:1px}
 .wp-block-kubio-heading__text .ah-headline.type .ah-words-wrapper.waiting:after{-webkit-animation:ah-pulse 1s infinite;animation:ah-pulse 1s infinite}
 .wp-block-kubio-heading__text .ah-headline.type .ah-words-wrapper.selected{background-color:#f0f0f0}
 .wp-block-kubio-heading__text .ah-headline.type .ah-words-wrapper.selected b{color:#363636}
 .wp-block-kubio-heading__text .ah-headline.type b.is-visible{visibility:visible}
 .wp-block-kubio-heading__text .ah-headline.type i{position:absolute;visibility:hidden}
 .wp-block-kubio-heading__text .ah-headline.type i.in{position:relative;visibility:visible}@-webkit-keyframes ah-pulse{0%{opacity:1;transform:translateY(-50%) scale(1)}40%{opacity:0;transform:translateY(-50%) scale(.9)}to{opacity:0;transform:translateY(-50%) scale(0)}}@keyframes ah-pulse{0%{opacity:1;transform:translateY(-50%) scale(1)}40%{opacity:0;transform:translateY(-50%) scale(.9)}to{opacity:0;transform:translateY(-50%) scale(0)}}
 .wp-block-kubio-heading__text .ah-headline.rotate-2 .ah-words-wrapper{perspective:300px}
 .wp-block-kubio-heading__text .ah-headline.rotate-2 em,
 .wp-block-kubio-heading__text .ah-headline.rotate-2 i{-webkit-backface-visibility:hidden;backface-visibility:hidden;display:inline-block}
 .wp-block-kubio-heading__text .ah-headline.rotate-2 b{opacity:0}
 .wp-block-kubio-heading__text .ah-headline.rotate-2 i{opacity:0;transform:translateZ(-20px) rotateX(90deg);transform-style:preserve-3d}
 .wp-block-kubio-heading__text .is-visible .ah-headline.rotate-2 i{opacity:1}
 .wp-block-kubio-heading__text .ah-headline.rotate-2 i.in{-webkit-animation:ah-rotate-2-in .4s forwards;animation:ah-rotate-2-in .4s forwards}
 .wp-block-kubio-heading__text .ah-headline.rotate-2 i.out{-webkit-animation:ah-rotate-2-out .4s forwards;animation:ah-rotate-2-out .4s forwards}
 .wp-block-kubio-heading__text .ah-headline.rotate-2 em{transform:translateZ(20px)}
 .wp-block-kubio-heading__text .no-csstransitions .ah-headline.rotate-2 i{opacity:0;transform:rotateX(0)}
 .wp-block-kubio-heading__text .no-csstransitions .ah-headline.rotate-2 i em{transform:scale(1)}
 .wp-block-kubio-heading__text .no-csstransitions .ah-headline.rotate-2 .is-visible i{opacity:1}@-webkit-keyframes ah-rotate-2-in{0%{opacity:0;transform:translateZ(-20px) rotateX(90deg)}60%{opacity:1;transform:translateZ(-20px) rotateX(-10deg)}to{opacity:1;transform:translateZ(-20px) rotateX(0)}}@keyframes ah-rotate-2-in{0%{opacity:0;transform:translateZ(-20px) rotateX(90deg)}60%{opacity:1;transform:translateZ(-20px) rotateX(-10deg)}to{opacity:1;transform:translateZ(-20px) rotateX(0)}}@-webkit-keyframes ah-rotate-2-out{0%{opacity:1;transform:translateZ(-20px) rotateX(0)}60%{opacity:0;transform:translateZ(-20px) rotateX(-100deg)}to{opacity:0;transform:translateZ(-20px) rotateX(-90deg)}}@keyframes ah-rotate-2-out{0%{opacity:1;transform:translateZ(-20px) rotateX(0)}60%{opacity:0;transform:translateZ(-20px) rotateX(-100deg)}to{opacity:0;transform:translateZ(-20px) rotateX(-90deg)}}
 .wp-block-kubio-heading__text .ah-headline.loading-bar .ah-words-wrapper:after{background:#356efd;bottom:0;content:"";height:3px;left:0;position:absolute;transition:width .3s -.1s;width:0;z-index:2}
 .wp-block-kubio-heading__text .ah-headline.loading-bar .ah-words-wrapper.is-loading:after{transition:width 3s;width:100%}
 .wp-block-kubio-heading__text .ah-headline.loading-bar b{opacity:0;top:.2em;transition:opacity .3s}
 .wp-block-kubio-heading__text .ah-headline.loading-bar b.is-visible{opacity:1;top:0}
 .wp-block-kubio-heading__text .ah-headline.slide b{opacity:0;top:.2em}
 .wp-block-kubio-heading__text .ah-headline.slide b.is-visible{-webkit-animation:slide-in .6s;animation:slide-in .6s;opacity:1;top:0}
 .wp-block-kubio-heading__text .ah-headline.slide b.is-hidden{-webkit-animation:slide-out .6s;animation:slide-out .6s}@-webkit-keyframes slide-in{0%{opacity:0;transform:translateY(-100%)}60%{opacity:1;transform:translateY(20%)}to{opacity:1;transform:translateY(0)}}@keyframes slide-in{0%{opacity:0;transform:translateY(-100%)}60%{opacity:1;transform:translateY(20%)}to{opacity:1;transform:translateY(0)}}@-webkit-keyframes slide-out{0%{opacity:1;transform:translateY(0)}60%{opacity:0;transform:translateY(120%)}to{opacity:0;transform:translateY(100%)}}@keyframes slide-out{0%{opacity:1;transform:translateY(0)}60%{opacity:0;transform:translateY(120%)}to{opacity:0;transform:translateY(100%)}}
 .wp-block-kubio-heading__text .ah-headline.clip .ah-words-wrapper:after{background-color:#363636;content:"";height:100%;position:absolute;right:0;top:0;width:2px}
 .wp-block-kubio-heading__text .ah-headline.clip b{opacity:0}
 .wp-block-kubio-heading__text .ah-headline.clip b.is-visible{opacity:1}
 .wp-block-kubio-heading__text .ah-headline.zoom .ah-words-wrapper{perspective:300px}
 .wp-block-kubio-heading__text .ah-headline.zoom b{opacity:0}
 .wp-block-kubio-heading__text .ah-headline.zoom b.is-visible{-webkit-animation:zoom-in .8s;animation:zoom-in .8s;opacity:1}
 .wp-block-kubio-heading__text .ah-headline.zoom b.is-hidden{-webkit-animation:zoom-out .8s;animation:zoom-out .8s}@-webkit-keyframes zoom-in{0%{opacity:0;transform:translateZ(100px)}to{opacity:1;transform:translateZ(0)}}@keyframes zoom-in{0%{opacity:0;transform:translateZ(100px)}to{opacity:1;transform:translateZ(0)}}@-webkit-keyframes zoom-out{0%{opacity:1;transform:translateZ(0)}to{opacity:0;transform:translateZ(-100px)}}@keyframes zoom-out{0%{opacity:1;transform:translateZ(0)}to{opacity:0;transform:translateZ(-100px)}}
 .wp-block-kubio-heading__text .ah-headline.rotate-3 .ah-words-wrapper{perspective:300px}
 .wp-block-kubio-heading__text .ah-headline.rotate-3 b{opacity:0}
 .wp-block-kubio-heading__text .ah-headline.rotate-3 i{-webkit-backface-visibility:hidden;backface-visibility:hidden;display:inline-block;transform:rotateY(180deg)}
 .wp-block-kubio-heading__text .is-visible .ah-headline.rotate-3 i{transform:rotateY(0)}
 .wp-block-kubio-heading__text .ah-headline.rotate-3 i.in{-webkit-animation:ah-rotate-3-in .6s forwards;animation:ah-rotate-3-in .6s forwards}
 .wp-block-kubio-heading__text .ah-headline.rotate-3 i.out{-webkit-animation:ah-rotate-3-out .6s forwards;animation:ah-rotate-3-out .6s forwards}
 .wp-block-kubio-heading__text .no-csstransitions .ah-headline.rotate-3 i{opacity:0;transform:rotateY(0)}
 .wp-block-kubio-heading__text .no-csstransitions .ah-headline.rotate-3 .is-visible i{opacity:1}@-webkit-keyframes ah-rotate-3-in{0%{transform:rotateY(180deg)}to{transform:rotateY(0)}}@keyframes ah-rotate-3-in{0%{transform:rotateY(180deg)}to{transform:rotateY(0)}}@-webkit-keyframes ah-rotate-3-out{0%{transform:rotateY(0)}to{transform:rotateY(-180deg)}}@keyframes ah-rotate-3-out{0%{transform:rotateY(0)}to{transform:rotateY(-180deg)}}
 .wp-block-kubio-heading__text .ah-headline.scale b{opacity:0}
 .wp-block-kubio-heading__text .ah-headline.scale i{display:inline-block;opacity:0;transform:scale(0)}
 .wp-block-kubio-heading__text .is-visible .ah-headline.scale i{opacity:1}
 .wp-block-kubio-heading__text .ah-headline.scale i.in{-webkit-animation:scale-up .6s forwards;animation:scale-up .6s forwards}
 .wp-block-kubio-heading__text .ah-headline.scale i.out{-webkit-animation:scale-down .6s forwards;animation:scale-down .6s forwards}
 .wp-block-kubio-heading__text .no-csstransitions .ah-headline.scale i{opacity:0;transform:scale(1)}
 .wp-block-kubio-heading__text .no-csstransitions .ah-headline.scale .is-visible i{opacity:1}@-webkit-keyframes scale-up{0%{opacity:0;transform:scale(0)}60%{opacity:1;transform:scale(1.2)}to{opacity:1;transform:scale(1)}}@keyframes scale-up{0%{opacity:0;transform:scale(0)}60%{opacity:1;transform:scale(1.2)}to{opacity:1;transform:scale(1)}}@-webkit-keyframes scale-down{0%{opacity:1;transform:scale(1)}60%{opacity:0;transform:scale(0)}}@keyframes scale-down{0%{opacity:1;transform:scale(1)}60%{opacity:0;transform:scale(0)}}
 .wp-block-kubio-heading__text .ah-headline.push b{opacity:0}
 .wp-block-kubio-heading__text .ah-headline.push b.is-visible{-webkit-animation:push-in .6s;animation:push-in .6s;opacity:1}
 .wp-block-kubio-heading__text .ah-headline.push b.is-hidden{-webkit-animation:push-out .6s;animation:push-out .6s}@-webkit-keyframes push-in{0%{opacity:0;transform:translateX(-100%)}60%{opacity:1;transform:translateX(10%)}to{opacity:1;transform:translateX(0)}}@keyframes push-in{0%{opacity:0;transform:translateX(-100%)}60%{opacity:1;transform:translateX(10%)}to{opacity:1;transform:translateX(0)}}@-webkit-keyframes push-out{0%{opacity:1;transform:translateX(0)}60%{opacity:0;transform:translateX(110%)}to{opacity:0;transform:translateX(100%)}}@keyframes push-out{0%{opacity:1;transform:translateX(0)}60%{opacity:0;transform:translateX(110%)}to{opacity:0;transform:translateX(100%)}}
 .wp-block-kubio-heading__text .fancy-title-headline .text-wrapper-fancy{overflow:visible;position:relative}
 .wp-block-kubio-heading__text .fancy-title-headline .text-animation-fancy{position:relative;z-index:1}
 .wp-block-kubio-heading__text .fancy-title-headline svg{height:calc(100% + 20px);left:50%;overflow:visible;position:absolute;top:50%;transform:translate(-50%,-50%);width:calc(100% + 20px)}
 .wp-block-kubio-heading__text .fancy-title-headline svg path{stroke:red;stroke-width:9;fill:none;stroke-dasharray:1500;stroke-dashoffset:1500;-webkit-animation:fancy-headline-dash 10s infinite;animation:fancy-headline-dash 10s infinite}
 .wp-block-kubio-heading__text .fancy-title-headline svg path:nth-of-type(2){-webkit-animation-delay:.6s;animation-delay:.6s}@-webkit-keyframes fancy-headline-dash{0%{stroke-dashoffset:1500}15%{stroke-dashoffset:0}85%{opacity:1}90%{stroke-dashoffset:0;opacity:0}to{stroke-dashoffset:1500;opacity:0}}@keyframes fancy-headline-dash{0%{stroke-dashoffset:1500}15%{stroke-dashoffset:0}85%{opacity:1}90%{stroke-dashoffset:0;opacity:0}to{stroke-dashoffset:1500;opacity:0}}
 .wp-block-kubio-heading__text [data-kubio-component=fancy-title]{display:inline-block}
 .wp-block-kubio-heading__text .ah-headline.clip span,
 .wp-block-kubio-heading__text .ah-headline.loading-bar span,
 .wp-block-kubio-heading__text .ah-headline.slide span{padding:0!important}
 .wp-block-kubio-heading__text .ah-headline.rotate-2 .ah-words-wrapper{perspective:unset!important}
 .wp-block-kubio-heading__text .bring-to-front+svg{z-index:2}
 .wp-block-kubio-heading__text .fancy-title-headline{display:inline-flex}@media (-ms-high-contrast:active),(-ms-high-contrast:none){
 .wp-block-kubio-heading__text .fancy-title-headline svg{display:none}}
 .wp-block-kubio-heading__text .ah-words-wrapper b,
 .wp-block-kubio-heading__text .ah-words-wrapper em,
 .wp-block-kubio-heading__text .ah-words-wrapper i{font-size:inherit!important;font-style:inherit;font-weight:inherit;text-decoration:inherit}
 .h-link,
 .wp-block-kubio-heading a{text-decoration:underline}
 a.d-block .wp-block-kubio-heading{margin-bottom:0}
 .wp-block-kubio-hero.wp-block,
 .wp-block-kubio-hero [data-kubio]:not([class*=h-col-]){max-width:unset!important}
 .wp-block-kubio-hero .kubio-sections-options-container{margin-top:var(--kubio-navigation-padding)}
 .wp-block-kubio-hero__inner{position:static!important}
 .h-down-arrow{bottom:0;left:0;position:absolute!important;width:100%}
 .h-scroll-to__outer{-webkit-animation-duration:2s;animation-duration:2s;-webkit-animation-iteration-count:infinite;animation-iteration-count:infinite;z-index:2}
 .h-scroll-to__outer>*{cursor:pointer}
 .move-down-bounce{-webkit-animation-name:move-down-bounce;animation-name:move-down-bounce}@-webkit-keyframes move-down-bounce{0%,20%,50%,80%,to{transform:translateY(0)}40%{transform:translateY(-20px)}60%{transform:translateY(-10px)}}@keyframes move-down-bounce{0%,20%,50%,80%,to{transform:translateY(0)}40%{transform:translateY(-20px)}60%{transform:translateY(-10px)}}
 .wp-block-kubio-home-button__outer{display:inline-flex;vertical-align:middle}
 .wp-block-kubio-home-button__link{align-items:center;cursor:pointer;display:inline-flex;word-break:break-word}
 .wp-block-kubio-home-button__inner{cursor:pointer;text-decoration:none}
 .wp-block-kubio-home-button__icon{flex-shrink:0}
 .wp-block-kubio-iconlist.wp-block{display:flex;flex-direction:column;flex-wrap:wrap;line-height:normal;list-style-type:none;margin-left:auto;margin-right:auto;padding:0;text-align:left}
 [data-kubio] .wp-block-kubio-iconlist.wp-block{margin-left:0;margin-right:0}
 .wp-block-kubio-iconlist .wp-block-kubio-iconlistitem__item{display:block;justify-content:inherit;max-width:100%;word-break:keep-all}
 .wp-block-kubio-iconlist .wp-block-kubio-iconlistitem__item .first-el-spacer{padding-bottom:0!important}
 .wp-block-kubio-iconlist .wp-block-kubio-iconlistitem__item .last-el-spacer{padding-top:0!important}
 .wp-block-kubio-iconlist .wp-block-kubio-iconlistitem__item:last-child .wp-block-kubio-iconlistitem__divider-wrapper:last-child{display:none}
 .wp-block-kubio-iconlist .wp-block-kubio-iconlistitem__item>a{display:inline-block;text-decoration:none}
 .wp-block-kubio-iconlist .wp-block-kubio-iconlistitem__text-wrapper{display:flex}
 .wp-block-kubio-iconlist .wp-block-kubio-iconlistitem__text{overflow:hidden}
 .wp-block-kubio-iconlist .wp-block-kubio-iconlistitem__icon{flex:0 0 auto;vertical-align:middle}
 .wp-block-kubio-iconlist .wp-block-kubio-iconlistitem__divider,
 .wp-block-kubio-iconlist .wp-block-kubio-iconlistitem__divider-wrapper{display:flex;justify-content:inherit}@media (min-width:1024px){
 .list-type-vertical-on-desktop .first-el-spacer,
 .list-type-vertical-on-desktop .last-el-spacer{display:none}
 .list-type-vertical-on-desktop .wp-block-kubio-iconlistitem__divider{border-left:none!important;height:auto!important}
 .list-type-vertical-on-desktop .wp-block-kubio-iconlistitem__divider-wrapper{height:auto!important;width:100%!important}}@media (min-width:768px) and (max-width:1023px){
 .list-type-vertical-on-tablet .first-el-spacer,
 .list-type-vertical-on-tablet .last-el-spacer{display:none}
 .list-type-vertical-on-tablet .wp-block-kubio-iconlistitem__divider{border-left:none!important;height:auto!important}
 .list-type-vertical-on-tablet .wp-block-kubio-iconlistitem__divider-wrapper{height:auto!important;width:100%!important}}@media (max-width:767px){
 .list-type-vertical-on-mobile .first-el-spacer,
 .list-type-vertical-on-mobile .last-el-spacer{display:none}
 .list-type-vertical-on-mobile .wp-block-kubio-iconlistitem__divider{border-left:none!important;height:auto!important}
 .list-type-vertical-on-mobile .wp-block-kubio-iconlistitem__divider-wrapper{height:auto!important;width:100%!important}}@media (min-width:1024px){
 .list-type-horizontal-on-desktop .first-el-spacer,
 .list-type-horizontal-on-desktop .last-el-spacer{display:none}
 .list-type-horizontal-on-desktop .wp-block-kubio-iconlistitem__item{display:flex}
 .list-type-horizontal-on-desktop .wp-block-kubio-iconlistitem__divider{border-bottom:none!important;width:auto!important}
 .list-type-horizontal-on-desktop .wp-block-kubio-iconlistitem__divider-wrapper{align-items:center;height:auto!important;width:auto!important}}@media (min-width:768px) and (max-width:1023px){
 .list-type-horizontal-on-tablet .first-el-spacer,
 .list-type-horizontal-on-tablet .last-el-spacer{display:none}
 .list-type-horizontal-on-tablet .wp-block-kubio-iconlistitem__item{display:flex}
 .list-type-horizontal-on-tablet .wp-block-kubio-iconlistitem__divider{border-bottom:none!important;width:auto!important}
 .list-type-horizontal-on-tablet .wp-block-kubio-iconlistitem__divider-wrapper{align-items:center;height:auto!important;width:auto!important}}@media (max-width:767px){
 .list-type-horizontal-on-mobile .first-el-spacer,
 .list-type-horizontal-on-mobile .last-el-spacer{display:none}
 .list-type-horizontal-on-mobile .wp-block-kubio-iconlistitem__item{display:flex}
 .list-type-horizontal-on-mobile .wp-block-kubio-iconlistitem__divider{border-bottom:none!important;width:auto!important}
 .list-type-horizontal-on-mobile .wp-block-kubio-iconlistitem__divider-wrapper{align-items:center;height:auto!important;width:auto!important}}
 .wp-block-kubio-icon a{display:block;line-height:1px}
 .wp-block-kubio-image-gallery__gallery{display:flex;flex-flow:wrap;max-width:100%}
 .wp-block-kubio-image-gallery_classic{align-items:flex-start;justify-items:center}
 .wp-block-kubio-image-gallery-item{display:block}
 .wp-block-kubio-image-gallery-item__image-overlay{bottom:0;display:block;left:0;position:absolute;right:0;top:0;z-index:99}
 .wp-block-kubio-image-gallery-item__image-caption-wrapper{position:relative}
 .wp-block-kubio-image-gallery .image-gallery-grid-item{text-align:center}
 .wp-block-kubio-image-gallery .image-gallery-grid-item a{display:block}
 .wp-block-kubio-image-gallery .image-gallery-grid-item img{display:block;width:100%}
 .wp-block-kubio-image-gallery figcaption{display:inline-block;line-height:1.6;overflow:hidden;text-overflow:ellipsis;white-space:normal;width:auto}
 .wp-block-kubio-image-gallery figure{margin:0}
 .wp-block-kubio-image-gallery_masonry .wp-block-kubio-image-gallery__item{-moz-column-break-inside:avoid;break-inside:avoid;display:inline-block;height:auto;margin-bottom:10px}
 .wp-block-kubio-image-gallery__image-overlay{bottom:0;display:block;left:0;position:absolute;right:0;top:0;z-index:99}
 .wp-block-kubio-image-gallery .hover-effect--blur figure:hover img{filter:blur(5px)}
 .wp-block-kubio-image-gallery .hover-effect--zoom figure{overflow:hidden}
 .wp-block-kubio-image-gallery .hover-effect--zoom img{transition:transform .5s ease}
 .wp-block-kubio-image-gallery .hover-effect--zoom figure:hover img{transform:scale(1.1)}
 .wp-block-kubio-image-gallery .hover-effect--fadeIn img{opacity:.7}
 .wp-block-kubio-image-gallery .hover-effect--fadeIn figure:hover img,
 .wp-block-kubio-image-gallery .hover-effect--fadeOut img{opacity:1}
 .wp-block-kubio-image-gallery .hover-effect--fadeOut figure:hover img{opacity:.7}
 .wp-block-kubio-image-gallery .hover-effect--glow figure:hover img{filter:brightness(1.3)}
 .wp-block-kubio-image-gallery .hover-effect--color img{filter:grayscale(100%)}
 .wp-block-kubio-image-gallery .hover-effect--color figure:hover img,
 .wp-block-kubio-image-gallery .hover-effect--grayscale img{filter:grayscale(0)}
 .wp-block-kubio-image-gallery .hover-effect--grayscale figure:hover img{filter:grayscale(100%)}
 .wp-block-kubio-image-gallery .hover-effect--addOverlay .wp-block-kubio-image-gallery-item__image-overlay{opacity:0;pointer-events:none}
 .wp-block-kubio-image-gallery .hover-effect--addOverlay figure:hover .wp-block-kubio-image-gallery-item__image-overlay{opacity:1}
 .wp-block-kubio-image-gallery .hover-effect--removeOverlay .wp-block-kubio-image-gallery-item__image-overlay{opacity:1;pointer-events:none}
 .wp-block-kubio-image-gallery .hover-effect--removeOverlay figure:hover .wp-block-kubio-image-gallery-item__image-overlay{opacity:0}
 .wp-block-kubio-image-gallery .caption-position{text-align:center}
 .wp-block-kubio-image-gallery .caption-position--over_on_hover figcaption,
 .wp-block-kubio-image-gallery .caption-position--over figcaption{left:0;position:absolute;right:0;top:50%;z-index:100}
 .wp-block-kubio-image-gallery .caption-position--below figcaption{bottom:0;display:block;position:relative}
 .wp-block-kubio-image-gallery .caption-position--over_on_hover figcaption{opacity:0;transition-property:opacity}
 .wp-block-kubio-image-gallery .caption-position--over_on_hover figure:hover figcaption{opacity:1}
 .wp-block-kubio-image-gallery .caption--start figcaption{bottom:auto;padding-top:inherit;top:0}
 .wp-block-kubio-image-gallery .caption--center:not(.caption-position--below) figcaption{top:50%;transform:translateY(-50%)}
 .wp-block-kubio-image-gallery .caption--end figcaption{bottom:0;padding-bottom:inherit;top:auto}
 .wp-block-kubio-image-gallery .components-placeholder{font:initial!important;font-style:normal;font-weight:400;letter-spacing:normal;text-decoration:none;text-transform:none}
 body.fancybox-active.compensate-for-scrollbar{margin-right:0!important}
 .wp-block-kubio-image{display:block;min-height:20px;vertical-align:middle;z-index:1}
 [data-kubio] .wp-block-kubio-image{display:inline-block;max-width:100%}
 .wp-block-kubio-image.wp-block.position-relative{line-height:0}
 .wp-block-kubio-image__outer{align-items:center;flex-direction:column;justify-content:center}
 [data-kubio] .wp-block-kubio-image__outer{margin:0;max-width:100%;width:100%}
 .wp-block-kubio-image__captionContainer{display:block}
 .wp-block-kubio-image__caption{line-height:1.6;width:100%;z-index:1}
 .wp-block-kubio-image__image{display:block;height:auto;max-height:100%;width:auto}
 .wp-block-kubio-image__frameContainer{display:inline-block;max-width:100%;position:relative;z-index:1}
 .wp-block-kubio-image__frameContainer img:before{background-color:transparent;content:" "!important;display:inline-block!important;font-size:300000px!important;height:100%!important;max-width:var(--kubio-image-width,100%);overflow:hidden;width:100%!important}
 .wp-block-kubio-image__frameContainer img[data-width]{width:var(--kubio-image-width,auto)}
 .wp-block-kubio-image__frameContainer .frame-type-background{border:inherit;border-color:transparent!important}
 .wp-block-kubio-image__overlay{bottom:0;left:0;overflow:hidden;pointer-events:none;position:absolute;right:0;top:0;z-index:1}
 .wp-block-kubio-image__frameImage{left:0;pointer-events:none;position:absolute;top:0;z-index:-1}
 .wp-block-kubio-image__frameImage.frame-image-shadow{box-shadow:0 2px 4px -1px rgba(0,0,0,.2),0 4px 5px 0 rgba(0,0,0,.14),0 1px 10px 0 rgba(0,0,0,.12)}
 .wp-block-kubio-image .components-placeholder{line-height:1.6!important;font:initial!important;font-style:normal;font-weight:400;letter-spacing:normal;text-decoration:none;text-transform:none}
 .wp-block-kubio-image .components-placeholder .components-placeholder__fieldset .components-button{padding:6px 12px}
 .image-link{display:contents;text-decoration:none}
 .wp-block-kubio-image img,
 [data-align=full]>.wp-block-kubio-image img,
 [data-align=wide]>.wp-block-kubio-image img{width:100%}
 .wp-block[data-align=left]>.wp-block-kubio-image{margin:.5em 1em .5em 0}
 .wp-block[data-align=right]>.wp-block-kubio-image{margin:.5em 0 .5em 1em}
 .wp-block[data-align=center]>.wp-block-kubio-image{margin-left:auto;margin-right:auto;text-align:center}
 .wp-block-kubio-image .aligncenter,
 .wp-block-kubio-image .alignleft,
 .wp-block-kubio-image .alignright,
 .wp-block-kubio-image.is-resized{display:table}
 .image-size-row-dropdown{flex-grow:1}
 .wp-block-kubio-linkgroup__outer{display:block;width:100%}
 [data-kubio] .wp-block-kubio-linkgroup__outer{display:inline-block}
 .wp-block-kubio-link__outer{display:inline-flex}
 .wp-block-kubio-link__link{align-items:center;border-color:transparent;cursor:pointer;display:inline-flex;justify-content:center}
 .wp-block-kubio-link__link svg{transform:translateY(1px)}
 .wp-block-kubio-link__inner{cursor:pointer;text-decoration:none}
 .wp-block-kubio-link__icon{flex-shrink:0}
 .h-navigation_sticky .kubio-logo-image,
 .kubio-alternate-logo-image{display:none}
 .h-navigation_sticky .kubio-alternate-logo-image,
 .normal-mode .kubio-logo-image{display:inline}
 .alternate-mode .kubio-logo-image,
 .normal-mode .kubio-alternate-logo-image{display:none}
 .alternate-mode .kubio-alternate-logo-image{display:inline}
 .wp-block-kubio-logo{align-items:center;display:flex;justify-content:center}
 .wp-block-kubio-logo.kubio-logo-direction-row{align-items:center!important;flex-direction:row}
 .wp-block-kubio-logo.kubio-logo-direction-row-reverse{align-items:center!important}
 .wp-block-kubio-logo.kubio-logo-direction-row-reverse span{order:1}
 .wp-block-kubio-logo.kubio-logo-direction-row-reverse img{order:2}
 .wp-block-kubio-logo.kubio-logo-direction-row.kubio-logo-without-text{gap:0!important}
 .wp-block-kubio-logo.kubio-logo-direction-column{flex-direction:column}
 .wp-block-kubio-logo.kubio-logo-direction-column-reverse{flex-direction:column-reverse}
 .wp-block-kubio-logo .kubio-logo-image,
 .wp-block-kubio-logo__alternateImage{max-height:70px}
 .wp-block-kubio-logo__container.show-logo-text:not(.show-logo-image){gap:0!important}
 .wp-block-kubio-logo.is-selected:after{height:calc(100% - 4px)!important;left:2px!important;top:2px!important;width:calc(100% - 4px)!important}
 .wp-block-kubio-map__wrapper{border-radius:inherit;height:100%;overflow:hidden;pointer-events:none;width:100%}
 .wp-block-kubio-map__wrapper.frontend-wrapper{pointer-events:all}
 .wp-block-kubio-map__iframe{border:none;height:100%;line-height:normal;margin:0;max-width:100%;width:100%}
 .kubio-menu ul{margin:0;padding:0}
 .kubio-menu ul,
 .kubio-menu ul li{list-style:none}
 .kubio-menu li{display:flex;text-align:initial}
 .kubio-menu a{align-items:center;color:inherit;display:flex;flex-grow:1;justify-content:space-between;white-space:break-spaces}
 .kubio-menu>ul>li{margin:unset}
 .kubio-menu ul li.current-menu-item>a,
 .kubio-menu ul li:hover>a,
 .kubio-menu ul li>a{color:inherit}
 .kubio-menu .is-selected svg.kubio-menu-item-icon{transform:rotate(0deg)}
 .kubio-menu svg.kubio-menu-item-icon{box-sizing:content-box;height:1em;min-height:1em;min-width:1em;width:1em}
 .kubio-menu svg.kubio-menu-item-icon path{fill:currentColor}
 .kubio-dropdown-menu svg.kubio-menu-item-icon{margin-right:0!important;padding-right:0!important}
 .mobile-menu-button{margin-top:10px}
 .kubio-dropdown-menu{display:flex;flex-grow:1}
 .kubio-dropdown-menu .wp-block-kubio-mobile-menu-icon{display:none}
 .kubio-dropdown-menu .kubio-menu{display:flex;width:100%}
 .kubio-dropdown-menu .kubio-menu li{align-items:center;display:flex}
 .kubio-dropdown-menu .kubio-menu li ul.open-reverse:not(#extra-1){left:auto;right:100%}
 .kubio-dropdown-menu .kubio-menu ul,
 .kubio-dropdown-menu .kubio-menu ul:not(.h-select-control__menu) li{margin:0;padding:0;position:relative}
 .kubio-dropdown-menu .kubio-menu>ul{align-items:center;display:flex;flex-grow:1;flex-wrap:wrap}
 .kubio-dropdown-menu .kubio-menu>ul:after,
 .kubio-dropdown-menu .kubio-menu>ul:before{display:none}
 .kubio-dropdown-menu .kubio-menu>ul>li>ul{margin-left:0!important}
 .kubio-dropdown-menu .kubio-menu>ul>li>ul:before{bottom:100%;content:"";display:block;position:absolute;width:100%}
 .kubio-dropdown-menu .kubio-menu>ul>li>ul li.menu-item-has-children:hover:after,
 .kubio-dropdown-menu .kubio-menu>ul>li>ul li.menu-item-has-children:hover:before{content:"";height:100%;position:absolute;top:0;width:50px;z-index:-1}
 .kubio-dropdown-menu .kubio-menu>ul>li>ul li.menu-item-has-children:hover:after{left:100%;right:auto}
 .kubio-dropdown-menu .kubio-menu>ul>li>ul li.menu-item-has-children:hover:before{left:auto;right:100%}
 .kubio-dropdown-menu .kubio-menu li>ul{left:0;min-width:200px;opacity:0;position:absolute;top:-100000px;transition:opacity .1s linear;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;z-index:2}
 .kubio-dropdown-menu .kubio-menu li>ul:empty{display:none}
 .kubio-dropdown-menu .kubio-menu li>ul .kubio-menu-item-icon{transform:rotate(-90deg)}
 .kubio-dropdown-menu .kubio-menu li>ul>li:last-of-type{border-bottom:none!important}
 .kubio-dropdown-menu .kubio-menu li.hover,
 .kubio-dropdown-menu .kubio-menu li.open,
 .kubio-dropdown-menu .kubio-menu li:hover{z-index:30}
 .kubio-dropdown-menu .kubio-menu li.hover>ul,
 .kubio-dropdown-menu .kubio-menu li.open>ul,
 .kubio-dropdown-menu .kubio-menu li:hover>ul{opacity:1;top:100%}
 .kubio-dropdown-menu .kubio-menu li>ul ul.reverse-directon{left:-100%}
 .kubio-dropdown-menu .kubio-menu>ul>li li.hover,
 .kubio-dropdown-menu .kubio-menu>ul>li li.open,
 .kubio-dropdown-menu .kubio-menu>ul>li li:hover{z-index:30}
 .kubio-dropdown-menu .kubio-menu>ul>li li.hover>ul,
 .kubio-dropdown-menu .kubio-menu>ul>li li.open>ul,
 .kubio-dropdown-menu .kubio-menu>ul>li li:hover>ul{left:100%;opacity:1;top:0}
 .kubio-dropdown-menu .h-block-placeholder{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;font-style:normal;font-weight:400;letter-spacing:normal;text-decoration:none;text-transform:none}
 .kubio-dropdown-menu .kubio-offscreen-icon-wrapper{border:none;display:none;line-height:1;margin:0;padding:0}
 .kubio-dropdown-menu .kubio-offscreen-icon-wrapper,
 .kubio-dropdown-menu .kubio-offscreen-icon-wrapper:focus,
 .kubio-dropdown-menu .kubio-offscreen-icon-wrapper:hover{background:none}
 .kubio-dropdown-menu .wp-block-kubio-menu-offscreen{display:none}@media (max-width:767px){
 .kubio-dropdown-menu.has-offcanvas-mobile .kubio-menu{display:none}
 .kubio-dropdown-menu.has-offcanvas-mobile .kubio-offscreen-icon-wrapper{display:inline-block}
 .kubio-dropdown-menu.has-offcanvas-mobile .wp-block-kubio-menu-offscreen{display:block}}@media (max-width:1023px){
 .kubio-dropdown-menu.has-offcanvas-tablet .kubio-menu{display:none}
 .kubio-dropdown-menu.has-offcanvas-tablet .kubio-offscreen-icon-wrapper{display:inline-block}
 .kubio-dropdown-menu.has-offcanvas-tablet .wp-block-kubio-menu-offscreen{display:block}}
 .kubio-dropdown-menu.has-offcanvas-desktop .kubio-menu{display:none}
 .kubio-dropdown-menu.has-offcanvas-desktop .kubio-offscreen-icon-wrapper{display:inline-block}
 .kubio-dropdown-menu.has-offcanvas-desktop .wp-block-kubio-menu-offscreen{display:block}
 .kubio-dropdown-menu.bordered-active-item .kubio-menu>ul>li{position:relative}
 .kubio-dropdown-menu.bordered-active-item .kubio-menu>ul>li:after,
 .kubio-dropdown-menu.bordered-active-item .kubio-menu>ul>li:before{content:" ";display:block;height:2px;left:0;opacity:0;position:absolute;width:100%;z-index:0}
 .kubio-dropdown-menu.bordered-active-item .kubio-menu>ul>li:before{top:0}
 .kubio-dropdown-menu.bordered-active-item .kubio-menu>ul>li:after{bottom:0}
 .kubio-dropdown-menu.bordered-active-item.effect-borders-in .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after,
 .kubio-dropdown-menu.bordered-active-item.effect-borders-in .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{opacity:0;transition:all .3s}
 .kubio-dropdown-menu.bordered-active-item.effect-borders-in .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{margin-top:-10px}
 .kubio-dropdown-menu.bordered-active-item.effect-borders-in .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after{margin-bottom:-10px}
 .kubio-dropdown-menu.bordered-active-item.effect-borders-in .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:after,
 .kubio-dropdown-menu.bordered-active-item.effect-borders-in .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:before,
 .kubio-dropdown-menu.bordered-active-item.effect-borders-in .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:after,
 .kubio-dropdown-menu.bordered-active-item.effect-borders-in .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:before{margin-bottom:0;margin-top:0;opacity:1}
 .kubio-dropdown-menu.bordered-active-item.effect-borders-out .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after,
 .kubio-dropdown-menu.bordered-active-item.effect-borders-out .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{opacity:0;transition:all .3s}
 .kubio-dropdown-menu.bordered-active-item.effect-borders-out .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{margin-top:10px}
 .kubio-dropdown-menu.bordered-active-item.effect-borders-out .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after{margin-bottom:10px}
 .kubio-dropdown-menu.bordered-active-item.effect-borders-out .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:after,
 .kubio-dropdown-menu.bordered-active-item.effect-borders-out .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:before,
 .kubio-dropdown-menu.bordered-active-item.effect-borders-out .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:after,
 .kubio-dropdown-menu.bordered-active-item.effect-borders-out .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:before{margin-bottom:0;margin-top:0;opacity:1}
 .kubio-dropdown-menu.bordered-active-item.effect-borders-grow .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after,
 .kubio-dropdown-menu.bordered-active-item.effect-borders-grow .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{content:"";opacity:0;transition:all .3s;width:0}
 .kubio-dropdown-menu.bordered-active-item.effect-borders-grow .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{left:0;right:auto}
 .kubio-dropdown-menu.bordered-active-item.effect-borders-grow .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after{left:auto;right:0}
 .kubio-dropdown-menu.bordered-active-item.effect-borders-grow .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:after,
 .kubio-dropdown-menu.bordered-active-item.effect-borders-grow .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:before,
 .kubio-dropdown-menu.bordered-active-item.effect-borders-grow .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:after,
 .kubio-dropdown-menu.bordered-active-item.effect-borders-grow .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:before{opacity:1;width:100%}
 .kubio-dropdown-menu.bordered-active-item.effect-none .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after,
 .kubio-dropdown-menu.bordered-active-item.effect-none .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{opacity:0;transition:none}
 .kubio-dropdown-menu.bordered-active-item.effect-none .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item) .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:after,
 .kubio-dropdown-menu.bordered-active-item.effect-none .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item) .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:before,
 .kubio-dropdown-menu.bordered-active-item.effect-none .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item) .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:after,
 .kubio-dropdown-menu.bordered-active-item.effect-none .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item) .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:before{opacity:1}
 .kubio-dropdown-menu.bordered-active-item.grow-from-left .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after,
 .kubio-dropdown-menu.bordered-active-item.grow-from-left .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{left:0!important;right:auto!important}
 .kubio-dropdown-menu.bordered-active-item.grow-from-right .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after,
 .kubio-dropdown-menu.bordered-active-item.grow-from-right .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{left:auto!important;right:0!important}
 .kubio-dropdown-menu.bordered-active-item.grow-from-center .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after,
 .kubio-dropdown-menu.bordered-active-item.grow-from-center .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{left:50%!important;right:auto!important}
 .kubio-dropdown-menu.bordered-active-item.grow-from-center .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:after,
 .kubio-dropdown-menu.bordered-active-item.grow-from-center .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:before,
 .kubio-dropdown-menu.bordered-active-item.grow-from-center .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:after,
 .kubio-dropdown-menu.bordered-active-item.grow-from-center .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:before{left:0!important;right:auto!important}
 .kubio-dropdown-menu.bordered-active-item.bordered-active-item--top .kubio-menu>ul>li:after{visibility:hidden}
 .kubio-dropdown-menu.bordered-active-item.bordered-active-item--top .kubio-menu>ul>li.current-menu-item:after,
 .kubio-dropdown-menu.bordered-active-item.bordered-active-item--top .kubio-menu>ul>li.current-menu-item:before,
 .kubio-dropdown-menu.bordered-active-item.bordered-active-item--top .kubio-menu>ul>li.current_page_item:after,
 .kubio-dropdown-menu.bordered-active-item.bordered-active-item--top .kubio-menu>ul>li.current_page_item:before{opacity:1}
 .kubio-dropdown-menu.bordered-active-item.bordered-active-item--bottom .kubio-menu>ul>li:before{visibility:hidden}
 .kubio-dropdown-menu.bordered-active-item.bordered-active-item--bottom .kubio-menu>ul>li.current-menu-item:after,
 .kubio-dropdown-menu.bordered-active-item.bordered-active-item--bottom .kubio-menu>ul>li.current-menu-item:before,
 .kubio-dropdown-menu.bordered-active-item.bordered-active-item--bottom .kubio-menu>ul>li.current_page_item:after,
 .kubio-dropdown-menu.bordered-active-item.bordered-active-item--bottom .kubio-menu>ul>li.current_page_item:before,
 .kubio-dropdown-menu.bordered-active-item.bordered-active-item--top-and-bottom .kubio-menu>ul>li.current-menu-item:after,
 .kubio-dropdown-menu.bordered-active-item.bordered-active-item--top-and-bottom .kubio-menu>ul>li.current-menu-item:before,
 .kubio-dropdown-menu.bordered-active-item.bordered-active-item--top-and-bottom .kubio-menu>ul>li.current_page_item:after,
 .kubio-dropdown-menu.bordered-active-item.bordered-active-item--top-and-bottom .kubio-menu>ul>li.current_page_item:before{opacity:1}
 .kubio-dropdown-menu.solid-active-item .kubio-menu>ul>li>.kubio-menu-item-link,
 .kubio-dropdown-menu.solid-active-item .kubio-menu>ul>li>a{color:#fff;transition:all .2s;z-index:1}
 .kubio-dropdown-menu.solid-active-item .kubio-menu>ul>li{position:relative}
 .kubio-dropdown-menu.solid-active-item .kubio-menu>ul>li:after,
 .kubio-dropdown-menu.solid-active-item .kubio-menu>ul>li:before{content:" ";display:block;height:100%;left:0;opacity:0;position:absolute;transition:all .2s;width:100%;z-index:0}
 .kubio-dropdown-menu.solid-active-item .kubio-menu>ul>li:before{top:0}
 .kubio-dropdown-menu.solid-active-item .kubio-menu>ul>li:after{bottom:0}
 .kubio-dropdown-menu.solid-active-item.effect-pull-down .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{height:0;opacity:1!important;transition:all .3s}
 .kubio-dropdown-menu.solid-active-item.effect-pull-down .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after{opacity:0!important;transition:none;visibility:hidden}
 .kubio-dropdown-menu.solid-active-item.effect-pull-down .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:before,
 .kubio-dropdown-menu.solid-active-item.effect-pull-down .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:before{height:100%}
 .kubio-dropdown-menu.solid-active-item.effect-pull-down .kubio-menu>ul>li.current-menu-item:before,
 .kubio-dropdown-menu.solid-active-item.effect-pull-down .kubio-menu>ul>li.current_page_item:before{opacity:1!important}
 .kubio-dropdown-menu.solid-active-item.effect-pull-down .kubio-menu>ul>li.current-menu-item:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-down .kubio-menu>ul>li.current_page_item:after{visibility:hidden}
 .kubio-dropdown-menu.solid-active-item.effect-pull-up .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after{height:0;opacity:1!important;transition:all .3s}
 .kubio-dropdown-menu.solid-active-item.effect-pull-up .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{opacity:0!important;transition:none;visibility:hidden}
 .kubio-dropdown-menu.solid-active-item.effect-pull-up .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-up .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:after{height:100%}
 .kubio-dropdown-menu.solid-active-item.effect-pull-up .kubio-menu>ul>li.current-menu-item:before,
 .kubio-dropdown-menu.solid-active-item.effect-pull-up .kubio-menu>ul>li.current_page_item:before{visibility:hidden}
 .kubio-dropdown-menu.solid-active-item.effect-pull-up .kubio-menu>ul>li.current-menu-item:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-up .kubio-menu>ul>li.current_page_item:after{opacity:1!important}
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{height:0;opacity:1!important;transition:all .4s}
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:before,
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:before{height:100%}
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down .kubio-menu>ul>li.current-menu-item:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down .kubio-menu>ul>li.current-menu-item:before,
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down .kubio-menu>ul>li.current_page_item:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down .kubio-menu>ul>li.current_page_item:before{opacity:1!important}
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down-reverse .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{height:0%;opacity:1!important;top:50%;transition:all .3s;width:100%}
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down-reverse .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after{opacity:0!important;transition:none;visibility:hidden}
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down-reverse .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:before,
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down-reverse .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:before{height:100%;top:0}
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down-reverse .kubio-menu>ul>li.current-menu-item:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down-reverse .kubio-menu>ul>li.current-menu-item:before,
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down-reverse .kubio-menu>ul>li.current_page_item:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-up-down-reverse .kubio-menu>ul>li.current_page_item:before{opacity:1!important}
 .kubio-dropdown-menu.solid-active-item.effect-pull-right .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after{opacity:1!important;transform:scaleX(0);transform-origin:100% 50%;transition:all .3s}
 .kubio-dropdown-menu.solid-active-item.effect-pull-right .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{opacity:0!important;transition:none;visibility:hidden}
 .kubio-dropdown-menu.solid-active-item.effect-pull-right .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-right .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:after{transform:scaleX(1)}
 .kubio-dropdown-menu.solid-active-item.effect-pull-right .kubio-menu>ul>li.current-menu-item:before,
 .kubio-dropdown-menu.solid-active-item.effect-pull-right .kubio-menu>ul>li.current_page_item:before{visibility:hidden}
 .kubio-dropdown-menu.solid-active-item.effect-pull-right .kubio-menu>ul>li.current-menu-item:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-right .kubio-menu>ul>li.current_page_item:after{opacity:1!important}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after{opacity:1!important;transform:scaleX(0);transform-origin:0 50%;transition:all .3s}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{opacity:0!important;transition:none;visibility:hidden}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-left .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:after{transform:scaleX(1)}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left .kubio-menu>ul>li.current-menu-item:before,
 .kubio-dropdown-menu.solid-active-item.effect-pull-left .kubio-menu>ul>li.current_page_item:before{visibility:hidden}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left .kubio-menu>ul>li.current-menu-item:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-left .kubio-menu>ul>li.current_page_item:after{opacity:1!important}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after{border-bottom-left-radius:0;border-top-left-radius:0;height:100%;left:auto;opacity:1!important;right:0;transition:all .3s;width:0}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{border-bottom-right-radius:0;border-top-right-radius:0;height:100%;left:0;opacity:1!important;right:auto;transition:all .3s;width:0}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:before,
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:before{border:inherit;width:100%}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right .kubio-menu>ul>li.current-menu-item:before,
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right .kubio-menu>ul>li.current_page_item:before{opacity:1!important}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right .kubio-menu>ul>li.current-menu-item:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right .kubio-menu>ul>li.current_page_item:after{visibility:hidden}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right-reverse .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{height:100%;left:50%;opacity:1!important;transition:all .3s;width:0}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right-reverse .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after{opacity:0!important;transition:none;visibility:hidden}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right-reverse .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right-reverse .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:before,
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right-reverse .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right-reverse .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:before{left:0;width:100%}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right-reverse .kubio-menu>ul>li.current-menu-item:before,
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right-reverse .kubio-menu>ul>li.current_page_item:before{opacity:1!important}
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right-reverse .kubio-menu>ul>li.current-menu-item:after,
 .kubio-dropdown-menu.solid-active-item.effect-pull-left-right-reverse .kubio-menu>ul>li.current_page_item:after{visibility:hidden}
 .kubio-dropdown-menu.solid-active-item.effect-none .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):before{height:100%;left:50%;opacity:1!important;transition:none;width:0}
 .kubio-dropdown-menu.solid-active-item.effect-none .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):after{opacity:0!important;transition:none;visibility:hidden}
 .kubio-dropdown-menu.solid-active-item.effect-none .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:after,
 .kubio-dropdown-menu.solid-active-item.effect-none .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item).hover:before,
 .kubio-dropdown-menu.solid-active-item.effect-none .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:after,
 .kubio-dropdown-menu.solid-active-item.effect-none .kubio-menu>ul>li:not(.current_page_item):not(.current-menu-item):hover:before{left:0;width:100%}
 .kubio-dropdown-menu.solid-active-item.effect-none .kubio-menu>ul>li.current-menu-item:before,
 .kubio-dropdown-menu.solid-active-item.effect-none .kubio-menu>ul>li.current_page_item:before{opacity:1!important}
 .kubio-dropdown-menu.solid-active-item.effect-none .kubio-menu>ul>li.current-menu-item:after,
 .kubio-dropdown-menu.solid-active-item.effect-none .kubio-menu>ul>li.current_page_item:after{visibility:hidden}
html[lang] .wp-block-kubio-dropdown-menu>.kubio-menu>.menu>.menu-item>a>br{display:none!important}
 .kubio-accordion-menu li{flex-direction:column}
 .kubio-accordion-menu li:last-of-type{border-bottom:none!important}
 .kubio-accordion-menu li>ul{display:none}
 .kubio-accordion-menu li>.kubio-menu-item-link>svg.kubio-menu-item-icon,
 .kubio-accordion-menu li>a>svg.kubio-menu-item-icon{color:inherit!important}
 .kubio-accordion-menu li.open>ul{display:block}
 .kubio-accordion-menu li.open>.kubio-menu-item-link svg.kubio-menu-item-icon,
 .kubio-accordion-menu li.open>a svg.kubio-menu-item-icon{transform:rotate(180deg)}
 .kubio-accordion-menu li svg.kubio-menu-item-icon:focus{outline:auto}
 .kubio-accordion-menu li ul>li>a{justify-content:flex-start}
 .kubio-accordion-menu li ul>li>a>span{flex-grow:1}
 .kubio-accordion-menu li ul>li>a:before{content:" ";display:block;flex-grow:0;flex-shrink:0;height:3px;min-width:calc(var(--kubio-accordion-menu-offset, 0)*var(--kubio-menu-item-depth, 0));order:0;position:static;width:calc(var(--kubio-accordion-menu-offset, 0)*var(--kubio-menu-item-depth, 0))}
 .kubio-accordion-menu .h-block-placeholder{font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;font-style:normal;font-weight:400;letter-spacing:normal;text-decoration:none;text-transform:none}
 .wp-block-kubio-menu-offscreen__container{width:100%}
 .wp-block-kubio-menu-offscreen__inner{height:100%}
 .wp-block-kubio-menu-offscreen__iconWrapper:focus:focus-visible{outline:auto}
 .kubio-offscreen{-webkit-animation-duration:.25s;animation-duration:.25s;height:100%;margin:0;min-height:100%;overflow:hidden auto;position:fixed;right:0;top:0;width:300px;z-index:2000001}
 .kubio-offscreen-overlay{bottom:0;cursor:pointer;display:block;left:0;opacity:0;position:fixed;right:0;top:0;transition:opacity .25s linear;visibility:hidden;z-index:-1000}
 .h-offcanvas-opened{display:block;opacity:1;visibility:visible;z-index:20000}
 .wp-block-kubio-menu-offscreen-content{display:flex;flex-direction:column;height:100%}
 .wp-block-kubio-menu-offscreen-content>.wp-block-kubio-row{flex-basis:unset;flex-grow:0}
 .wp-block-kubio-menu-offscreen-content>.wp-block-kubio-accordion-menu{display:flex;flex-grow:1;width:100%}
 .wp-block-kubio-menu-offscreen-content>.wp-block-kubio-accordion-menu .wp-block-kubio-menu-items{width:100%}
 .wp-block-kubio-navigation-section{-webkit-backface-visibility:hidden;backface-visibility:hidden;position:relative;transition:all .5s;z-index:20}
 .wp-block-kubio-navigation{padding-left:inherit;padding-right:inherit}
 .wp-block-kubio-navigation.wp-block,
 .wp-block-kubio-navigation [data-kubio]:not([class*=h-col-]){max-width:unset!important}
 .wp-block-kubio-navigation.h-navigation_overlap{left:0;position:absolute!important;right:0;z-index:10001}
 .wp-block-kubio-navigation [data-nav-normal]{transition:all .5s}
 .wp-block-kubio-navigation .h-hide-normal{display:none}
 .wp-block-kubio-navigation .h-navigation_sticky .wp-block-kubio-row__inner{display:grid;grid-template-columns:auto auto;justify-content:space-between!important}
 .wp-block-kubio-navigation .h-navigation_sticky .wp-block-kubio-row__inner:has(>:nth-child(3)){display:flex}
 .wp-block-kubio-navigation .h-navigation_sticky .h-hide-normal{display:flex}
 .wp-block-kubio-navigation .h-navigation_sticky .h-hide-sticky{display:none}
 .wp-block-kubio-navigation__outer{position:relative}
 .wp-block-kubio-navigation_container-in-sticky{z-index:9999}@-webkit-keyframes slideOutDownNavigation{0%{transform:translateZ(0)}to{transform:translate3d(0,-100%,0);visibility:hidden}}@keyframes slideOutDownNavigation{0%{transform:translateZ(0)}to{transform:translate3d(0,-100%,0);visibility:hidden}}
 .slideOutDownNavigation{-webkit-animation-name:slideOutDownNavigation;animation-name:slideOutDownNavigation}
 .fade-animation-without-other-transitions{transition-property:opacity!important}
 .wp-block-kubio-page-title{word-break:break-word}
 .wp-block-kubio-page-title .components-select-control__input{line-height:unset!important}
 .wp-block-kubio-page-title .kubio-alternate-logo-image{display:none}
 .wp-block-kubio-pagination-numbers .page-numbers{display:inline-block}
 .wp-block-kubio-post-author-name a{width:100%}
 .wp-block-kubio-post-author-name p{margin-bottom:0;margin-top:0;width:100%}
 .comment-respond{text-align:initial}
 .comment-respond label{display:block}
 .comment-respond .comment-reply-title{text-align:left}
 .comment-respond input,
 .comment-respond textarea{max-width:100%}
 .comment-respond p{text-align:left}
 .comment-respond textarea{min-height:200px;resize:vertical;width:100%}
 .comment-respond input[type=checkbox]+label{display:inline}
 .comment-respond input[type=submit]{-webkit-appearance:none;-moz-appearance:none;appearance:none;cursor:pointer;display:inline}
 .comment-respond .form-submit{display:block}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments{padding:10px;text-align:left}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-meta{display:flex;flex-direction:column;word-break:break-word}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-meta>.comment-author.vcard{align-items:center;display:flex;margin-top:12px}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-meta>.comment-author.vcard>.fn{height:100%;margin-left:5px;margin-right:5px}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-meta>.comment-author.vcard>b{font-weight:400}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-meta>.comment-author.vcard>.says{height:21px}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-metadata *{color:inherit;font-family:inherit;font-weight:inherit}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-author img{box-sizing:initial}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-author cite a{color:inherit;font:inherit;line-height:inherit}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-author .url{display:inline-block}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-body .reply a{display:block}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-body .comment-content *{color:inherit;font-family:inherit;font-size:inherit;font-weight:inherit;line-height:inherit}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-body ol,
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-body ul{margin:auto 1.5em 1em}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-body ol ol,
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-body ol ul,
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-body ul ol,
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-body ul ul{margin:0 0 0 1.5em}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-list{padding:revert}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-list,
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-list .children{list-style-type:none}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comments-disabled{margin-bottom:0;text-align:center}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-respond{padding-left:1em}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-respond .comment-reply-title{font-size:1.0625em;font-weight:400;margin-bottom:0}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-respond .comment-reply-title>small{font-size:inherit;margin-left:.5em}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-respond .logged-in-as,
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-respond p.comment-notes{margin-top:.2em}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .post-comments .comment-respond p.comment-notes{font-size:80%}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .blog-post-comments-not-allow{background-color:rgba(3,169,244,.05);border:1px solid rgba(3,169,244,.1);border-radius:3px;padding-bottom:20px;padding-top:20px;text-align:center}
 .wp-block-kubio-post-comments:not([class*=kubio-migration--]) .blog-post-comments-not-allow .blog-comments-not-allow-message{font-size:16px;font-weight:800}
 .wp-block-kubio-post-comments.kubio-migration--1{text-align:left}
 .wp-block-kubio-post-comments.kubio-migration--1 .comment>.children{padding-left:0}
 .wp-block-kubio-post-comments.kubio-migration--1 .comment pre{white-space:pre-wrap}
 .wp-block-kubio-post-comments.kubio-migration--1 .comment-content{clear:both}
 .wp-block-kubio-post-comments.kubio-migration--1 .comment-author{align-items:flex-start;display:flex}
 .wp-block-kubio-post-comments.kubio-migration--1 .comment-author .avatar{display:block}
 .wp-block-kubio-post-comments.kubio-migration--1 .comment-list{margin:0;padding:0}
 .wp-block-kubio-post-comments.kubio-migration--1 .comment-list,
 .wp-block-kubio-post-comments.kubio-migration--1 .comment-list .children{list-style-type:none}
 .wp-block-kubio-post-comments.kubio-migration--1 .comments-disabled{margin-bottom:0;text-align:center}
 .wp-block-kubio-post-comments.kubio-migration--1 .comment-respond{padding-left:1em}
 .wp-block-kubio-post-comments.kubio-migration--1 .comment-respond .comment-reply-title{font-size:1.0625em;font-weight:400;margin-bottom:0}
 .wp-block-kubio-post-comments.kubio-migration--1 .comment-respond .comment-reply-title>small{font-size:inherit;margin-left:.5em}
 .wp-block-kubio-post-comments.kubio-migration--1 .comment-respond .logged-in-as,
 .wp-block-kubio-post-comments.kubio-migration--1 .comment-respond p.comment-notes{margin-top:.2em}
 .wp-block-kubio-post-comments.kubio-migration--1 .comment-respond p.comment-notes{font-size:80%}
 .wp-block-kubio-post-comments.kubio-migration--1 .blog-post-comments-not-allow{background-color:rgba(3,169,244,.05);border:1px solid rgba(3,169,244,.1);border-radius:3px;padding-bottom:20px;padding-top:20px;text-align:center}
 .wp-block-kubio-post-comments.kubio-migration--1 .blog-post-comments-not-allow .blog-comments-not-allow-message{font-size:16px;font-weight:800}
 .entry-content:not(.wc-tab)>*{margin:clamp(1rem,.5em,2.5rem) auto clamp(1rem,.25em,2rem)}
 .entry-content:not(.wc-tab)>:first-child{margin-top:0}
 .entry-content:not(.wc-tab)>:last-child{margin-bottom:0}
 .entry-content:not(.wc-tab)>.wp-block-kubio-section{margin:0;max-width:unset}
 .entry-content:not(.wc-tab)>*{max-width:840px}
 .entry-content:not(.wc-tab) .alignwide{margin-left:auto;margin-right:auto;max-width:1200px;width:100%}@media (max-width:767px){
 .entry-content:not(.wc-tab) .alignwide{max-width:100%;width:100%}}@media (min-width:768px) and (max-width:1023px){
 .entry-content:not(.wc-tab) .alignwide{max-width:100%;width:100%}}
 .wp-block-kubio-section .entry-content:not(.wc-tab)>*{margin:clamp(1rem,.5em,2.5rem) auto clamp(1rem,.25em,2rem)}
 .wp-block-kubio-section .entry-content:not(.wc-tab)>:first-child{margin-top:0}
 .wp-block-kubio-section .entry-content:not(.wc-tab)>:last-child{margin-bottom:0}
 .wp-block-kubio-section .entry-content:not(.wc-tab)>.wp-block-kubio-section{margin:0;max-width:unset}
 .wp-block-kubio-section .entry-content:not(.wc-tab)>*{max-width:840px}
 .wp-block-kubio-section .entry-content:not(.wc-tab) .alignwide{margin-left:auto;margin-right:auto;max-width:1200px;width:100%}@media (max-width:767px){
 .wp-block-kubio-section .entry-content:not(.wc-tab) .alignwide{max-width:100%;width:100%}}@media (min-width:768px) and (max-width:1023px){
 .wp-block-kubio-section .entry-content:not(.wc-tab) .alignwide{max-width:100%;width:100%}}
 .wp-site-blocks:has(.wp-block-kubio-header) .wp-block-post-content{-webkit-margin-before:0;-webkit-margin-after:0;margin-block-end:0;margin-block-start:0}
 .wp-block-kubio-post-featured-image{margin:0}
 .wp-block-kubio-post-featured-image>img{border-radius:inherit;display:block;height:100%;width:100%}
 .wp-block-kubio-post-featured-image .block-list-appender{width:100%}
 .wp-block-kubio-post-featured-image:not(.kubio-post-featured-image--natural-size).h-aspect-ratio--1-1,
 .wp-block-kubio-post-featured-image:not(.kubio-post-featured-image--natural-size).h-aspect-ratio--4-3,
 .wp-block-kubio-post-featured-image:not(.kubio-post-featured-image--natural-size).h-aspect-ratio--16-9{height:0!important}
 .wp-block-kubio-post-featured-image:not(.kubio-post-featured-image--natural-size).h-aspect-ratio--1-1>img,
 .wp-block-kubio-post-featured-image:not(.kubio-post-featured-image--natural-size).h-aspect-ratio--4-3>img,
 .wp-block-kubio-post-featured-image:not(.kubio-post-featured-image--natural-size).h-aspect-ratio--16-9>img{bottom:0;left:0;position:absolute;right:0;top:0}
 .wp-block-kubio-post-featured-image:not(.kubio-post-featured-image--natural-size).h-aspect-ratio--16-9{padding:56.25% 0 0!important}
 .wp-block-kubio-post-featured-image:not(.kubio-post-featured-image--natural-size).h-aspect-ratio--4-3{padding:75% 0 0!important}
 .wp-block-kubio-post-featured-image:not(.kubio-post-featured-image--natural-size).h-aspect-ratio--1-1{padding:100% 0 0!important}
 .wp-block-kubio-post-featured-image.kubio-post-featured-image--has-image.kubio-post-featured-image--image-missing{display:none}
 .wp-block-kubio-post-featured-image.kubio-post-featured-image--natural-size.kubio-post-featured-image--has-image{height:auto!important}
 .wp-block-kubio-post-featured-image.kubio-post-featured-image--natural-size.kubio-post-featured-image--has-image>img{height:auto;-o-object-position:center center!important;object-position:center center!important}
 .wp-block-kubio-post-featured-image__inner{bottom:0;display:flex;flex:1 0 auto;height:100%;left:0;pointer-events:none;position:absolute;right:0;top:0;width:100%}
 .wp-block-kubio-post-featured-image__inner *{pointer-events:all;z-index:1}
 .wp-block-kubio-post-featured-image__align{width:100%}
 .wp-block-kubio-post-meta{align-items:center;display:flex;flex-wrap:wrap;line-height:1em}
 .wp-block-kubio-post-meta .metadata-item{align-items:center;-moz-column-gap:4px;column-gap:4px;display:inline-flex}
 .wp-block-kubio-post-meta .metadata-item .h-svg-icon{display:inline-block!important;line-height:inherit;vertical-align:middle}
 .wp-block-kubio-post-meta .metadata-item svg{box-sizing:content-box}
 .wp-block-kubio-post-meta .metadata-item .meta-separator{display:inline-block}
 .wp-block-kubio-post-meta .metadata-item a{align-items:center;display:inline-flex;text-decoration:none}
 .wp-block-kubio-post-meta .shortcode-placeholder{display:inline-block}
 .kubio-sortable-accordion-title .toggle-control-wrapper{margin-right:32px}
 .kubio-sortable-accordion-title .components-toggle-control .components-base-control__field .components-form-toggle{margin-right:0}
 .wp-block-kubio-post-tags__container{justify-content:center}
 .wp-block-kubio-post-tags__container a{white-space:pre}
 .wp-block-kubio-post-tags__tags>div{word-break:break-all}
 .wp-block-kubio-post-tags__tags>div a{display:inline-block;white-space:normal}
 .wp-block-kubio-query-pagination .components-placeholder:not(.extra-1){background:#f5f7f7;padding:30px 40px}
 .wp-block-kubio-query-pagination .components-placeholder__label{color:#454545;font-size:24px!important;font-weight:500!important;line-height:1.2;margin-bottom:5px}
 .wp-block-kubio-query-pagination .kubio-block-icon{display:none}
 .wp-block-kubio-query-pagination .block-editor-block-variation-picker__variations{justify-content:flex-start!important;margin-left:-8px!important;margin-top:0!important}
 .wp-block-kubio-query-pagination .block-editor-block-variation-picker__variation:not(.extra-1){border:1px solid #ccc;box-shadow:none;color:#1e1e1e}
 .wp-block-kubio-query-pagination .block-editor-block-variation-picker__variation:not(.extra-1) svg{height:40px;width:40px}
 .wp-block-kubio-query-pagination .block-editor-block-variation-picker__variation:not(.extra-1):hover{background-color:#e5f1f8!important;border-color:#007cba;color:#007cba}
 .wp-block-kubio-query-loop-item{max-width:100%;min-width:0}
 .wp-block-kubio-query-loop-item.masonry-item{transition-duration:0s}
 .wp-block-kubio-query-loop-item__content .h-heading h1:last-child,
 .wp-block-kubio-query-loop-item__content .h-heading h2:last-child,
 .wp-block-kubio-query-loop-item__content .h-heading h3:last-child,
 .wp-block-kubio-query-loop-item__content .h-heading h4:last-child,
 .wp-block-kubio-query-loop-item__content .h-heading h5:last-child,
 .wp-block-kubio-query-loop-item__content .h-heading h6:last-child,
 .wp-block-kubio-query-loop-item__content .h-heading p:last-child,
 .wp-block-kubio-query-loop-item__content .h-text h1:last-child,
 .wp-block-kubio-query-loop-item__content .h-text h2:last-child,
 .wp-block-kubio-query-loop-item__content .h-text h3:last-child,
 .wp-block-kubio-query-loop-item__content .h-text h4:last-child,
 .wp-block-kubio-query-loop-item__content .h-text h5:last-child,
 .wp-block-kubio-query-loop-item__content .h-text h6:last-child,
 .wp-block-kubio-query-loop-item__content .h-text p:last-child,
 .wp-block-kubio-query-loop-item__content>:last-child{margin-bottom:0}
 .wp-block-kubio-query-loop-item__inner{flex-shrink:1;max-width:100%;position:relative}
 .wp-block-kubio-query-loop-item__align{flex:1 0 auto;max-width:100%}
 .wp-block-kubio-post-featured-image .block-list-appender{margin-left:0}
 [data-kubio] .wp-block-kubio-query{max-width:unset}
 .wp-block-kubio-query-loop{flex-basis:100%;position:relative}
 .wp-block-kubio-query-loop.wp-block{margin-left:0;margin-right:0}
 .wp-block-kubio-query-loop h2.kubio-empty-query-result{display:block;margin:0;width:100%}
 .wp-block-kubio-query-loop .kubio-query-loop--use-masonry{justify-content:flex-start!important}
 .wp-block-kubio-read-more-button__outer{display:inline-flex;vertical-align:middle}
 .wp-block-kubio-read-more-button__link{align-items:center;cursor:pointer;display:inline-flex}
 .wp-block-kubio-read-more-button__inner{cursor:pointer;text-decoration:none}
 .wp-block-kubio-read-more-button__icon{flex-shrink:0}
 .kubio-reorder-controls-toolbar .kubio-toolbar-reorder-controls{border-right:1px solid #1e1e1e}
 .kubio-reorder-controls-toolbar.is-fixed .kubio-toolbar-reorder-controls{border-right:1px solid #e0e0e0}
 .kubio-reorder-controls-toolbar.kubio-on--mobile .block-editor-block-toolbar__block-controls,
 .kubio-reorder-controls-toolbar.kubio-on--tablet .block-editor-block-toolbar__block-controls{border-right:none!important}
 .kubio-reorder-controls-toolbar.kubio-on--mobile .block-editor-block-mover__move-button-container,
 .kubio-reorder-controls-toolbar.kubio-on--tablet .block-editor-block-mover__move-button-container{display:none!important}
 .kubio-reorder-controls-toolbar.kubio-on--mobile .kubio-toolbar-reorder-controls .block-editor-block-mover__move-button-container,
 .kubio-reorder-controls-toolbar.kubio-on--tablet .kubio-toolbar-reorder-controls .block-editor-block-mover__move-button-container{display:flex!important}
 .wp-block-kubio-row{flex-basis:100%;position:relative}
 [data-kubio] .wp-block-kubio-row.wp-block{margin-left:0;margin-right:0}
 #kubio .wp-block-kubio-search-form form{flex-wrap:nowrap;margin-bottom:0;overflow:hidden}
 #kubio .wp-block-kubio-search-form label{flex:0 0 100%}
 #kubio .wp-block-kubio-search-form__input{border:0;flex:auto;height:40px;margin:0;min-width:0;width:auto}
 #kubio .wp-block-kubio-search-form__button{border:0;float:right;height:40px;padding:0;white-space:nowrap}
 #kubio .wp-block-kubio-search-form__button span{height:auto!important;margin:0}
 #kubio .wp-block-kubio-search-form__button span svg{height:100%;max-height:100%;max-width:100%;width:100%}
 #kubio .wp-block-kubio-search-form .search-input:focus::-moz-placeholder{color:transparent}
 #kubio .wp-block-kubio-search-form .search-input:focus:-ms-input-placeholder{color:transparent}
 #kubio .wp-block-kubio-search-form .search-input:focus::placeholder{color:transparent}
 .kubio-section-between-sections-inserter-wrapper{align-items:center;background:transparent;display:flex;height:4px;justify-content:center;left:0;position:absolute;width:100%}
 .kubio-section-between-sections-inserter-wrapper .kubio-section-between-sections-inserter__line{-webkit-animation-duration:.3s;animation-duration:.3s;-webkit-animation-fill-mode:both;animation-fill-mode:both;-webkit-animation-name:between-section-inserter-animation;animation-name:between-section-inserter-animation;-webkit-animation-timing-function:ease-in-out;animation-timing-function:ease-in-out;background:var(--wp-admin-theme-color);height:100%;position:absolute;transform-origin:center;width:0}
 .kubio-section-between-sections-inserter-wrapper__dialog{background:transparent;border:none;height:100%;padding:0;pointer-events:none;top:0;width:100%;z-index:999999999}
 .kubio-section-between-sections-inserter-wrapper__dialog button{pointer-events:auto;position:absolute}
 .kubio-section-between-sections-inserter-wrapper--top{top:-2px}
 .kubio-section-between-sections-inserter-wrapper--top button{top:50%;transform:translateY(-50%)}
 .kubio-section-between-sections-inserter-wrapper--bottom{bottom:-2px}
 .kubio-section-between-sections-inserter-wrapper--bottom button{top:50%;transform:translateY(-50%)}@-webkit-keyframes between-section-inserter-animation{0%{width:50%}to{width:100%}}@keyframes between-section-inserter-animation{0%{width:50%}to{width:100%}}
 .kubio-inserter-popup-disabled{display:none!important}
 .kubio-disable-animation:not(#extra-1){-webkit-animation-name:none;animation-name:none}
 .wp-block-kubio-section.wp-block,
 .wp-block-kubio-section [data-kubio]:not([class*=h-col-]){max-width:unset!important}
 .wp-block-kubio-section>div{display:flex;flex-direction:column;z-index:1}
 .wp-block-kubio-section>div.h-separator{z-index:1}
 .wp-block-kubio-section .entry-content>*{max-width:unset}
 .h-shortcode-placeholder-preview{background-color:#f7f7f7;border:1px solid #dadada;color:#919191;padding:10px;text-align:center}
 .wp-block-kubio-social-icon{display:inline-block}
 .wp-block-kubio-social-icon .h-svg-icon svg{width:100%}
 .h-tabs--horizontal--auto.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:auto;flex-grow:0}
 .h-tabs--horizontal--stretch.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:auto;flex-grow:1}
 .h-tabs--horizontal--full.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:100%;flex-grow:0}
 .h-tabs--vertical--auto.h-tabs-vertical{flex-direction:row}
 .h-tabs--vertical--auto.h-tabs-vertical>.h-tabs-navigation{flex:0 0 auto;max-width:33%}
 .h-tabs--vertical--auto.h-tabs-vertical>.h-tabs-navigation>*{flex-basis:auto;flex-grow:0}
 .h-tabs--vertical--auto.h-tabs-vertical .h-tabs-item-content__container{flex-basis:0;flex-grow:1}
 .h-tabs--vertical--full.h-tabs-vertical{flex-direction:column}
 .h-tabs--vertical--full.h-tabs-vertical>.h-tabs-navigation{max-width:100%}
 .h-tabs--vertical--full.h-tabs-vertical>.h-tabs-navigation>*{flex-basis:100%;flex-grow:0}
 .h-tabs--vertical--full.h-tabs-vertical .h-tabs-item-content__container{flex-basis:auto;flex-grow:0}@media (min-width:576px){
 .h-tabs--horizontal--auto-sm.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:auto;flex-grow:0}
 .h-tabs--horizontal--stretch-sm.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:auto;flex-grow:1}
 .h-tabs--horizontal--full-sm.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:100%;flex-grow:0}
 .h-tabs--vertical--auto-sm.h-tabs-vertical{flex-direction:row}
 .h-tabs--vertical--auto-sm.h-tabs-vertical>.h-tabs-navigation{flex:0 0 auto;max-width:33%}
 .h-tabs--vertical--auto-sm.h-tabs-vertical>.h-tabs-navigation>*{flex-basis:auto;flex-grow:0}
 .h-tabs--vertical--auto-sm.h-tabs-vertical .h-tabs-item-content__container{flex-basis:0;flex-grow:1}
 .h-tabs--vertical--full-sm.h-tabs-vertical{flex-direction:column}
 .h-tabs--vertical--full-sm.h-tabs-vertical>.h-tabs-navigation{max-width:100%}
 .h-tabs--vertical--full-sm.h-tabs-vertical>.h-tabs-navigation>*{flex-basis:100%;flex-grow:0}
 .h-tabs--vertical--full-sm.h-tabs-vertical .h-tabs-item-content__container{flex-basis:auto;flex-grow:0}}@media (min-width:768px){
 .h-tabs--horizontal--auto-md.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:auto;flex-grow:0}
 .h-tabs--horizontal--stretch-md.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:auto;flex-grow:1}
 .h-tabs--horizontal--full-md.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:100%;flex-grow:0}
 .h-tabs--vertical--auto-md.h-tabs-vertical{flex-direction:row}
 .h-tabs--vertical--auto-md.h-tabs-vertical>.h-tabs-navigation{flex:0 0 auto;max-width:33%}
 .h-tabs--vertical--auto-md.h-tabs-vertical>.h-tabs-navigation>*{flex-basis:auto;flex-grow:0}
 .h-tabs--vertical--auto-md.h-tabs-vertical .h-tabs-item-content__container{flex-basis:0;flex-grow:1}
 .h-tabs--vertical--full-md.h-tabs-vertical{flex-direction:column}
 .h-tabs--vertical--full-md.h-tabs-vertical>.h-tabs-navigation{max-width:100%}
 .h-tabs--vertical--full-md.h-tabs-vertical>.h-tabs-navigation>*{flex-basis:100%;flex-grow:0}
 .h-tabs--vertical--full-md.h-tabs-vertical .h-tabs-item-content__container{flex-basis:auto;flex-grow:0}}@media (min-width:1024px){
 .h-tabs--horizontal--auto-lg.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:auto;flex-grow:0}
 .h-tabs--horizontal--stretch-lg.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:auto;flex-grow:1}
 .h-tabs--horizontal--full-lg.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:100%;flex-grow:0}
 .h-tabs--vertical--auto-lg.h-tabs-vertical{flex-direction:row}
 .h-tabs--vertical--auto-lg.h-tabs-vertical>.h-tabs-navigation{flex:0 0 auto;max-width:33%}
 .h-tabs--vertical--auto-lg.h-tabs-vertical>.h-tabs-navigation>*{flex-basis:auto;flex-grow:0}
 .h-tabs--vertical--auto-lg.h-tabs-vertical .h-tabs-item-content__container{flex-basis:0;flex-grow:1}
 .h-tabs--vertical--full-lg.h-tabs-vertical{flex-direction:column}
 .h-tabs--vertical--full-lg.h-tabs-vertical>.h-tabs-navigation{max-width:100%}
 .h-tabs--vertical--full-lg.h-tabs-vertical>.h-tabs-navigation>*{flex-basis:100%;flex-grow:0}
 .h-tabs--vertical--full-lg.h-tabs-vertical .h-tabs-item-content__container{flex-basis:auto;flex-grow:0}}@media (min-width:1200px){
 .h-tabs--horizontal--auto-xl.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:auto;flex-grow:0}
 .h-tabs--horizontal--stretch-xl.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:auto;flex-grow:1}
 .h-tabs--horizontal--full-xl.h-tabs-horizontal>.h-tabs-navigation>*{flex-basis:100%;flex-grow:0}
 .h-tabs--vertical--auto-xl.h-tabs-vertical{flex-direction:row}
 .h-tabs--vertical--auto-xl.h-tabs-vertical>.h-tabs-navigation{flex:0 0 auto;max-width:33%}
 .h-tabs--vertical--auto-xl.h-tabs-vertical>.h-tabs-navigation>*{flex-basis:auto;flex-grow:0}
 .h-tabs--vertical--auto-xl.h-tabs-vertical .h-tabs-item-content__container{flex-basis:0;flex-grow:1}
 .h-tabs--vertical--full-xl.h-tabs-vertical{flex-direction:column}
 .h-tabs--vertical--full-xl.h-tabs-vertical>.h-tabs-navigation{max-width:100%}
 .h-tabs--vertical--full-xl.h-tabs-vertical>.h-tabs-navigation>*{flex-basis:100%;flex-grow:0}
 .h-tabs--vertical--full-xl.h-tabs-vertical .h-tabs-item-content__container{flex-basis:auto;flex-grow:0}}
 .h-tabs{display:flex;flex-direction:column;z-index:0}
 .h-tabs .h-tabs-item{min-height:100px}
 .h-tabs .h-tabs-navigation-item{align-items:center;line-height:1.15em}
 .h-tabs .h-tabs-item-content{display:none;flex:1;justify-content:center;max-width:100%!important;text-align:left}
 .h-tabs .h-tabs-item-content__container{width:100%}@media (min-width:767px){
 .h-tabs .h-tabs-content-vertical{flex-basis:0;flex-grow:1}}
 .h-tabs .h-tabs-content-active{display:flex;flex-direction:column}
 .h-tabs-horizontal{flex-direction:column}
 .h-tabs-horizontal>.h-tabs-navigation{margin-right:0!important}
 .h-tabs-horizontal>.h-tabs-navigation .h-tabs-navigation-item{display:flex}
 .h-tabs-horizontal>.h-tabs-navigation .h-tabs-navigation-item.position-relative.wp-block[data-kubio]{margin-bottom:0}
 .h-tabs-horizontal .h-tabs-navigation{align-items:center;display:flex;flex-wrap:wrap;text-align:left}
 .h-tabs-horizontal .h-tabs-navigation>*{flex-basis:100%}@media (min-width:767px){
 .h-tabs-horizontal .h-tabs-navigation>*{flex-basis:auto}}
 .h-tabs-vertical{align-items:stretch;flex-direction:column}@media (min-width:767px){
 .h-tabs-vertical{flex-direction:row}}
 .h-tabs-vertical>.h-tabs-navigation{flex-direction:column;margin:0;text-align:center}
 .h-tabs-vertical>.h-tabs-navigation .h-tabs-navigation-item{display:flex}@media (min-width:767px){
 .h-tabs-vertical>.h-tabs-navigation{flex-basis:auto;flex-grow:0;max-width:33%;width:auto}}
 .h-tabs-navigation{margin-bottom:0;margin-left:0;z-index:1}
 .h-tabs-navigation-item{text-decoration:none}
 .h-tabs-navigation-item>.h-tabs-navigation-item__text{flex:0 0 auto;max-width:100%}
 .h-tabs-navigation-active-item,
 .h-tabs-navigation-item{cursor:pointer}
 .h-tabs-navigation-active-item{position:relative;z-index:1}
 .h-tabs-navigation .h-svg-icon{height:1em;width:1em}
 .h-tabs-navigation .h-svg-icon svg{width:100%}
 .h-tabs-title-icon{fill:currentColor;height:1em;margin-right:12px;width:1em}
 .components-input-control__label{cursor:default!important;font-size:13px;font-weight:400;text-transform:none}
 .wp-block-kubio-text a{text-decoration:underline}
 .wp-block-kubio-video .embed-container,
 .wp-block-kubio-video .embed-youtube{margin-bottom:0}
 .wp-block-kubio-video__video .wp-block-kubio-shortcode__outer,
 .wp-block-kubio-video__video iframe,
 .wp-block-kubio-video__video video{height:100%;width:100%}
 .wp-block-kubio-video__outer{width:100%}
 .wp-block-kubio-video__outer:before{content:"";display:block}
 .wp-block-kubio-video__outer.h-aspect-ratio:before{width:100%}
 .wp-block-kubio-video__outer.h-aspect-ratio--3-2:before{padding-top:66%}
 .wp-block-kubio-video__outer.h-aspect-ratio--4-3:before{padding-top:75%}
 .wp-block-kubio-video__outer.h-aspect-ratio--16-9:before{padding-top:56.25%}
 .wp-block-kubio-video__outer.h-aspect-ratio--21-9:before{padding-top:42.857142%}
 .wp-block-kubio-video__outer .components-disabled{position:unset}
 .wp-block-kubio-video__video{bottom:0;display:flex!important;height:100%;left:0;position:absolute!important;right:0;top:0;width:100%}
 .wp-block-kubio-video__video .components-placeholder__fieldset{justify-content:center}
 .wp-block-kubio-video__poster{align-items:center;background-position:50%;background-size:cover;bottom:0;display:flex;justify-content:center;left:0;position:absolute;right:0;top:0;z-index:2}
 .wp-block-kubio-video .wp-block-kubio-video__lightbox+.wp-block-kubio-video__video{display:none!important}
 .wp-block-kubio-video .h-svg-icon path{cursor:pointer}
 .wp-block-kubio-video .h-video-main{height:100%;width:100%}
 .components-flex.components-input-control.kubio-video-time-container{align-items:flex-end;display:flex;flex-direction:row;justify-content:center}
 .components-flex.components-input-control.kubio-video-time-container>.components-flex__item{flex-basis:0;flex-grow:1;margin-bottom:0}
 .kubio-media-upload{pointer-events:none}
 .video-options-customize-play__container{margin:0 -10px;padding:0 10px 10px}
 .wp-block-kubio-pagination-nav-button__outer{display:inline-flex;vertical-align:middle}
 .wp-block-kubio-pagination-nav-button__link{align-items:center;cursor:pointer;display:inline-flex}
 .wp-block-kubio-pagination-nav-button__inner{cursor:pointer;text-decoration:none}
 .wp-block-kubio-pagination-nav-button__icon{flex-shrink:0}
 .wp-block-kubio-post-categories__container{word-break:break-word}
 .wp-block-kubio-post-categories__container a{white-space:nowrap}
 .wp-block-kubio-post-categories__container>.kubio-post-categories-link a{color:unset!important}
 .wp-block-kubio-post-categories__container a:first-of-type{margin-left:0!important}
 .wp-block-kubio-post-categories__container .separator{padding-right:0!important}
 .wp-block-kubio-post-categories__container .wp-block-kubio-post-categories__placeholder{vertical-align:text-bottom}
 .wp-block-kubio-post-categories__container .wp-block-kubio-post-categories__placeholder:not(:empty){display:inline-block}
 .wp-block-kubio-post-excerpt p{margin:0}
 .interface-complementary-area.edit-post-sidebar .excerpt-length-wrapper .kubio-range-control{margin-left:0}
 .wp-block-kubio-post-title__link{word-break:break-word}
 .wp-block-kubio-post-title__link>h1,
 .wp-block-kubio-post-title__link>h2,
 .wp-block-kubio-post-title__link>h3,
 .wp-block-kubio-post-title__link>h4,
 .wp-block-kubio-post-title__link>h5,
 .wp-block-kubio-post-title__link>h6{margin:0}
 .wp-block-kubio-query-layout.wp-block,
 .wp-block-kubio-query-layout [data-kubio]:not([class*=h-col-]){max-width:unset!important}
 .wp-block-kubio-query-layout>div{display:flex;flex-direction:column;z-index:1}
 .wp-block-kubio-query-layout>div.h-separator{z-index:1}
 .wp-block-kubio-query-layout .entry-content>*{max-width:unset}
 [data-kubio-aos].force-hide:not([data-kubio-aos=none]){visibility:none!important}
 [data-kubio-aos]:not([data-kubio-aos=none]){visibility:hidden!important}
 [data-kubio-aos]:not([data-kubio-aos=none]):not([class*=fade]){opacity:1!important}
 [data-kubio-aos].animated:not(.force-hide){visibility:visible!important}
 [data-kubio-aos].animated:not([class*=fade]){opacity:1!important}
 .kubio-aos-hide-animation{-webkit-animation-delay:0!important;animation-delay:0!important;-webkit-animation-name:unset!important;animation-name:unset!important}
 .wp-block-kubio-multipleimages{position:relative;width:100%}
 .wp-block-kubio-multipleimages img{height:auto;width:100%!important}
 .wp-block-kubio-multipleimages .ratio-inner{bottom:0;display:block;height:100%;left:0;overflow:hidden;position:absolute;right:0;top:0;width:100%}
 .wp-block-kubio-multipleimages .ratio-inner>*>.block-editor-block-list__layout{height:100%;position:absolute;width:100%}
 .wp-block-kubio-multipleimages .h-image__frame-container,
 .wp-block-kubio-multipleimages .h-multiple-image-inside-container{padding-top:50%;width:100%}
 .wp-block-kubio-multipleimages .wp-block-kubio-multipleimagespicture__overlay{border-color:transparent!important}
 .wp-block-kubio-multipleimages .wp-block-kubio-multipleimagespicture__overlay .background-wrapper{border-radius:0!important}
 .wp-block-kubio-multipleimagespicture{display:block;min-height:20px;vertical-align:middle;z-index:1}
 [data-kubio] .wp-block-kubio-multipleimagespicture{display:inline-block;max-width:100%}
 .wp-block-kubio-multipleimagespicture.wp-block.position-relative{line-height:0}
 .wp-block-kubio-multipleimagespicture__outer{align-items:center;flex-direction:column;justify-content:center}
 [data-kubio] .wp-block-kubio-multipleimagespicture__outer{margin:0;max-width:100%;width:100%}
 .wp-block-kubio-multipleimagespicture__captionContainer{display:block}
 .wp-block-kubio-multipleimagespicture__caption{line-height:1.6;width:100%;z-index:1}
 .wp-block-kubio-multipleimagespicture__image{display:block;height:auto;max-height:100%;width:auto}
 .wp-block-kubio-multipleimagespicture__frameContainer{display:inline-block;max-width:100%;position:relative;z-index:1}
 .wp-block-kubio-multipleimagespicture__frameContainer img:before{background-color:transparent;content:" "!important;display:inline-block!important;font-size:300000px!important;height:100%!important;max-width:var(--kubio-image-width,100%);overflow:hidden;width:100%!important}
 .wp-block-kubio-multipleimagespicture__frameContainer img[data-width]{width:var(--kubio-image-width,auto)}
 .wp-block-kubio-multipleimagespicture__frameContainer .frame-type-background{border:inherit;border-color:transparent!important}
 .wp-block-kubio-multipleimagespicture__overlay{bottom:0;left:0;overflow:hidden;pointer-events:none;position:absolute;right:0;top:0;z-index:1}
 .wp-block-kubio-multipleimagespicture__frameImage{left:0;pointer-events:none;position:absolute;top:0;z-index:-1}
 .wp-block-kubio-multipleimagespicture__frameImage.frame-image-shadow{box-shadow:0 2px 4px -1px rgba(0,0,0,.2),0 4px 5px 0 rgba(0,0,0,.14),0 1px 10px 0 rgba(0,0,0,.12)}
 .wp-block-kubio-multipleimagespicture .components-placeholder{line-height:1.6!important;font:initial!important;font-style:normal;font-weight:400;letter-spacing:normal;text-decoration:none;text-transform:none}
 .wp-block-kubio-multipleimagespicture .components-placeholder .components-placeholder__fieldset .components-button{padding:6px 12px}
 .wp-block-kubio-multipleimagespicture__frameContainer{width:100%}
 .wp-block-kubio-counter :after,
 .wp-block-kubio-counter :before{display:none!important}
 .wp-block-kubio-counter__outer{display:block}
 .wp-block-kubio-counter__outer .bar-counter.same-row-with-title{margin-left:auto}
 .wp-block-kubio-counter__counterContainer{box-sizing:border-box;display:inline-flex;flex-direction:column;max-height:100%;max-width:100%;overflow:hidden}
 .wp-block-kubio-counter__counterContainer .progress-bar__animation{-webkit-animation:progress ease-in-out;animation:progress ease-in-out}
 .wp-block-kubio-counter .h-circle-progress .wp-block-kubio-counter__counter-wrapper,
 .wp-block-kubio-counter .h-circle-progress .wp-block-kubio-counter__title{align-items:center!important;justify-content:center!important;text-align:center}
 .wp-block-kubio-counter .kubio-bar-counter-position--inside .wp-block-kubio-counter__counterContainer{overflow:visible}
 .wp-block-kubio-counter .kubio-bar-counter-position--same .title-counter-bar{justify-content:space-between!important}
 .wp-block-kubio-counter .kubio-bar-counter-position--same .title-counter-bar:after,
 .wp-block-kubio-counter .kubio-bar-counter-position--same .title-counter-bar:before{display:none!important}
 .wp-block-kubio-counter .kubio-bar-counter-position--hide .wp-block-kubio-counter__title,
 .wp-block-kubio-counter .kubio-bar-counter-position--inside .wp-block-kubio-counter__title{flex:1}
 .wp-block-kubio-counter .progress-number{align-items:center;bottom:0;display:flex;justify-content:center;left:0;margin:auto;position:absolute;right:0;top:0}
 .wp-block-kubio-counter__progressBarWrapper{position:relative}
 .wp-block-kubio-counter__progressBarContainer{box-shadow:inset 0 1px 2px rgba(0,0,0,.1);overflow:hidden}
 .wp-block-kubio-counter__progressBar{box-shadow:inset 0 -1px 0 rgba(0,0,0,.15);color:#fff;float:left;font-size:12px;height:100%;line-height:20px;text-align:center;transition:width .6s ease;width:0}
 .wp-block-kubio-counter .content-circle-inside{align-items:center;display:flex;flex-direction:column;justify-content:center}
 .wp-block-kubio-counter .kubio-counter-title--under.kubio-counter-type--bar .wp-block-kubio-counter__counterContainer,
 .wp-block-kubio-counter .kubio-counter-title--under.kubio-counter-type--circle .content-circle-inside,
 .wp-block-kubio-counter .kubio-counter-title--under.kubio-counter-type--number .wp-block-kubio-counter__counterContainer{flex-direction:column-reverse}
 .wp-block-kubio-counter .h-circle-progress canvas{display:block;max-height:100%;max-width:100%;min-height:100%;min-width:100%}
 .wp-block-kubio-counter .title-counter-bar{align-items:center;flex-direction:row;justify-content:center}@-webkit-keyframes progress{0%{width:0}}@keyframes progress{0%{width:0}}@-webkit-keyframes show{0%{opacity:0}to{opacity:1}}@keyframes show{0%{opacity:0}to{opacity:1}}
/*!
 * animate.css -http://daneden.me/animate
 * Version - 3.7.0
 * Licensed under the MIT license - http://opensource.org/licenses/MIT
 *
 * Copyright (c) 2018 Daniel Eden
 */@-webkit-keyframes bounce{0%,20%,53%,80%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1);-webkit-transform:translateZ(0);transform:translateZ(0)}40%,43%{-webkit-animation-timing-function:cubic-bezier(.755,.05,.855,.06);animation-timing-function:cubic-bezier(.755,.05,.855,.06);-webkit-transform:translate3d(0,-30px,0);transform:translate3d(0,-30px,0)}70%{-webkit-animation-timing-function:cubic-bezier(.755,.05,.855,.06);animation-timing-function:cubic-bezier(.755,.05,.855,.06);-webkit-transform:translate3d(0,-15px,0);transform:translate3d(0,-15px,0)}90%{transform:translate3d(0,-4px,0)}}@keyframes bounce{0%,20%,53%,80%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1);-webkit-transform:translateZ(0);transform:translateZ(0)}40%,43%{-webkit-animation-timing-function:cubic-bezier(.755,.05,.855,.06);animation-timing-function:cubic-bezier(.755,.05,.855,.06);-webkit-transform:translate3d(0,-30px,0);transform:translate3d(0,-30px,0)}70%{-webkit-animation-timing-function:cubic-bezier(.755,.05,.855,.06);animation-timing-function:cubic-bezier(.755,.05,.855,.06);-webkit-transform:translate3d(0,-15px,0);transform:translate3d(0,-15px,0)}90%{transform:translate3d(0,-4px,0)}}
 .bounce{-webkit-animation-name:bounce;animation-name:bounce;-webkit-transform-origin:center bottom;transform-origin:center bottom}@-webkit-keyframes flash{0%,50%,to{opacity:1}25%,75%{opacity:0}}@keyframes flash{0%,50%,to{opacity:1}25%,75%{opacity:0}}
 .flash{-webkit-animation-name:flash;animation-name:flash}@-webkit-keyframes pulse{0%{transform:scaleX(1)}50%{transform:scale3d(1.05,1.05,1.05)}to{transform:scaleX(1)}}@keyframes pulse{0%{transform:scaleX(1)}50%{transform:scale3d(1.05,1.05,1.05)}to{transform:scaleX(1)}}
 .pulse{-webkit-animation-name:pulse;animation-name:pulse}@-webkit-keyframes rubberBand{0%{transform:scaleX(1)}30%{transform:scale3d(1.25,.75,1)}40%{transform:scale3d(.75,1.25,1)}50%{transform:scale3d(1.15,.85,1)}65%{transform:scale3d(.95,1.05,1)}75%{transform:scale3d(1.05,.95,1)}to{transform:scaleX(1)}}@keyframes rubberBand{0%{transform:scaleX(1)}30%{transform:scale3d(1.25,.75,1)}40%{transform:scale3d(.75,1.25,1)}50%{transform:scale3d(1.15,.85,1)}65%{transform:scale3d(.95,1.05,1)}75%{transform:scale3d(1.05,.95,1)}to{transform:scaleX(1)}}
 .rubberBand{-webkit-animation-name:rubberBand;animation-name:rubberBand}@-webkit-keyframes shake{0%,to{transform:translateZ(0)}10%,30%,50%,70%,90%{transform:translate3d(-10px,0,0)}20%,40%,60%,80%{transform:translate3d(10px,0,0)}}@keyframes shake{0%,to{transform:translateZ(0)}10%,30%,50%,70%,90%{transform:translate3d(-10px,0,0)}20%,40%,60%,80%{transform:translate3d(10px,0,0)}}
 .shake{-webkit-animation-name:shake;animation-name:shake}@-webkit-keyframes headShake{0%{transform:translateX(0)}6.5%{transform:translateX(-6px) rotateY(-9deg)}18.5%{transform:translateX(5px) rotateY(7deg)}31.5%{transform:translateX(-3px) rotateY(-5deg)}43.5%{transform:translateX(2px) rotateY(3deg)}50%{transform:translateX(0)}}@-webkit-keyframes swing{20%{transform:rotate(15deg)}40%{transform:rotate(-10deg)}60%{transform:rotate(5deg)}80%{transform:rotate(-5deg)}to{transform:rotate(0deg)}}@keyframes swing{20%{transform:rotate(15deg)}40%{transform:rotate(-10deg)}60%{transform:rotate(5deg)}80%{transform:rotate(-5deg)}to{transform:rotate(0deg)}}
 .swing{-webkit-animation-name:swing;animation-name:swing;-webkit-transform-origin:top center;transform-origin:top center}@-webkit-keyframes tada{0%{transform:scaleX(1)}10%,20%{transform:scale3d(.9,.9,.9) rotate(-3deg)}30%,50%,70%,90%{transform:scale3d(1.1,1.1,1.1) rotate(3deg)}40%,60%,80%{transform:scale3d(1.1,1.1,1.1) rotate(-3deg)}to{transform:scaleX(1)}}@keyframes tada{0%{transform:scaleX(1)}10%,20%{transform:scale3d(.9,.9,.9) rotate(-3deg)}30%,50%,70%,90%{transform:scale3d(1.1,1.1,1.1) rotate(3deg)}40%,60%,80%{transform:scale3d(1.1,1.1,1.1) rotate(-3deg)}to{transform:scaleX(1)}}
 .tada{-webkit-animation-name:tada;animation-name:tada}@-webkit-keyframes wobble{0%{transform:translateZ(0)}15%{transform:translate3d(-25%,0,0) rotate(-5deg)}30%{transform:translate3d(20%,0,0) rotate(3deg)}45%{transform:translate3d(-15%,0,0) rotate(-3deg)}60%{transform:translate3d(10%,0,0) rotate(2deg)}75%{transform:translate3d(-5%,0,0) rotate(-1deg)}to{transform:translateZ(0)}}@keyframes wobble{0%{transform:translateZ(0)}15%{transform:translate3d(-25%,0,0) rotate(-5deg)}30%{transform:translate3d(20%,0,0) rotate(3deg)}45%{transform:translate3d(-15%,0,0) rotate(-3deg)}60%{transform:translate3d(10%,0,0) rotate(2deg)}75%{transform:translate3d(-5%,0,0) rotate(-1deg)}to{transform:translateZ(0)}}
 .wobble{-webkit-animation-name:wobble;animation-name:wobble}@-webkit-keyframes jello{0%,11.1%,to{transform:translateZ(0)}22.2%{transform:skewX(-12.5deg) skewY(-12.5deg)}33.3%{transform:skewX(6.25deg) skewY(6.25deg)}44.4%{transform:skewX(-3.125deg) skewY(-3.125deg)}55.5%{transform:skewX(1.5625deg) skewY(1.5625deg)}66.6%{transform:skewX(-.78125deg) skewY(-.78125deg)}77.7%{transform:skewX(.390625deg) skewY(.390625deg)}88.8%{transform:skewX(-.1953125deg) skewY(-.1953125deg)}}@keyframes jello{0%,11.1%,to{transform:translateZ(0)}22.2%{transform:skewX(-12.5deg) skewY(-12.5deg)}33.3%{transform:skewX(6.25deg) skewY(6.25deg)}44.4%{transform:skewX(-3.125deg) skewY(-3.125deg)}55.5%{transform:skewX(1.5625deg) skewY(1.5625deg)}66.6%{transform:skewX(-.78125deg) skewY(-.78125deg)}77.7%{transform:skewX(.390625deg) skewY(.390625deg)}88.8%{transform:skewX(-.1953125deg) skewY(-.1953125deg)}}
 .jello{-webkit-animation-name:jello;animation-name:jello;-webkit-transform-origin:center;transform-origin:center}@-webkit-keyframes heartBeat{0%{transform:scale(1)}14%{transform:scale(1.3)}28%{transform:scale(1)}42%{transform:scale(1.3)}70%{transform:scale(1)}}@keyframes heartBeat{0%{transform:scale(1)}14%{transform:scale(1.3)}28%{transform:scale(1)}42%{transform:scale(1.3)}70%{transform:scale(1)}}
 .heartBeat{-webkit-animation-duration:1.3s;animation-duration:1.3s;-webkit-animation-name:heartBeat;animation-name:heartBeat;-webkit-animation-timing-function:ease-in-out;animation-timing-function:ease-in-out}@-webkit-keyframes backInDown{0%{opacity:.7;transform:translateY(-1200px) scale(.7)}80%{opacity:.7;transform:translateY(0) scale(.7)}to{opacity:1;transform:scale(1)}}@keyframes backInDown{0%{opacity:.7;transform:translateY(-1200px) scale(.7)}80%{opacity:.7;transform:translateY(0) scale(.7)}to{opacity:1;transform:scale(1)}}
 .backInDown{-webkit-animation-name:backInDown;animation-name:backInDown}@-webkit-keyframes backInLeft{0%{opacity:.7;transform:translateX(-2000px) scale(.7)}80%{opacity:.7;transform:translateX(0) scale(.7)}to{opacity:1;transform:scale(1)}}@keyframes backInLeft{0%{opacity:.7;transform:translateX(-2000px) scale(.7)}80%{opacity:.7;transform:translateX(0) scale(.7)}to{opacity:1;transform:scale(1)}}
 .backInLeft{-webkit-animation-name:backInLeft;animation-name:backInLeft}@-webkit-keyframes backInRight{0%{opacity:.7;transform:translateX(2000px) scale(.7)}80%{opacity:.7;transform:translateX(0) scale(.7)}to{opacity:1;transform:scale(1)}}@keyframes backInRight{0%{opacity:.7;transform:translateX(2000px) scale(.7)}80%{opacity:.7;transform:translateX(0) scale(.7)}to{opacity:1;transform:scale(1)}}
 .backInRight{-webkit-animation-name:backInRight;animation-name:backInRight}@-webkit-keyframes backInUp{0%{opacity:.7;transform:translateY(1200px) scale(.7)}80%{opacity:.7;transform:translateY(0) scale(.7)}to{opacity:1;transform:scale(1)}}@keyframes backInUp{0%{opacity:.7;transform:translateY(1200px) scale(.7)}80%{opacity:.7;transform:translateY(0) scale(.7)}to{opacity:1;transform:scale(1)}}
 .backInUp{-webkit-animation-name:backInUp;animation-name:backInUp}@-webkit-keyframes bounceIn{0%,20%,40%,60%,80%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;-webkit-transform:scale3d(.3,.3,.3);transform:scale3d(.3,.3,.3)}20%{transform:scale3d(1.1,1.1,1.1)}40%{transform:scale3d(.9,.9,.9)}60%{opacity:1;-webkit-transform:scale3d(1.03,1.03,1.03);transform:scale3d(1.03,1.03,1.03)}80%{transform:scale3d(.97,.97,.97)}to{opacity:1;-webkit-transform:scaleX(1);transform:scaleX(1)}}@keyframes bounceIn{0%,20%,40%,60%,80%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;-webkit-transform:scale3d(.3,.3,.3);transform:scale3d(.3,.3,.3)}20%{transform:scale3d(1.1,1.1,1.1)}40%{transform:scale3d(.9,.9,.9)}60%{opacity:1;-webkit-transform:scale3d(1.03,1.03,1.03);transform:scale3d(1.03,1.03,1.03)}80%{transform:scale3d(.97,.97,.97)}to{opacity:1;-webkit-transform:scaleX(1);transform:scaleX(1)}}
 .bounceIn{-webkit-animation-duration:.75s;animation-duration:.75s;-webkit-animation-name:bounceIn;animation-name:bounceIn}@-webkit-keyframes bounceInDown{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;-webkit-transform:translate3d(0,-3000px,0);transform:translate3d(0,-3000px,0)}60%{opacity:1;-webkit-transform:translate3d(0,25px,0);transform:translate3d(0,25px,0)}75%{transform:translate3d(0,-10px,0)}90%{transform:translate3d(0,5px,0)}to{transform:translateZ(0)}}@keyframes bounceInDown{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;-webkit-transform:translate3d(0,-3000px,0);transform:translate3d(0,-3000px,0)}60%{opacity:1;-webkit-transform:translate3d(0,25px,0);transform:translate3d(0,25px,0)}75%{transform:translate3d(0,-10px,0)}90%{transform:translate3d(0,5px,0)}to{transform:translateZ(0)}}
 .bounceInDown{-webkit-animation-name:bounceInDown;animation-name:bounceInDown}@-webkit-keyframes bounceInLeft{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;-webkit-transform:translate3d(-3000px,0,0);transform:translate3d(-3000px,0,0)}60%{opacity:1;-webkit-transform:translate3d(25px,0,0);transform:translate3d(25px,0,0)}75%{transform:translate3d(-10px,0,0)}90%{transform:translate3d(5px,0,0)}to{transform:translateZ(0)}}@keyframes bounceInLeft{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;-webkit-transform:translate3d(-3000px,0,0);transform:translate3d(-3000px,0,0)}60%{opacity:1;-webkit-transform:translate3d(25px,0,0);transform:translate3d(25px,0,0)}75%{transform:translate3d(-10px,0,0)}90%{transform:translate3d(5px,0,0)}to{transform:translateZ(0)}}
 .bounceInLeft{-webkit-animation-name:bounceInLeft;animation-name:bounceInLeft}@-webkit-keyframes bounceInRight{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;-webkit-transform:translate3d(3000px,0,0);transform:translate3d(3000px,0,0)}60%{opacity:1;-webkit-transform:translate3d(-25px,0,0);transform:translate3d(-25px,0,0)}75%{transform:translate3d(10px,0,0)}90%{transform:translate3d(-5px,0,0)}to{transform:translateZ(0)}}@keyframes bounceInRight{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;-webkit-transform:translate3d(3000px,0,0);transform:translate3d(3000px,0,0)}60%{opacity:1;-webkit-transform:translate3d(-25px,0,0);transform:translate3d(-25px,0,0)}75%{transform:translate3d(10px,0,0)}90%{transform:translate3d(-5px,0,0)}to{transform:translateZ(0)}}
 .bounceInRight{-webkit-animation-name:bounceInRight;animation-name:bounceInRight}@-webkit-keyframes bounceInUp{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;-webkit-transform:translate3d(0,3000px,0);transform:translate3d(0,3000px,0)}60%{opacity:1;-webkit-transform:translate3d(0,-20px,0);transform:translate3d(0,-20px,0)}75%{transform:translate3d(0,10px,0)}90%{transform:translate3d(0,-5px,0)}to{transform:translateZ(0)}}@keyframes bounceInUp{0%,60%,75%,90%,to{-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}0%{opacity:0;-webkit-transform:translate3d(0,3000px,0);transform:translate3d(0,3000px,0)}60%{opacity:1;-webkit-transform:translate3d(0,-20px,0);transform:translate3d(0,-20px,0)}75%{transform:translate3d(0,10px,0)}90%{transform:translate3d(0,-5px,0)}to{transform:translateZ(0)}}
 .bounceInUp{-webkit-animation-name:bounceInUp;animation-name:bounceInUp}@-webkit-keyframes bounceOut{20%{transform:scale3d(.9,.9,.9)}50%,55%{opacity:1;-webkit-transform:scale3d(1.1,1.1,1.1);transform:scale3d(1.1,1.1,1.1)}to{opacity:0;-webkit-transform:scale3d(.3,.3,.3);transform:scale3d(.3,.3,.3)}}@keyframes bounceOut{20%{transform:scale3d(.9,.9,.9)}50%,55%{opacity:1;-webkit-transform:scale3d(1.1,1.1,1.1);transform:scale3d(1.1,1.1,1.1)}to{opacity:0;-webkit-transform:scale3d(.3,.3,.3);transform:scale3d(.3,.3,.3)}}
 .bounceOut{-webkit-animation-duration:.75s;animation-duration:.75s;-webkit-animation-name:bounceOut;animation-name:bounceOut}@-webkit-keyframes bounceOutDown{20%{transform:translate3d(0,10px,0)}40%,45%{opacity:1;-webkit-transform:translate3d(0,-20px,0);transform:translate3d(0,-20px,0)}to{opacity:0;-webkit-transform:translate3d(0,2000px,0);transform:translate3d(0,2000px,0)}}@keyframes bounceOutDown{20%{transform:translate3d(0,10px,0)}40%,45%{opacity:1;-webkit-transform:translate3d(0,-20px,0);transform:translate3d(0,-20px,0)}to{opacity:0;-webkit-transform:translate3d(0,2000px,0);transform:translate3d(0,2000px,0)}}
 .bounceOutDown{-webkit-animation-name:bounceOutDown;animation-name:bounceOutDown}@-webkit-keyframes bounceOutLeft{20%{opacity:1;-webkit-transform:translate3d(20px,0,0);transform:translate3d(20px,0,0)}to{opacity:0;-webkit-transform:translate3d(-2000px,0,0);transform:translate3d(-2000px,0,0)}}@keyframes bounceOutLeft{20%{opacity:1;-webkit-transform:translate3d(20px,0,0);transform:translate3d(20px,0,0)}to{opacity:0;-webkit-transform:translate3d(-2000px,0,0);transform:translate3d(-2000px,0,0)}}
 .bounceOutLeft{-webkit-animation-name:bounceOutLeft;animation-name:bounceOutLeft}@-webkit-keyframes bounceOutRight{20%{opacity:1;-webkit-transform:translate3d(-20px,0,0);transform:translate3d(-20px,0,0)}to{opacity:0;-webkit-transform:translate3d(2000px,0,0);transform:translate3d(2000px,0,0)}}@keyframes bounceOutRight{20%{opacity:1;-webkit-transform:translate3d(-20px,0,0);transform:translate3d(-20px,0,0)}to{opacity:0;-webkit-transform:translate3d(2000px,0,0);transform:translate3d(2000px,0,0)}}
 .bounceOutRight{-webkit-animation-name:bounceOutRight;animation-name:bounceOutRight}@-webkit-keyframes bounceOutUp{20%{transform:translate3d(0,-10px,0)}40%,45%{opacity:1;-webkit-transform:translate3d(0,20px,0);transform:translate3d(0,20px,0)}to{opacity:0;-webkit-transform:translate3d(0,-2000px,0);transform:translate3d(0,-2000px,0)}}@keyframes bounceOutUp{20%{transform:translate3d(0,-10px,0)}40%,45%{opacity:1;-webkit-transform:translate3d(0,20px,0);transform:translate3d(0,20px,0)}to{opacity:0;-webkit-transform:translate3d(0,-2000px,0);transform:translate3d(0,-2000px,0)}}
 .bounceOutUp{-webkit-animation-name:bounceOutUp;animation-name:bounceOutUp}@-webkit-keyframes fadeIn{0%{opacity:0}to{opacity:1}}@keyframes fadeIn{0%{opacity:0}to{opacity:1}}
 .fadeIn{-webkit-animation-name:fadeIn;animation-name:fadeIn}@-webkit-keyframes fadeInDown{0%{opacity:0;-webkit-transform:translate3d(0,-100%,0);transform:translate3d(0,-100%,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}@keyframes fadeInDown{0%{opacity:0;-webkit-transform:translate3d(0,-100%,0);transform:translate3d(0,-100%,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}
 .fadeInDown{-webkit-animation-name:fadeInDown;animation-name:fadeInDown}@-webkit-keyframes fadeInDownBig{0%{opacity:0;-webkit-transform:translate3d(0,-2000px,0);transform:translate3d(0,-2000px,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}@keyframes fadeInDownBig{0%{opacity:0;-webkit-transform:translate3d(0,-2000px,0);transform:translate3d(0,-2000px,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}
 .fadeInDownBig{-webkit-animation-name:fadeInDownBig;animation-name:fadeInDownBig}@-webkit-keyframes fadeInLeft{0%{opacity:0;-webkit-transform:translate3d(-100%,0,0);transform:translate3d(-100%,0,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}@keyframes fadeInLeft{0%{opacity:0;-webkit-transform:translate3d(-100%,0,0);transform:translate3d(-100%,0,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}
 .fadeInLeft{-webkit-animation-name:fadeInLeft;animation-name:fadeInLeft}@-webkit-keyframes fadeInLeftBig{0%{opacity:0;-webkit-transform:translate3d(-2000px,0,0);transform:translate3d(-2000px,0,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}@keyframes fadeInLeftBig{0%{opacity:0;-webkit-transform:translate3d(-2000px,0,0);transform:translate3d(-2000px,0,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}
 .fadeInLeftBig{-webkit-animation-name:fadeInLeftBig;animation-name:fadeInLeftBig}@-webkit-keyframes fadeInRight{0%{opacity:0;-webkit-transform:translate3d(100%,0,0);transform:translate3d(100%,0,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}@keyframes fadeInRight{0%{opacity:0;-webkit-transform:translate3d(100%,0,0);transform:translate3d(100%,0,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}
 .fadeInRight{-webkit-animation-name:fadeInRight;animation-name:fadeInRight}@-webkit-keyframes fadeInRightBig{0%{opacity:0;-webkit-transform:translate3d(2000px,0,0);transform:translate3d(2000px,0,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}@keyframes fadeInRightBig{0%{opacity:0;-webkit-transform:translate3d(2000px,0,0);transform:translate3d(2000px,0,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}
 .fadeInRightBig{-webkit-animation-name:fadeInRightBig;animation-name:fadeInRightBig}@-webkit-keyframes fadeInUp{0%{opacity:0;-webkit-transform:translate3d(0,100%,0);transform:translate3d(0,100%,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}@keyframes fadeInUp{0%{opacity:0;-webkit-transform:translate3d(0,100%,0);transform:translate3d(0,100%,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}
 .fadeInUp{-webkit-animation-name:fadeInUp;animation-name:fadeInUp}@-webkit-keyframes fadeInUpBig{0%{opacity:0;-webkit-transform:translate3d(0,2000px,0);transform:translate3d(0,2000px,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}@keyframes fadeInUpBig{0%{opacity:0;-webkit-transform:translate3d(0,2000px,0);transform:translate3d(0,2000px,0)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}
 .fadeInUpBig{-webkit-animation-name:fadeInUpBig;animation-name:fadeInUpBig}@-webkit-keyframes fadeOut{0%{opacity:1}to{opacity:0}}@keyframes fadeOut{0%{opacity:1}to{opacity:0}}
 .fadeOut{-webkit-animation-name:fadeOut;animation-name:fadeOut}@-webkit-keyframes fadeOutDown{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,100%,0);transform:translate3d(0,100%,0)}}@keyframes fadeOutDown{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,100%,0);transform:translate3d(0,100%,0)}}
 .fadeOutDown{-webkit-animation-name:fadeOutDown;animation-name:fadeOutDown}@-webkit-keyframes fadeOutDownBig{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,2000px,0);transform:translate3d(0,2000px,0)}}@keyframes fadeOutDownBig{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,2000px,0);transform:translate3d(0,2000px,0)}}
 .fadeOutDownBig{-webkit-animation-name:fadeOutDownBig;animation-name:fadeOutDownBig}@-webkit-keyframes fadeOutLeft{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(-100%,0,0);transform:translate3d(-100%,0,0)}}@keyframes fadeOutLeft{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(-100%,0,0);transform:translate3d(-100%,0,0)}}
 .fadeOutLeft{-webkit-animation-name:fadeOutLeft;animation-name:fadeOutLeft}@-webkit-keyframes fadeOutLeftBig{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(-2000px,0,0);transform:translate3d(-2000px,0,0)}}@keyframes fadeOutLeftBig{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(-2000px,0,0);transform:translate3d(-2000px,0,0)}}
 .fadeOutLeftBig{-webkit-animation-name:fadeOutLeftBig;animation-name:fadeOutLeftBig}@-webkit-keyframes fadeOutRight{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(100%,0,0);transform:translate3d(100%,0,0)}}@keyframes fadeOutRight{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(100%,0,0);transform:translate3d(100%,0,0)}}
 .fadeOutRight{-webkit-animation-name:fadeOutRight;animation-name:fadeOutRight}@-webkit-keyframes fadeOutRightBig{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(2000px,0,0);transform:translate3d(2000px,0,0)}}@keyframes fadeOutRightBig{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(2000px,0,0);transform:translate3d(2000px,0,0)}}
 .fadeOutRightBig{-webkit-animation-name:fadeOutRightBig;animation-name:fadeOutRightBig}@-webkit-keyframes fadeOutUp{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,-100%,0);transform:translate3d(0,-100%,0)}}@keyframes fadeOutUp{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,-100%,0);transform:translate3d(0,-100%,0)}}
 .fadeOutUp{-webkit-animation-name:fadeOutUp;animation-name:fadeOutUp}@-webkit-keyframes fadeOutUpBig{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,-2000px,0);transform:translate3d(0,-2000px,0)}}@keyframes fadeOutUpBig{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,-2000px,0);transform:translate3d(0,-2000px,0)}}
 .fadeOutUpBig{-webkit-animation-name:fadeOutUpBig;animation-name:fadeOutUpBig}@-webkit-keyframes flip{0%{-webkit-animation-timing-function:ease-out;animation-timing-function:ease-out;-webkit-transform:perspective(400px) scaleX(1) translateZ(0) rotateY(-1turn);transform:perspective(400px) scaleX(1) translateZ(0) rotateY(-1turn)}40%{-webkit-animation-timing-function:ease-out;animation-timing-function:ease-out;-webkit-transform:perspective(400px) scaleX(1) translateZ(150px) rotateY(-190deg);transform:perspective(400px) scaleX(1) translateZ(150px) rotateY(-190deg)}50%{-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in;-webkit-transform:perspective(400px) scaleX(1) translateZ(150px) rotateY(-170deg);transform:perspective(400px) scaleX(1) translateZ(150px) rotateY(-170deg)}80%{-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in;-webkit-transform:perspective(400px) scale3d(.95,.95,.95) translateZ(0) rotateY(0deg);transform:perspective(400px) scale3d(.95,.95,.95) translateZ(0) rotateY(0deg)}to{-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in;-webkit-transform:perspective(400px) scaleX(1) translateZ(0) rotateY(0deg);transform:perspective(400px) scaleX(1) translateZ(0) rotateY(0deg)}}@keyframes flip{0%{-webkit-animation-timing-function:ease-out;animation-timing-function:ease-out;-webkit-transform:perspective(400px) scaleX(1) translateZ(0) rotateY(-1turn);transform:perspective(400px) scaleX(1) translateZ(0) rotateY(-1turn)}40%{-webkit-animation-timing-function:ease-out;animation-timing-function:ease-out;-webkit-transform:perspective(400px) scaleX(1) translateZ(150px) rotateY(-190deg);transform:perspective(400px) scaleX(1) translateZ(150px) rotateY(-190deg)}50%{-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in;-webkit-transform:perspective(400px) scaleX(1) translateZ(150px) rotateY(-170deg);transform:perspective(400px) scaleX(1) translateZ(150px) rotateY(-170deg)}80%{-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in;-webkit-transform:perspective(400px) scale3d(.95,.95,.95) translateZ(0) rotateY(0deg);transform:perspective(400px) scale3d(.95,.95,.95) translateZ(0) rotateY(0deg)}to{-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in;-webkit-transform:perspective(400px) scaleX(1) translateZ(0) rotateY(0deg);transform:perspective(400px) scaleX(1) translateZ(0) rotateY(0deg)}}
 .animated.flip{-webkit-animation-name:flip;animation-name:flip;-webkit-backface-visibility:visible;backface-visibility:visible}@-webkit-keyframes flipInX{0%{-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in;opacity:0;-webkit-transform:perspective(400px) rotateX(90deg);transform:perspective(400px) rotateX(90deg)}40%{-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in;-webkit-transform:perspective(400px) rotateX(-20deg);transform:perspective(400px) rotateX(-20deg)}60%{opacity:1;-webkit-transform:perspective(400px) rotateX(10deg);transform:perspective(400px) rotateX(10deg)}80%{transform:perspective(400px) rotateX(-5deg)}to{transform:perspective(400px)}}@keyframes flipInX{0%{-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in;opacity:0;-webkit-transform:perspective(400px) rotateX(90deg);transform:perspective(400px) rotateX(90deg)}40%{-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in;-webkit-transform:perspective(400px) rotateX(-20deg);transform:perspective(400px) rotateX(-20deg)}60%{opacity:1;-webkit-transform:perspective(400px) rotateX(10deg);transform:perspective(400px) rotateX(10deg)}80%{transform:perspective(400px) rotateX(-5deg)}to{transform:perspective(400px)}}
 .flipInX{-webkit-animation-name:flipInX;animation-name:flipInX;-webkit-backface-visibility:visible!important;backface-visibility:visible!important}@-webkit-keyframes flipInY{0%{-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in;opacity:0;-webkit-transform:perspective(400px) rotateY(90deg);transform:perspective(400px) rotateY(90deg)}40%{-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in;-webkit-transform:perspective(400px) rotateY(-20deg);transform:perspective(400px) rotateY(-20deg)}60%{opacity:1;-webkit-transform:perspective(400px) rotateY(10deg);transform:perspective(400px) rotateY(10deg)}80%{transform:perspective(400px) rotateY(-5deg)}to{transform:perspective(400px)}}@keyframes flipInY{0%{-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in;opacity:0;-webkit-transform:perspective(400px) rotateY(90deg);transform:perspective(400px) rotateY(90deg)}40%{-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in;-webkit-transform:perspective(400px) rotateY(-20deg);transform:perspective(400px) rotateY(-20deg)}60%{opacity:1;-webkit-transform:perspective(400px) rotateY(10deg);transform:perspective(400px) rotateY(10deg)}80%{transform:perspective(400px) rotateY(-5deg)}to{transform:perspective(400px)}}
 .flipInY{-webkit-animation-name:flipInY;animation-name:flipInY;-webkit-backface-visibility:visible!important;backface-visibility:visible!important}@-webkit-keyframes flipOutX{0%{transform:perspective(400px)}30%{opacity:1;-webkit-transform:perspective(400px) rotateX(-20deg);transform:perspective(400px) rotateX(-20deg)}to{opacity:0;-webkit-transform:perspective(400px) rotateX(90deg);transform:perspective(400px) rotateX(90deg)}}@keyframes flipOutX{0%{transform:perspective(400px)}30%{opacity:1;-webkit-transform:perspective(400px) rotateX(-20deg);transform:perspective(400px) rotateX(-20deg)}to{opacity:0;-webkit-transform:perspective(400px) rotateX(90deg);transform:perspective(400px) rotateX(90deg)}}
 .flipOutX{-webkit-animation-duration:.75s;animation-duration:.75s;-webkit-animation-name:flipOutX;animation-name:flipOutX;-webkit-backface-visibility:visible!important;backface-visibility:visible!important}@-webkit-keyframes flipOutY{0%{transform:perspective(400px)}30%{opacity:1;-webkit-transform:perspective(400px) rotateY(-15deg);transform:perspective(400px) rotateY(-15deg)}to{opacity:0;-webkit-transform:perspective(400px) rotateY(90deg);transform:perspective(400px) rotateY(90deg)}}@keyframes flipOutY{0%{transform:perspective(400px)}30%{opacity:1;-webkit-transform:perspective(400px) rotateY(-15deg);transform:perspective(400px) rotateY(-15deg)}to{opacity:0;-webkit-transform:perspective(400px) rotateY(90deg);transform:perspective(400px) rotateY(90deg)}}
 .flipOutY{-webkit-animation-duration:.75s;animation-duration:.75s;-webkit-animation-name:flipOutY;animation-name:flipOutY;-webkit-backface-visibility:visible!important;backface-visibility:visible!important}@-webkit-keyframes lightSpeedIn{0%{opacity:0;-webkit-transform:translate3d(100%,0,0) skewX(-30deg);transform:translate3d(100%,0,0) skewX(-30deg)}60%{opacity:1;-webkit-transform:skewX(20deg);transform:skewX(20deg)}80%{transform:skewX(-5deg)}to{transform:translateZ(0)}}@keyframes lightSpeedIn{0%{opacity:0;-webkit-transform:translate3d(100%,0,0) skewX(-30deg);transform:translate3d(100%,0,0) skewX(-30deg)}60%{opacity:1;-webkit-transform:skewX(20deg);transform:skewX(20deg)}80%{transform:skewX(-5deg)}to{transform:translateZ(0)}}
 .lightSpeedIn{-webkit-animation-name:lightSpeedIn;animation-name:lightSpeedIn;-webkit-animation-timing-function:ease-out;animation-timing-function:ease-out}@-webkit-keyframes lightSpeedOut{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(100%,0,0) skewX(30deg);transform:translate3d(100%,0,0) skewX(30deg)}}@keyframes lightSpeedOut{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(100%,0,0) skewX(30deg);transform:translate3d(100%,0,0) skewX(30deg)}}
 .lightSpeedOut{-webkit-animation-name:lightSpeedOut;animation-name:lightSpeedOut;-webkit-animation-timing-function:ease-in;animation-timing-function:ease-in}@-webkit-keyframes rotateIn{0%{opacity:0;-webkit-transform:rotate(-200deg);transform:rotate(-200deg);-webkit-transform-origin:center;transform-origin:center}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0);-webkit-transform-origin:center;transform-origin:center}}@keyframes rotateIn{0%{opacity:0;-webkit-transform:rotate(-200deg);transform:rotate(-200deg);-webkit-transform-origin:center;transform-origin:center}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0);-webkit-transform-origin:center;transform-origin:center}}
 .rotateIn{-webkit-animation-name:rotateIn;animation-name:rotateIn}@-webkit-keyframes rotateInDownLeft{0%{opacity:0;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);-webkit-transform-origin:left bottom;transform-origin:left bottom}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0);-webkit-transform-origin:left bottom;transform-origin:left bottom}}@keyframes rotateInDownLeft{0%{opacity:0;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);-webkit-transform-origin:left bottom;transform-origin:left bottom}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0);-webkit-transform-origin:left bottom;transform-origin:left bottom}}
 .rotateInDownLeft{-webkit-animation-name:rotateInDownLeft;animation-name:rotateInDownLeft}@-webkit-keyframes rotateInDownRight{0%{opacity:0;-webkit-transform:rotate(45deg);transform:rotate(45deg);-webkit-transform-origin:right bottom;transform-origin:right bottom}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0);-webkit-transform-origin:right bottom;transform-origin:right bottom}}@keyframes rotateInDownRight{0%{opacity:0;-webkit-transform:rotate(45deg);transform:rotate(45deg);-webkit-transform-origin:right bottom;transform-origin:right bottom}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0);-webkit-transform-origin:right bottom;transform-origin:right bottom}}
 .rotateInDownRight{-webkit-animation-name:rotateInDownRight;animation-name:rotateInDownRight}@-webkit-keyframes rotateInUpLeft{0%{opacity:0;-webkit-transform:rotate(45deg);transform:rotate(45deg);-webkit-transform-origin:left bottom;transform-origin:left bottom}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0);-webkit-transform-origin:left bottom;transform-origin:left bottom}}@keyframes rotateInUpLeft{0%{opacity:0;-webkit-transform:rotate(45deg);transform:rotate(45deg);-webkit-transform-origin:left bottom;transform-origin:left bottom}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0);-webkit-transform-origin:left bottom;transform-origin:left bottom}}
 .rotateInUpLeft{-webkit-animation-name:rotateInUpLeft;animation-name:rotateInUpLeft}@-webkit-keyframes rotateInUpRight{0%{opacity:0;-webkit-transform:rotate(-90deg);transform:rotate(-90deg);-webkit-transform-origin:right bottom;transform-origin:right bottom}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0);-webkit-transform-origin:right bottom;transform-origin:right bottom}}@keyframes rotateInUpRight{0%{opacity:0;-webkit-transform:rotate(-90deg);transform:rotate(-90deg);-webkit-transform-origin:right bottom;transform-origin:right bottom}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0);-webkit-transform-origin:right bottom;transform-origin:right bottom}}
 .rotateInUpRight{-webkit-animation-name:rotateInUpRight;animation-name:rotateInUpRight}@-webkit-keyframes rotateOut{0%{opacity:1;-webkit-transform-origin:center;transform-origin:center}to{opacity:0;-webkit-transform:rotate(200deg);transform:rotate(200deg);-webkit-transform-origin:center;transform-origin:center}}@keyframes rotateOut{0%{opacity:1;-webkit-transform-origin:center;transform-origin:center}to{opacity:0;-webkit-transform:rotate(200deg);transform:rotate(200deg);-webkit-transform-origin:center;transform-origin:center}}
 .rotateOut{-webkit-animation-name:rotateOut;animation-name:rotateOut}@-webkit-keyframes rotateOutDownLeft{0%{opacity:1;-webkit-transform-origin:left bottom;transform-origin:left bottom}to{opacity:0;-webkit-transform:rotate(45deg);transform:rotate(45deg);-webkit-transform-origin:left bottom;transform-origin:left bottom}}@keyframes rotateOutDownLeft{0%{opacity:1;-webkit-transform-origin:left bottom;transform-origin:left bottom}to{opacity:0;-webkit-transform:rotate(45deg);transform:rotate(45deg);-webkit-transform-origin:left bottom;transform-origin:left bottom}}
 .rotateOutDownLeft{-webkit-animation-name:rotateOutDownLeft;animation-name:rotateOutDownLeft}@-webkit-keyframes rotateOutDownRight{0%{opacity:1;-webkit-transform-origin:right bottom;transform-origin:right bottom}to{opacity:0;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);-webkit-transform-origin:right bottom;transform-origin:right bottom}}@keyframes rotateOutDownRight{0%{opacity:1;-webkit-transform-origin:right bottom;transform-origin:right bottom}to{opacity:0;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);-webkit-transform-origin:right bottom;transform-origin:right bottom}}
 .rotateOutDownRight{-webkit-animation-name:rotateOutDownRight;animation-name:rotateOutDownRight}@-webkit-keyframes rotateOutUpLeft{0%{opacity:1;-webkit-transform-origin:left bottom;transform-origin:left bottom}to{opacity:0;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);-webkit-transform-origin:left bottom;transform-origin:left bottom}}@keyframes rotateOutUpLeft{0%{opacity:1;-webkit-transform-origin:left bottom;transform-origin:left bottom}to{opacity:0;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);-webkit-transform-origin:left bottom;transform-origin:left bottom}}
 .rotateOutUpLeft{-webkit-animation-name:rotateOutUpLeft;animation-name:rotateOutUpLeft}@-webkit-keyframes rotateOutUpRight{0%{opacity:1;-webkit-transform-origin:right bottom;transform-origin:right bottom}to{opacity:0;-webkit-transform:rotate(90deg);transform:rotate(90deg);-webkit-transform-origin:right bottom;transform-origin:right bottom}}@keyframes rotateOutUpRight{0%{opacity:1;-webkit-transform-origin:right bottom;transform-origin:right bottom}to{opacity:0;-webkit-transform:rotate(90deg);transform:rotate(90deg);-webkit-transform-origin:right bottom;transform-origin:right bottom}}
 .rotateOutUpRight{-webkit-animation-name:rotateOutUpRight;animation-name:rotateOutUpRight}@-webkit-keyframes hinge{0%{-webkit-animation-timing-function:ease-in-out;animation-timing-function:ease-in-out;-webkit-transform-origin:top left;transform-origin:top left}20%,60%{-webkit-animation-timing-function:ease-in-out;animation-timing-function:ease-in-out;-webkit-transform:rotate(80deg);transform:rotate(80deg);-webkit-transform-origin:top left;transform-origin:top left}40%,80%{-webkit-animation-timing-function:ease-in-out;animation-timing-function:ease-in-out;opacity:1;-webkit-transform:rotate(60deg);transform:rotate(60deg);-webkit-transform-origin:top left;transform-origin:top left}to{opacity:0;-webkit-transform:translate3d(0,700px,0);transform:translate3d(0,700px,0)}}@keyframes hinge{0%{-webkit-animation-timing-function:ease-in-out;animation-timing-function:ease-in-out;-webkit-transform-origin:top left;transform-origin:top left}20%,60%{-webkit-animation-timing-function:ease-in-out;animation-timing-function:ease-in-out;-webkit-transform:rotate(80deg);transform:rotate(80deg);-webkit-transform-origin:top left;transform-origin:top left}40%,80%{-webkit-animation-timing-function:ease-in-out;animation-timing-function:ease-in-out;opacity:1;-webkit-transform:rotate(60deg);transform:rotate(60deg);-webkit-transform-origin:top left;transform-origin:top left}to{opacity:0;-webkit-transform:translate3d(0,700px,0);transform:translate3d(0,700px,0)}}
 .hinge{-webkit-animation-duration:2s;animation-duration:2s;-webkit-animation-name:hinge;animation-name:hinge}@-webkit-keyframes jackInTheBox{0%{opacity:0;-webkit-transform:scale(.1) rotate(30deg);transform:scale(.1) rotate(30deg);-webkit-transform-origin:center bottom;transform-origin:center bottom}50%{transform:rotate(-10deg)}70%{transform:rotate(3deg)}to{opacity:1;-webkit-transform:scale(1);transform:scale(1)}}@keyframes jackInTheBox{0%{opacity:0;-webkit-transform:scale(.1) rotate(30deg);transform:scale(.1) rotate(30deg);-webkit-transform-origin:center bottom;transform-origin:center bottom}50%{transform:rotate(-10deg)}70%{transform:rotate(3deg)}to{opacity:1;-webkit-transform:scale(1);transform:scale(1)}}
 .jackInTheBox{-webkit-animation-name:jackInTheBox;animation-name:jackInTheBox}@-webkit-keyframes rollIn{0%{opacity:0;-webkit-transform:translate3d(-100%,0,0) rotate(-120deg);transform:translate3d(-100%,0,0) rotate(-120deg)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}@keyframes rollIn{0%{opacity:0;-webkit-transform:translate3d(-100%,0,0) rotate(-120deg);transform:translate3d(-100%,0,0) rotate(-120deg)}to{opacity:1;-webkit-transform:translateZ(0);transform:translateZ(0)}}
 .rollIn{-webkit-animation-name:rollIn;animation-name:rollIn}@-webkit-keyframes rollOut{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(100%,0,0) rotate(120deg);transform:translate3d(100%,0,0) rotate(120deg)}}@keyframes rollOut{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(100%,0,0) rotate(120deg);transform:translate3d(100%,0,0) rotate(120deg)}}
 .rollOut{-webkit-animation-name:rollOut;animation-name:rollOut}@-webkit-keyframes zoomIn{0%{opacity:0;-webkit-transform:scale3d(.3,.3,.3);transform:scale3d(.3,.3,.3)}50%{opacity:1}}@keyframes zoomIn{0%{opacity:0;-webkit-transform:scale3d(.3,.3,.3);transform:scale3d(.3,.3,.3)}50%{opacity:1}}
 .zoomIn{-webkit-animation-name:zoomIn;animation-name:zoomIn}@-webkit-keyframes zoomInDown{0%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(0,-1000px,0);transform:scale3d(.1,.1,.1) translate3d(0,-1000px,0)}60%{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(0,60px,0);transform:scale3d(.475,.475,.475) translate3d(0,60px,0)}}@keyframes zoomInDown{0%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(0,-1000px,0);transform:scale3d(.1,.1,.1) translate3d(0,-1000px,0)}60%{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(0,60px,0);transform:scale3d(.475,.475,.475) translate3d(0,60px,0)}}
 .zoomInDown{-webkit-animation-name:zoomInDown;animation-name:zoomInDown}@-webkit-keyframes zoomInLeft{0%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(-1000px,0,0);transform:scale3d(.1,.1,.1) translate3d(-1000px,0,0)}60%{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(10px,0,0);transform:scale3d(.475,.475,.475) translate3d(10px,0,0)}}@keyframes zoomInLeft{0%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(-1000px,0,0);transform:scale3d(.1,.1,.1) translate3d(-1000px,0,0)}60%{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(10px,0,0);transform:scale3d(.475,.475,.475) translate3d(10px,0,0)}}
 .zoomInLeft{-webkit-animation-name:zoomInLeft;animation-name:zoomInLeft}@-webkit-keyframes zoomInRight{0%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(1000px,0,0);transform:scale3d(.1,.1,.1) translate3d(1000px,0,0)}60%{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(-10px,0,0);transform:scale3d(.475,.475,.475) translate3d(-10px,0,0)}}@keyframes zoomInRight{0%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(1000px,0,0);transform:scale3d(.1,.1,.1) translate3d(1000px,0,0)}60%{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(-10px,0,0);transform:scale3d(.475,.475,.475) translate3d(-10px,0,0)}}
 .zoomInRight{-webkit-animation-name:zoomInRight;animation-name:zoomInRight}@-webkit-keyframes zoomInUp{0%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(0,1000px,0);transform:scale3d(.1,.1,.1) translate3d(0,1000px,0)}60%{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(0,-60px,0);transform:scale3d(.475,.475,.475) translate3d(0,-60px,0)}}@keyframes zoomInUp{0%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(0,1000px,0);transform:scale3d(.1,.1,.1) translate3d(0,1000px,0)}60%{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(0,-60px,0);transform:scale3d(.475,.475,.475) translate3d(0,-60px,0)}}
 .zoomInUp{-webkit-animation-name:zoomInUp;animation-name:zoomInUp}@-webkit-keyframes zoomOut{0%{opacity:1}50%{opacity:0;-webkit-transform:scale3d(.3,.3,.3);transform:scale3d(.3,.3,.3)}to{opacity:0}}@keyframes zoomOut{0%{opacity:1}50%{opacity:0;-webkit-transform:scale3d(.3,.3,.3);transform:scale3d(.3,.3,.3)}to{opacity:0}}
 .zoomOut{-webkit-animation-name:zoomOut;animation-name:zoomOut}@-webkit-keyframes zoomOutDown{40%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(0,-60px,0);transform:scale3d(.475,.475,.475) translate3d(0,-60px,0)}to{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(0,2000px,0);transform:scale3d(.1,.1,.1) translate3d(0,2000px,0);-webkit-transform-origin:center bottom;transform-origin:center bottom}}@keyframes zoomOutDown{40%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(0,-60px,0);transform:scale3d(.475,.475,.475) translate3d(0,-60px,0)}to{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(0,2000px,0);transform:scale3d(.1,.1,.1) translate3d(0,2000px,0);-webkit-transform-origin:center bottom;transform-origin:center bottom}}
 .zoomOutDown{-webkit-animation-name:zoomOutDown;animation-name:zoomOutDown}@-webkit-keyframes zoomOutLeft{40%{opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(42px,0,0);transform:scale3d(.475,.475,.475) translate3d(42px,0,0)}to{opacity:0;-webkit-transform:scale(.1) translate3d(-2000px,0,0);transform:scale(.1) translate3d(-2000px,0,0);-webkit-transform-origin:left center;transform-origin:left center}}@keyframes zoomOutLeft{40%{opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(42px,0,0);transform:scale3d(.475,.475,.475) translate3d(42px,0,0)}to{opacity:0;-webkit-transform:scale(.1) translate3d(-2000px,0,0);transform:scale(.1) translate3d(-2000px,0,0);-webkit-transform-origin:left center;transform-origin:left center}}
 .zoomOutLeft{-webkit-animation-name:zoomOutLeft;animation-name:zoomOutLeft}@-webkit-keyframes zoomOutRight{40%{opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(-42px,0,0);transform:scale3d(.475,.475,.475) translate3d(-42px,0,0)}to{opacity:0;-webkit-transform:scale(.1) translate3d(2000px,0,0);transform:scale(.1) translate3d(2000px,0,0);-webkit-transform-origin:right center;transform-origin:right center}}@keyframes zoomOutRight{40%{opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(-42px,0,0);transform:scale3d(.475,.475,.475) translate3d(-42px,0,0)}to{opacity:0;-webkit-transform:scale(.1) translate3d(2000px,0,0);transform:scale(.1) translate3d(2000px,0,0);-webkit-transform-origin:right center;transform-origin:right center}}
 .zoomOutRight{-webkit-animation-name:zoomOutRight;animation-name:zoomOutRight}@-webkit-keyframes zoomOutUp{40%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(0,60px,0);transform:scale3d(.475,.475,.475) translate3d(0,60px,0)}to{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(0,-2000px,0);transform:scale3d(.1,.1,.1) translate3d(0,-2000px,0);-webkit-transform-origin:center bottom;transform-origin:center bottom}}@keyframes zoomOutUp{40%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(0,60px,0);transform:scale3d(.475,.475,.475) translate3d(0,60px,0)}to{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(0,-2000px,0);transform:scale3d(.1,.1,.1) translate3d(0,-2000px,0);-webkit-transform-origin:center bottom;transform-origin:center bottom}}
 .zoomOutUp{-webkit-animation-name:zoomOutUp;animation-name:zoomOutUp}@-webkit-keyframes slideInDown{0%{transform:translate3d(0,-100%,0);visibility:visible}to{transform:translateZ(0)}}@keyframes slideInDown{0%{transform:translate3d(0,-100%,0);visibility:visible}to{transform:translateZ(0)}}
 .slideInDown{-webkit-animation-name:slideInDown;animation-name:slideInDown}@-webkit-keyframes slideInLeft{0%{transform:translate3d(-100%,0,0);visibility:visible}to{transform:translateZ(0)}}@keyframes slideInLeft{0%{transform:translate3d(-100%,0,0);visibility:visible}to{transform:translateZ(0)}}
 .slideInLeft{-webkit-animation-name:slideInLeft;animation-name:slideInLeft}@-webkit-keyframes slideInRight{0%{transform:translate3d(100%,0,0);visibility:visible}to{transform:translateZ(0)}}@keyframes slideInRight{0%{transform:translate3d(100%,0,0);visibility:visible}to{transform:translateZ(0)}}
 .slideInRight{-webkit-animation-name:slideInRight;animation-name:slideInRight}@-webkit-keyframes slideInUp{0%{transform:translate3d(0,100%,0);visibility:visible}to{transform:translateZ(0)}}@keyframes slideInUp{0%{transform:translate3d(0,100%,0);visibility:visible}to{transform:translateZ(0)}}
 .slideInUp{-webkit-animation-name:slideInUp;animation-name:slideInUp}@-webkit-keyframes slideOutDown{0%{transform:translateZ(0)}to{transform:translate3d(0,100%,0);visibility:hidden}}@keyframes slideOutDown{0%{transform:translateZ(0)}to{transform:translate3d(0,100%,0);visibility:hidden}}
 .slideOutDown{-webkit-animation-name:slideOutDown;animation-name:slideOutDown}@-webkit-keyframes slideOutLeft{0%{transform:translateZ(0)}to{transform:translate3d(-100%,0,0);visibility:hidden}}@keyframes slideOutLeft{0%{transform:translateZ(0)}to{transform:translate3d(-100%,0,0);visibility:hidden}}
 .slideOutLeft{-webkit-animation-name:slideOutLeft;animation-name:slideOutLeft}@-webkit-keyframes slideOutRight{0%{transform:translateZ(0)}to{transform:translate3d(100%,0,0);visibility:hidden}}@keyframes slideOutRight{0%{transform:translateZ(0)}to{transform:translate3d(100%,0,0);visibility:hidden}}
 .slideOutRight{-webkit-animation-name:slideOutRight;animation-name:slideOutRight}@-webkit-keyframes slideOutUp{0%{transform:translateZ(0)}to{transform:translate3d(0,-100%,0);visibility:hidden}}@keyframes slideOutUp{0%{transform:translateZ(0)}to{transform:translate3d(0,-100%,0);visibility:hidden}}@keyframes headShake{0%{transform:translateX(0)}6.5%{transform:translateX(-6px) rotateY(-9deg)}18.5%{transform:translateX(5px) rotateY(7deg)}31.5%{transform:translateX(-3px) rotateY(-5deg)}43.5%{transform:translateX(2px) rotateY(3deg)}50%{transform:translateX(0)}}
 .headShake{-webkit-animation-name:headShake;animation-name:headShake;-webkit-animation-timing-function:ease-in-out;animation-timing-function:ease-in-out}
 .slideOutUp{-webkit-animation-name:slideOutUp;animation-name:slideOutUp}
 .animated{-webkit-animation-duration:1s;animation-duration:1s;-webkit-animation-fill-mode:both;animation-fill-mode:both}
 .animated.infinite{-webkit-animation-iteration-count:infinite;animation-iteration-count:infinite}
 .animated.delay-1s{-webkit-animation-delay:1s;animation-delay:1s}
 .animated.delay-2s{-webkit-animation-delay:2s;animation-delay:2s}
 .animated.delay-3s{-webkit-animation-delay:3s;animation-delay:3s}
 .animated.delay-4s{-webkit-animation-delay:4s;animation-delay:4s}
 .animated.delay-5s{-webkit-animation-delay:5s;animation-delay:5s}
 .animated.fast{-webkit-animation-duration:.8s;animation-duration:.8s}
 .animated.faster{-webkit-animation-duration:.5s;animation-duration:.5s}
 .animated.slow{-webkit-animation-duration:2s;animation-duration:2s}
 .animated.slower{-webkit-animation-duration:3s;animation-duration:3s}@media (prefers-reduced-motion){
 .animated{-webkit-animation:unset!important;animation:unset!important;-webkit-transition:none!important;transition:none!important}}@-webkit-keyframes hFlipInBackX{0%{transform:rotateY(-180deg)}to{transform:rotateY(0deg)}}@keyframes hFlipInBackX{0%{transform:rotateY(-180deg)}to{transform:rotateY(0deg)}}@-webkit-keyframes hFlipOutBackX{0%{transform:rotateY(0deg)}to{transform:rotateY(-180deg)}}@keyframes hFlipOutBackX{0%{transform:rotateY(0deg)}to{transform:rotateY(-180deg)}}@-webkit-keyframes hFlipInFrontX{0%{transform:rotateY(0deg)}to{transform:rotateY(180deg)}}@keyframes hFlipInFrontX{0%{transform:rotateY(0deg)}to{transform:rotateY(180deg)}}@-webkit-keyframes hFlipOutFrontX{0%{transform:rotateY(180deg)}to{transform:rotateY(0deg)}}@keyframes hFlipOutFrontX{0%{transform:rotateY(180deg)}to{transform:rotateY(0deg)}}@-webkit-keyframes hFlipInBackY{0%{transform:rotateX(180deg)}to{transform:rotateX(0deg)}}@keyframes hFlipInBackY{0%{transform:rotateX(180deg)}to{transform:rotateX(0deg)}}@-webkit-keyframes hFlipOutBackY{0%{transform:rotateX(0deg)}to{transform:rotateX(180deg)}}@keyframes hFlipOutBackY{0%{transform:rotateX(0deg)}to{transform:rotateX(180deg)}}@-webkit-keyframes hFlipInFrontY{0%{transform:rotateX(0deg)}to{transform:rotateX(180deg)}}@keyframes hFlipInFrontY{0%{transform:rotateX(0deg)}to{transform:rotateX(180deg)}}@-webkit-keyframes hFlipOutFrontY{0%{transform:rotateX(180deg)}to{transform:rotateX(0deg)}}@keyframes hFlipOutFrontY{0%{transform:rotateX(180deg)}to{transform:rotateX(0deg)}}
 .hFlipInBackX{-webkit-animation-name:hFlipInBackX;animation-name:hFlipInBackX}
 .hFlipOutBackX{-webkit-animation-name:hFlipOutBackX;animation-name:hFlipOutBackX}
 .hFlipInFrontX{-webkit-animation-name:hFlipInFrontX;animation-name:hFlipInFrontX}
 .hFlipOutFrontX{-webkit-animation-name:hFlipOutFrontX;animation-name:hFlipOutFrontX}
 .hFlipInBackY{-webkit-animation-name:hFlipInBackY;animation-name:hFlipInBackY}
 .hFlipOutBackY{-webkit-animation-name:hFlipOutBackY;animation-name:hFlipOutBackY}
 .hFlipInFrontY{-webkit-animation-name:hFlipInFrontY;animation-name:hFlipInFrontY}
 .hFlipOutFrontY{-webkit-animation-name:hFlipOutFrontY;animation-name:hFlipOutFrontY}
 .flip-container{perspective:1000px}
 .flip-container .flipper{overflow:visible!important;position:relative}
 .flip-container .flipper,
 .flip-container .flipper .back,
 .flip-container .flipper .front{transform-style:preserve-3d}
 .flip-container .back{z-index:9}
 .flip-container .front{z-index:10}
 .back,
 .front{-webkit-backface-visibility:hidden;backface-visibility:hidden}@media (-ms-high-contrast:active),(-ms-high-contrast:none){
 .content-swap .bounceIn,
 .content-swap .bounceInDown,
 .content-swap .bounceInLeft,
 .content-swap .bounceInRight,
 .content-swap .bounceInUp,
 .content-swap .hFlipInBackX,
 .content-swap .hFlipInBackY,
 .content-swap .rotateIn,
 .content-swap .rotateInDownLeft,
 .content-swap .rotateInDownRight,
 .content-swap .rotateInUpLeft,
 .content-swap .rotateInUpRight,
 .content-swap .slideInDown,
 .content-swap .slideInLeft,
 .content-swap .slideInRight,
 .content-swap .slideInUp,
 .content-swap .zoomIn,
 .content-swap .zoomInDown,
 .content-swap .zoomInLeft,
 .content-swap .zoomInRight,
 .content-swap .zoomInUp{-webkit-animation-name:fadeIn;animation-name:fadeIn}
 .content-swap .bounceOut,
 .content-swap .bounceOutDown,
 .content-swap .bounceOutLeft,
 .content-swap .bounceOutRight,
 .content-swap .bounceOutUp,
 .content-swap .hFlipOutBackX,
 .content-swap .hFlipOutBackY,
 .content-swap .rotateOut,
 .content-swap .rotateOutDownLeft,
 .content-swap .rotateOutDownRight,
 .content-swap .rotateOutUpLeft,
 .content-swap .rotateOutUpRight,
 .content-swap .slideOutDown,
 .content-swap .slideOutLeft,
 .content-swap .slideOutRight,
 .content-swap .slideOutUp,
 .content-swap .zoomOut,
 .content-swap .zoomOutDown,
 .content-swap .zoomOutLeft,
 .content-swap .zoomOutRight,
 .content-swap .zoomOutUp{-webkit-animation-name:fadeOut;animation-name:fadeOut}
 .content-swap .hFlipInFrontX,
 .content-swap .hFlipInFrontY,
 .content-swap .hFlipOutFrontX,
 .content-swap .hFlipOutFrontY{-webkit-animation-name:none;animation-name:none;z-index:0}}@supports (-ms-ime-align:auto){@-webkit-keyframes edge-force-rerender{0%{transform:translatez(0)}to{transform:translatez(1px)}}@keyframes edge-force-rerender{0%{transform:translatez(0)}to{transform:translatez(1px)}}
 .content-swap{-webkit-animation-delay:1s;animation-delay:1s;-webkit-animation-duration:.2s;animation-duration:.2s;-webkit-animation-name:edge-force-rerender;animation-name:edge-force-rerender}}@-webkit-keyframes slideOutDownNew{0%{transform:translateZ(0)}to{transform:translate3d(0,-100%,0);visibility:hidden}}@keyframes slideOutDownNew{0%{transform:translateZ(0)}to{transform:translate3d(0,-100%,0);visibility:hidden}}
 .wp-block-kubio-flipbox .slideOutDown{-webkit-animation-name:slideOutDownNew;animation-name:slideOutDownNew}@-webkit-keyframes slideOutUpNew{0%{transform:translateZ(0)}to{transform:translate3d(0,100%,0);visibility:hidden}}@keyframes slideOutUpNew{0%{transform:translateZ(0)}to{transform:translate3d(0,100%,0);visibility:hidden}}
 .wp-block-kubio-flipbox .slideOutUp{-webkit-animation-name:slideOutUpNew;animation-name:slideOutUpNew}@-webkit-keyframes zoomOutDownNew{40%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(0,60px,0);transform:scale3d(.475,.475,.475) translate3d(0,60px,0)}to{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(0,-2000px,0);transform:scale3d(.1,.1,.1) translate3d(0,-2000px,0);-webkit-transform-origin:center bottom;transform-origin:center bottom}}@keyframes zoomOutDownNew{40%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(0,60px,0);transform:scale3d(.475,.475,.475) translate3d(0,60px,0)}to{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(0,-2000px,0);transform:scale3d(.1,.1,.1) translate3d(0,-2000px,0);-webkit-transform-origin:center bottom;transform-origin:center bottom}}
 .wp-block-kubio-flipbox .zoomOutDown{-webkit-animation-name:zoomOutDownNew;animation-name:zoomOutDownNew}@-webkit-keyframes zoomOutUpNew{40%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(0,-60px,0);transform:scale3d(.475,.475,.475) translate3d(0,-60px,0)}to{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(0,2000px,0);transform:scale3d(.1,.1,.1) translate3d(0,2000px,0);-webkit-transform-origin:center bottom;transform-origin:center bottom}}@keyframes zoomOutUpNew{40%{-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19);opacity:1;-webkit-transform:scale3d(.475,.475,.475) translate3d(0,-60px,0);transform:scale3d(.475,.475,.475) translate3d(0,-60px,0)}to{-webkit-animation-timing-function:cubic-bezier(.175,.885,.32,1);animation-timing-function:cubic-bezier(.175,.885,.32,1);opacity:0;-webkit-transform:scale3d(.1,.1,.1) translate3d(0,2000px,0);transform:scale3d(.1,.1,.1) translate3d(0,2000px,0);-webkit-transform-origin:center bottom;transform-origin:center bottom}}
 .wp-block-kubio-flipbox .zoomOutUp{-webkit-animation-name:zoomOutUpNew;animation-name:zoomOutUpNew}@-webkit-keyframes rotateOutUpLeftNew{0%{opacity:1;-webkit-transform-origin:left bottom;transform-origin:left bottom}to{opacity:0;-webkit-transform:rotate(45deg);transform:rotate(45deg);-webkit-transform-origin:left bottom;transform-origin:left bottom}}@keyframes rotateOutUpLeftNew{0%{opacity:1;-webkit-transform-origin:left bottom;transform-origin:left bottom}to{opacity:0;-webkit-transform:rotate(45deg);transform:rotate(45deg);-webkit-transform-origin:left bottom;transform-origin:left bottom}}
 .wp-block-kubio-flipbox .rotateOutUpLeft{-webkit-animation-name:rotateOutUpLeftNew;animation-name:rotateOutUpLeftNew}@-webkit-keyframes rotateOutUpRightNew{0%{opacity:1;-webkit-transform-origin:right bottom;transform-origin:right bottom}to{opacity:0;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);-webkit-transform-origin:right bottom;transform-origin:right bottom}}@keyframes rotateOutUpRightNew{0%{opacity:1;-webkit-transform-origin:right bottom;transform-origin:right bottom}to{opacity:0;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);-webkit-transform-origin:right bottom;transform-origin:right bottom}}
 .wp-block-kubio-flipbox .rotateOutUpRight{-webkit-animation-name:rotateOutUpRightNew;animation-name:rotateOutUpRightNew}@-webkit-keyframes rotateOutDownLeftNew{0%{opacity:1;-webkit-transform-origin:left bottom;transform-origin:left bottom}to{opacity:0;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);-webkit-transform-origin:left bottom;transform-origin:left bottom}}@keyframes rotateOutDownLeftNew{0%{opacity:1;-webkit-transform-origin:left bottom;transform-origin:left bottom}to{opacity:0;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);-webkit-transform-origin:left bottom;transform-origin:left bottom}}
 .wp-block-kubio-flipbox .rotateOutDownLeft{-webkit-animation-name:rotateOutDownLeftNew;animation-name:rotateOutDownLeftNew}@-webkit-keyframes rotateOutDownRightNew{0%{opacity:1;-webkit-transform-origin:right bottom;transform-origin:right bottom}to{opacity:0;-webkit-transform:rotate(90deg);transform:rotate(90deg);-webkit-transform-origin:right bottom;transform-origin:right bottom}}@keyframes rotateOutDownRightNew{0%{opacity:1;-webkit-transform-origin:right bottom;transform-origin:right bottom}to{opacity:0;-webkit-transform:rotate(90deg);transform:rotate(90deg);-webkit-transform-origin:right bottom;transform-origin:right bottom}}
 .wp-block-kubio-flipbox .rotateOutDownRight{-webkit-animation-name:rotateOutDownRightNew;animation-name:rotateOutDownRightNew}@-webkit-keyframes fadeOutDownNew{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,-100%,0);transform:translate3d(0,-100%,0)}}@keyframes fadeOutDownNew{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,-100%,0);transform:translate3d(0,-100%,0)}}
 .wp-block-kubio-flipbox .fadeOutDown{-webkit-animation-name:fadeOutDownNew;animation-name:fadeOutDownNew}@-webkit-keyframes fadeOutUpNew{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,100%,0);transform:translate3d(0,100%,0)}}@keyframes fadeOutUpNew{0%{opacity:1}to{opacity:0;-webkit-transform:translate3d(0,100%,0);transform:translate3d(0,100%,0)}}
 .wp-block-kubio-flipbox .fadeOutUp{-webkit-animation-name:fadeOutUpNew;animation-name:fadeOutUpNew}@-webkit-keyframes bounceOutDownNew{20%{transform:translate3d(0,-10px,0)}40%,45%{opacity:1;-webkit-transform:translate3d(0,20px,0);transform:translate3d(0,20px,0)}to{opacity:0;-webkit-transform:translate3d(0,-2000px,0);transform:translate3d(0,-2000px,0)}}@keyframes bounceOutDownNew{20%{transform:translate3d(0,-10px,0)}40%,45%{opacity:1;-webkit-transform:translate3d(0,20px,0);transform:translate3d(0,20px,0)}to{opacity:0;-webkit-transform:translate3d(0,-2000px,0);transform:translate3d(0,-2000px,0)}}
 .wp-block-kubio-flipbox .bounceOutDown{-webkit-animation-name:bounceOutDownNew;animation-name:bounceOutDownNew}@-webkit-keyframes bounceOutUpNew{20%{transform:translate3d(0,10px,0)}40%,45%{opacity:1;-webkit-transform:translate3d(0,-20px,0);transform:translate3d(0,-20px,0)}to{opacity:0;-webkit-transform:translate3d(0,2000px,0);transform:translate3d(0,2000px,0)}}@keyframes bounceOutUpNew{20%{transform:translate3d(0,10px,0)}40%,45%{opacity:1;-webkit-transform:translate3d(0,-20px,0);transform:translate3d(0,-20px,0)}to{opacity:0;-webkit-transform:translate3d(0,2000px,0);transform:translate3d(0,2000px,0)}}
 .wp-block-kubio-flipbox .bounceOutUp{-webkit-animation-name:bounceOutUpNew;animation-name:bounceOutUpNew}
 .site .wp-block-kubio-flipbox__container:hover .h-flipbox-hover-container{opacity:1;visibility:visible}
 .wp-block-kubio-flipbox.is-box-state-hover .h-flipbox-hover-container{display:flex;opacity:1;visibility:visible}
 .wp-block-kubio-flipbox .h-show-hover-state[class*=Out]{-webkit-animation-fill-mode:unset;animation-fill-mode:unset}
 .wp-block-kubio-flipboxcontent__container{ms-flex:1!important;flex:1!important}
 .wp-block-kubio-flipboxcontent__container .block-list-appender,
 .wp-block-kubio-flipboxcontent__container>*,
 .wp-block-kubio-flipboxcontent__inner{width:100%}
 .wp-block-kubio-flipboxhover__container{background-color:rgba(0,0,0,.6);display:none;height:100%;left:0;position:absolute;top:0;width:100%;z-index:1}
 .wp-block-kubio-flipboxhover__container>*{width:100%}
 .wp-block-kubio-flipboxhover__container[data-kubio-component=link]{cursor:pointer}
 .wp-block-kubio-flipboxhover__container .block-list-appender{box-shadow:inset 0 0 0 1px #fff;color:#fff;width:100%}
 .wp-block-kubio-flipboxhover__container .wp-block-kubio-flipboxhover__inner .h-x-container-inner{margin-left:0;margin-right:0}
 .editor-styles-wrapper .wp-block-kubio-flipboxhover__container{display:none;position:absolute}
 .h-hide-animation{-webkit-animation-name:unset!important;animation-name:unset!important}
 .border-radius-inherit{border-radius:inherit}
 .wp-block-kubio-pricing{display:flex;margin-bottom:0;max-width:100%}
 .wp-block-kubio-pricing.wp-block[data-kubio]{line-height:1}
 .wp-block-kubio-pricing__container .wp-block-kubio-pricing__originalPrice{padding-right:10px}
 .wp-block-kubio-pricing__container .wp-block-kubio-pricing__currentPrice,
 .wp-block-kubio-pricing__container .wp-block-kubio-pricing__originalPrice{display:flex}
 .wp-block-kubio-pricing__container .wp-block-kubio-pricing__currentPrice .wp-block-kubio-pricing__>span,
 .wp-block-kubio-pricing__container .wp-block-kubio-pricing__originalPrice .wp-block-kubio-pricing__>span{display:block}
 .wp-block-kubio-pricing__originalPriceDecimal,
 .wp-block-kubio-pricing__originalPriceInner,
 .wp-block-kubio-pricing__originalPriceSymbol{text-decoration:line-through}
 .wp-block-kubio-pricing-table-item{max-width:100%;min-width:0}
 .wp-block-kubio-pricing-table-item.masonry-item{transition-duration:0s}
 .wp-block-kubio-pricing-table-item__content .h-heading h1:last-child,
 .wp-block-kubio-pricing-table-item__content .h-heading h2:last-child,
 .wp-block-kubio-pricing-table-item__content .h-heading h3:last-child,
 .wp-block-kubio-pricing-table-item__content .h-heading h4:last-child,
 .wp-block-kubio-pricing-table-item__content .h-heading h5:last-child,
 .wp-block-kubio-pricing-table-item__content .h-heading h6:last-child,
 .wp-block-kubio-pricing-table-item__content .h-heading p:last-child,
 .wp-block-kubio-pricing-table-item__content .h-text h1:last-child,
 .wp-block-kubio-pricing-table-item__content .h-text h2:last-child,
 .wp-block-kubio-pricing-table-item__content .h-text h3:last-child,
 .wp-block-kubio-pricing-table-item__content .h-text h4:last-child,
 .wp-block-kubio-pricing-table-item__content .h-text h5:last-child,
 .wp-block-kubio-pricing-table-item__content .h-text h6:last-child,
 .wp-block-kubio-pricing-table-item__content .h-text p:last-child,
 .wp-block-kubio-pricing-table-item__content>:last-child{margin-bottom:0}
 .wp-block-kubio-pricing-table-item__inner{flex-shrink:1;max-width:100%;position:relative}
 .wp-block-kubio-pricing-table-item__align{flex:1 0 auto;max-width:100%}
 .c-y-container .h-heading h1:last-child,
 .c-y-container .h-heading h2:last-child,
 .c-y-container .h-heading h3:last-child,
 .c-y-container .h-heading h4:last-child,
 .c-y-container .h-heading h5:last-child,
 .c-y-container .h-heading h6:last-child,
 .c-y-container .h-heading p:last-child,
 .c-y-container .h-text h1:last-child,
 .c-y-container .h-text h2:last-child,
 .c-y-container .h-text h3:last-child,
 .c-y-container .h-text h4:last-child,
 .c-y-container .h-text h5:last-child,
 .c-y-container .h-text h6:last-child,
 .c-y-container .h-text p:last-child{margin-bottom:0}
 .wp-block-kubio-pricing-table-item__ribbon{position:absolute!important;top:0;z-index:1}
 .wp-block-kubio-pricing-table-item__ribbon.price-ribbon--left{left:0}
 .wp-block-kubio-pricing-table-item__ribbon.price-ribbon--left .ribbon-text__outside{left:0;transform:rotate(1turn)}
 .wp-block-kubio-pricing-table-item__ribbon.price-ribbon--left .ribbon-icon{left:30%}
 .wp-block-kubio-pricing-table-item__ribbon.price-ribbon--left .triangle-top{border-left-width:0!important;border-right-color:transparent!important;border-style:solid solid none none!important}
 .wp-block-kubio-pricing-table-item__ribbon.price-ribbon--right{right:0}
 .wp-block-kubio-pricing-table-item__ribbon.price-ribbon--right .ribbon-text__outside{right:0;transform:rotate(90deg)}
 .wp-block-kubio-pricing-table-item__ribbon.price-ribbon--right .ribbon-icon{left:70%}
 .wp-block-kubio-pricing-table-item__ribbon.price-ribbon--right .triangle-top{border-left-color:transparent!important;border-right-width:0!important;border-style:solid none none solid!important}
 .wp-block-kubio-pricing-table-item__ribbon-wrapper{bottom:0;left:0;overflow:hidden;pointer-events:none;position:absolute!important;right:0;top:0;z-index:1000}
 .wp-block-kubio-pricing-table-item__triangle-top{background-color:transparent!important;border-bottom-width:0!important;box-sizing:border-box;height:0;position:static!important;width:0}
 .wp-block-kubio-pricing-table-item__ribbon-icon{position:absolute!important;top:30%;transform:translate(-50%,-50%)}
 .wp-block-kubio-pricing-table-item__ribbon-text{align-items:center;display:inline-flex;justify-content:center;text-align:center;transform-origin:center center 0;width:200%}
 .wp-block-kubio-pricing-table-item .ribbon-text__outside{height:250px;position:absolute;top:0;width:250px}
 .wp-block-kubio-slider{position:relative}
 [data-kubio] .wp-block-kubio-slider{max-width:100%!important}
 .wp-block-kubio-slider__container{display:flex;width:100%}
 .wp-block-kubio-slider .swiper-wrapper{align-items:stretch!important}
 .wp-block-kubio-slider-item__outer{flex-basis:100%!important;min-width:100%!important;width:100%!important}
 .wp-block-kubio-slider-item__inner{word-wrap:break-word;height:100%!important;width:100%}
 .wp-block-kubio-slider-item__align{width:100%}
 body:not(.editor-styles-wrapper) .wp-block-kubio-slider-item .h-column__content .h-x-container .wp-block-kubio-buttongroup__spacing>:last-child,
 body:not(.editor-styles-wrapper) .wp-block-kubio-slider-item .h-column__content .h-x-container>:last-child,
 body:not(.editor-styles-wrapper) .wp-block-kubio-slider-item .h-x-container-inner{margin-bottom:0}
 .wp-block-kubio-slider-item.is-selected{visibility:visible}
 .ken-burns-effect .swiper-slide-active .wp-block-kubio-slider-item__inner>.background-wrapper>.background-layer .forceBackgroundLayer{-webkit-animation:slider-ken-burns-effect 10s ease infinite alternate;animation:slider-ken-burns-effect 10s ease infinite alternate;background-attachment:scroll;background-position:50%;background-repeat:no-repeat;background-size:cover}
 .swiper-container-fade .wp-block-kubio-slider-item__outer:not(.swiper-slide-active){opacity:0!important}@-webkit-keyframes slider-ken-burns-effect{0%{transform:scale(1);transform-origin:center center}to{transform:scale(1.1)}}@keyframes slider-ken-burns-effect{0%{transform:scale(1);transform-origin:center center}to{transform:scale(1.1)}}
 .swiper-container-coverflow{padding:18px 0}
 .kubio-slider-play-effect button{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}
 .kubio-slider-play-effect button[disabled]{pointer-events:none}
 .kubio-slider-play-effect .h-control-notice{margin-top:10px}
 .wp-block-kubio-carousel{position:relative}
 [data-kubio] .wp-block-kubio-carousel{max-width:100%!important}
 .wp-block-kubio-carousel__container{display:flex;width:100%}
 .wp-block-kubio-carousel__outer{padding-left:0;padding-right:0}
 .wp-block-kubio-carousel .swiper-wrapper{align-items:stretch!important}
 .wp-block-kubio-slider-content{display:flex;height:-webkit-max-content!important;height:-moz-max-content!important;height:max-content!important;width:100%}
 .wp-block-kubio-slider-content .swiper-wrapper{height:auto}
 .wp-block-kubio-slider-content__outer{height:100%!important;padding:0}
 .wp-block-kubio-slider-content__inner{flex-wrap:nowrap;margin:0}
 .wp-block-kubio-carousel-item__inner{word-wrap:break-word;height:100%!important;width:100%}
 .wp-block-kubio-carousel-item__align{width:100%}
 body:not(.editor-styles-wrapper) .wp-block-kubio-carousel-item .h-column__content .h-x-container .wp-block-kubio-buttongroup__spacing>:last-child,
 body:not(.editor-styles-wrapper) .wp-block-kubio-carousel-item .h-column__content .h-x-container>:last-child,
 body:not(.editor-styles-wrapper) .wp-block-kubio-carousel-item .h-x-container-inner{margin-bottom:0}
 .wp-block-kubio-carousel-item.is-selected{visibility:visible}
 .wp-block-kubio-slider-arrow.wp-block.position-relative[data-kubio],
 .wp-block-kubio-slider-arrow[data-kubio]{margin:0}
 .wp-block-kubio-slider-arrow__outer{bottom:0;display:flex;left:0;pointer-events:none;position:absolute!important;right:0;top:0;z-index:100}
 .wp-block-kubio-slider-arrow__container{width:100%}
 .wp-block-kubio-slider-arrow__inner{background-image:none!important;cursor:pointer;display:inline-block;height:auto;left:0;margin-top:0!important;pointer-events:auto;position:relative!important;top:unset!important;transform:translateY(0);width:auto;z-index:200}
 .wp-block-kubio-slider-arrow__inner.swiper-button-next{left:auto;right:0}
 .wp-block-kubio-slider-arrow__inner span{cursor:pointer}
 .wp-block-kubio-slider-dots[data-kubio]{margin:0}
 .wp-block-kubio-slider-dots__inner{display:flex}
 .wp-block-kubio-slider-dots__outer{bottom:0;display:flex;left:0;pointer-events:none;position:absolute!important;right:0;top:0;z-index:300}
 .wp-block-kubio-slider-dots__outer .swiper-pagination{bottom:0;position:relative;text-align:center;z-index:300}
 .wp-block-kubio-slider-dots__outer .swiper-pagination .swiper-pagination-bullet{background-color:#333;background-image:none;border-radius:100%;cursor:pointer;display:inline-block;height:10px;margin:0 4px;pointer-events:auto;width:10px}
 .swiper-container:not(.swiper-container-cube) .swiper-cube-shadow{display:none!important}
 .swiper-container.swiper-container-coverflow{perspective:1200px}
 .swiper-container.swiper-container-coverflow .swiper-slide-shadow-left,
 .swiper-container.swiper-container-coverflow .swiper-slide-shadow-right{opacity:0!important}
 .ken-burns-effect .swiper-slide-active .wp-block-kubio-carousel-item__inner>.background-wrapper>.background-layer .forceBackgroundLayer{-webkit-animation:slider-ken-burns-effect 10s ease infinite alternate;animation:slider-ken-burns-effect 10s ease infinite alternate;background-attachment:scroll;background-position:50%;background-repeat:no-repeat;background-size:cover}
 .breadcrumb-items__wrapper{display:flex}
 .breadcrumb-items__wrapper .breadcrumb-items__prefix{align-items:center;display:inline-flex}
 .breadcrumb-items__wrapper .kubio-breadcrumb{align-items:center;display:inline-flex;flex-wrap:wrap;list-style:none;margin:0;padding:0}
 .breadcrumb-items__wrapper .kubio-breadcrumb>li{align-items:center;display:inline-flex;margin:0;vertical-align:middle}
 .breadcrumb-items__wrapper .kubio-breadcrumb>li+li:before{color:#ccc;content:"/ ";padding:0 5px}
 .breadcrumb-items__wrapper .kubio-breadcrumb>li a{display:inline-flex;line-height:1em!important}
 .breadcrumb-items__wrapper .kubio-breadcrumb>li svg{fill:currentColor;color:currentColor}
 .breadcrumb-items__wrapper .kubio-breadcrumb>li:last-child span{line-height:1em}
 .wp-block-kubio-subscribe-form .submit-button--inline .mc4wp-form-fields{display:inline-flex;display:inline-grid;flex-wrap:wrap;grid-template-columns:auto auto}
 .wp-block-kubio-subscribe-form .submit-button--inline .mc4wp-form-fields input:not([type=file]):not([type=radio]):not([type=checkbox]):not([type=submit]){width:100%}
 .wp-block-kubio-subscribe-form .submit-button--inline .mc4wp-form-fields .kubio-newsletter__email-group{align-items:center;flex:1 1 auto;flex-direction:row;justify-content:flex-start}
 .wp-block-kubio-subscribe-form .submit-button--inline .mc4wp-form-fields .kubio-newsletter__agree-terms-group{flex:0 1 100%;grid-column:1/span 2;grid-row:2}
 .wp-block-kubio-subscribe-form .submit-button--inline .mc4wp-form-fields .kubio-newsletter__submit-group{flex:0 1 auto;grid-column:2/span 1;grid-row:1}
 .wp-block-kubio-subscribe-form .submit-button--inline.kubio-newsletter-email--auto .mc4wp-form-fields{grid-template-columns:1fr auto;width:100%}
 .wp-block-kubio-subscribe-form .submit-button--inline.kubio-newsletter-email--auto .mc4wp-form-fields .kubio-newsletter__email-group input{min-width:100%!important}
 .wp-block-kubio-subscribe-form .submit-button--inline.kubio-newsletter-email--custom .mc4wp-form-fields{grid-template-columns:auto auto;width:auto}
 .wp-block-kubio-subscribe-form .submit-button--inline.kubio-newsletter-email--custom .mc4wp-form-fields .kubio-newsletter__email-group input{min-width:unset!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--auto,
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--auto form{width:100%}
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--custom,
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--custom form{width:auto}
 .wp-block-kubio-subscribe-form .submit-button--below .mc4wp-form-fields{display:block}
 .wp-block-kubio-subscribe-form .submit-button--below .mc4wp-form-fields .kubio-newsletter__email-group{align-items:flex-start;flex-direction:column;justify-content:center}
 .wp-block-kubio-subscribe-form .submit-button--below .mc4wp-form-fields .kubio-newsletter__agree-terms-group,
 .wp-block-kubio-subscribe-form .submit-button--below .mc4wp-form-fields .kubio-newsletter__submit-group{grid-column:unset;grid-row:unset}
 .wp-block-kubio-subscribe-form .submit-button--below.kubio-newsletter-email--auto .kubio-newsletter__email-group input{min-width:100%!important}
 .wp-block-kubio-subscribe-form .submit-button--below.kubio-newsletter-email--custom .kubio-newsletter__email-group input{min-width:unset!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--flex-start [type=submit]{margin-left:0!important;margin-right:auto!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--center [type=submit]{margin-left:auto!important;margin-right:auto!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--flex-end [type=submit]{margin-left:auto!important;margin-right:0!important}@media (min-width:576px){
 .wp-block-kubio-subscribe-form .submit-button--inline-sm .mc4wp-form-fields{display:inline-flex;display:inline-grid;flex-wrap:wrap;grid-template-columns:auto auto}
 .wp-block-kubio-subscribe-form .submit-button--inline-sm .mc4wp-form-fields input:not([type=file]):not([type=radio]):not([type=checkbox]):not([type=submit]){width:100%}
 .wp-block-kubio-subscribe-form .submit-button--inline-sm .mc4wp-form-fields .kubio-newsletter__email-group{align-items:center;flex:1 1 auto;flex-direction:row;justify-content:flex-start}
 .wp-block-kubio-subscribe-form .submit-button--inline-sm .mc4wp-form-fields .kubio-newsletter__agree-terms-group{flex:0 1 100%;grid-column:1/span 2;grid-row:2}
 .wp-block-kubio-subscribe-form .submit-button--inline-sm .mc4wp-form-fields .kubio-newsletter__submit-group{flex:0 1 auto;grid-column:2/span 1;grid-row:1}
 .wp-block-kubio-subscribe-form .submit-button--inline-sm.kubio-newsletter-email--auto-sm .mc4wp-form-fields{grid-template-columns:1fr auto;width:100%}
 .wp-block-kubio-subscribe-form .submit-button--inline-sm.kubio-newsletter-email--auto-sm .mc4wp-form-fields .kubio-newsletter__email-group input{min-width:100%!important}
 .wp-block-kubio-subscribe-form .submit-button--inline-sm.kubio-newsletter-email--custom-sm .mc4wp-form-fields{grid-template-columns:auto auto;width:auto}
 .wp-block-kubio-subscribe-form .submit-button--inline-sm.kubio-newsletter-email--custom-sm .mc4wp-form-fields .kubio-newsletter__email-group input{min-width:unset!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--auto-sm,
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--auto-sm form{width:100%}
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--custom-sm,
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--custom-sm form{width:auto}
 .wp-block-kubio-subscribe-form .submit-button--below-sm .mc4wp-form-fields{display:block}
 .wp-block-kubio-subscribe-form .submit-button--below-sm .mc4wp-form-fields .kubio-newsletter__email-group{align-items:flex-start;flex-direction:column;justify-content:center}
 .wp-block-kubio-subscribe-form .submit-button--below-sm .mc4wp-form-fields .kubio-newsletter__agree-terms-group,
 .wp-block-kubio-subscribe-form .submit-button--below-sm .mc4wp-form-fields .kubio-newsletter__submit-group{grid-column:unset;grid-row:unset}
 .wp-block-kubio-subscribe-form .submit-button--below-sm.kubio-newsletter-email--auto-sm .kubio-newsletter__email-group input{min-width:100%!important}
 .wp-block-kubio-subscribe-form .submit-button--below-sm.kubio-newsletter-email--custom-sm .kubio-newsletter__email-group input{min-width:unset!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--flex-start-sm [type=submit]{margin-left:0!important;margin-right:auto!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--center-sm [type=submit]{margin-left:auto!important;margin-right:auto!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--flex-end-sm [type=submit]{margin-left:auto!important;margin-right:0!important}}@media (min-width:768px){
 .wp-block-kubio-subscribe-form .submit-button--inline-md .mc4wp-form-fields{display:inline-flex;display:inline-grid;flex-wrap:wrap;grid-template-columns:auto auto}
 .wp-block-kubio-subscribe-form .submit-button--inline-md .mc4wp-form-fields input:not([type=file]):not([type=radio]):not([type=checkbox]):not([type=submit]){width:100%}
 .wp-block-kubio-subscribe-form .submit-button--inline-md .mc4wp-form-fields .kubio-newsletter__email-group{align-items:center;flex:1 1 auto;flex-direction:row;justify-content:flex-start}
 .wp-block-kubio-subscribe-form .submit-button--inline-md .mc4wp-form-fields .kubio-newsletter__agree-terms-group{flex:0 1 100%;grid-column:1/span 2;grid-row:2}
 .wp-block-kubio-subscribe-form .submit-button--inline-md .mc4wp-form-fields .kubio-newsletter__submit-group{flex:0 1 auto;grid-column:2/span 1;grid-row:1}
 .wp-block-kubio-subscribe-form .submit-button--inline-md.kubio-newsletter-email--auto-md .mc4wp-form-fields{grid-template-columns:1fr auto;width:100%}
 .wp-block-kubio-subscribe-form .submit-button--inline-md.kubio-newsletter-email--auto-md .mc4wp-form-fields .kubio-newsletter__email-group input{min-width:100%!important}
 .wp-block-kubio-subscribe-form .submit-button--inline-md.kubio-newsletter-email--custom-md .mc4wp-form-fields{grid-template-columns:auto auto;width:auto}
 .wp-block-kubio-subscribe-form .submit-button--inline-md.kubio-newsletter-email--custom-md .mc4wp-form-fields .kubio-newsletter__email-group input{min-width:unset!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--auto-md,
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--auto-md form{width:100%}
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--custom-md,
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--custom-md form{width:auto}
 .wp-block-kubio-subscribe-form .submit-button--below-md .mc4wp-form-fields{display:block}
 .wp-block-kubio-subscribe-form .submit-button--below-md .mc4wp-form-fields .kubio-newsletter__email-group{align-items:flex-start;flex-direction:column;justify-content:center}
 .wp-block-kubio-subscribe-form .submit-button--below-md .mc4wp-form-fields .kubio-newsletter__agree-terms-group,
 .wp-block-kubio-subscribe-form .submit-button--below-md .mc4wp-form-fields .kubio-newsletter__submit-group{grid-column:unset;grid-row:unset}
 .wp-block-kubio-subscribe-form .submit-button--below-md.kubio-newsletter-email--auto-md .kubio-newsletter__email-group input{min-width:100%!important}
 .wp-block-kubio-subscribe-form .submit-button--below-md.kubio-newsletter-email--custom-md .kubio-newsletter__email-group input{min-width:unset!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--flex-start-md [type=submit]{margin-left:0!important;margin-right:auto!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--center-md [type=submit]{margin-left:auto!important;margin-right:auto!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--flex-end-md [type=submit]{margin-left:auto!important;margin-right:0!important}}@media (min-width:1024px){
 .wp-block-kubio-subscribe-form .submit-button--inline-lg .mc4wp-form-fields{display:inline-flex;display:inline-grid;flex-wrap:wrap;grid-template-columns:auto auto}
 .wp-block-kubio-subscribe-form .submit-button--inline-lg .mc4wp-form-fields input:not([type=file]):not([type=radio]):not([type=checkbox]):not([type=submit]){width:100%}
 .wp-block-kubio-subscribe-form .submit-button--inline-lg .mc4wp-form-fields .kubio-newsletter__email-group{align-items:center;flex:1 1 auto;flex-direction:row;justify-content:flex-start}
 .wp-block-kubio-subscribe-form .submit-button--inline-lg .mc4wp-form-fields .kubio-newsletter__agree-terms-group{flex:0 1 100%;grid-column:1/span 2;grid-row:2}
 .wp-block-kubio-subscribe-form .submit-button--inline-lg .mc4wp-form-fields .kubio-newsletter__submit-group{flex:0 1 auto;grid-column:2/span 1;grid-row:1}
 .wp-block-kubio-subscribe-form .submit-button--inline-lg.kubio-newsletter-email--auto-lg .mc4wp-form-fields{grid-template-columns:1fr auto;width:100%}
 .wp-block-kubio-subscribe-form .submit-button--inline-lg.kubio-newsletter-email--auto-lg .mc4wp-form-fields .kubio-newsletter__email-group input{min-width:100%!important}
 .wp-block-kubio-subscribe-form .submit-button--inline-lg.kubio-newsletter-email--custom-lg .mc4wp-form-fields{grid-template-columns:auto auto;width:auto}
 .wp-block-kubio-subscribe-form .submit-button--inline-lg.kubio-newsletter-email--custom-lg .mc4wp-form-fields .kubio-newsletter__email-group input{min-width:unset!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--auto-lg,
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--auto-lg form{width:100%}
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--custom-lg,
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--custom-lg form{width:auto}
 .wp-block-kubio-subscribe-form .submit-button--below-lg .mc4wp-form-fields{display:block}
 .wp-block-kubio-subscribe-form .submit-button--below-lg .mc4wp-form-fields .kubio-newsletter__email-group{align-items:flex-start;flex-direction:column;justify-content:center}
 .wp-block-kubio-subscribe-form .submit-button--below-lg .mc4wp-form-fields .kubio-newsletter__agree-terms-group,
 .wp-block-kubio-subscribe-form .submit-button--below-lg .mc4wp-form-fields .kubio-newsletter__submit-group{grid-column:unset;grid-row:unset}
 .wp-block-kubio-subscribe-form .submit-button--below-lg.kubio-newsletter-email--auto-lg .kubio-newsletter__email-group input{min-width:100%!important}
 .wp-block-kubio-subscribe-form .submit-button--below-lg.kubio-newsletter-email--custom-lg .kubio-newsletter__email-group input{min-width:unset!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--flex-start-lg [type=submit]{margin-left:0!important;margin-right:auto!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--center-lg [type=submit]{margin-left:auto!important;margin-right:auto!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--flex-end-lg [type=submit]{margin-left:auto!important;margin-right:0!important}}@media (min-width:1200px){
 .wp-block-kubio-subscribe-form .submit-button--inline-xl .mc4wp-form-fields{display:inline-flex;display:inline-grid;flex-wrap:wrap;grid-template-columns:auto auto}
 .wp-block-kubio-subscribe-form .submit-button--inline-xl .mc4wp-form-fields input:not([type=file]):not([type=radio]):not([type=checkbox]):not([type=submit]){width:100%}
 .wp-block-kubio-subscribe-form .submit-button--inline-xl .mc4wp-form-fields .kubio-newsletter__email-group{align-items:center;flex:1 1 auto;flex-direction:row;justify-content:flex-start}
 .wp-block-kubio-subscribe-form .submit-button--inline-xl .mc4wp-form-fields .kubio-newsletter__agree-terms-group{flex:0 1 100%;grid-column:1/span 2;grid-row:2}
 .wp-block-kubio-subscribe-form .submit-button--inline-xl .mc4wp-form-fields .kubio-newsletter__submit-group{flex:0 1 auto;grid-column:2/span 1;grid-row:1}
 .wp-block-kubio-subscribe-form .submit-button--inline-xl.kubio-newsletter-email--auto-xl .mc4wp-form-fields{grid-template-columns:1fr auto;width:100%}
 .wp-block-kubio-subscribe-form .submit-button--inline-xl.kubio-newsletter-email--auto-xl .mc4wp-form-fields .kubio-newsletter__email-group input{min-width:100%!important}
 .wp-block-kubio-subscribe-form .submit-button--inline-xl.kubio-newsletter-email--custom-xl .mc4wp-form-fields{grid-template-columns:auto auto;width:auto}
 .wp-block-kubio-subscribe-form .submit-button--inline-xl.kubio-newsletter-email--custom-xl .mc4wp-form-fields .kubio-newsletter__email-group input{min-width:unset!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--auto-xl,
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--auto-xl form{width:100%}
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--custom-xl,
 .wp-block-kubio-subscribe-form .kubio-newsletter-email--custom-xl form{width:auto}
 .wp-block-kubio-subscribe-form .submit-button--below-xl .mc4wp-form-fields{display:block}
 .wp-block-kubio-subscribe-form .submit-button--below-xl .mc4wp-form-fields .kubio-newsletter__email-group{align-items:flex-start;flex-direction:column;justify-content:center}
 .wp-block-kubio-subscribe-form .submit-button--below-xl .mc4wp-form-fields .kubio-newsletter__agree-terms-group,
 .wp-block-kubio-subscribe-form .submit-button--below-xl .mc4wp-form-fields .kubio-newsletter__submit-group{grid-column:unset;grid-row:unset}
 .wp-block-kubio-subscribe-form .submit-button--below-xl.kubio-newsletter-email--auto-xl .kubio-newsletter__email-group input{min-width:100%!important}
 .wp-block-kubio-subscribe-form .submit-button--below-xl.kubio-newsletter-email--custom-xl .kubio-newsletter__email-group input{min-width:unset!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--flex-start-xl [type=submit]{margin-left:0!important;margin-right:auto!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--center-xl [type=submit]{margin-left:auto!important;margin-right:auto!important}
 .wp-block-kubio-subscribe-form .kubio-newsletter--shortcode-layout.submit-button-align--flex-end-xl [type=submit]{margin-left:auto!important;margin-right:0!important}}
 .wp-block-kubio-subscribe-form .h-block-placeholder{font-style:normal;font-weight:400;letter-spacing:normal;text-decoration:none;text-transform:none}
 .wp-block-kubio-subscribe-form__container{overflow:visible}
 .wp-block-kubio-subscribe-form__container form{display:inline-block;margin:0;max-width:100%}
 .wp-block-kubio-subscribe-form__container form input{line-height:normal;max-width:100%;outline:none}
 .wp-block-kubio-subscribe-form__container form input[type=checkbox],
 .wp-block-kubio-subscribe-form__container form input[type=radio]{bottom:0}
 .wp-block-kubio-subscribe-form__container form [type=submit]{border-color:transparent}
 .wp-block-kubio-subscribe-form__container form input:focus{box-shadow:none}
 .wp-block-kubio-subscribe-form__container form .mc4wp-form-fields>*{align-items:center;display:flex;justify-content:space-between}
 .wp-block-kubio-subscribe-form__container form .mc4wp-form-fields>p{margin:0}
 .wp-block-kubio-subscribe-form__container form .kubio-newsletter__agree-terms-group{justify-content:flex-start}
 .wp-block-kubio-subscribe-form__container form .kubio-newsletter__agree-terms-group input[type=checkbox]{height:16px;margin:0 5px 0 0;width:16px}
 .wp-block-kubio-subscribe-form__container form .kubio-newsletter__email-group{display:flex;flex:1}
 .wp-block-kubio-subscribe-form__container form .kubio-newsletter__email-group label{white-space:nowrap}
 .wp-block-kubio-subscribe-form__container form .kubio-newsletter__submit-group button{align-items:center;display:inline-flex}
 .wp-block-kubio-subscribe-form__container form .kubio-newsletter__submit-group button .kubio-newsletter__submit-text{order:2}
 .wp-block-kubio-subscribe-form__container form .kubio-newsletter__submit-group button svg{height:100%;width:100%}
 .wp-block-kubio-subscribe-form__container form .mc4wp-alert p{margin-bottom:0}
 .wp-block-kubio-subscribe-form__container.submit_icon_position-after .kubio-newsletter__submit-group button[type=submit]{align-items:center;display:flex;flex-direction:row}
 .wp-block-kubio-subscribe-form .kubio-newsletter__agree-terms-group p{color:inherit!important;font-family:inherit!important;font-size:inherit!important;font-style:inherit!important;font-weight:inherit!important;letter-spacing:inherit!important;line-height:inherit!important;text-decoration:inherit!important;text-transform:inherit!important}
 #end-resizable-kubio-section{display:none}@media screen and (max-width:600px){
 #wpadminbar{position:fixed}}
 .kubio-front-header__k__9IGHpldIpw-container{align-items:center}
 .kubio-post-content a,
 .kubio-post-content a:hover,
 .kubio-post-content a:visited{text-decoration:underline!important}
 .wp-block-kubio-navigation-section,
 .wp-block-kubio-navigation [data-nav-normal]{transition:all 0ms}
 #kubio .kubio-header__k__jZZ7ZgkWWk-outer .wp-block-kubio-navigation-section__nav{-webkit-animation-duration:.5s;animation-duration:.5s;padding:30px 20px}
 #kubio .kubio-header__k__jZZ7ZgkWWk-outer .h-navigation_sticky.wp-block-kubio-navigation-section__nav{background-color:#fff;box-shadow:0 0 10px 0 rgba(23,25,39,.1);padding-bottom:10px;padding-top:10px}
 #kubio .kubio-header__k__b2YVMldxUMm-outer{background-color:#000;padding-bottom:5px;padding-top:5px}
 #kubio .kubio-header__k__ltBLs1jKCt_-inner{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-header__k__ltBLs1jKCt_-container{height:auto;min-height:unset}
 #kubio .kubio-header__k__zY9YjrzJJVK-outer{align-content:flex-start;flex-direction:row;justify-content:flex-start}
 #kubio .kubio-header__k__zY9YjrzJJVK-outer .wp-block-kubio-iconlistitem__text{align-items:center;color:rgba(var(--kubio-color-5),1);font-size:14px;margin-left:5px}
 #kubio .kubio-header__k__zY9YjrzJJVK-outer .wp-block-kubio-iconlistitem__text-wrapper{align-items:center;padding-bottom:0;padding-right:0}
 #kubio .kubio-header__k__zY9YjrzJJVK-outer .wp-block-kubio-iconlistitem__icon{fill:rgba(var(--kubio-color-5),1);border:2px rgba(var(--kubio-color-1),1);height:18px;padding-left:0;width:18px}
 #kubio .kubio-header__k__zY9YjrzJJVK-outer .wp-block-kubio-iconlistitem__icon:hover{background-color:rgba(3,169,244,0)}
 #kubio .kubio-header__k__zY9YjrzJJVK-outer .wp-block-kubio-iconlistitem__divider{border-bottom:0 #000;border-left-width:1px;border-right-width:0;border-style:solid;border-top-width:0;color:#000;height:100%;margin-left:0;width:100%}
 #kubio .kubio-header__k__zY9YjrzJJVK-outer .wp-block-kubio-iconlistitem__divider-wrapper{align-items:center;padding:0 10px;width:1px}
 #kubio .kubio-header__k__kvhfjD7jyyb-inner{height:auto;min-height:unset;text-align:center}
 #kubio .kubio-header__k__kvhfjD7jyyb-container{height:auto;min-height:unset}
 #kubio .kubio-header__k__8HsNbkMIffG-outer{text-align:right}
 #kubio .kubio-header__k__8HsNbkMIffG-outer .h-svg-icon{fill:rgba(var(--kubio-color-5-variant-2),1);height:20px;margin-right:0;min-height:20px;min-width:20px;padding:5px;width:20px}
 #kubio .kubio-header__k__8HsNbkMIffG-outer .h-svg-icon:hover{fill:rgba(var(--kubio-color-5),1)}
 #kubio .kubio-header__k__p8q1gQwZk8-inner{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-header__k__p8q1gQwZk8-container{height:auto;min-height:unset}
 #kubio .kubio-header__k__pCBjS67tbM7-container{--kubio-gap-fallback:10px;gap:10px;text-decoration:none}
 #kubio .kubio-header__k__pCBjS67tbM7-container .kubio-logo-image,
 #kubio .kubio-header__k__pCBjS67tbM7-image{max-height:70px}
 #kubio .kubio-header__k__pCBjS67tbM7-text{color:rgba(var(--kubio-color-5),1);font-family:Syncopate,Helvetica,Arial,Sans-Serif,serif;font-size:24px;font-weight:700}
 #kubio .kubio-header__k__GQy4e2i_VhU-inner{text-align:center}
 #kubio .kubio-header__k__GQy4e2i_VhU-container{height:auto;min-height:unset}
 #kubio .kubio-header__k__uTjkb3qLKro-container{height:50px}
 #kubio .kubio-header__k__Vb6ApGnmw8l-inner{height:auto;min-height:unset;text-align:right}
 #kubio .kubio-header__k__Vb6ApGnmw8l-container{height:auto;min-height:unset}
 #kubio .kubio-header__k__S2itoG6vEiw-outer.bordered-active-item>.kubio-menu>ul>li:after,
 #kubio .kubio-header__k__S2itoG6vEiw-outer.bordered-active-item>.kubio-menu>ul>li:before{background-color:rgba(var(--kubio-color-5),1);height:1px}
 #kubio .kubio-header__k__S2itoG6vEiw-outer.solid-active-item>.kubio-menu>ul>li:after,
 #kubio .kubio-header__k__S2itoG6vEiw-outer.solid-active-item>.kubio-menu>ul>li:before{background-color:#fff;border-bottom-left-radius:0;border-bottom-right-radius:0;border-top-left-radius:0;border-top-right-radius:0}
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul{--kubio-gap-fallback:50px;gap:50px;justify-content:center}
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li>a{color:rgba(var(--kubio-color-5),.8);font-family:Mulish,Helvetica,Arial,Sans-Serif,serif;font-size:16px;font-weight:400;letter-spacing:0;line-height:1.5em;padding:10px 0;text-decoration:none;text-transform:none}
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li.current-menu-item>a,
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li.current_page_item>a,
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li>a.hover,
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li>a:hover{color:rgba(var(--kubio-color-5),1)}
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li>a>svg{padding-left:5px;padding-right:5px}
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu li>ul{background-color:#fff;box-shadow:0 0 5px 2px rgba(0,0,0,.04);margin-left:5px;margin-right:5px}
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu li>ul>li>a{background-color:#fff;border-bottom:1px solid hsla(0,0%,50%,.2);color:rgba(var(--kubio-color-6),1);font-size:14px;padding:10px 20px;text-decoration:none}
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu li>ul>li.current-menu-item>a,
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu li>ul>li.current_page_item>a,
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu li>ul>li>a.hover,
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu li>ul>li>a:hover{background-color:rgba(var(--kubio-color-1),1);color:rgba(var(--kubio-color-5),1)}
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li>ul{margin-top:10px}
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li>ul:before{height:10px;width:100%}
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer.bordered-active-item>.kubio-menu>ul>li:after,
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer.bordered-active-item>.kubio-menu>ul>li:before{background-color:rgba(var(--kubio-color-6),1)}
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul{justify-content:flex-end}
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li>a{color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-header__k__LCYaOhT1Q-f-icon{fill:rgba(var(--kubio-color-5),1);background-color:rgba(var(--kubio-color-3-variant-5),0);border:0 #000;border-bottom-left-radius:0;border-bottom-right-radius:0;border-top-left-radius:0;border-top-right-radius:0;height:24px;min-height:24px;min-width:24px;padding:5px;width:24px}
 #kubio .kubio-header__k__LCYaOhT1Q-f-icon:hover{fill:rgba(var(--kubio-color-1),1)}
 .kubio-header__k__LCYaOhT1Q-f-offscreen{background-color:rgba(var(--kubio-color-6),1);width:300px!important}
 .kubio-header__k__LCYaOhT1Q-f-offscreenOverlay{background-color:rgba(0,0,0,.5)}
 #kubio .kubio-header__k__MlGjFpYlgDP-inner{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-header__k__MlGjFpYlgDP-container{height:auto;min-height:unset}
 #kubio .kubio-header__k__x8ZMD9qFOX9-container{--kubio-gap-fallback:10px;align-items:flex-start;gap:10px;justify-content:flex-start;text-decoration:none}
 #kubio .kubio-header__k__x8ZMD9qFOX9-container .kubio-logo-image,
 #kubio .kubio-header__k__x8ZMD9qFOX9-image{max-height:70px}
 #kubio .kubio-header__k__x8ZMD9qFOX9-text{color:rgba(var(--kubio-color-5),1);font-family:Syncopate,Helvetica,Arial,Sans-Serif,serif;font-size:20px;font-weight:700}
 #kubio .kubio-header__k__3ncDYaLs9lk-outer>.kubio-menu>ul{--kubio-accordion-menu-offset:10px}
 #kubio .kubio-header__k__3ncDYaLs9lk-outer>.kubio-menu>ul>li>a{border-bottom:1px rgba(var(--kubio-color-5),.2);border-left-color:grey;border-right-color:grey;border-top-color:grey;color:rgba(var(--kubio-color-5),1);font-size:14px;padding-bottom:20px;padding-left:40px;padding-top:20px;text-decoration:none}
 #kubio .kubio-header__k__3ncDYaLs9lk-outer>.kubio-menu>ul>li.current-menu-item>a,
 #kubio .kubio-header__k__3ncDYaLs9lk-outer>.kubio-menu>ul>li.current_page_item>a,
 #kubio .kubio-header__k__3ncDYaLs9lk-outer>.kubio-menu>ul>li>a.hover,
 #kubio .kubio-header__k__3ncDYaLs9lk-outer>.kubio-menu>ul>li>a:hover{background-color:rgba(var(--kubio-color-1),1)}
 #kubio .kubio-header__k__3ncDYaLs9lk-outer>.kubio-menu>ul>li>a>svg{padding-left:20px;padding-right:20px}
 #kubio .kubio-header__k__3ncDYaLs9lk-outer>.kubio-menu li>ul>li>a{border-bottom:1px solid rgba(var(--kubio-color-5),.2);border-left-color:grey;border-right-color:grey;border-top-color:grey;color:rgba(var(--kubio-color-5),1);font-size:14px;padding-bottom:12px;padding-left:40px;padding-top:12px;text-decoration:none}
 #kubio .kubio-header__k__3ncDYaLs9lk-outer>.kubio-menu li>ul>li.current-menu-item>a,
 #kubio .kubio-header__k__3ncDYaLs9lk-outer>.kubio-menu li>ul>li.current_page_item>a,
 #kubio .kubio-header__k__3ncDYaLs9lk-outer>.kubio-menu li>ul>li>a.hover,
 #kubio .kubio-header__k__3ncDYaLs9lk-outer>.kubio-menu li>ul>li>a:hover{background-color:rgba(var(--kubio-color-1),.8)}
 #kubio .kubio-header__k__3ncDYaLs9lk-outer>.kubio-menu li>ul>li>a>svg{padding-left:20px;padding-right:20px}
 #kubio .kubio-header__k__53skekCRYGP-inner{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-header__k__53skekCRYGP-container{height:auto;min-height:unset}
 #kubio .kubio-header__k__ju3b6-jxyfk-outer p{color:rgba(var(--kubio-color-5),.4)}
 #kubio .kubio-header__k__KFTMhA6WOVh-outer{background-attachment:scroll;background-position:52% 94%;background-repeat:no-repeat;background-size:cover;height:auto;min-height:unset;padding-top:100px}
 #kubio .kubio-header__k__KFTMhA6WOVh-outer,
 #kubio .kubio-header__k__KFTMhA6WOVh-outer [data-kubio]:not(h1):not(h2):not(h3):not(h4):not(h5):not(h6),
 #kubio .kubio-header__k__KFTMhA6WOVh-outer h1,
 #kubio .kubio-header__k__KFTMhA6WOVh-outer h1[data-kubio],
 #kubio .kubio-header__k__KFTMhA6WOVh-outer h2,
 #kubio .kubio-header__k__KFTMhA6WOVh-outer h2[data-kubio],
 #kubio .kubio-header__k__KFTMhA6WOVh-outer h3,
 #kubio .kubio-header__k__KFTMhA6WOVh-outer h3[data-kubio],
 #kubio .kubio-header__k__KFTMhA6WOVh-outer h4,
 #kubio .kubio-header__k__KFTMhA6WOVh-outer h4[data-kubio],
 #kubio .kubio-header__k__KFTMhA6WOVh-outer h5,
 #kubio .kubio-header__k__KFTMhA6WOVh-outer h5[data-kubio],
 #kubio .kubio-header__k__KFTMhA6WOVh-outer h6,
 #kubio .kubio-header__k__KFTMhA6WOVh-outer h6[data-kubio],
 #kubio .kubio-header__k__KFTMhA6WOVh-outer p,
 #kubio .kubio-header__k__KFTMhA6WOVh-outer p[data-kubio]{color:rgba(var(--kubio-color-5),1)}
 #kubio .kubio-header__k__vPVKm6K-swr-inner{border-bottom-left-radius:9px;border-bottom-right-radius:9px;border-top-left-radius:9px;border-top-right-radius:9px;height:auto;min-height:unset;text-align:center}
 #kubio .kubio-header__k__vPVKm6K-swr-container{height:auto;min-height:unset}
 #kubio h1.wp-block.kubio-header__k__SzZXH7PdCL-container,
 #kubio h2.wp-block.kubio-header__k__SzZXH7PdCL-container,
 #kubio h3.wp-block.kubio-header__k__SzZXH7PdCL-container,
 #kubio h4.wp-block.kubio-header__k__SzZXH7PdCL-container,
 #kubio h5.wp-block.kubio-header__k__SzZXH7PdCL-container,
 #kubio h6.wp-block.kubio-header__k__SzZXH7PdCL-container,
 #kubio p.wp-block.kubio-header__k__SzZXH7PdCL-container{font-size:2.5em}
 #kubio .kubio-footer__k__vP0mYzy99sE-outer{background-color:rgba(var(--kubio-color-5),1);padding-bottom:0;padding-top:0}
 #kubio .kubio-footer__k__vP0mYzy99sE-outer a,
 #kubio .kubio-footer__k__vP0mYzy99sE-outer a[data-kubio]{color:rgba(var(--kubio-color-1),1)}
 #kubio .kubio-footer__k__vP0mYzy99sE-outer a:hover,
 #kubio .kubio-footer__k__vP0mYzy99sE-outer a[data-kubio]:hover{color:rgba(var(--kubio-color-1-variant-2),1)}
 #kubio .kubio-footer__k__nJpox2eRXHV-inner{text-align:center}
 #kubio .kubio-footer__k__nJpox2eRXHV-container{height:auto;min-height:unset;text-align:center}
 #kubio .kubio-index__k__FwcIquvVBo-inner{text-align:center}
 #kubio .kubio-index__k__FwcIquvVBo-container{height:auto;min-height:unset}
 #kubio .kubio-index__k__HE2LPNtfKX-inner{border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;text-align:left}
 #kubio .kubio-index__k__HE2LPNtfKX-container{height:auto;min-height:unset}
 #kubio .kubio-index__k__ciaK61IeR-input{background-color:rgba(var(--kubio-color-6),.05);border-bottom-left-radius:3px;border-bottom-right-radius:0;border-top-left-radius:3px;border-top-right-radius:0;font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-weight:400}
 #kubio .kubio-index__k__ciaK61IeR-button{background-color:rgba(var(--kubio-color-1),1);border-bottom-left-radius:0;border-bottom-right-radius:3px;border-style:none;border-top-left-radius:0;border-top-right-radius:3px;border-width:0;color:rgba(var(--kubio-color-5),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:14px;font-weight:400;letter-spacing:0;text-transform:none;width:80px}
 #kubio .kubio-index__k__ciaK61IeR-button:hover{background-color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-index__k__ciaK61IeR-icon{fill:rgba(var(--kubio-color-5),1);height:20px;min-height:20px;min-width:20px;width:20px}
 #kubio .wp-block.wp-block-kubio-heading__text.kubio-index__k__R9xOJzpKQW0-text{margin-bottom:10px}
 #kubio .wp-block.wp-block-kubio-heading__text.kubio-index__k__R9xOJzpKQW0-text .text-wrapper-fancy svg path{stroke:#000;stroke-linejoin:initial;stroke-linecap:initial;stroke-width:8px}
 #kubio .kubio-index__k__dAlw2G59Yo-widget-box{background-color:unset;background-image:none;font-size:14px;margin:0;padding:0}
 #kubio .kubio-index__k__dAlw2G59Yo-widget-box a{color:rgba(var(--kubio-color-1),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:16px;font-weight:400}
 #kubio .kubio-index__k__dAlw2G59Yo-widget-box a:hover{color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-index__k__dAlw2G59Yo-widget-box time{color:rgba(var(--kubio-color-6),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:14px;font-weight:400;margin-bottom:20px}
 #kubio .kubio-index__k__dAlw2G59Yo-widget-box.wp-block-latest-comments .wp-block-latest-comments__comment-excerpt p{color:rgba(var(--kubio-color-6),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:16px;font-weight:400}
 #kubio .kubio-index__k__dAlw2G59Yo-widget-box.wp-block-latest-comments .wp-block-latest-comments__comment-avatar{border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;height:30px;width:30px}
 #kubio .kubio-index__k__kxeqsSpdy-n-inner{text-align:center}
 #kubio .kubio-index__k__kxeqsSpdy-n-container{height:auto;min-height:unset}
 #kubio .kubio-index__k__fx1L_l5Ny--inner{box-shadow:none;margin:0;padding-bottom:3em;text-align:left}
 #kubio .kubio-index__k__fx1L_l5Ny--container{height:auto;min-height:unset}
 #kubio .kubio-index__k__6duco09NdG-container{background-color:rgba(var(--kubio-color-4),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;height:300px;text-align:center}
 #kubio .kubio-index__k__6duco09NdG-image{-o-object-fit:cover;object-fit:cover;-o-object-position:top center;object-position:top center}
 #kubio .kubio-index__k__T2yqalWyM-metaDataContainer{justify-content:flex-start}
 #kubio .kubio-index__k__T2yqalWyM-metaDataContainer a{color:rgba(var(--kubio-color-6),.5);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:12px;font-weight:400;letter-spacing:1px}
 #kubio .kubio-index__k__T2yqalWyM-metaDataContainer a:hover{color:rgba(var(--kubio-color-1),1)}
 #kubio .kubio-index__k__T2yqalWyM-metaDataContainer .metadata-prefix,
 #kubio .kubio-index__k__T2yqalWyM-metaDataContainer .metadata-suffix{font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:12px;font-weight:400;letter-spacing:1px}
 #kubio .kubio-index__k__T2yqalWyM-metaDataContainer .h-svg-icon{height:20px;margin-right:5px;width:20px}
 #kubio .kubio-index__k__T2yqalWyM-metaDataContainer .metadata-separator{padding-left:5px;padding-right:5px}
 #kubio h1.wp-block.kubio-index__k__yndIzn0LAb-container,
 #kubio h2.wp-block.kubio-index__k__yndIzn0LAb-container,
 #kubio h3.wp-block.kubio-index__k__yndIzn0LAb-container,
 #kubio h4.wp-block.kubio-index__k__yndIzn0LAb-container,
 #kubio h5.wp-block.kubio-index__k__yndIzn0LAb-container,
 #kubio h6.wp-block.kubio-index__k__yndIzn0LAb-container,
 #kubio p.wp-block.kubio-index__k__yndIzn0LAb-container{padding-top:15px;text-align:left}
 #kubio a.kubio-index__k__yndIzn0LAb-link{text-decoration:none}
 #kubio .kubio-index__k__fVTtKcA3Zp-text{font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:16px;font-weight:400;line-height:1.4;text-align:justify}
 #kubio .kubio-index__k__tBYU0uM8Xx-inner{text-align:center}
 #kubio .kubio-index__k__tBYU0uM8Xx-container{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-index__k__ELgmeRXRD--outer a.kubio-index__k__ELgmeRXRD--link{background-color:rgba(var(--kubio-color-1),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-style:none;border-top-left-radius:3px;border-top-right-radius:3px;border-width:0;color:rgba(var(--kubio-color-5),1);font-size:12px;font-weight:600;justify-content:center;letter-spacing:1px;line-height:1;padding:12px 24px;text-decoration:none}
 #kubio .kubio-index__k__ELgmeRXRD--outer a.kubio-index__k__ELgmeRXRD--link:hover{background-color:rgba(var(--kubio-color-6),1)}
 #kubio a.kubio-index__k__ELgmeRXRD--link .kubio-index__k__ELgmeRXRD--icon{height:12px;margin-left:0;margin-right:10px;min-height:12px;min-width:12px;width:12px}
 #kubio .kubio-index__k__P2OarhUKUK-inner{text-align:center}
 #kubio .kubio-index__k__P2OarhUKUK-container{height:auto;min-height:unset;text-align:center}
 #kubio .kubio-index__k__tRiQFlrj8q-outer{text-align:center}
 #kubio .kubio-index__k__tRiQFlrj8q-outer .page-numbers{font-family:Syncopate,Helvetica,Arial,Sans-Serif,serif;font-size:14px;font-weight:400;padding-left:5px;padding-right:5px}
 #kubio .kubio-index__k__tRiQFlrj8q-outer .page-numbers:not(.current):not(.dots){background-color:rgba(var(--kubio-color-5),0);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;color:rgba(var(--kubio-color-6-variant-4),1);padding:2px 4px}
 #kubio .kubio-index__k__tRiQFlrj8q-outer .page-numbers:not(.current):not(.dots):hover{color:rgba(var(--kubio-color-1),1)}
 #kubio .kubio-index__k__tRiQFlrj8q-outer .page-numbers.current{background-color:rgba(var(--kubio-color-5),0);border-bottom-left-radius:0;border-bottom-right-radius:0;border-top-left-radius:0;border-top-right-radius:0;color:rgba(var(--kubio-color-1),1);padding:2px 4px}
 #kubio .kubio-index__k__tRiQFlrj8q-outer .page-numbers.current:hover{border-color:rgba(var(--kubio-color-1),1)}
 #kubio .kubio-index__k__tRiQFlrj8q-outer .page-numbers.dots{font-weight:300}
 #kubio .kubio-index__k__2nd5yuWmz9-inner{text-align:center}
 #kubio .kubio-index__k__2nd5yuWmz9-container{height:auto;min-height:unset;text-align:right}
 #kubio .kubio-index__k__ACSe8L2gsX-outer a.kubio-index__k__ACSe8L2gsX-link{background-color:rgba(var(--kubio-color-1),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;color:rgba(var(--kubio-color-5),1);font-size:12px;font-weight:600;justify-content:center;letter-spacing:1px;line-height:1;padding:12px 24px;text-decoration:none}
 #kubio .kubio-index__k__ACSe8L2gsX-outer a.kubio-index__k__ACSe8L2gsX-link:hover{background-color:rgba(var(--kubio-color-6),1);border-color:rgba(var(--kubio-color-6-variant-4),1)}
 #kubio a.kubio-index__k__ACSe8L2gsX-link .kubio-index__k__ACSe8L2gsX-icon{height:12px;margin-left:10px;margin-right:0;min-height:12px;min-width:12px;width:12px}
 #kubio .kubio-page__k__DbkmkmgSJj-inner{text-align:left}
 #kubio .kubio-page__k__DbkmkmgSJj-container{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-search__k__kxeqsSpdy-n-inner{text-align:center}
 #kubio .kubio-search__k__kxeqsSpdy-n-container{height:auto;min-height:unset}
 #kubio .kubio-search__k__fx1L_l5Ny--inner{box-shadow:none;padding-bottom:3em;text-align:left}
 #kubio .kubio-search__k__fx1L_l5Ny--container{height:auto;min-height:unset}
 #kubio .kubio-search__k__6duco09NdG-container{background-color:rgba(var(--kubio-color-4),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;height:300px;text-align:center}
 #kubio .kubio-search__k__6duco09NdG-image{-o-object-fit:cover;object-fit:cover;-o-object-position:top center;object-position:top center}
 #kubio .kubio-search__k__nng4XPLA_-metaDataContainer{justify-content:flex-end}
 #kubio .kubio-search__k__nng4XPLA_-metaDataContainer a{color:rgba(var(--kubio-color-6),.5);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:12px;font-weight:400;letter-spacing:1px}
 #kubio .kubio-search__k__nng4XPLA_-metaDataContainer a:hover{color:rgba(var(--kubio-color-1),1)}
 #kubio .kubio-search__k__nng4XPLA_-metaDataContainer .metadata-prefix,
 #kubio .kubio-search__k__nng4XPLA_-metaDataContainer .metadata-suffix{font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:12px;font-weight:400;letter-spacing:1px}
 #kubio .kubio-search__k__nng4XPLA_-metaDataContainer .h-svg-icon{height:20px;margin-right:5px;width:20px}
 #kubio .kubio-search__k__nng4XPLA_-metaDataContainer .metadata-separator{padding-left:5px;padding-right:5px}
 #kubio h1.wp-block.kubio-search__k__yndIzn0LAb-container,
 #kubio h2.wp-block.kubio-search__k__yndIzn0LAb-container,
 #kubio h3.wp-block.kubio-search__k__yndIzn0LAb-container,
 #kubio h4.wp-block.kubio-search__k__yndIzn0LAb-container,
 #kubio h5.wp-block.kubio-search__k__yndIzn0LAb-container,
 #kubio h6.wp-block.kubio-search__k__yndIzn0LAb-container,
 #kubio p.wp-block.kubio-search__k__yndIzn0LAb-container{padding-top:15px;text-align:left}
 #kubio a.kubio-search__k__yndIzn0LAb-link{text-decoration:none}
 #kubio .kubio-search__k__fVTtKcA3Zp-text{font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:16px;font-weight:400}
 #kubio .kubio-search__k__tBYU0uM8Xx-inner{text-align:center}
 #kubio .kubio-search__k__tBYU0uM8Xx-container{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-search__k__ELgmeRXRD--outer a.kubio-search__k__ELgmeRXRD--link{background-color:rgba(var(--kubio-color-1),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-style:none;border-top-left-radius:3px;border-top-right-radius:3px;border-width:0;color:rgba(var(--kubio-color-5),1);font-size:12px;font-weight:600;justify-content:center;letter-spacing:1px;line-height:1;padding:12px 24px;text-decoration:none}
 #kubio .kubio-search__k__ELgmeRXRD--outer a.kubio-search__k__ELgmeRXRD--link:hover{background-color:rgba(var(--kubio-color-6),1)}
 #kubio a.kubio-search__k__ELgmeRXRD--link .kubio-search__k__ELgmeRXRD--icon{height:12px;margin-left:0;margin-right:10px;min-height:12px;min-width:12px;width:12px}
 #kubio .kubio-search__k__P2OarhUKUK-inner{text-align:center}
 #kubio .kubio-search__k__P2OarhUKUK-container{height:auto;min-height:unset;text-align:center}
 #kubio .kubio-search__k__tRiQFlrj8q-outer{text-align:center}
 #kubio .kubio-search__k__tRiQFlrj8q-outer .page-numbers{font-family:Syncopate,Helvetica,Arial,Sans-Serif,serif;font-size:14px;font-weight:400;padding-left:2px;padding-right:2px}
 #kubio .kubio-search__k__tRiQFlrj8q-outer .page-numbers:not(.current):not(.dots){background-color:rgba(var(--kubio-color-5),0);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;color:rgba(var(--kubio-color-6-variant-4),1);padding:2px 4px}
 #kubio .kubio-search__k__tRiQFlrj8q-outer .page-numbers:not(.current):not(.dots):hover{color:rgba(var(--kubio-color-1),1)}
 #kubio .kubio-search__k__tRiQFlrj8q-outer .page-numbers.current{background-color:rgba(var(--kubio-color-5),0);border-bottom-left-radius:0;border-bottom-right-radius:0;border-top-left-radius:0;border-top-right-radius:0;color:rgba(var(--kubio-color-1),1);padding:2px 4px}
 #kubio .kubio-search__k__tRiQFlrj8q-outer .page-numbers.current:hover{border-color:rgba(var(--kubio-color-1),1)}
 #kubio .kubio-search__k__tRiQFlrj8q-outer .page-numbers.dots{font-weight:300}
 #kubio .kubio-search__k__2nd5yuWmz9-inner{text-align:center}
 #kubio .kubio-search__k__2nd5yuWmz9-container{height:auto;min-height:unset;text-align:right}
 #kubio .kubio-search__k__ACSe8L2gsX-outer a.kubio-search__k__ACSe8L2gsX-link{background-color:rgba(var(--kubio-color-1),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-style:none;border-top-left-radius:3px;border-top-right-radius:3px;border-width:0;color:rgba(var(--kubio-color-5),1);font-size:12px;font-weight:600;justify-content:center;letter-spacing:1px;line-height:1;padding:12px 24px;text-decoration:none}
 #kubio .kubio-search__k__ACSe8L2gsX-outer a.kubio-search__k__ACSe8L2gsX-link:hover{background-color:rgba(var(--kubio-color-6),1)}
 #kubio a.kubio-search__k__ACSe8L2gsX-link .kubio-search__k__ACSe8L2gsX-icon{height:12px;margin-left:10px;margin-right:0;min-height:12px;min-width:12px;width:12px}
 #kubio .kubio-search__k__f5wDJx69T0o-inner{text-align:center}
 #kubio .kubio-search__k__f5wDJx69T0o-container{height:auto;min-height:unset}
 #kubio .kubio-search__k__HE2LPNtfKX-inner{border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;text-align:left}
 #kubio .kubio-search__k__HE2LPNtfKX-container{height:auto;min-height:unset}
 #kubio .kubio-search__k__ciaK61IeR-input{background-color:rgba(var(--kubio-color-6),.05);border-bottom-left-radius:3px;border-bottom-right-radius:0;border-top-left-radius:3px;border-top-right-radius:0;font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-weight:400}
 #kubio .kubio-search__k__ciaK61IeR-button{background-color:rgba(var(--kubio-color-1),1);border-bottom-left-radius:0;border-bottom-right-radius:3px;border-style:none;border-top-left-radius:0;border-top-right-radius:3px;border-width:0;color:rgba(var(--kubio-color-5),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:14px;font-weight:400;letter-spacing:0;text-transform:none;width:80px}
 #kubio .kubio-search__k__ciaK61IeR-button:hover{background-color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-search__k__ciaK61IeR-icon{fill:rgba(var(--kubio-color-5),1);height:20px;min-height:20px;min-width:20px;width:20px}
 #kubio .wp-block.wp-block-kubio-heading__text.kubio-search__k__R9xOJzpKQW0-text{margin-bottom:10px}
 #kubio .wp-block.wp-block-kubio-heading__text.kubio-search__k__R9xOJzpKQW0-text .text-wrapper-fancy svg path{stroke:#000;stroke-linejoin:initial;stroke-linecap:initial;stroke-width:8px}
 #kubio .kubio-search__k__dAlw2G59Yo-widget-box{background-color:unset;background-image:none;font-size:14px;margin:0;padding:0}
 #kubio .kubio-search__k__dAlw2G59Yo-widget-box a{color:rgba(var(--kubio-color-1),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:16px;font-weight:400}
 #kubio .kubio-search__k__dAlw2G59Yo-widget-box a:hover{color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-search__k__dAlw2G59Yo-widget-box time{color:rgba(var(--kubio-color-6),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:14px;font-weight:400;margin-bottom:20px}
 #kubio .kubio-search__k__dAlw2G59Yo-widget-box.wp-block-latest-comments .wp-block-latest-comments__comment-excerpt p{color:rgba(var(--kubio-color-6),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:16px;font-weight:400}
 #kubio .kubio-search__k__dAlw2G59Yo-widget-box.wp-block-latest-comments .wp-block-latest-comments__comment-avatar{border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;height:30px;width:30px}
 #kubio .kubio-single__k__single-kxeqsSpdy-n-inner{text-align:center}
 #kubio .kubio-single__k__single-kxeqsSpdy-n-container{height:auto;min-height:unset}
 #kubio .kubio-single__k__single-rlYTEhTMib-container{background-color:rgba(var(--kubio-color-4),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;height:300px;text-align:center}
 #kubio .kubio-single__k__single-rlYTEhTMib-image{-o-object-fit:cover;object-fit:cover;-o-object-position:center center;object-position:center center}
 #kubio .kubio-single__k__KGesgqe_P-metaDataContainer{justify-content:flex-start}
 #kubio .kubio-single__k__KGesgqe_P-metaDataContainer a{color:rgba(var(--kubio-color-6),.5);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:12px;font-weight:400;letter-spacing:1px}
 #kubio .kubio-single__k__KGesgqe_P-metaDataContainer a:hover{color:rgba(var(--kubio-color-1),1)}
 #kubio .kubio-single__k__KGesgqe_P-metaDataContainer .metadata-prefix,
 #kubio .kubio-single__k__KGesgqe_P-metaDataContainer .metadata-suffix{font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:12px;font-weight:400;letter-spacing:1px}
 #kubio .kubio-single__k__KGesgqe_P-metaDataContainer .h-svg-icon{height:20px;margin-right:5px;width:20px}
 #kubio .kubio-single__k__KGesgqe_P-metaDataContainer .metadata-separator{padding-left:5px;padding-right:5px}
 #kubio .kubio-single__k__single-3VGwAjm9cX-inner{text-align:left}
 #kubio .kubio-single__k__single-3VGwAjm9cX-container{height:auto;min-height:unset}
 #kubio .kubio-single__k__wETEbWZUNc-inner{background-color:rgba(var(--kubio-color-1-variant-1),.2);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;text-align:center}
 #kubio .kubio-single__k__wETEbWZUNc-container{height:auto;min-height:unset}
 #kubio p.wp-block.wp-block-kubio-text__text.kubio-single__k__single-1pwRcGAnh-text{font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:14px;font-weight:400;letter-spacing:1px;text-transform:uppercase}
 #kubio .kubio-single__k__up5pQ_Cww-container{text-align:center}
 #kubio .kubio-single__k__up5pQ_Cww-container a{margin-left:2px;margin-right:2px}
 #kubio .kubio-single__k__up5pQ_Cww-container .separator,
 #kubio .kubio-single__k__up5pQ_Cww-container a{font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:12px;font-weight:400}
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner{background-color:rgba(var(--kubio-color-6),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;text-align:center}
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner,
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner [data-kubio]:not(h1):not(h2):not(h3):not(h4):not(h5):not(h6),
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner h1,
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner h1[data-kubio],
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner h2,
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner h2[data-kubio],
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner h3,
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner h3[data-kubio],
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner h4,
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner h4[data-kubio],
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner h5,
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner h5[data-kubio],
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner h6,
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner h6[data-kubio],
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner p,
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner p[data-kubio]{color:rgba(var(--kubio-color-5),1)}
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner a,
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner a[data-kubio]{color:rgba(var(--kubio-color-1-variant-2),1)}
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner a:hover,
 #kubio .kubio-single__k__single-K4Akm2YNqS-inner a[data-kubio]:hover{color:rgba(var(--kubio-color-1-variant-1),1)}
 #kubio .kubio-single__k__single-K4Akm2YNqS-container{height:auto;min-height:unset}
 #kubio .kubio-single__k__single-tlSt_AyBi-container{text-align:center}
 #kubio .kubio-single__k__single-tlSt_AyBi-container a{color:rgba(var(--kubio-color-5),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:12px;font-weight:400;margin:4px 0 4px 4px;padding:0 4px}
 #kubio .kubio-single__k__single-tlSt_AyBi-container a:hover{color:rgba(var(--kubio-color-1-variant-2),1)}
 #kubio .kubio-single__k__single-tlSt_AyBi-placeholder{font-size:13px}
 #kubio .kubio-single__k__single-3ndM77FkZV-inner{text-align:left}
 #kubio .kubio-single__k__single-3ndM77FkZV-container{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-single__k__single-ELgmeRXRD--outer a.kubio-single__k__single-ELgmeRXRD--link{background-color:rgba(var(--kubio-color-1),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-style:none;border-top-left-radius:3px;border-top-right-radius:3px;border-width:0;color:rgba(var(--kubio-color-5),1);font-size:12px;font-weight:600;justify-content:center;letter-spacing:1px;line-height:1;padding:12px 24px;text-decoration:none}
 #kubio .kubio-single__k__single-ELgmeRXRD--outer a.kubio-single__k__single-ELgmeRXRD--link:hover{background-color:rgba(var(--kubio-color-6),1)}
 #kubio a.kubio-single__k__single-ELgmeRXRD--link .kubio-single__k__single-ELgmeRXRD--icon{height:12px;margin-left:0;margin-right:10px;min-height:12px;min-width:12px;width:12px}
 #kubio .kubio-single__k__single-mMPMCQqWfs-inner{padding-left:15px;text-align:right}
 #kubio .kubio-single__k__single-mMPMCQqWfs-container{height:auto;min-height:unset;text-align:right}
 #kubio .kubio-single__k__single-ACSe8L2gsX-outer a.kubio-single__k__single-ACSe8L2gsX-link{background-color:rgba(var(--kubio-color-1),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-style:none;border-top-left-radius:3px;border-top-right-radius:3px;border-width:0;color:rgba(var(--kubio-color-5),1);font-size:12px;font-weight:600;justify-content:center;letter-spacing:1px;line-height:1;padding:12px 24px;text-decoration:none}
 #kubio .kubio-single__k__single-ACSe8L2gsX-outer a.kubio-single__k__single-ACSe8L2gsX-link:hover{background-color:rgba(var(--kubio-color-6),1)}
 #kubio a.kubio-single__k__single-ACSe8L2gsX-link .kubio-single__k__single-ACSe8L2gsX-icon{height:12px;margin-left:10px;margin-right:0;min-height:12px;min-width:12px;width:12px}
 #kubio .kubio-single__k__single-s5UQRGEAN-commentsContainer{color:rgba(var(--kubio-color-6),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-weight:400}
 #kubio .kubio-single__k__single-s5UQRGEAN-commentsContainer .comment.even,
 #kubio .kubio-single__k__single-s5UQRGEAN-commentsContainer .comment.odd{border-left:1px solid rgba(var(--kubio-color-6),.2);margin-top:20px;padding:0 12px}
 #kubio .kubio-single__k__single-s5UQRGEAN-commentsContainer .comment-author img{border-bottom-left-radius:3%;border-bottom-right-radius:3%;border-top-left-radius:3%;border-top-right-radius:3%;margin-right:15px}
 #kubio .kubio-single__k__single-s5UQRGEAN-commentsContainer .comment-author .fn{color:rgba(var(--kubio-color-6),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:14px;font-weight:400;line-height:1.2}
 #kubio .kubio-single__k__single-s5UQRGEAN-commentsContainer .comment-author .fn a{color:rgba(var(--kubio-color-1),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;line-height:1.2}
 #kubio .kubio-single__k__single-s5UQRGEAN-commentsContainer .comment-author .fn a:hover{color:rgba(var(--kubio-color-1-variant-4),1)}
 #kubio .kubio-single__k__single-s5UQRGEAN-commentsContainer .comment-metadata>a{color:rgba(var(--kubio-color-6),.5);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:12px;font-weight:400}
 #kubio .kubio-single__k__single-s5UQRGEAN-commentsContainer .comment-metadata>a:hover{color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-single__k__single-s5UQRGEAN-commentsContainer .comment-metadata>.edit-link>a{color:rgba(var(--kubio-color-2),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:12px;font-weight:400}
 #kubio .kubio-single__k__single-s5UQRGEAN-commentsContainer .comment-metadata>.edit-link>a:hover{color:rgba(var(--kubio-color-2-variant-4),1)}
 #kubio .kubio-single__k__single-s5UQRGEAN-commentsContainer .comment-body .reply a{background-color:rgba(var(--kubio-color-6),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;color:rgba(var(--kubio-color-5),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:12px;font-weight:400;padding:2px 5px}
 #kubio .kubio-single__k__single-s5UQRGEAN-commentsContainer .comment-body .reply a:hover{color:rgba(var(--kubio-color-1-variant-4),1)}
 #kubio .kubio-single__k__single-s5UQRGEAN-commentsContainer .comment>.children{margin-left:12px}
 #kubio .kubio-single__k__single-oXoikmHxB-container .comment-reply-title{color:rgba(var(--kubio-color-6-variant-4),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:1.25em;font-weight:600}
 #kubio .kubio-single__k__single-oXoikmHxB-container label{color:rgba(var(--kubio-color-6),.5);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-weight:400}
 #kubio .kubio-single__k__single-oXoikmHxB-container input:not([type=submit]),
 #kubio .kubio-single__k__single-oXoikmHxB-container textarea{background-color:rgba(var(--kubio-color-5),.6);border:1px solid rgba(var(--kubio-color-6),.2);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;color:rgba(var(--kubio-color-6),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-weight:400}
 #kubio .kubio-single__k__single-oXoikmHxB-container .form-submit{text-align:left}
 #kubio .kubio-single__k__single-oXoikmHxB-container .comment-form [type=submit]{background-color:rgba(var(--kubio-color-1),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-style:none;border-top-left-radius:3px;border-top-right-radius:3px;border-width:0;color:rgba(var(--kubio-color-5),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:16px;font-weight:400;letter-spacing:0;padding:13px 32px;text-transform:none}
 #kubio .kubio-single__k__single-oXoikmHxB-container .comment-form [type=submit]:hover{background-color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-single__k__single-oXoikmHxB-container .comment-form a,
 #kubio .kubio-single__k__single-oXoikmHxB-container .comment-respond a{color:rgba(var(--kubio-color-1),1)}
 #kubio .kubio-single__k__single-oXoikmHxB-container .comment-form a:hover,
 #kubio .kubio-single__k__single-oXoikmHxB-container .comment-respond a:hover{color:rgba(var(--kubio-color-1-variant-4),1)}
 #kubio .kubio-single__k__single-f5wDJx69T0o-inner{text-align:center}
 #kubio .kubio-single__k__single-f5wDJx69T0o-container{height:auto;min-height:unset}
 #kubio .kubio-single__k__HE2LPNtfKX-inner{border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;text-align:left}
 #kubio .kubio-single__k__HE2LPNtfKX-container{height:auto;min-height:unset}
 #kubio .kubio-single__k__ciaK61IeR-input{background-color:rgba(var(--kubio-color-6),.05);border-bottom-left-radius:3px;border-bottom-right-radius:0;border-top-left-radius:3px;border-top-right-radius:0;font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-weight:400}
 #kubio .kubio-single__k__ciaK61IeR-button{background-color:rgba(var(--kubio-color-1),1);border-bottom-left-radius:0;border-bottom-right-radius:3px;border-style:none;border-top-left-radius:0;border-top-right-radius:3px;border-width:0;color:rgba(var(--kubio-color-5),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:14px;font-weight:400;letter-spacing:0;text-transform:none;width:80px}
 #kubio .kubio-single__k__ciaK61IeR-button:hover{background-color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-single__k__ciaK61IeR-icon{fill:rgba(var(--kubio-color-5),1);height:20px;min-height:20px;min-width:20px;width:20px}
 #kubio .wp-block.wp-block-kubio-heading__text.kubio-single__k__R9xOJzpKQW0-text{margin-bottom:10px}
 #kubio .wp-block.wp-block-kubio-heading__text.kubio-single__k__R9xOJzpKQW0-text .text-wrapper-fancy svg path{stroke:#000;stroke-linejoin:initial;stroke-linecap:initial;stroke-width:8px}
 #kubio .kubio-single__k__dAlw2G59Yo-widget-box{background-color:unset;background-image:none;font-size:14px;margin:0;padding:0}
 #kubio .kubio-single__k__dAlw2G59Yo-widget-box a{color:rgba(var(--kubio-color-1),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:16px;font-weight:400}
 #kubio .kubio-single__k__dAlw2G59Yo-widget-box a:hover{color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-single__k__dAlw2G59Yo-widget-box time{color:rgba(var(--kubio-color-6),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:14px;font-weight:400;margin-bottom:20px}
 #kubio .kubio-single__k__dAlw2G59Yo-widget-box.wp-block-latest-comments .wp-block-latest-comments__comment-excerpt p{color:rgba(var(--kubio-color-6),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:16px;font-weight:400}
 #kubio .kubio-single__k__dAlw2G59Yo-widget-box.wp-block-latest-comments .wp-block-latest-comments__comment-avatar{border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-top-left-radius:3px;border-top-right-radius:3px;height:30px;width:30px}
 #kubio .kubio-404-header__k__6mt_9f_jXJ-outer .wp-block-kubio-navigation-section__nav{-webkit-animation-duration:.5s;animation-duration:.5s;padding:30px 20px}
 #kubio .kubio-404-header__k__6mt_9f_jXJ-outer .h-navigation_sticky.wp-block-kubio-navigation-section__nav{background-color:#fff;box-shadow:0 0 10px 0 rgba(23,25,39,.1);padding-bottom:10px;padding-top:10px}
 #kubio .kubio-404-header__k__H8RmTvAhse-inner{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-404-header__k__H8RmTvAhse-container{height:auto;min-height:unset}
 #kubio .kubio-404-header__k__M_USijtyQ9V-container{--kubio-gap-fallback:10px;gap:10px;text-decoration:none}
 #kubio .kubio-404-header__k__M_USijtyQ9V-container .kubio-logo-image,
 #kubio .kubio-404-header__k__M_USijtyQ9V-image{max-height:70px}
 #kubio .kubio-404-header__k__M_USijtyQ9V-text{color:rgba(var(--kubio-color-5),1);font-family:Syncopate,Helvetica,Arial,Sans-Serif,serif;font-size:24px;font-weight:700}
 #kubio .kubio-404-header__k__j2mBpzoGD3u-inner{text-align:center}
 #kubio .kubio-404-header__k__j2mBpzoGD3u-container{height:auto;min-height:unset}
 #kubio .kubio-404-header__k__5MiNu0AQQL1-container{height:50px}
 #kubio .kubio-404-header__k__AfH-7iFRqPz-inner{height:auto;min-height:unset;text-align:right}
 #kubio .kubio-404-header__k__AfH-7iFRqPz-container{height:auto;min-height:unset}
 #kubio .kubio-404-header__k___GipAjLnn8q-outer.bordered-active-item>.kubio-menu>ul>li:after,
 #kubio .kubio-404-header__k___GipAjLnn8q-outer.bordered-active-item>.kubio-menu>ul>li:before{background-color:rgba(var(--kubio-color-5),1);height:1px}
 #kubio .kubio-404-header__k___GipAjLnn8q-outer.solid-active-item>.kubio-menu>ul>li:after,
 #kubio .kubio-404-header__k___GipAjLnn8q-outer.solid-active-item>.kubio-menu>ul>li:before{background-color:#fff;border-bottom-left-radius:0;border-bottom-right-radius:0;border-top-left-radius:0;border-top-right-radius:0}
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul{--kubio-gap-fallback:50px;gap:50px;justify-content:center}
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li>a{color:rgba(var(--kubio-color-5),.8);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:18px;font-weight:400;letter-spacing:0;line-height:1.5em;padding:10px 0;text-decoration:none;text-transform:none}
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li.current-menu-item>a,
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li.current_page_item>a,
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li>a.hover,
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li>a:hover{color:rgba(var(--kubio-color-5),1)}
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li>a>svg{padding-left:5px;padding-right:5px}
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu li>ul{background-color:#fff;box-shadow:0 0 5px 2px rgba(0,0,0,.04);margin-left:5px;margin-right:5px}
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu li>ul>li>a{background-color:#fff;border-bottom:1px solid hsla(0,0%,50%,.2);color:rgba(var(--kubio-color-6),1);font-size:14px;padding:10px 20px;text-decoration:none}
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu li>ul>li.current-menu-item>a,
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu li>ul>li.current_page_item>a,
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu li>ul>li>a.hover,
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu li>ul>li>a:hover{background-color:rgba(var(--kubio-color-1),1);color:rgba(var(--kubio-color-5),1)}
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li>ul{margin-top:10px}
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li>ul:before{height:10px;width:100%}
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer.bordered-active-item>.kubio-menu>ul>li:after,
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer.bordered-active-item>.kubio-menu>ul>li:before{background-color:rgba(var(--kubio-color-6),1)}
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul{justify-content:flex-end}
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li>a{color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-404-header__k__J_ZGXBPetlN-icon{fill:rgba(var(--kubio-color-5),1);background-color:rgba(var(--kubio-color-3-variant-5),0);border:0 #000;border-bottom-left-radius:0;border-bottom-right-radius:0;border-top-left-radius:0;border-top-right-radius:0;height:24px;min-height:24px;min-width:24px;padding:5px;width:24px}
 #kubio .kubio-404-header__k__J_ZGXBPetlN-icon:hover{fill:rgba(var(--kubio-color-1),1)}
 .kubio-404-header__k__J_ZGXBPetlN-offscreen{background-color:rgba(var(--kubio-color-6),1);width:300px!important}
 .kubio-404-header__k__J_ZGXBPetlN-offscreenOverlay{background-color:rgba(0,0,0,.5)}
 #kubio .kubio-404-header__k__lgGJSkbc5GX-inner{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-404-header__k__lgGJSkbc5GX-container{height:auto;min-height:unset}
 #kubio .kubio-404-header__k__fOYPUOZaWPL-container{--kubio-gap-fallback:10px;align-items:flex-start;gap:10px;justify-content:flex-start;padding:25px;text-decoration:none}
 #kubio .kubio-404-header__k__fOYPUOZaWPL-container .kubio-logo-image,
 #kubio .kubio-404-header__k__fOYPUOZaWPL-image{max-height:70px}
 #kubio .kubio-404-header__k__fOYPUOZaWPL-text{color:rgba(var(--kubio-color-5),1);font-family:Poppins,Helvetica,Arial,Sans-Serif,serif;font-size:20px;font-weight:900}
 #kubio .kubio-404-header__k__kiKZXZD5DHk-outer>.kubio-menu>ul{--kubio-accordion-menu-offset:10px}
 #kubio .kubio-404-header__k__kiKZXZD5DHk-outer>.kubio-menu>ul>li>a{border-bottom:1px rgba(var(--kubio-color-5),.2);border-left-color:grey;border-right-color:grey;border-top-color:grey;color:rgba(var(--kubio-color-5),1);font-size:14px;padding-bottom:20px;padding-left:40px;padding-top:20px;text-decoration:none}
 #kubio .kubio-404-header__k__kiKZXZD5DHk-outer>.kubio-menu>ul>li.current-menu-item>a,
 #kubio .kubio-404-header__k__kiKZXZD5DHk-outer>.kubio-menu>ul>li.current_page_item>a,
 #kubio .kubio-404-header__k__kiKZXZD5DHk-outer>.kubio-menu>ul>li>a.hover,
 #kubio .kubio-404-header__k__kiKZXZD5DHk-outer>.kubio-menu>ul>li>a:hover{background-color:rgba(var(--kubio-color-1),1)}
 #kubio .kubio-404-header__k__kiKZXZD5DHk-outer>.kubio-menu>ul>li>a>svg{padding-left:20px;padding-right:20px}
 #kubio .kubio-404-header__k__kiKZXZD5DHk-outer>.kubio-menu li>ul>li>a{border-bottom:1px solid rgba(var(--kubio-color-5),.2);border-left-color:grey;border-right-color:grey;border-top-color:grey;color:rgba(var(--kubio-color-5),1);font-size:14px;padding-bottom:12px;padding-left:40px;padding-top:12px;text-decoration:none}
 #kubio .kubio-404-header__k__kiKZXZD5DHk-outer>.kubio-menu li>ul>li.current-menu-item>a,
 #kubio .kubio-404-header__k__kiKZXZD5DHk-outer>.kubio-menu li>ul>li.current_page_item>a,
 #kubio .kubio-404-header__k__kiKZXZD5DHk-outer>.kubio-menu li>ul>li>a.hover,
 #kubio .kubio-404-header__k__kiKZXZD5DHk-outer>.kubio-menu li>ul>li>a:hover{background-color:rgba(var(--kubio-color-1),.8)}
 #kubio .kubio-404-header__k__kiKZXZD5DHk-outer>.kubio-menu li>ul>li>a>svg{padding-left:20px;padding-right:20px}
 #kubio .kubio-404-header__k__V1o78ibgzH1-inner{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-404-header__k__V1o78ibgzH1-container{height:auto;min-height:unset}
 #kubio .kubio-404-header__k__A7ivpo5AVXC-outer p{color:rgba(var(--kubio-color-5),.4)}
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer{background-attachment:scroll;background-position:50% 50%;background-repeat:no-repeat;background-size:cover;min-height:100vh;padding-bottom:150px;padding-top:150px}
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer,
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer [data-kubio]:not(h1):not(h2):not(h3):not(h4):not(h5):not(h6),
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer h1,
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer h1[data-kubio],
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer h2,
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer h2[data-kubio],
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer h3,
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer h3[data-kubio],
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer h4,
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer h4[data-kubio],
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer h5,
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer h5[data-kubio],
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer h6,
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer h6[data-kubio],
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer p,
 #kubio .kubio-404-header__k__KFTMhA6WOVh-outer p[data-kubio]{color:rgba(var(--kubio-color-5),1)}
 #kubio .kubio-404-header__k__vPVKm6K-swr-inner{border-bottom-left-radius:9px;border-bottom-right-radius:9px;border-top-left-radius:9px;border-top-right-radius:9px;height:auto;min-height:unset;text-align:center}
 #kubio .kubio-404-header__k__vPVKm6K-swr-container{height:auto;min-height:unset}
 #kubio .wp-block.wp-block-kubio-heading__text.kubio-404-header__k__CryHflZk8-text{text-align:center}
 #kubio .wp-block.wp-block-kubio-heading__text.kubio-404-header__k__CryHflZk8-text .text-wrapper-fancy svg path{stroke:#000;stroke-linejoin:initial;stroke-linecap:initial;stroke-width:8px}
 #kubio .kubio-404-header__k__XE8iPl7Auw-outer a.kubio-404-header__k__XE8iPl7Auw-link{background-color:rgba(var(--kubio-color-1),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-style:none;border-top-left-radius:3px;border-top-right-radius:3px;border-width:0;color:#fff;font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:16px;font-weight:400;justify-content:center;letter-spacing:0;line-height:1;padding:16px 32px;text-align:center;text-decoration:none;text-transform:none}
 #kubio .kubio-404-header__k__XE8iPl7Auw-outer a.kubio-404-header__k__XE8iPl7Auw-link:hover{background-color:rgba(var(--kubio-color-6),1)}
 #kubio a.kubio-404-header__k__XE8iPl7Auw-link .kubio-404-header__k__XE8iPl7Auw-icon{height:20px;margin-left:0;margin-right:15px;min-height:20px;min-width:20px;width:20px}
 #kubio .kubio-404-header__k__XE8iPl7Auw-spacing{text-align:center}
 #kubio .kubio-front-header__k__Gp3qTlxXlu-outer .wp-block-kubio-navigation-section__nav{-webkit-animation-duration:.5s;animation-duration:.5s;padding:30px 20px}
 #kubio .kubio-front-header__k__Gp3qTlxXlu-outer .h-navigation_sticky.wp-block-kubio-navigation-section__nav{background-color:#fff;box-shadow:0 0 10px 0 rgba(23,25,39,.1);padding-bottom:10px;padding-top:10px}
 #kubio .kubio-front-header__k__toCQddZ5xwe-outer{background-color:#000;padding-bottom:5px;padding-top:5px}
 #kubio .kubio-front-header__k__f6qqM6zykAu-inner{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-front-header__k__f6qqM6zykAu-container{height:auto;min-height:unset}
 #kubio .kubio-front-header__k__7yznDknZZGE-outer{align-content:flex-start;flex-direction:row;justify-content:flex-start}
 #kubio .kubio-front-header__k__7yznDknZZGE-outer .wp-block-kubio-iconlistitem__text{align-items:center;color:rgba(var(--kubio-color-5),1);font-size:14px;margin-left:5px}
 #kubio .kubio-front-header__k__7yznDknZZGE-outer .wp-block-kubio-iconlistitem__text-wrapper{align-items:center;padding-bottom:0;padding-right:0}
 #kubio .kubio-front-header__k__7yznDknZZGE-outer .wp-block-kubio-iconlistitem__icon{fill:rgba(var(--kubio-color-5),1);border:2px rgba(var(--kubio-color-1),1);height:18px;padding-left:0;width:18px}
 #kubio .kubio-front-header__k__7yznDknZZGE-outer .wp-block-kubio-iconlistitem__icon:hover{background-color:rgba(3,169,244,0)}
 #kubio .kubio-front-header__k__7yznDknZZGE-outer .wp-block-kubio-iconlistitem__divider{border-bottom:0 #000;border-left-width:1px;border-right-width:0;border-style:solid;border-top-width:0;color:#000;height:100%;margin-left:0;width:100%}
 #kubio .kubio-front-header__k__7yznDknZZGE-outer .wp-block-kubio-iconlistitem__divider-wrapper{align-items:center;padding:0 10px;width:1px}
 #kubio .kubio-front-header__k__WYzrSI-Wi8J-inner{height:auto;min-height:unset;text-align:center}
 #kubio .kubio-front-header__k__WYzrSI-Wi8J-container{height:auto;min-height:unset}
 #kubio .kubio-front-header__k__wlDkjcCCsVj-outer{text-align:right}
 #kubio .kubio-front-header__k__wlDkjcCCsVj-outer .h-svg-icon{fill:rgba(var(--kubio-color-5-variant-2),1);height:20px;margin-right:0;min-height:20px;min-width:20px;padding:5px;width:20px}
 #kubio .kubio-front-header__k__wlDkjcCCsVj-outer .h-svg-icon:hover{fill:rgba(var(--kubio-color-5),1)}
 #kubio .kubio-front-header__k__SFXC9Ze09eu-inner{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-front-header__k__SFXC9Ze09eu-container{height:auto;min-height:unset}
 #kubio .kubio-front-header__k__0xSC3AT64-container{--kubio-gap-fallback:10px;gap:10px;text-decoration:none}
 #kubio .kubio-front-header__k__0xSC3AT64-container .kubio-logo-image,
 #kubio .kubio-front-header__k__0xSC3AT64-image{max-height:70px}
 #kubio .kubio-front-header__k__0xSC3AT64-text{color:rgba(var(--kubio-color-5),1);font-family:Syncopate,Helvetica,Arial,Sans-Serif,serif;font-size:24px;font-weight:700}
 #kubio .kubio-front-header__k__DJ3dK9XoVZ-inner{text-align:center}
 #kubio .kubio-front-header__k__DJ3dK9XoVZ-container{height:auto;min-height:unset}
 #kubio .kubio-front-header__k__mRmagmI3LJv-container{height:50px}
 #kubio .kubio-front-header__k__ZEkYpBrx7RA-inner{height:auto;min-height:unset;text-align:right}
 #kubio .kubio-front-header__k__ZEkYpBrx7RA-container{height:auto;min-height:unset}
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer.bordered-active-item>.kubio-menu>ul>li:after,
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer.bordered-active-item>.kubio-menu>ul>li:before{background-color:rgba(var(--kubio-color-5),1);height:1px}
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer.solid-active-item>.kubio-menu>ul>li:after,
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer.solid-active-item>.kubio-menu>ul>li:before{background-color:#fff;border-bottom-left-radius:0;border-bottom-right-radius:0;border-top-left-radius:0;border-top-right-radius:0}
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul{--kubio-gap-fallback:50px;gap:50px;justify-content:center}
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li>a{color:rgba(var(--kubio-color-5),.8);font-family:Mulish,Helvetica,Arial,Sans-Serif,serif;font-size:16px;font-weight:400;letter-spacing:0;line-height:1.5em;padding:10px 0;text-decoration:none;text-transform:none}
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li.current-menu-item>a,
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li.current_page_item>a,
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li>a.hover,
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li>a:hover{color:rgba(var(--kubio-color-5),1)}
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li>a>svg{padding-left:5px;padding-right:5px}
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu li>ul{background-color:#fff;box-shadow:0 0 5px 2px rgba(0,0,0,.04);margin-left:5px;margin-right:5px}
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu li>ul>li>a{background-color:#fff;border-bottom:1px solid hsla(0,0%,50%,.2);color:rgba(var(--kubio-color-6),1);font-size:14px;padding:10px 20px;text-decoration:none}
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu li>ul>li.current-menu-item>a,
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu li>ul>li.current_page_item>a,
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu li>ul>li>a.hover,
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu li>ul>li>a:hover{background-color:rgba(var(--kubio-color-1),1);color:rgba(var(--kubio-color-5),1)}
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li>ul{margin-top:10px}
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li>ul:before{height:10px;width:100%}
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer.bordered-active-item>.kubio-menu>ul>li:after,
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer.bordered-active-item>.kubio-menu>ul>li:before{background-color:rgba(var(--kubio-color-6),1)}
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul{justify-content:flex-end}
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li>a{color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-front-header__k__r1Ph182_RWJ-icon{fill:rgba(var(--kubio-color-5),1);background-color:rgba(var(--kubio-color-3-variant-5),0);border:0 #000;border-bottom-left-radius:0;border-bottom-right-radius:0;border-top-left-radius:0;border-top-right-radius:0;height:24px;min-height:24px;min-width:24px;padding:5px;width:24px}
 #kubio .kubio-front-header__k__r1Ph182_RWJ-icon:hover{fill:rgba(var(--kubio-color-1),1)}
 .kubio-front-header__k__r1Ph182_RWJ-offscreen{background-color:rgba(var(--kubio-color-6),1);width:300px!important}
 .kubio-front-header__k__r1Ph182_RWJ-offscreenOverlay{background-color:rgba(0,0,0,.5)}
 #kubio .kubio-front-header__k__dySu33XviAE-inner{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-front-header__k__dySu33XviAE-container{height:auto;min-height:unset}
 #kubio .kubio-front-header__k__nVjkPY2tu-container{--kubio-gap-fallback:10px;align-items:flex-start;gap:10px;justify-content:flex-start;text-decoration:none}
 #kubio .kubio-front-header__k__nVjkPY2tu-container .kubio-logo-image,
 #kubio .kubio-front-header__k__nVjkPY2tu-image{max-height:70px}
 #kubio .kubio-front-header__k__nVjkPY2tu-text{color:rgba(var(--kubio-color-5),1);font-family:Syncopate,Helvetica,Arial,Sans-Serif,serif;font-size:20px;font-weight:700}
 #kubio .kubio-front-header__k__RfKm7zJUMjR-outer>.kubio-menu>ul{--kubio-accordion-menu-offset:10px}
 #kubio .kubio-front-header__k__RfKm7zJUMjR-outer>.kubio-menu>ul>li>a{border-bottom:1px rgba(var(--kubio-color-5),.2);border-left-color:grey;border-right-color:grey;border-top-color:grey;color:rgba(var(--kubio-color-5),1);font-size:14px;padding-bottom:20px;padding-left:40px;padding-top:20px;text-decoration:none}
 #kubio .kubio-front-header__k__RfKm7zJUMjR-outer>.kubio-menu>ul>li.current-menu-item>a,
 #kubio .kubio-front-header__k__RfKm7zJUMjR-outer>.kubio-menu>ul>li.current_page_item>a,
 #kubio .kubio-front-header__k__RfKm7zJUMjR-outer>.kubio-menu>ul>li>a.hover,
 #kubio .kubio-front-header__k__RfKm7zJUMjR-outer>.kubio-menu>ul>li>a:hover{background-color:rgba(var(--kubio-color-1),1)}
 #kubio .kubio-front-header__k__RfKm7zJUMjR-outer>.kubio-menu>ul>li>a>svg{padding-left:20px;padding-right:20px}
 #kubio .kubio-front-header__k__RfKm7zJUMjR-outer>.kubio-menu li>ul>li>a{border-bottom:1px solid rgba(var(--kubio-color-5),.2);border-left-color:grey;border-right-color:grey;border-top-color:grey;color:rgba(var(--kubio-color-5),1);font-size:14px;padding-bottom:12px;padding-left:40px;padding-top:12px;text-decoration:none}
 #kubio .kubio-front-header__k__RfKm7zJUMjR-outer>.kubio-menu li>ul>li.current-menu-item>a,
 #kubio .kubio-front-header__k__RfKm7zJUMjR-outer>.kubio-menu li>ul>li.current_page_item>a,
 #kubio .kubio-front-header__k__RfKm7zJUMjR-outer>.kubio-menu li>ul>li>a.hover,
 #kubio .kubio-front-header__k__RfKm7zJUMjR-outer>.kubio-menu li>ul>li>a:hover{background-color:rgba(var(--kubio-color-1),.8)}
 #kubio .kubio-front-header__k__RfKm7zJUMjR-outer>.kubio-menu li>ul>li>a>svg{padding-left:20px;padding-right:20px}
 #kubio .kubio-front-header__k__7AuOkWajPWG-inner{height:auto;min-height:unset;text-align:left}
 #kubio .kubio-front-header__k__7AuOkWajPWG-container{height:auto;min-height:unset}
 #kubio .kubio-front-header__k__nicBEJtZM-outer p{color:rgba(var(--kubio-color-5),.4)}
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer{background-attachment:fixed;background-position:0 0;background-repeat:no-repeat;background-size:cover;height:auto;min-height:unset}
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer,
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer [data-kubio]:not(h1):not(h2):not(h3):not(h4):not(h5):not(h6),
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer h1,
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer h1[data-kubio],
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer h2,
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer h2[data-kubio],
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer h3,
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer h3[data-kubio],
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer h4,
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer h4[data-kubio],
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer h5,
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer h5[data-kubio],
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer h6,
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer h6[data-kubio],
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer p,
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer p[data-kubio]{color:rgba(var(--kubio-color-5),1)}
 #kubio .kubio-front-header__k__9IGHpldIpw-inner{height:auto;min-height:unset;text-align:center}
 #kubio .kubio-front-header__k__9IGHpldIpw-container{height:auto;min-height:unset}
 #kubio .wp-block.wp-block-kubio-heading__text.kubio-front-header__k__ukjZtaF3MN-text .text-wrapper-fancy svg path{stroke:#000;stroke-linejoin:initial;stroke-linecap:initial;stroke-width:8px}
 #kubio .kubio-front-header__k__9uoTT9gnxCy-outer{padding-top:40px}
 #kubio .kubio-front-header__k__Dud6AOZG0Hc-outer a.kubio-front-header__k__Dud6AOZG0Hc-link{background-color:rgba(var(--kubio-color-1),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-style:none;border-top-left-radius:3px;border-top-right-radius:3px;border-width:0;color:rgba(var(--kubio-color-5),1);justify-content:center;padding:15px 40px;text-align:center;text-decoration:none}
 #kubio .kubio-front-header__k__Dud6AOZG0Hc-outer a.kubio-front-header__k__Dud6AOZG0Hc-link:hover{background-color:rgba(var(--kubio-color-6),1);border-color:rgba(var(--kubio-color-2-variant-3),1)}
 #kubio a.kubio-front-header__k__Dud6AOZG0Hc-link .kubio-front-header__k__Dud6AOZG0Hc-icon{height:14px;margin-left:10px;margin-right:0;min-height:14px;min-width:14px;width:14px}
 #kubio .kubio-front-header__k__OcIljpMOK-outer a.kubio-front-header__k__OcIljpMOK-link{background-color:rgba(var(--kubio-color-5),1);border-bottom-left-radius:3px;border-bottom-right-radius:3px;border-style:none;border-top-left-radius:3px;border-top-right-radius:3px;border-width:0;color:rgba(var(--kubio-color-6),1);justify-content:center;padding:15px 40px;text-align:center;text-decoration:none}
 #kubio .kubio-front-header__k__OcIljpMOK-outer a.kubio-front-header__k__OcIljpMOK-link:hover{background-color:rgba(var(--kubio-color-1),1);color:rgba(var(--kubio-color-5),1)}
 #kubio a.kubio-front-header__k__OcIljpMOK-link .kubio-front-header__k__OcIljpMOK-icon{height:14px;margin-left:10px;margin-right:0;min-height:14px;min-width:14px;width:14px}
 #kubio .kubio-front-header__k__3z5JmMUdl-inner{text-align:center}
 #kubio .kubio-front-header__k__3z5JmMUdl-container{height:auto;min-height:unset}
 #kubio .kubio-local-4-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-12-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-21-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-23-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-25-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-31-container,
 #kubio .kubio-local-36-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-40-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-48-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-57-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-59-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-61-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-67-container,
 #kubio .kubio-local-72-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-76-container{flex:0 0 auto;-ms-flex:0 0 auto;width:50%}
 #kubio .kubio-local-81-container{flex:0 0 auto;-ms-flex:0 0 auto}
 #kubio .kubio-local-87-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-95-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-104-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-106-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-108-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-114-container,
 #kubio .kubio-local-119-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-123-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-131-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-140-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-142-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-144-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-150-container,
 #kubio .kubio-local-155-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-159-container{flex:0 0 auto;-ms-flex:0 0 auto;width:50%}
 #kubio .kubio-local-163-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-166-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-169-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-172-container{flex:0 0 auto;-ms-flex:0 0 auto}
 #kubio .kubio-local-178-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-180-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-182-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-186-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-189-container{flex:0 0 auto;-ms-flex:0 0 auto}
 #kubio .kubio-local-195-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-197-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-199-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-204-container{flex:0 0 auto;-ms-flex:0 0 auto}
 #kubio .kubio-local-210-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-218-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-227-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-229-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-231-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-237-container,
 #kubio .kubio-local-242-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-246-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-254-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-263-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-265-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-267-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-273-container,
 #kubio .kubio-local-278-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-282-container{flex:0 0 auto;-ms-flex:0 0 auto;width:50%}
 #kubio .kubio-local-286-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-290-container{flex:0 0 auto;-ms-flex:0 0 auto}
 #kubio .kubio-local-296-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-304-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-313-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-315-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-317-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-323-container,
 #kubio .kubio-local-328-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-332-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-340-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-349-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-351-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-353-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-359-container,
 #kubio .kubio-local-364-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-368-container{flex:0 0 auto;-ms-flex:0 0 auto;width:50%}
 #kubio .kubio-local-372-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-375-container{flex:0 0 auto;-ms-flex:0 0 auto}
 #kubio .kubio-local-381-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-383-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-385-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-387-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-390-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-395-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-398-container{flex:0 0 auto;-ms-flex:0 0 auto}
 #kubio .kubio-local-404-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-406-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-408-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-413-container{flex:0 0 auto;-ms-flex:0 0 auto}
 #kubio .kubio-local-419-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-427-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-436-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-438-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-440-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-446-container,
 #kubio .kubio-local-451-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-455-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-463-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-472-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-474-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-476-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-482-container,
 #kubio .kubio-local-487-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-491-container{flex:0 0 auto;-ms-flex:0 0 auto;width:50%}
 #kubio .kubio-local-495-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-499-container,
 #kubio .kubio-local-501-container,
 #kubio .kubio-local-505-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-509-container,
 #kubio .kubio-local-511-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-515-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-518-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-523-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-527-container,
 #kubio .kubio-local-529-container,
 #kubio .kubio-local-533-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-537-container,
 #kubio .kubio-local-539-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-546-container{flex:0 0 auto;-ms-flex:0 0 auto}
 #kubio .kubio-local-553-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-555-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-557-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-563-container,
 #kubio .kubio-local-568-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-573-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-575-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-577-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-583-container,
 #kubio .kubio-local-588-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-592-container{flex:0 0 auto;-ms-flex:0 0 auto;width:50%}
 #kubio .kubio-local-599-container{flex:0 0 auto;-ms-flex:0 0 auto}
 #kubio .kubio-local-605-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-613-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-622-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-624-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-626-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-632-container,
 #kubio .kubio-local-637-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-641-container{flex:0 0 auto;-ms-flex:0 0 auto;width:75%}
 #kubio .kubio-local-649-container{flex:0 0 auto;-ms-flex:0 0 auto;width:25%}
 #kubio .kubio-local-658-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-660-container{ms-flex:1 1 0%;flex:1 1 0;max-width:100%}
 #kubio .kubio-local-662-container{ms-flex:0 0 auto;flex:0 0 auto;max-width:100%;width:auto}
 #kubio .kubio-local-668-container,
 #kubio .kubio-local-673-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-677-container,
 #kubio .kubio-local-686-container{flex:0 0 auto;-ms-flex:0 0 auto;width:50%}
 #kubio .kubio-local-691-container{flex:0 0 auto;-ms-flex:0 0 auto}
 .h-x-container-inner>*,
 .h-y-container>:not(:last-child){margin-bottom:20px}
 .h-column__content>.h-x-container>:last-child,
 .h-x-container-inner,
 .h-y-container>.kubio-block-inserter{margin-bottom:-20px}
 .h-x-container-inner{margin-left:-10px;margin-right:-10px}
 .h-x-container-inner>*{padding-left:10px;padding-right:10px}
 body .kubio-index__k__fx1L_l5Ny--container>*>.h-y-container>:not(:last-child),
 body .kubio-search__k__fx1L_l5Ny--container>*>.h-y-container>:not(:last-child){margin-bottom:5px}
 body .kubio-single__k__single-3VGwAjm9cX-container>*>.h-y-container>:not(:last-child){margin-bottom:0}
 body .kubio-single__k__single-K4Akm2YNqS-container>*>.h-y-container>:not(:last-child){margin-bottom:5px}
 body .kubio-404-header__k__vPVKm6K-swr-container>*>.h-y-container>:not(:last-child){margin-bottom:40px}
 body .kubio-front-header__k__9IGHpldIpw-container>*>.h-y-container>:not(:last-child){margin-bottom:0}
 .with-kubio-global-style a:not([class*=wp-block-button]),
 [data-kubio] a:not([class*=wp-block-button]),
 a:not([class*=wp-block-button])[data-kubio]{color:rgba(var(--kubio-color-1),1);font-family:Mulish,Helvetica,Arial,Sans-Serif,serif;font-size:1em;font-weight:600;line-height:1.5;text-decoration:none}
 .with-kubio-global-style a:not([class*=wp-block-button]):hover,
 [data-kubio] a:not([class*=wp-block-button]):hover,
 a:not([class*=wp-block-button])[data-kubio]:hover{color:rgba(var(--kubio-color-1-variant-4),1)}
 .with-kubio-global-style h1,
 [data-kubio] h1,
 h1[data-kubio]{font-size:5.5em;line-height:1.26}
 .with-kubio-global-style h1,
 .with-kubio-global-style h2,
 [data-kubio] h1,
 [data-kubio] h2,
 h1[data-kubio],
 h2[data-kubio]{color:rgba(var(--kubio-color-6),1);font-family:Mulish,Helvetica,Arial,Sans-Serif,serif;font-weight:700;text-transform:none}
 .with-kubio-global-style h2,
 [data-kubio] h2,
 h2[data-kubio]{font-size:3em;line-height:1.143}
 .with-kubio-global-style h3,
 [data-kubio] h3,
 h3[data-kubio]{color:rgba(var(--kubio-color-6),1);font-family:Mulish,Helvetica,Arial,Sans-Serif,serif;font-size:1.8em;font-weight:700;line-height:1.25;text-transform:none}
 .with-kubio-global-style h4,
 [data-kubio] h4,
 h4[data-kubio]{font-size:1.4em;font-weight:500}
 .with-kubio-global-style h4,
 .with-kubio-global-style h5,
 [data-kubio] h4,
 [data-kubio] h5,
 h4[data-kubio],
 h5[data-kubio]{color:rgba(var(--kubio-color-6),1);font-family:Mulish,Helvetica,Arial,Sans-Serif,serif;line-height:1.4;text-transform:none}
 .with-kubio-global-style h5,
 [data-kubio] h5,
 h5[data-kubio]{font-size:1.125em;font-weight:400}
 .with-kubio-global-style h6,
 [data-kubio] h6,
 h6[data-kubio]{color:rgba(var(--kubio-color-1),1);font-family:Mulish,Helvetica,Arial,Sans-Serif,serif;font-size:.9em;font-weight:400;letter-spacing:1px;line-height:1.4;text-transform:uppercase}
 .with-kubio-global-style,
 .with-kubio-global-style p,
 [data-kubio],
 [data-kubio] p,
 p[data-kubio]{color:rgba(var(--kubio-color-6-variant-4),1);font-family:Mulish,Helvetica,Arial,Sans-Serif,serif;font-size:16px;font-weight:300;line-height:1.4;text-transform:none}
 .h-lead[data-kubio],
 .with-kubio-global-style .h-lead,
 [data-kubio] .h-lead{color:rgba(var(--kubio-color-6),1);font-family:Mulish,Helvetica,Arial,Sans-Serif,serif;font-size:1.2em;font-weight:400;line-height:1.5;text-transform:none}
 div.h-section-global-spacing{padding-bottom:100px;padding-top:100px}
 .h-global-transition,
 .h-global-transition-all,
 .h-global-transition-all *{transition-duration:1s}
 [data-kubio] input:not([type]),
 [data-kubio] input[type=color],
 [data-kubio] input[type=date],
 [data-kubio] input[type=datetime-local],
 [data-kubio] input[type=datetime],
 [data-kubio] input[type=email],
 [data-kubio] input[type=month],
 [data-kubio] input[type=number],
 [data-kubio] input[type=password],
 [data-kubio] input[type=search],
 [data-kubio] input[type=tel],
 [data-kubio] input[type=text],
 [data-kubio] input[type=time],
 [data-kubio] input[type=url],
 [data-kubio] input[type=week],
 [data-kubio] select,
 [data-kubio] textarea{background-color:rgba(var(--kubio-color-5),1);border:1px solid rgba(var(--kubio-color-5-variant-2),1);border-bottom-left-radius:4px;border-bottom-right-radius:4px;border-top-left-radius:4px;border-top-right-radius:4px;font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-size:16px;font-weight:400;line-height:1.6;margin-bottom:10px;padding:4px 10px;text-transform:none}
 [data-kubio] input:not([type]):hover,
 [data-kubio] input[type=color]:hover,
 [data-kubio] input[type=date]:hover,
 [data-kubio] input[type=datetime-local]:hover,
 [data-kubio] input[type=datetime]:hover,
 [data-kubio] input[type=email]:hover,
 [data-kubio] input[type=month]:hover,
 [data-kubio] input[type=number]:hover,
 [data-kubio] input[type=password]:hover,
 [data-kubio] input[type=search]:hover,
 [data-kubio] input[type=tel]:hover,
 [data-kubio] input[type=text]:hover,
 [data-kubio] input[type=time]:hover,
 [data-kubio] input[type=url]:hover,
 [data-kubio] input[type=week]:hover,
 [data-kubio] select:hover,
 [data-kubio] textarea:hover{border-color:rgba(var(--kubio-color-6-variant-1),1);color:rgba(var(--kubio-color-6),1)}
 [data-kubio] input:not([type]):focus,
 [data-kubio] input[type=color]:focus,
 [data-kubio] input[type=date]:focus,
 [data-kubio] input[type=datetime-local]:focus,
 [data-kubio] input[type=datetime]:focus,
 [data-kubio] input[type=email]:focus,
 [data-kubio] input[type=month]:focus,
 [data-kubio] input[type=number]:focus,
 [data-kubio] input[type=password]:focus,
 [data-kubio] input[type=search]:focus,
 [data-kubio] input[type=tel]:focus,
 [data-kubio] input[type=text]:focus,
 [data-kubio] input[type=time]:focus,
 [data-kubio] input[type=url]:focus,
 [data-kubio] input[type=week]:focus,
 [data-kubio] select:focus,
 [data-kubio] textarea:focus{border-color:rgba(var(--kubio-color-1),1);color:rgba(var(--kubio-color-6),1)}
 [data-kubio] button:not(figure button):where(:not(.wp-block-accordion-heading__toggle):not(.wp-block-navigation-submenu__toggle):not(.wp-block-woocommerce-accordion-header .accordion-item__toggle)),
 [data-kubio] input[type=button]:not(figure input[type=button]){background-color:rgba(var(--kubio-color-1),1);border:2px solid rgba(var(--kubio-color-1),1);border-bottom-left-radius:4px;border-bottom-right-radius:4px;border-top-left-radius:4px;border-top-right-radius:4px;color:rgba(var(--kubio-color-5),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-weight:400;padding:8px 24px 8px 25px}
 [data-kubio] button:not(figure button):where(:not(.wp-block-accordion-heading__toggle):not(.wp-block-navigation-submenu__toggle):not(.wp-block-woocommerce-accordion-header .accordion-item__toggle)):hover,
 [data-kubio] input[type=button]:not(figure input[type=button]):hover{background-color:rgba(var(--kubio-color-1-variant-4),1);border-color:rgba(var(--kubio-color-1-variant-4),1)}
 [data-kubio] button:not(figure button):where(:not(.wp-block-accordion-heading__toggle):not(.wp-block-navigation-submenu__toggle):not(.wp-block-woocommerce-accordion-header .accordion-item__toggle)):disabled,
 [data-kubio] button:not(figure button):where(:not(.wp-block-accordion-heading__toggle):not(.wp-block-navigation-submenu__toggle):not(.wp-block-woocommerce-accordion-header .accordion-item__toggle))[disabled],
 [data-kubio] input[type=button]:not(figure input[type=button]):disabled,
 [data-kubio] input[type=button]:not(figure input[type=button])[disabled]{background-color:rgba(var(--kubio-color-5-variant-2),1);border-color:rgba(var(--kubio-color-5-variant-2),1);color:rgba(var(--kubio-color-5-variant-3),1)}
 [data-kubio] button:not(figure button):where(:not(.wp-block-accordion-heading__toggle):not(.wp-block-navigation-submenu__toggle):not(.wp-block-woocommerce-accordion-header .accordion-item__toggle))[type=submit],
 [data-kubio] input[type=submit]{background-color:rgba(var(--kubio-color-1),1);border:2px solid rgba(var(--kubio-color-1),1);border-bottom-left-radius:4px;border-bottom-right-radius:4px;border-top-left-radius:4px;border-top-right-radius:4px;color:rgba(var(--kubio-color-5),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-weight:400;padding:8px 24px 8px 25px}
 [data-kubio] button:not(figure button):where(:not(.wp-block-accordion-heading__toggle):not(.wp-block-navigation-submenu__toggle):not(.wp-block-woocommerce-accordion-header .accordion-item__toggle))[type=submit]:hover,
 [data-kubio] input[type=submit]:hover{background-color:rgba(var(--kubio-color-1-variant-4),1);border-color:rgba(var(--kubio-color-1-variant-4),1)}
 [data-kubio] button:not(figure button):where(:not(.wp-block-accordion-heading__toggle):not(.wp-block-navigation-submenu__toggle):not(.wp-block-woocommerce-accordion-header .accordion-item__toggle))[type=submit]:disabled,
 [data-kubio] button:not(figure button):where(:not(.wp-block-accordion-heading__toggle):not(.wp-block-navigation-submenu__toggle):not(.wp-block-woocommerce-accordion-header .accordion-item__toggle))[type=submit][disabled],
 [data-kubio] input[type=submit]:disabled,
 [data-kubio] input[type=submit][disabled]{background-color:rgba(var(--kubio-color-5-variant-2),1);border-color:rgba(var(--kubio-color-5-variant-2),1);color:rgba(var(--kubio-color-5-variant-3),1)}
 [data-kubio] button:not(figure button):where(:not(.wp-block-accordion-heading__toggle):not(.wp-block-navigation-submenu__toggle):not(.wp-block-woocommerce-accordion-header .accordion-item__toggle))[type=reset],
 [data-kubio] input[type=reset]{background-color:rgba(var(--kubio-color-1-variant-1),1);border:2px solid rgba(var(--kubio-color-1-variant-1),1);border-bottom-left-radius:4px;border-bottom-right-radius:4px;border-top-left-radius:4px;border-top-right-radius:4px;color:rgba(var(--kubio-color-6-variant-2),1);font-family:Syne,Helvetica,Arial,Sans-Serif,serif;font-weight:400;padding:8px 24px 8px 25px}
 [data-kubio] button:not(figure button):where(:not(.wp-block-accordion-heading__toggle):not(.wp-block-navigation-submenu__toggle):not(.wp-block-woocommerce-accordion-header .accordion-item__toggle))[type=reset]:hover,
 [data-kubio] input[type=reset]:hover{background-color:rgba(var(--kubio-color-1-variant-2),1);border-color:rgba(var(--kubio-color-1-variant-2),1)}
 [data-kubio] button:not(figure button):where(:not(.wp-block-accordion-heading__toggle):not(.wp-block-navigation-submenu__toggle):not(.wp-block-woocommerce-accordion-header .accordion-item__toggle))[type=reset]:disabled,
 [data-kubio] button:not(figure button):where(:not(.wp-block-accordion-heading__toggle):not(.wp-block-navigation-submenu__toggle):not(.wp-block-woocommerce-accordion-header .accordion-item__toggle))[type=reset][disabled],
 [data-kubio] input[type=reset]:disabled,
 [data-kubio] input[type=reset][disabled]{background-color:rgba(var(--kubio-color-5-variant-2),1);border-color:rgba(var(--kubio-color-5-variant-2),1);color:rgba(var(--kubio-color-5-variant-3),1)}
 #kubio .woocommerce #respond input#submit,
 #kubio .woocommerce a.button,
 #kubio .woocommerce button.button,
 #kubio .woocommerce input.button{background-color:rgba(var(--kubio-color-2),1);border:2px solid rgba(var(--kubio-color-2),1);border-bottom-left-radius:4px;border-bottom-right-radius:4px;border-top-left-radius:4px;border-top-right-radius:4px;color:rgba(var(--kubio-color-5),1);font-family:Open Sans,Helvetica,Arial,Sans-Serif,serif;font-size:14px;font-weight:400;line-height:1.2;text-transform:none}
 #kubio .woocommerce #respond input#submit:hover,
 #kubio .woocommerce a.button:hover,
 #kubio .woocommerce button.button:hover,
 #kubio .woocommerce input.button:hover{background-color:rgba(var(--kubio-color-2-variant-4),1);border-color:rgba(var(--kubio-color-2-variant-4),1)}
 #kubio .woocommerce #respond input#submit:disabled,
 #kubio .woocommerce #respond input#submit[disabled],
 #kubio .woocommerce a.button:disabled,
 #kubio .woocommerce a.button[disabled],
 #kubio .woocommerce button.button:disabled,
 #kubio .woocommerce button.button[disabled],
 #kubio .woocommerce input.button:disabled,
 #kubio .woocommerce input.button[disabled]{background-color:rgba(var(--kubio-color-5-variant-2),1);border-color:rgba(var(--kubio-color-5-variant-2),1);color:rgba(var(--kubio-color-5-variant-4),1)}
 #kubio .woocommerce #respond input#submit.add_to_cart_button,
 #kubio .woocommerce #respond input#submit.alt,
 #kubio .woocommerce #respond input#submit.woocommerce-form-login__submit,
 #kubio .woocommerce a.button.add_to_cart_button,
 #kubio .woocommerce a.button.alt,
 #kubio .woocommerce a.button.woocommerce-form-login__submit,
 #kubio .woocommerce button.button.add_to_cart_button,
 #kubio .woocommerce button.button.alt,
 #kubio .woocommerce button.button.woocommerce-form-login__submit,
 #kubio .woocommerce input.button.add_to_cart_button,
 #kubio .woocommerce input.button.alt,
 #kubio .woocommerce input.button.woocommerce-form-login__submit{background-color:rgba(var(--kubio-color-1),1);border:2px solid rgba(var(--kubio-color-1),1);border-bottom-left-radius:4px;border-bottom-right-radius:4px;border-top-left-radius:4px;border-top-right-radius:4px;box-shadow:0 27px 15px -24px rgba(0,0,0,.5);color:rgba(var(--kubio-color-5),1);font-family:Open Sans,Helvetica,Arial,Sans-Serif,serif;font-size:14px;font-weight:400;line-height:1.2;text-transform:none}
 #kubio .woocommerce #respond input#submit.add_to_cart_button:hover,
 #kubio .woocommerce #respond input#submit.alt:hover,
 #kubio .woocommerce #respond input#submit.woocommerce-form-login__submit:hover,
 #kubio .woocommerce a.button.add_to_cart_button:hover,
 #kubio .woocommerce a.button.alt:hover,
 #kubio .woocommerce a.button.woocommerce-form-login__submit:hover,
 #kubio .woocommerce button.button.add_to_cart_button:hover,
 #kubio .woocommerce button.button.alt:hover,
 #kubio .woocommerce button.button.woocommerce-form-login__submit:hover,
 #kubio .woocommerce input.button.add_to_cart_button:hover,
 #kubio .woocommerce input.button.alt:hover,
 #kubio .woocommerce input.button.woocommerce-form-login__submit:hover{background-color:rgba(var(--kubio-color-1-variant-4),1);border-color:rgba(var(--kubio-color-1-variant-4),1)}
 #kubio .woocommerce #respond input#submit.add_to_cart_button:disabled,
 #kubio .woocommerce #respond input#submit.add_to_cart_button[disabled],
 #kubio .woocommerce #respond input#submit.alt:disabled,
 #kubio .woocommerce #respond input#submit.alt[disabled],
 #kubio .woocommerce #respond input#submit.woocommerce-form-login__submit:disabled,
 #kubio .woocommerce #respond input#submit.woocommerce-form-login__submit[disabled],
 #kubio .woocommerce a.button.add_to_cart_button:disabled,
 #kubio .woocommerce a.button.add_to_cart_button[disabled],
 #kubio .woocommerce a.button.alt:disabled,
 #kubio .woocommerce a.button.alt[disabled],
 #kubio .woocommerce a.button.woocommerce-form-login__submit:disabled,
 #kubio .woocommerce a.button.woocommerce-form-login__submit[disabled],
 #kubio .woocommerce button.button.add_to_cart_button:disabled,
 #kubio .woocommerce button.button.add_to_cart_button[disabled],
 #kubio .woocommerce button.button.alt:disabled,
 #kubio .woocommerce button.button.alt[disabled],
 #kubio .woocommerce button.button.woocommerce-form-login__submit:disabled,
 #kubio .woocommerce button.button.woocommerce-form-login__submit[disabled],
 #kubio .woocommerce input.button.add_to_cart_button:disabled,
 #kubio .woocommerce input.button.add_to_cart_button[disabled],
 #kubio .woocommerce input.button.alt:disabled,
 #kubio .woocommerce input.button.alt[disabled],
 #kubio .woocommerce input.button.woocommerce-form-login__submit:disabled,
 #kubio .woocommerce input.button.woocommerce-form-login__submit[disabled]{background-color:rgba(var(--kubio-color-5-variant-2),1);border-color:rgba(var(--kubio-color-5-variant-2),1);color:rgba(var(--kubio-color-5-variant-4),1)}
 #kubio .woocommerce-loop-product__link .onsale{background-color:rgba(var(--kubio-color-3-variant-2),1);border-bottom-left-radius:10px;border-bottom-right-radius:10px;border-top-left-radius:10px;border-top-right-radius:10px;color:rgba(var(--kubio-color-5),1);padding:5px 10px}@media (min-width:768px) and (max-width:1023px){
 #kubio .kubio-header__k__jZZ7ZgkWWk-outer .h-navigation_sticky.wp-block-kubio-navigation-section__nav{padding-bottom:30px;padding-top:30px}
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer.bordered-active-item>.kubio-menu>ul>li:after,
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer.bordered-active-item>.kubio-menu>ul>li:before{background-color:rgba(var(--kubio-color-5),1)}
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul{justify-content:center}
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li>a{color:rgba(var(--kubio-color-5),.8)}
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li.current-menu-item>a,
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li.current_page_item>a,
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li>a.hover,
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li>a:hover{color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-header__k__x8ZMD9qFOX9-container{padding:10px}
 #kubio .kubio-header__k__KFTMhA6WOVh-outer{padding-bottom:60px;padding-top:60px}
 #kubio .kubio-index__k__kxeqsSpdy-n-inner{margin-top:-15px}
 #kubio .kubio-404-header__k__6mt_9f_jXJ-outer .h-navigation_sticky.wp-block-kubio-navigation-section__nav{padding-bottom:30px;padding-top:30px}
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer.bordered-active-item>.kubio-menu>ul>li:after,
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer.bordered-active-item>.kubio-menu>ul>li:before{background-color:rgba(var(--kubio-color-5),1)}
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul{justify-content:center}
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li>a{color:rgba(var(--kubio-color-5),.8)}
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li.current-menu-item>a,
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li.current_page_item>a,
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li>a.hover,
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li>a:hover{color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-404-header__k__fOYPUOZaWPL-container{padding:30px}
 #kubio .kubio-front-header__k__Gp3qTlxXlu-outer .h-navigation_sticky.wp-block-kubio-navigation-section__nav{padding-bottom:30px;padding-top:30px}
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer.bordered-active-item>.kubio-menu>ul>li:after,
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer.bordered-active-item>.kubio-menu>ul>li:before{background-color:rgba(var(--kubio-color-5),1)}
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul{justify-content:center}
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li>a{color:rgba(var(--kubio-color-5),.8)}
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li.current-menu-item>a,
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li.current_page_item>a,
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li>a.hover,
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li>a:hover{color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-front-header__k__nVjkPY2tu-container{padding:10px}
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer{padding-top:60px}
 #kubio .kubio-local-76-container,
 #kubio .kubio-local-159-container{width:80%}
 #kubio .kubio-local-163-container{width:33%}
 #kubio .kubio-local-282-container,
 #kubio .kubio-local-368-container{width:80%}
 #kubio .kubio-local-372-container{width:70%}
 #kubio .kubio-local-387-container{width:30%}
 #kubio .kubio-local-395-container{width:70%}
 #kubio .kubio-local-491-container{width:80%}
 #kubio .kubio-local-495-container{width:70%}
 #kubio .kubio-local-515-container{width:30%}
 #kubio .kubio-local-523-container{width:70%}
 #kubio .kubio-local-592-container,
 #kubio .kubio-local-677-container{width:80%}
 .with-kubio-global-style h1,
 [data-kubio] h1,
 h1[data-kubio]{font-size:5em}
 div.h-section-global-spacing{padding-bottom:60px;padding-top:60px}}@media (max-width:767px){
 #kubio .kubio-header__k__jZZ7ZgkWWk-outer .wp-block-kubio-navigation-section__nav{padding-bottom:10px;padding-top:10px}
 #kubio .kubio-header__k__jZZ7ZgkWWk-outer .h-navigation_sticky.wp-block-kubio-navigation-section__nav{background-color:rgba(var(--kubio-color-5),1);padding-bottom:0;padding-top:0}
 #kubio .kubio-header__k__8HsNbkMIffG-outer{text-align:center}
 #kubio .kubio-header__k__pCBjS67tbM7-container{align-items:flex-start;justify-content:flex-start}
 #kubio .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul{justify-content:flex-end}
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer.bordered-active-item>.kubio-menu>ul>li:after,
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer.bordered-active-item>.kubio-menu>ul>li:before{background-color:rgba(var(--kubio-color-5),1)}
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li>a{color:rgba(var(--kubio-color-5),.8)}
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li.current-menu-item>a,
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li.current_page_item>a,
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li>a.hover,
 #kubio .h-navigation_sticky .kubio-header__k__S2itoG6vEiw-outer>.kubio-menu>ul>li>a:hover{color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-header__k__LCYaOhT1Q-f-icon{border-bottom-left-radius:0;border-bottom-right-radius:0;border-top-left-radius:0;border-top-right-radius:0}
 #kubio .kubio-header__k__x8ZMD9qFOX9-container{padding:10px}
 #kubio .kubio-header__k__KFTMhA6WOVh-outer{padding-bottom:60px;padding-top:30px}
 #kubio h1.wp-block.kubio-header__k__SzZXH7PdCL-container,
 #kubio h2.wp-block.kubio-header__k__SzZXH7PdCL-container,
 #kubio h3.wp-block.kubio-header__k__SzZXH7PdCL-container,
 #kubio h4.wp-block.kubio-header__k__SzZXH7PdCL-container,
 #kubio h5.wp-block.kubio-header__k__SzZXH7PdCL-container,
 #kubio h6.wp-block.kubio-header__k__SzZXH7PdCL-container,
 #kubio p.wp-block.kubio-header__k__SzZXH7PdCL-container{font-size:2em;font-weight:400}
 #kubio .kubio-index__k__kxeqsSpdy-n-inner{margin-top:0}
 #kubio .kubio-index__k__tRiQFlrj8q-outer .page-numbers{padding-left:0;padding-right:0}
 #kubio .kubio-index__k__tRiQFlrj8q-outer .page-numbers:not(.current):not(.dots){padding-left:2px;padding-right:2px}
 #kubio .kubio-search__k__kxeqsSpdy-n-inner{margin-top:0}
 #kubio .kubio-search__k__tRiQFlrj8q-outer .page-numbers{padding-left:0;padding-right:0}
 #kubio .kubio-search__k__tRiQFlrj8q-outer .page-numbers:not(.current):not(.dots){padding-left:2px;padding-right:2px}
 #kubio .kubio-search__k__f5wDJx69T0o-inner,
 #kubio .kubio-single__k__single-f5wDJx69T0o-inner{margin-top:30px}
 #kubio .kubio-404-header__k__6mt_9f_jXJ-outer .wp-block-kubio-navigation-section__nav{padding-bottom:10px;padding-top:10px}
 #kubio .kubio-404-header__k__6mt_9f_jXJ-outer .h-navigation_sticky.wp-block-kubio-navigation-section__nav{background-color:rgba(var(--kubio-color-5),1);padding-bottom:0;padding-top:0}
 #kubio .kubio-404-header__k__M_USijtyQ9V-container{align-items:flex-start;justify-content:flex-start}
 #kubio .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul{justify-content:flex-end}
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer.bordered-active-item>.kubio-menu>ul>li:after,
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer.bordered-active-item>.kubio-menu>ul>li:before{background-color:rgba(var(--kubio-color-5),1)}
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li>a{color:rgba(var(--kubio-color-5),.8)}
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li.current-menu-item>a,
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li.current_page_item>a,
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li>a.hover,
 #kubio .h-navigation_sticky .kubio-404-header__k___GipAjLnn8q-outer>.kubio-menu>ul>li>a:hover{color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-404-header__k__J_ZGXBPetlN-icon{border-bottom-left-radius:0;border-bottom-right-radius:0;border-top-left-radius:0;border-top-right-radius:0}
 #kubio .kubio-404-header__k__fOYPUOZaWPL-container{padding:30px}
 #kubio .kubio-front-header__k__Gp3qTlxXlu-outer .wp-block-kubio-navigation-section__nav{padding-bottom:10px;padding-top:10px}
 #kubio .kubio-front-header__k__Gp3qTlxXlu-outer .h-navigation_sticky.wp-block-kubio-navigation-section__nav{background-color:rgba(var(--kubio-color-5),1);padding-bottom:0;padding-top:0}
 #kubio .kubio-front-header__k__wlDkjcCCsVj-outer{text-align:center}
 #kubio .kubio-front-header__k__0xSC3AT64-container{align-items:flex-start;justify-content:flex-start}
 #kubio .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul{justify-content:flex-end}
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer.bordered-active-item>.kubio-menu>ul>li:after,
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer.bordered-active-item>.kubio-menu>ul>li:before{background-color:rgba(var(--kubio-color-5),1)}
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li>a{color:rgba(var(--kubio-color-5),.8)}
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li.current-menu-item>a,
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li.current_page_item>a,
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li>a.hover,
 #kubio .h-navigation_sticky .kubio-front-header__k__c6BbujDIAOY-outer>.kubio-menu>ul>li>a:hover{color:rgba(var(--kubio-color-6),1)}
 #kubio .kubio-front-header__k__r1Ph182_RWJ-icon{border-bottom-left-radius:0;border-bottom-right-radius:0;border-top-left-radius:0;border-top-right-radius:0}
 #kubio .kubio-front-header__k__nVjkPY2tu-container{padding:10px}
 #kubio .kubio-front-header__k__J6FPNZyUrn-outer{min-height:100vh;padding-bottom:30px;padding-top:30px}
 #kubio p.wp-block.wp-block-kubio-text__text.kubio-front-header__k__Xia0GT4t_-text{font-size:16px;line-height:1.5}
 #kubio .kubio-local-4-container,
 #kubio .kubio-local-12-container{width:100%}
 #kubio .kubio-local-21-container{ms-flex:1 1 0%;flex:1 1 0}
 #kubio .kubio-local-23-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-40-container,
 #kubio .kubio-local-48-container{width:100%}
 #kubio .kubio-local-57-container{ms-flex:1 1 0%;flex:1 1 0}
 #kubio .kubio-local-59-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-76-container,
 #kubio .kubio-local-81-container,
 #kubio .kubio-local-87-container,
 #kubio .kubio-local-95-container{width:100%}
 #kubio .kubio-local-104-container{ms-flex:1 1 0%;flex:1 1 0}
 #kubio .kubio-local-106-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-123-container,
 #kubio .kubio-local-131-container{width:100%}
 #kubio .kubio-local-140-container{ms-flex:1 1 0%;flex:1 1 0}
 #kubio .kubio-local-142-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-159-container,
 #kubio .kubio-local-163-container{width:100%}
 #kubio .kubio-local-169-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-172-container{width:100%}
 #kubio .kubio-local-186-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-189-container,
 #kubio .kubio-local-204-container,
 #kubio .kubio-local-210-container,
 #kubio .kubio-local-218-container{width:100%}
 #kubio .kubio-local-227-container{ms-flex:1 1 0%;flex:1 1 0}
 #kubio .kubio-local-229-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-246-container,
 #kubio .kubio-local-254-container{width:100%}
 #kubio .kubio-local-263-container{ms-flex:1 1 0%;flex:1 1 0}
 #kubio .kubio-local-265-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-282-container,
 #kubio .kubio-local-290-container,
 #kubio .kubio-local-296-container,
 #kubio .kubio-local-304-container{width:100%}
 #kubio .kubio-local-313-container{ms-flex:1 1 0%;flex:1 1 0}
 #kubio .kubio-local-315-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-332-container,
 #kubio .kubio-local-340-container{width:100%}
 #kubio .kubio-local-349-container{ms-flex:1 1 0%;flex:1 1 0}
 #kubio .kubio-local-351-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-368-container,
 #kubio .kubio-local-372-container,
 #kubio .kubio-local-375-container,
 #kubio .kubio-local-387-container,
 #kubio .kubio-local-395-container,
 #kubio .kubio-local-398-container,
 #kubio .kubio-local-413-container,
 #kubio .kubio-local-419-container,
 #kubio .kubio-local-427-container{width:100%}
 #kubio .kubio-local-436-container{ms-flex:1 1 0%;flex:1 1 0}
 #kubio .kubio-local-438-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-455-container,
 #kubio .kubio-local-463-container{width:100%}
 #kubio .kubio-local-472-container{ms-flex:1 1 0%;flex:1 1 0}
 #kubio .kubio-local-474-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-491-container,
 #kubio .kubio-local-495-container{width:100%}
 #kubio .kubio-local-509-container,
 #kubio .kubio-local-511-container{flex:0 0 auto;-ms-flex:0 0 auto;width:50%}
 #kubio .kubio-local-515-container,
 #kubio .kubio-local-523-container{width:100%}
 #kubio .kubio-local-537-container,
 #kubio .kubio-local-539-container{flex:0 0 auto;-ms-flex:0 0 auto;width:50%}
 #kubio .kubio-local-546-container{width:100%}
 #kubio .kubio-local-553-container{ms-flex:1 1 0%;flex:1 1 0}
 #kubio .kubio-local-555-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-573-container{ms-flex:1 1 0%;flex:1 1 0}
 #kubio .kubio-local-575-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-592-container,
 #kubio .kubio-local-599-container,
 #kubio .kubio-local-605-container,
 #kubio .kubio-local-613-container{width:100%}
 #kubio .kubio-local-622-container{ms-flex:1 1 0%;flex:1 1 0}
 #kubio .kubio-local-624-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-641-container,
 #kubio .kubio-local-649-container{width:100%}
 #kubio .kubio-local-658-container{ms-flex:1 1 0%;flex:1 1 0}
 #kubio .kubio-local-660-container{flex:0 0 auto;-ms-flex:0 0 auto;width:100%}
 #kubio .kubio-local-677-container,
 #kubio .kubio-local-686-container,
 #kubio .kubio-local-691-container{width:100%}
 body .kubio-front-header__k__9IGHpldIpw-container>*>.h-y-container>:not(:last-child){margin-bottom:20px}
 .with-kubio-global-style h1,
 [data-kubio] h1,
 h1[data-kubio]{font-size:2.5em}
 div.h-section-global-spacing{padding-bottom:30px;padding-top:30px}}
 .wp-block-kubio-iconlist.wp-block{display:inline-flex}
 :focus:focus-visible{outline:auto!important}
 #colibri .h-navigation_outer:not(.h-navigation_overlap) .text-logo{color:#000}
 .wp-block-image.alignfull img{margin-left:unset;margin-right:unset;max-width:100%}
 .wp-block-image .aligncenter{max-width:100%;text-align:center;width:100%}
 .colibri-word-wrap{word-break:break-word}
 ul.colibri-menu>li>a>svg{color:currentColor!important}
 ul.colibri-menu>li>a>svg,
 ul.colibri-menu>li>a>svg path{transition-duration:0s!important}
 .h-blog-meta,
 .h-svg-icon:not(.h-icon__icon),
 .h-svg-icon:not(.h-icon__icon) *,
 .metadata-item{transition-duration:0s}
 .h-blog-meta a{display:inline-table}
 .h-blog-meta-text{display:inline-flex}
 #colibri .style-18>div>.colibri-menu-container>ul.colibri-menu>li>a>.arrow-wrapper,
 #colibri .style-18>div>.colibri-menu-container>ul.colibri-menu>li>a>svg{color:#fff}
 #colibri .style-18>div>.colibri-menu-container>ul.colibri-menu li>ul>li>a{padding-right:54px;white-space:normal}
 #wpadminbar{text-align:initial}
 #wpadminbar:before,
 #wpadminbar :before{box-sizing:content-box;display:block;height:unset;width:unset}
 #wpadminbar .admin-bar-search .ab-item:before,
 #wpadminbar form:before{content:normal}
 #wpadminbar .ab-sub-wrapper ul{display:block}
 .wp-block-kubio-menu-offscreen-content{height:100vh}
 .wp-block-kubio-menu-offscreen__align{display:flex}
 .kubio-offscreen .h-global-transition-all{color:rgb(var(--kubio-color-5),.4)}
 .kubio-offscreen .h-global-transition-all a{color:var(--wp--preset--color--luminous-vivid-orange)}
 .wp-block-kubio-query-loop [class*=h-col-].wp-block-kubio-query-loop-item{padding:15px}@media (max-width:1023px){
 .wp-block-kubio-query-loop [class*=h-col-].wp-block-kubio-query-loop-item{padding:10px}}
